var fnn=Object.defineProperty;var hnn=(l,s,u)=>s in l?fnn(l,s,{enumerable:!0,configurable:!0,writable:!0,value:u}):l[s]=u;var oEe=(l,s,u)=>hnn(l,typeof s!="symbol"?s+"":s,u);(function(){const s=document.createElement("link").relList;if(s&&s.supports&&s.supports("modulepreload"))return;for(const g of document.querySelectorAll('link[rel="modulepreload"]'))h(g);new MutationObserver(g=>{for(const w of g)if(w.type==="childList")for(const p of w.addedNodes)p.tagName==="LINK"&&p.rel==="modulepreload"&&h(p)}).observe(document,{childList:!0,subtree:!0});function u(g){const w={};return g.integrity&&(w.integrity=g.integrity),g.referrerPolicy&&(w.referrerPolicy=g.referrerPolicy),g.crossOrigin==="use-credentials"?w.credentials="include":g.crossOrigin==="anonymous"?w.credentials="omit":w.credentials="same-origin",w}function h(g){if(g.ep)return;g.ep=!0;const w=u(g);fetch(g.href,w)}})();var Pvt=typeof globalThis<"u"?globalThis:typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{};function xMe(l){return l&&l.__esModule&&Object.prototype.hasOwnProperty.call(l,"default")?l.default:l}var cEe={exports:{}},bX={};/**
 * @license React
 * react-jsx-runtime.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Ivt;function dnn(){if(Ivt)return bX;Ivt=1;var l=Symbol.for("react.transitional.element"),s=Symbol.for("react.fragment");function u(h,g,w){var p=null;if(w!==void 0&&(p=""+w),g.key!==void 0&&(p=""+g.key),"key"in g){w={};for(var k in g)k!=="key"&&(w[k]=g[k])}else w=g;return g=w.ref,{$$typeof:l,type:h,key:p,ref:g!==void 0?g:null,props:w}}return bX.Fragment=s,bX.jsx=u,bX.jsxs=u,bX}var Rvt;function gnn(){return Rvt||(Rvt=1,cEe.exports=dnn()),cEe.exports}var E=gnn(),lEe={exports:{}},zs={};/**
 * @license React
 * react.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var $vt;function pnn(){if($vt)return zs;$vt=1;var l=Symbol.for("react.transitional.element"),s=Symbol.for("react.portal"),u=Symbol.for("react.fragment"),h=Symbol.for("react.strict_mode"),g=Symbol.for("react.profiler"),w=Symbol.for("react.consumer"),p=Symbol.for("react.context"),k=Symbol.for("react.forward_ref"),j=Symbol.for("react.suspense"),A=Symbol.for("react.memo"),_=Symbol.for("react.lazy"),D=Symbol.for("react.activity"),I=Symbol.iterator;function B(Ae){return Ae===null||typeof Ae!="object"?null:(Ae=I&&Ae[I]||Ae["@@iterator"],typeof Ae=="function"?Ae:null)}var F={isMounted:function(){return!1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},U=Object.assign,K={};function Y(Ae,Ye,mt){this.props=Ae,this.context=Ye,this.refs=K,this.updater=mt||F}Y.prototype.isReactComponent={},Y.prototype.setState=function(Ae,Ye){if(typeof Ae!="object"&&typeof Ae!="function"&&Ae!=null)throw Error("takes an object of state variables to update or a function which returns an object of state variables.");this.updater.enqueueSetState(this,Ae,Ye,"setState")},Y.prototype.forceUpdate=function(Ae){this.updater.enqueueForceUpdate(this,Ae,"forceUpdate")};function Z(){}Z.prototype=Y.prototype;function ee(Ae,Ye,mt){this.props=Ae,this.context=Ye,this.refs=K,this.updater=mt||F}var ce=ee.prototype=new Z;ce.constructor=ee,U(ce,Y.prototype),ce.isPureReactComponent=!0;var fe=Array.isArray;function be(){}var me={H:null,A:null,T:null,S:null},Re=Object.prototype.hasOwnProperty;function Te(Ae,Ye,mt){var Ue=mt.ref;return{$$typeof:l,type:Ae,key:Ye,ref:Ue!==void 0?Ue:null,props:mt}}function Ke(Ae,Ye){return Te(Ae.type,Ye,Ae.props)}function ze(Ae){return typeof Ae=="object"&&Ae!==null&&Ae.$$typeof===l}function je(Ae){var Ye={"=":"=0",":":"=2"};return"$"+Ae.replace(/[=:]/g,function(mt){return Ye[mt]})}var te=/\/+/g;function ge(Ae,Ye){return typeof Ae=="object"&&Ae!==null&&Ae.key!=null?je(""+Ae.key):Ye.toString(36)}function He(Ae){switch(Ae.status){case"fulfilled":return Ae.value;case"rejected":throw Ae.reason;default:switch(typeof Ae.status=="string"?Ae.then(be,be):(Ae.status="pending",Ae.then(function(Ye){Ae.status==="pending"&&(Ae.status="fulfilled",Ae.value=Ye)},function(Ye){Ae.status==="pending"&&(Ae.status="rejected",Ae.reason=Ye)})),Ae.status){case"fulfilled":return Ae.value;case"rejected":throw Ae.reason}}throw Ae}function ae(Ae,Ye,mt,Ue,Pt){var rn=typeof Ae;(rn==="undefined"||rn==="boolean")&&(Ae=null);var Cn=!1;if(Ae===null)Cn=!0;else switch(rn){case"bigint":case"string":case"number":Cn=!0;break;case"object":switch(Ae.$$typeof){case l:case s:Cn=!0;break;case _:return Cn=Ae._init,ae(Cn(Ae._payload),Ye,mt,Ue,Pt)}}if(Cn)return Pt=Pt(Ae),Cn=Ue===""?"."+ge(Ae,0):Ue,fe(Pt)?(mt="",Cn!=null&&(mt=Cn.replace(te,"$&/")+"/"),ae(Pt,Ye,mt,"",function(er){return er})):Pt!=null&&(ze(Pt)&&(Pt=Ke(Pt,mt+(Pt.key==null||Ae&&Ae.key===Pt.key?"":(""+Pt.key).replace(te,"$&/")+"/")+Cn)),Ye.push(Pt)),1;Cn=0;var Pn=Ue===""?".":Ue+":";if(fe(Ae))for(var mi=0;mi<Ae.length;mi++)Ue=Ae[mi],rn=Pn+ge(Ue,mi),Cn+=ae(Ue,Ye,mt,rn,Pt);else if(mi=B(Ae),typeof mi=="function")for(Ae=mi.call(Ae),mi=0;!(Ue=Ae.next()).done;)Ue=Ue.value,rn=Pn+ge(Ue,mi++),Cn+=ae(Ue,Ye,mt,rn,Pt);else if(rn==="object"){if(typeof Ae.then=="function")return ae(He(Ae),Ye,mt,Ue,Pt);throw Ye=String(Ae),Error("Objects are not valid as a React child (found: "+(Ye==="[object Object]"?"object with keys {"+Object.keys(Ae).join(", ")+"}":Ye)+"). If you meant to render a collection of children, use an array instead.")}return Cn}function Le(Ae,Ye,mt){if(Ae==null)return Ae;var Ue=[],Pt=0;return ae(Ae,Ue,"","",function(rn){return Ye.call(mt,rn,Pt++)}),Ue}function Oe(Ae){if(Ae._status===-1){var Ye=Ae._result;Ye=Ye(),Ye.then(function(mt){(Ae._status===0||Ae._status===-1)&&(Ae._status=1,Ae._result=mt)},function(mt){(Ae._status===0||Ae._status===-1)&&(Ae._status=2,Ae._result=mt)}),Ae._status===-1&&(Ae._status=0,Ae._result=Ye)}if(Ae._status===1)return Ae._result.default;throw Ae._result}var Qe=typeof reportError=="function"?reportError:function(Ae){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var Ye=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof Ae=="object"&&Ae!==null&&typeof Ae.message=="string"?String(Ae.message):String(Ae),error:Ae});if(!window.dispatchEvent(Ye))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",Ae);return}console.error(Ae)},kt={map:Le,forEach:function(Ae,Ye,mt){Le(Ae,function(){Ye.apply(this,arguments)},mt)},count:function(Ae){var Ye=0;return Le(Ae,function(){Ye++}),Ye},toArray:function(Ae){return Le(Ae,function(Ye){return Ye})||[]},only:function(Ae){if(!ze(Ae))throw Error("React.Children.only expected to receive a single React element child.");return Ae}};return zs.Activity=D,zs.Children=kt,zs.Component=Y,zs.Fragment=u,zs.Profiler=g,zs.PureComponent=ee,zs.StrictMode=h,zs.Suspense=j,zs.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=me,zs.__COMPILER_RUNTIME={__proto__:null,c:function(Ae){return me.H.useMemoCache(Ae)}},zs.cache=function(Ae){return function(){return Ae.apply(null,arguments)}},zs.cacheSignal=function(){return null},zs.cloneElement=function(Ae,Ye,mt){if(Ae==null)throw Error("The argument must be a React element, but you passed "+Ae+".");var Ue=U({},Ae.props),Pt=Ae.key;if(Ye!=null)for(rn in Ye.key!==void 0&&(Pt=""+Ye.key),Ye)!Re.call(Ye,rn)||rn==="key"||rn==="__self"||rn==="__source"||rn==="ref"&&Ye.ref===void 0||(Ue[rn]=Ye[rn]);var rn=arguments.length-2;if(rn===1)Ue.children=mt;else if(1<rn){for(var Cn=Array(rn),Pn=0;Pn<rn;Pn++)Cn[Pn]=arguments[Pn+2];Ue.children=Cn}return Te(Ae.type,Pt,Ue)},zs.createContext=function(Ae){return Ae={$$typeof:p,_currentValue:Ae,_currentValue2:Ae,_threadCount:0,Provider:null,Consumer:null},Ae.Provider=Ae,Ae.Consumer={$$typeof:w,_context:Ae},Ae},zs.createElement=function(Ae,Ye,mt){var Ue,Pt={},rn=null;if(Ye!=null)for(Ue in Ye.key!==void 0&&(rn=""+Ye.key),Ye)Re.call(Ye,Ue)&&Ue!=="key"&&Ue!=="__self"&&Ue!=="__source"&&(Pt[Ue]=Ye[Ue]);var Cn=arguments.length-2;if(Cn===1)Pt.children=mt;else if(1<Cn){for(var Pn=Array(Cn),mi=0;mi<Cn;mi++)Pn[mi]=arguments[mi+2];Pt.children=Pn}if(Ae&&Ae.defaultProps)for(Ue in Cn=Ae.defaultProps,Cn)Pt[Ue]===void 0&&(Pt[Ue]=Cn[Ue]);return Te(Ae,rn,Pt)},zs.createRef=function(){return{current:null}},zs.forwardRef=function(Ae){return{$$typeof:k,render:Ae}},zs.isValidElement=ze,zs.lazy=function(Ae){return{$$typeof:_,_payload:{_status:-1,_result:Ae},_init:Oe}},zs.memo=function(Ae,Ye){return{$$typeof:A,type:Ae,compare:Ye===void 0?null:Ye}},zs.startTransition=function(Ae){var Ye=me.T,mt={};me.T=mt;try{var Ue=Ae(),Pt=me.S;Pt!==null&&Pt(mt,Ue),typeof Ue=="object"&&Ue!==null&&typeof Ue.then=="function"&&Ue.then(be,Qe)}catch(rn){Qe(rn)}finally{Ye!==null&&mt.types!==null&&(Ye.types=mt.types),me.T=Ye}},zs.unstable_useCacheRefresh=function(){return me.H.useCacheRefresh()},zs.use=function(Ae){return me.H.use(Ae)},zs.useActionState=function(Ae,Ye,mt){return me.H.useActionState(Ae,Ye,mt)},zs.useCallback=function(Ae,Ye){return me.H.useCallback(Ae,Ye)},zs.useContext=function(Ae){return me.H.useContext(Ae)},zs.useDebugValue=function(){},zs.useDeferredValue=function(Ae,Ye){return me.H.useDeferredValue(Ae,Ye)},zs.useEffect=function(Ae,Ye){return me.H.useEffect(Ae,Ye)},zs.useEffectEvent=function(Ae){return me.H.useEffectEvent(Ae)},zs.useId=function(){return me.H.useId()},zs.useImperativeHandle=function(Ae,Ye,mt){return me.H.useImperativeHandle(Ae,Ye,mt)},zs.useInsertionEffect=function(Ae,Ye){return me.H.useInsertionEffect(Ae,Ye)},zs.useLayoutEffect=function(Ae,Ye){return me.H.useLayoutEffect(Ae,Ye)},zs.useMemo=function(Ae,Ye){return me.H.useMemo(Ae,Ye)},zs.useOptimistic=function(Ae,Ye){return me.H.useOptimistic(Ae,Ye)},zs.useReducer=function(Ae,Ye,mt){return me.H.useReducer(Ae,Ye,mt)},zs.useRef=function(Ae){return me.H.useRef(Ae)},zs.useState=function(Ae){return me.H.useState(Ae)},zs.useSyncExternalStore=function(Ae,Ye,mt){return me.H.useSyncExternalStore(Ae,Ye,mt)},zs.useTransition=function(){return me.H.useTransition()},zs.version="19.2.4",zs}var Bvt;function wV(){return Bvt||(Bvt=1,lEe.exports=pnn()),lEe.exports}var pe=wV();const CX=xMe(pe);var uEe={exports:{}},mX={},aEe={exports:{}},fEe={};/**
 * @license React
 * scheduler.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var zvt;function bnn(){return zvt||(zvt=1,(function(l){function s(ae,Le){var Oe=ae.length;ae.push(Le);e:for(;0<Oe;){var Qe=Oe-1>>>1,kt=ae[Qe];if(0<g(kt,Le))ae[Qe]=Le,ae[Oe]=kt,Oe=Qe;else break e}}function u(ae){return ae.length===0?null:ae[0]}function h(ae){if(ae.length===0)return null;var Le=ae[0],Oe=ae.pop();if(Oe!==Le){ae[0]=Oe;e:for(var Qe=0,kt=ae.length,Ae=kt>>>1;Qe<Ae;){var Ye=2*(Qe+1)-1,mt=ae[Ye],Ue=Ye+1,Pt=ae[Ue];if(0>g(mt,Oe))Ue<kt&&0>g(Pt,mt)?(ae[Qe]=Pt,ae[Ue]=Oe,Qe=Ue):(ae[Qe]=mt,ae[Ye]=Oe,Qe=Ye);else if(Ue<kt&&0>g(Pt,Oe))ae[Qe]=Pt,ae[Ue]=Oe,Qe=Ue;else break e}}return Le}function g(ae,Le){var Oe=ae.sortIndex-Le.sortIndex;return Oe!==0?Oe:ae.id-Le.id}if(l.unstable_now=void 0,typeof performance=="object"&&typeof performance.now=="function"){var w=performance;l.unstable_now=function(){return w.now()}}else{var p=Date,k=p.now();l.unstable_now=function(){return p.now()-k}}var j=[],A=[],_=1,D=null,I=3,B=!1,F=!1,U=!1,K=!1,Y=typeof setTimeout=="function"?setTimeout:null,Z=typeof clearTimeout=="function"?clearTimeout:null,ee=typeof setImmediate<"u"?setImmediate:null;function ce(ae){for(var Le=u(A);Le!==null;){if(Le.callback===null)h(A);else if(Le.startTime<=ae)h(A),Le.sortIndex=Le.expirationTime,s(j,Le);else break;Le=u(A)}}function fe(ae){if(U=!1,ce(ae),!F)if(u(j)!==null)F=!0,be||(be=!0,je());else{var Le=u(A);Le!==null&&He(fe,Le.startTime-ae)}}var be=!1,me=-1,Re=5,Te=-1;function Ke(){return K?!0:!(l.unstable_now()-Te<Re)}function ze(){if(K=!1,be){var ae=l.unstable_now();Te=ae;var Le=!0;try{e:{F=!1,U&&(U=!1,Z(me),me=-1),B=!0;var Oe=I;try{t:{for(ce(ae),D=u(j);D!==null&&!(D.expirationTime>ae&&Ke());){var Qe=D.callback;if(typeof Qe=="function"){D.callback=null,I=D.priorityLevel;var kt=Qe(D.expirationTime<=ae);if(ae=l.unstable_now(),typeof kt=="function"){D.callback=kt,ce(ae),Le=!0;break t}D===u(j)&&h(j),ce(ae)}else h(j);D=u(j)}if(D!==null)Le=!0;else{var Ae=u(A);Ae!==null&&He(fe,Ae.startTime-ae),Le=!1}}break e}finally{D=null,I=Oe,B=!1}Le=void 0}}finally{Le?je():be=!1}}}var je;if(typeof ee=="function")je=function(){ee(ze)};else if(typeof MessageChannel<"u"){var te=new MessageChannel,ge=te.port2;te.port1.onmessage=ze,je=function(){ge.postMessage(null)}}else je=function(){Y(ze,0)};function He(ae,Le){me=Y(function(){ae(l.unstable_now())},Le)}l.unstable_IdlePriority=5,l.unstable_ImmediatePriority=1,l.unstable_LowPriority=4,l.unstable_NormalPriority=3,l.unstable_Profiling=null,l.unstable_UserBlockingPriority=2,l.unstable_cancelCallback=function(ae){ae.callback=null},l.unstable_forceFrameRate=function(ae){0>ae||125<ae?console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported"):Re=0<ae?Math.floor(1e3/ae):5},l.unstable_getCurrentPriorityLevel=function(){return I},l.unstable_next=function(ae){switch(I){case 1:case 2:case 3:var Le=3;break;default:Le=I}var Oe=I;I=Le;try{return ae()}finally{I=Oe}},l.unstable_requestPaint=function(){K=!0},l.unstable_runWithPriority=function(ae,Le){switch(ae){case 1:case 2:case 3:case 4:case 5:break;default:ae=3}var Oe=I;I=ae;try{return Le()}finally{I=Oe}},l.unstable_scheduleCallback=function(ae,Le,Oe){var Qe=l.unstable_now();switch(typeof Oe=="object"&&Oe!==null?(Oe=Oe.delay,Oe=typeof Oe=="number"&&0<Oe?Qe+Oe:Qe):Oe=Qe,ae){case 1:var kt=-1;break;case 2:kt=250;break;case 5:kt=1073741823;break;case 4:kt=1e4;break;default:kt=5e3}return kt=Oe+kt,ae={id:_++,callback:Le,priorityLevel:ae,startTime:Oe,expirationTime:kt,sortIndex:-1},Oe>Qe?(ae.sortIndex=Oe,s(A,ae),u(j)===null&&ae===u(A)&&(U?(Z(me),me=-1):U=!0,He(fe,Oe-Qe))):(ae.sortIndex=kt,s(j,ae),F||B||(F=!0,be||(be=!0,je()))),ae},l.unstable_shouldYield=Ke,l.unstable_wrapCallback=function(ae){var Le=I;return function(){var Oe=I;I=Le;try{return ae.apply(this,arguments)}finally{I=Oe}}}})(fEe)),fEe}var Fvt;function mnn(){return Fvt||(Fvt=1,aEe.exports=bnn()),aEe.exports}var hEe={exports:{}},sg={};/**
 * @license React
 * react-dom.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var qvt;function wnn(){if(qvt)return sg;qvt=1;var l=wV();function s(j){var A="https://react.dev/errors/"+j;if(1<arguments.length){A+="?args[]="+encodeURIComponent(arguments[1]);for(var _=2;_<arguments.length;_++)A+="&args[]="+encodeURIComponent(arguments[_])}return"Minified React error #"+j+"; visit "+A+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function u(){}var h={d:{f:u,r:function(){throw Error(s(522))},D:u,C:u,L:u,m:u,X:u,S:u,M:u},p:0,findDOMNode:null},g=Symbol.for("react.portal");function w(j,A,_){var D=3<arguments.length&&arguments[3]!==void 0?arguments[3]:null;return{$$typeof:g,key:D==null?null:""+D,children:j,containerInfo:A,implementation:_}}var p=l.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE;function k(j,A){if(j==="font")return"";if(typeof A=="string")return A==="use-credentials"?A:""}return sg.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=h,sg.createPortal=function(j,A){var _=2<arguments.length&&arguments[2]!==void 0?arguments[2]:null;if(!A||A.nodeType!==1&&A.nodeType!==9&&A.nodeType!==11)throw Error(s(299));return w(j,A,null,_)},sg.flushSync=function(j){var A=p.T,_=h.p;try{if(p.T=null,h.p=2,j)return j()}finally{p.T=A,h.p=_,h.d.f()}},sg.preconnect=function(j,A){typeof j=="string"&&(A?(A=A.crossOrigin,A=typeof A=="string"?A==="use-credentials"?A:"":void 0):A=null,h.d.C(j,A))},sg.prefetchDNS=function(j){typeof j=="string"&&h.d.D(j)},sg.preinit=function(j,A){if(typeof j=="string"&&A&&typeof A.as=="string"){var _=A.as,D=k(_,A.crossOrigin),I=typeof A.integrity=="string"?A.integrity:void 0,B=typeof A.fetchPriority=="string"?A.fetchPriority:void 0;_==="style"?h.d.S(j,typeof A.precedence=="string"?A.precedence:void 0,{crossOrigin:D,integrity:I,fetchPriority:B}):_==="script"&&h.d.X(j,{crossOrigin:D,integrity:I,fetchPriority:B,nonce:typeof A.nonce=="string"?A.nonce:void 0})}},sg.preinitModule=function(j,A){if(typeof j=="string")if(typeof A=="object"&&A!==null){if(A.as==null||A.as==="script"){var _=k(A.as,A.crossOrigin);h.d.M(j,{crossOrigin:_,integrity:typeof A.integrity=="string"?A.integrity:void 0,nonce:typeof A.nonce=="string"?A.nonce:void 0})}}else A==null&&h.d.M(j)},sg.preload=function(j,A){if(typeof j=="string"&&typeof A=="object"&&A!==null&&typeof A.as=="string"){var _=A.as,D=k(_,A.crossOrigin);h.d.L(j,_,{crossOrigin:D,integrity:typeof A.integrity=="string"?A.integrity:void 0,nonce:typeof A.nonce=="string"?A.nonce:void 0,type:typeof A.type=="string"?A.type:void 0,fetchPriority:typeof A.fetchPriority=="string"?A.fetchPriority:void 0,referrerPolicy:typeof A.referrerPolicy=="string"?A.referrerPolicy:void 0,imageSrcSet:typeof A.imageSrcSet=="string"?A.imageSrcSet:void 0,imageSizes:typeof A.imageSizes=="string"?A.imageSizes:void 0,media:typeof A.media=="string"?A.media:void 0})}},sg.preloadModule=function(j,A){if(typeof j=="string")if(A){var _=k(A.as,A.crossOrigin);h.d.m(j,{as:typeof A.as=="string"&&A.as!=="script"?A.as:void 0,crossOrigin:_,integrity:typeof A.integrity=="string"?A.integrity:void 0})}else h.d.m(j)},sg.requestFormReset=function(j){h.d.r(j)},sg.unstable_batchedUpdates=function(j,A){return j(A)},sg.useFormState=function(j,A,_){return p.H.useFormState(j,A,_)},sg.useFormStatus=function(){return p.H.useHostTransitionStatus()},sg.version="19.2.4",sg}var Hvt;function l4t(){if(Hvt)return hEe.exports;Hvt=1;function l(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(l)}catch(s){console.error(s)}}return l(),hEe.exports=wnn(),hEe.exports}/**
 * @license React
 * react-dom-client.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Qvt;function vnn(){if(Qvt)return mX;Qvt=1;var l=mnn(),s=wV(),u=l4t();function h(m){var y="https://react.dev/errors/"+m;if(1<arguments.length){y+="?args[]="+encodeURIComponent(arguments[1]);for(var O=2;O<arguments.length;O++)y+="&args[]="+encodeURIComponent(arguments[O])}return"Minified React error #"+m+"; visit "+y+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function g(m){return!(!m||m.nodeType!==1&&m.nodeType!==9&&m.nodeType!==11)}function w(m){var y=m,O=m;if(m.alternate)for(;y.return;)y=y.return;else{m=y;do y=m,(y.flags&4098)!==0&&(O=y.return),m=y.return;while(m)}return y.tag===3?O:null}function p(m){if(m.tag===13){var y=m.memoizedState;if(y===null&&(m=m.alternate,m!==null&&(y=m.memoizedState)),y!==null)return y.dehydrated}return null}function k(m){if(m.tag===31){var y=m.memoizedState;if(y===null&&(m=m.alternate,m!==null&&(y=m.memoizedState)),y!==null)return y.dehydrated}return null}function j(m){if(w(m)!==m)throw Error(h(188))}function A(m){var y=m.alternate;if(!y){if(y=w(m),y===null)throw Error(h(188));return y!==m?null:m}for(var O=m,N=y;;){var $=O.return;if($===null)break;var q=$.alternate;if(q===null){if(N=$.return,N!==null){O=N;continue}break}if($.child===q.child){for(q=$.child;q;){if(q===O)return j($),m;if(q===N)return j($),y;q=q.sibling}throw Error(h(188))}if(O.return!==N.return)O=$,N=q;else{for(var le=!1,Ce=$.child;Ce;){if(Ce===O){le=!0,O=$,N=q;break}if(Ce===N){le=!0,N=$,O=q;break}Ce=Ce.sibling}if(!le){for(Ce=q.child;Ce;){if(Ce===O){le=!0,O=q,N=$;break}if(Ce===N){le=!0,N=q,O=$;break}Ce=Ce.sibling}if(!le)throw Error(h(189))}}if(O.alternate!==N)throw Error(h(190))}if(O.tag!==3)throw Error(h(188));return O.stateNode.current===O?m:y}function _(m){var y=m.tag;if(y===5||y===26||y===27||y===6)return m;for(m=m.child;m!==null;){if(y=_(m),y!==null)return y;m=m.sibling}return null}var D=Object.assign,I=Symbol.for("react.element"),B=Symbol.for("react.transitional.element"),F=Symbol.for("react.portal"),U=Symbol.for("react.fragment"),K=Symbol.for("react.strict_mode"),Y=Symbol.for("react.profiler"),Z=Symbol.for("react.consumer"),ee=Symbol.for("react.context"),ce=Symbol.for("react.forward_ref"),fe=Symbol.for("react.suspense"),be=Symbol.for("react.suspense_list"),me=Symbol.for("react.memo"),Re=Symbol.for("react.lazy"),Te=Symbol.for("react.activity"),Ke=Symbol.for("react.memo_cache_sentinel"),ze=Symbol.iterator;function je(m){return m===null||typeof m!="object"?null:(m=ze&&m[ze]||m["@@iterator"],typeof m=="function"?m:null)}var te=Symbol.for("react.client.reference");function ge(m){if(m==null)return null;if(typeof m=="function")return m.$$typeof===te?null:m.displayName||m.name||null;if(typeof m=="string")return m;switch(m){case U:return"Fragment";case Y:return"Profiler";case K:return"StrictMode";case fe:return"Suspense";case be:return"SuspenseList";case Te:return"Activity"}if(typeof m=="object")switch(m.$$typeof){case F:return"Portal";case ee:return m.displayName||"Context";case Z:return(m._context.displayName||"Context")+".Consumer";case ce:var y=m.render;return m=m.displayName,m||(m=y.displayName||y.name||"",m=m!==""?"ForwardRef("+m+")":"ForwardRef"),m;case me:return y=m.displayName||null,y!==null?y:ge(m.type)||"Memo";case Re:y=m._payload,m=m._init;try{return ge(m(y))}catch{}}return null}var He=Array.isArray,ae=s.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,Le=u.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,Oe={pending:!1,data:null,method:null,action:null},Qe=[],kt=-1;function Ae(m){return{current:m}}function Ye(m){0>kt||(m.current=Qe[kt],Qe[kt]=null,kt--)}function mt(m,y){kt++,Qe[kt]=m.current,m.current=y}var Ue=Ae(null),Pt=Ae(null),rn=Ae(null),Cn=Ae(null);function Pn(m,y){switch(mt(rn,y),mt(Pt,m),mt(Ue,null),y.nodeType){case 9:case 11:m=(m=y.documentElement)&&(m=m.namespaceURI)?zB(m):0;break;default:if(m=y.tagName,y=y.namespaceURI)y=zB(y),m=FB(y,m);else switch(m){case"svg":m=1;break;case"math":m=2;break;default:m=0}}Ye(Ue),mt(Ue,m)}function mi(){Ye(Ue),Ye(Pt),Ye(rn)}function er(m){m.memoizedState!==null&&mt(Cn,m);var y=Ue.current,O=FB(y,m.type);y!==O&&(mt(Pt,m),mt(Ue,O))}function Mr(m){Pt.current===m&&(Ye(Ue),Ye(Pt)),Cn.current===m&&(Ye(Cn),o6._currentValue=Oe)}var hr,Gn;function Ir(m){if(hr===void 0)try{throw Error()}catch(O){var y=O.stack.trim().match(/\n( *(at )?)/);hr=y&&y[1]||"",Gn=-1<O.stack.indexOf(`
    at`)?" (<anonymous>)":-1<O.stack.indexOf("@")?"@unknown:0:0":""}return`
`+hr+m+Gn}var is=!1;function bs(m,y){if(!m||is)return"";is=!0;var O=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{var N={DetermineComponentFrameRoot:function(){try{if(y){var xn=function(){throw Error()};if(Object.defineProperty(xn.prototype,"props",{set:function(){throw Error()}}),typeof Reflect=="object"&&Reflect.construct){try{Reflect.construct(xn,[])}catch(on){var Zt=on}Reflect.construct(m,[],xn)}else{try{xn.call()}catch(on){Zt=on}m.call(xn.prototype)}}else{try{throw Error()}catch(on){Zt=on}(xn=m())&&typeof xn.catch=="function"&&xn.catch(function(){})}}catch(on){if(on&&Zt&&typeof on.stack=="string")return[on.stack,Zt.stack]}return[null,null]}};N.DetermineComponentFrameRoot.displayName="DetermineComponentFrameRoot";var $=Object.getOwnPropertyDescriptor(N.DetermineComponentFrameRoot,"name");$&&$.configurable&&Object.defineProperty(N.DetermineComponentFrameRoot,"name",{value:"DetermineComponentFrameRoot"});var q=N.DetermineComponentFrameRoot(),le=q[0],Ce=q[1];if(le&&Ce){var dt=le.split(`
`),Ft=Ce.split(`
`);for($=N=0;N<dt.length&&!dt[N].includes("DetermineComponentFrameRoot");)N++;for(;$<Ft.length&&!Ft[$].includes("DetermineComponentFrameRoot");)$++;if(N===dt.length||$===Ft.length)for(N=dt.length-1,$=Ft.length-1;1<=N&&0<=$&&dt[N]!==Ft[$];)$--;for(;1<=N&&0<=$;N--,$--)if(dt[N]!==Ft[$]){if(N!==1||$!==1)do if(N--,$--,0>$||dt[N]!==Ft[$]){var gn=`
`+dt[N].replace(" at new "," at ");return m.displayName&&gn.includes("<anonymous>")&&(gn=gn.replace("<anonymous>",m.displayName)),gn}while(1<=N&&0<=$);break}}}finally{is=!1,Error.prepareStackTrace=O}return(O=m?m.displayName||m.name:"")?Ir(O):""}function bo(m,y){switch(m.tag){case 26:case 27:case 5:return Ir(m.type);case 16:return Ir("Lazy");case 13:return m.child!==y&&y!==null?Ir("Suspense Fallback"):Ir("Suspense");case 19:return Ir("SuspenseList");case 0:case 15:return bs(m.type,!1);case 11:return bs(m.type.render,!1);case 1:return bs(m.type,!0);case 31:return Ir("Activity");default:return""}}function Bl(m){try{var y="",O=null;do y+=bo(m,O),O=m,m=m.return;while(m);return y}catch(N){return`
Error generating stack: `+N.message+`
`+N.stack}}var Zl=Object.prototype.hasOwnProperty,rs=l.unstable_scheduleCallback,Ls=l.unstable_cancelCallback,f1=l.unstable_shouldYield,mo=l.unstable_requestPaint,eu=l.unstable_now,Un=l.unstable_getCurrentPriorityLevel,Rc=l.unstable_ImmediatePriority,io=l.unstable_UserBlockingPriority,zf=l.unstable_NormalPriority,tu=l.unstable_LowPriority,Kw=l.unstable_IdlePriority,uO=l.log,aO=l.unstable_setDisableYieldValue,Cp=null,Ff=null;function lg(m){if(typeof uO=="function"&&aO(m),Ff&&typeof Ff.setStrictMode=="function")try{Ff.setStrictMode(Cp,m)}catch{}}var qf=Math.clz32?Math.clz32:dO,fO=Math.log,hO=Math.LN2;function dO(m){return m>>>=0,m===0?32:31-(fO(m)/hO|0)|0}var Yw=256,Zw=262144,e2=4194304;function f0(m){var y=m&42;if(y!==0)return y;switch(m&-m){case 1:return 1;case 2:return 2;case 4:return 4;case 8:return 8;case 16:return 16;case 32:return 32;case 64:return 64;case 128:return 128;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:return m&261888;case 262144:case 524288:case 1048576:case 2097152:return m&3932160;case 4194304:case 8388608:case 16777216:case 33554432:return m&62914560;case 67108864:return 67108864;case 134217728:return 134217728;case 268435456:return 268435456;case 536870912:return 536870912;case 1073741824:return 0;default:return m}}function t2(m,y,O){var N=m.pendingLanes;if(N===0)return 0;var $=0,q=m.suspendedLanes,le=m.pingedLanes;m=m.warmLanes;var Ce=N&134217727;return Ce!==0?(N=Ce&~q,N!==0?$=f0(N):(le&=Ce,le!==0?$=f0(le):O||(O=Ce&~m,O!==0&&($=f0(O))))):(Ce=N&~q,Ce!==0?$=f0(Ce):le!==0?$=f0(le):O||(O=N&~m,O!==0&&($=f0(O)))),$===0?0:y!==0&&y!==$&&(y&q)===0&&(q=$&-$,O=y&-y,q>=O||q===32&&(O&4194048)!==0)?y:$}function im(m,y){return(m.pendingLanes&~(m.suspendedLanes&~m.pingedLanes)&y)===0}function gO(m,y){switch(m){case 1:case 2:case 4:case 8:case 64:return y+250;case 16:case 32:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return y+5e3;case 4194304:case 8388608:case 16777216:case 33554432:return-1;case 67108864:case 134217728:case 268435456:case 536870912:case 1073741824:return-1;default:return-1}}function _y(){var m=e2;return e2<<=1,(e2&62914560)===0&&(e2=4194304),m}function Ti(m){for(var y=[],O=0;31>O;O++)y.push(m);return y}function gu(m,y){m.pendingLanes|=y,y!==268435456&&(m.suspendedLanes=0,m.pingedLanes=0,m.warmLanes=0)}function gh(m,y,O,N,$,q){var le=m.pendingLanes;m.pendingLanes=O,m.suspendedLanes=0,m.pingedLanes=0,m.warmLanes=0,m.expiredLanes&=O,m.entangledLanes&=O,m.errorRecoveryDisabledLanes&=O,m.shellSuspendCounter=0;var Ce=m.entanglements,dt=m.expirationTimes,Ft=m.hiddenUpdates;for(O=le&~O;0<O;){var gn=31-qf(O),xn=1<<gn;Ce[gn]=0,dt[gn]=-1;var Zt=Ft[gn];if(Zt!==null)for(Ft[gn]=null,gn=0;gn<Zt.length;gn++){var on=Zt[gn];on!==null&&(on.lane&=-536870913)}O&=~xn}N!==0&&h0(m,N,0),q!==0&&$===0&&m.tag!==0&&(m.suspendedLanes|=q&~(le&~y))}function h0(m,y,O){m.pendingLanes|=y,m.suspendedLanes&=~y;var N=31-qf(y);m.entangledLanes|=y,m.entanglements[N]=m.entanglements[N]|1073741824|O&261930}function pO(m,y){var O=m.entangledLanes|=y;for(m=m.entanglements;O;){var N=31-qf(O),$=1<<N;$&y|m[N]&y&&(m[N]|=y),O&=~$}}function M8(m,y){var O=y&-y;return O=(O&42)!==0?1:Dy(O),(O&(m.suspendedLanes|y))!==0?0:O}function Dy(m){switch(m){case 2:m=1;break;case 8:m=4;break;case 32:m=16;break;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:case 4194304:case 8388608:case 16777216:case 33554432:m=128;break;case 268435456:m=134217728;break;default:m=0}return m}function bO(m){return m&=-m,2<m?8<m?(m&134217727)!==0?32:268435456:8:2}function A8(){var m=Le.p;return m!==0?m:(m=window.event,m===void 0?32:CK(m.type))}function mO(m,y){var O=Le.p;try{return Le.p=m,y()}finally{Le.p=O}}var Mp=Math.random().toString(36).slice(2),Pa="__reactFiber$"+Mp,ph="__reactProps$"+Mp,rm="__reactContainer$"+Mp,e4="__reactEvents$"+Mp,N8="__reactListeners$"+Mp,MM="__reactHandles$"+Mp,_8="__reactResources$"+Mp,Ly="__reactMarker$"+Mp;function wO(m){delete m[Pa],delete m[ph],delete m[e4],delete m[N8],delete m[MM]}function Ap(m){var y=m[Pa];if(y)return y;for(var O=m.parentNode;O;){if(y=O[rm]||O[Pa]){if(O=y.alternate,y.child!==null||O!==null&&O.child!==null)for(m=JB(m);m!==null;){if(O=m[Pa])return O;m=JB(m)}return y}m=O,O=m.parentNode}return null}function n2(m){if(m=m[Pa]||m[rm]){var y=m.tag;if(y===5||y===6||y===13||y===31||y===26||y===27||y===3)return m}return null}function i2(m){var y=m.tag;if(y===5||y===26||y===27||y===6)return m.stateNode;throw Error(h(33))}function r2(m){var y=m[_8];return y||(y=m[_8]={hoistableStyles:new Map,hoistableScripts:new Map}),y}function ra(m){m[Ly]=!0}var D8=new Set,L8={};function sm(m,y){s2(m,y),s2(m+"Capture",y)}function s2(m,y){for(L8[m]=y,m=0;m<y.length;m++)D8.add(y[m])}var AM=RegExp("^[:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD][:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$"),vO={},P8={};function I8(m){return Zl.call(P8,m)?!0:Zl.call(vO,m)?!1:AM.test(m)?P8[m]=!0:(vO[m]=!0,!1)}function Py(m,y,O){if(I8(y))if(O===null)m.removeAttribute(y);else{switch(typeof O){case"undefined":case"function":case"symbol":m.removeAttribute(y);return;case"boolean":var N=y.toLowerCase().slice(0,5);if(N!=="data-"&&N!=="aria-"){m.removeAttribute(y);return}}m.setAttribute(y,""+O)}}function t4(m,y,O){if(O===null)m.removeAttribute(y);else{switch(typeof O){case"undefined":case"function":case"symbol":case"boolean":m.removeAttribute(y);return}m.setAttribute(y,""+O)}}function d0(m,y,O,N){if(N===null)m.removeAttribute(O);else{switch(typeof N){case"undefined":case"function":case"symbol":case"boolean":m.removeAttribute(O);return}m.setAttributeNS(y,O,""+N)}}function Ed(m){switch(typeof m){case"bigint":case"boolean":case"number":case"string":case"undefined":return m;case"object":return m;default:return""}}function R8(m){var y=m.type;return(m=m.nodeName)&&m.toLowerCase()==="input"&&(y==="checkbox"||y==="radio")}function NM(m,y,O){var N=Object.getOwnPropertyDescriptor(m.constructor.prototype,y);if(!m.hasOwnProperty(y)&&typeof N<"u"&&typeof N.get=="function"&&typeof N.set=="function"){var $=N.get,q=N.set;return Object.defineProperty(m,y,{configurable:!0,get:function(){return $.call(this)},set:function(le){O=""+le,q.call(this,le)}}),Object.defineProperty(m,y,{enumerable:N.enumerable}),{getValue:function(){return O},setValue:function(le){O=""+le},stopTracking:function(){m._valueTracker=null,delete m[y]}}}}function o2(m){if(!m._valueTracker){var y=R8(m)?"checked":"value";m._valueTracker=NM(m,y,""+m[y])}}function $8(m){if(!m)return!1;var y=m._valueTracker;if(!y)return!0;var O=y.getValue(),N="";return m&&(N=R8(m)?m.checked?"true":"false":m.value),m=N,m!==O?(y.setValue(m),!0):!1}function Iy(m){if(m=m||(typeof document<"u"?document:void 0),typeof m>"u")return null;try{return m.activeElement||m.body}catch{return m.body}}var _M=/[\n"\\]/g;function Cd(m){return m.replace(_M,function(y){return"\\"+y.charCodeAt(0).toString(16)+" "})}function Ry(m,y,O,N,$,q,le,Ce){m.name="",le!=null&&typeof le!="function"&&typeof le!="symbol"&&typeof le!="boolean"?m.type=le:m.removeAttribute("type"),y!=null?le==="number"?(y===0&&m.value===""||m.value!=y)&&(m.value=""+Ed(y)):m.value!==""+Ed(y)&&(m.value=""+Ed(y)):le!=="submit"&&le!=="reset"||m.removeAttribute("value"),y!=null?yO(m,le,Ed(y)):O!=null?yO(m,le,Ed(O)):N!=null&&m.removeAttribute("value"),$==null&&q!=null&&(m.defaultChecked=!!q),$!=null&&(m.checked=$&&typeof $!="function"&&typeof $!="symbol"),Ce!=null&&typeof Ce!="function"&&typeof Ce!="symbol"&&typeof Ce!="boolean"?m.name=""+Ed(Ce):m.removeAttribute("name")}function B8(m,y,O,N,$,q,le,Ce){if(q!=null&&typeof q!="function"&&typeof q!="symbol"&&typeof q!="boolean"&&(m.type=q),y!=null||O!=null){if(!(q!=="submit"&&q!=="reset"||y!=null)){o2(m);return}O=O!=null?""+Ed(O):"",y=y!=null?""+Ed(y):O,Ce||y===m.value||(m.value=y),m.defaultValue=y}N=N??$,N=typeof N!="function"&&typeof N!="symbol"&&!!N,m.checked=Ce?m.checked:!!N,m.defaultChecked=!!N,le!=null&&typeof le!="function"&&typeof le!="symbol"&&typeof le!="boolean"&&(m.name=le),o2(m)}function yO(m,y,O){y==="number"&&Iy(m.ownerDocument)===m||m.defaultValue===""+O||(m.defaultValue=""+O)}function om(m,y,O,N){if(m=m.options,y){y={};for(var $=0;$<O.length;$++)y["$"+O[$]]=!0;for(O=0;O<m.length;O++)$=y.hasOwnProperty("$"+m[O].value),m[O].selected!==$&&(m[O].selected=$),$&&N&&(m[O].defaultSelected=!0)}else{for(O=""+Ed(O),y=null,$=0;$<m.length;$++){if(m[$].value===O){m[$].selected=!0,N&&(m[$].defaultSelected=!0);return}y!==null||m[$].disabled||(y=m[$])}y!==null&&(y.selected=!0)}}function QI(m,y,O){if(y!=null&&(y=""+Ed(y),y!==m.value&&(m.value=y),O==null)){m.defaultValue!==y&&(m.defaultValue=y);return}m.defaultValue=O!=null?""+Ed(O):""}function GI(m,y,O,N){if(y==null){if(N!=null){if(O!=null)throw Error(h(92));if(He(N)){if(1<N.length)throw Error(h(93));N=N[0]}O=N}O==null&&(O=""),y=O}O=Ed(y),m.defaultValue=O,N=m.textContent,N===O&&N!==""&&N!==null&&(m.value=N),o2(m)}function n4(m,y){if(y){var O=m.firstChild;if(O&&O===m.lastChild&&O.nodeType===3){O.nodeValue=y;return}}m.textContent=y}var BV=new Set("animationIterationCount aspectRatio borderImageOutset borderImageSlice borderImageWidth boxFlex boxFlexGroup boxOrdinalGroup columnCount columns flex flexGrow flexPositive flexShrink flexNegative flexOrder gridArea gridRow gridRowEnd gridRowSpan gridRowStart gridColumn gridColumnEnd gridColumnSpan gridColumnStart fontWeight lineClamp lineHeight opacity order orphans scale tabSize widows zIndex zoom fillOpacity floodOpacity stopOpacity strokeDasharray strokeDashoffset strokeMiterlimit strokeOpacity strokeWidth MozAnimationIterationCount MozBoxFlex MozBoxFlexGroup MozLineClamp msAnimationIterationCount msFlex msZoom msFlexGrow msFlexNegative msFlexOrder msFlexPositive msFlexShrink msGridColumn msGridColumnSpan msGridRow msGridRowSpan WebkitAnimationIterationCount WebkitBoxFlex WebKitBoxFlexGroup WebkitBoxOrdinalGroup WebkitColumnCount WebkitColumns WebkitFlex WebkitFlexGrow WebkitFlexPositive WebkitFlexShrink WebkitLineClamp".split(" "));function UI(m,y,O){var N=y.indexOf("--")===0;O==null||typeof O=="boolean"||O===""?N?m.setProperty(y,""):y==="float"?m.cssFloat="":m[y]="":N?m.setProperty(y,O):typeof O!="number"||O===0||BV.has(y)?y==="float"?m.cssFloat=O:m[y]=(""+O).trim():m[y]=O+"px"}function JI(m,y,O){if(y!=null&&typeof y!="object")throw Error(h(62));if(m=m.style,O!=null){for(var N in O)!O.hasOwnProperty(N)||y!=null&&y.hasOwnProperty(N)||(N.indexOf("--")===0?m.setProperty(N,""):N==="float"?m.cssFloat="":m[N]="");for(var $ in y)N=y[$],y.hasOwnProperty($)&&O[$]!==N&&UI(m,$,N)}else for(var q in y)y.hasOwnProperty(q)&&UI(m,q,y[q])}function DM(m){if(m.indexOf("-")===-1)return!1;switch(m){case"annotation-xml":case"color-profile":case"font-face":case"font-face-src":case"font-face-uri":case"font-face-format":case"font-face-name":case"missing-glyph":return!1;default:return!0}}var zV=new Map([["acceptCharset","accept-charset"],["htmlFor","for"],["httpEquiv","http-equiv"],["crossOrigin","crossorigin"],["accentHeight","accent-height"],["alignmentBaseline","alignment-baseline"],["arabicForm","arabic-form"],["baselineShift","baseline-shift"],["capHeight","cap-height"],["clipPath","clip-path"],["clipRule","clip-rule"],["colorInterpolation","color-interpolation"],["colorInterpolationFilters","color-interpolation-filters"],["colorProfile","color-profile"],["colorRendering","color-rendering"],["dominantBaseline","dominant-baseline"],["enableBackground","enable-background"],["fillOpacity","fill-opacity"],["fillRule","fill-rule"],["floodColor","flood-color"],["floodOpacity","flood-opacity"],["fontFamily","font-family"],["fontSize","font-size"],["fontSizeAdjust","font-size-adjust"],["fontStretch","font-stretch"],["fontStyle","font-style"],["fontVariant","font-variant"],["fontWeight","font-weight"],["glyphName","glyph-name"],["glyphOrientationHorizontal","glyph-orientation-horizontal"],["glyphOrientationVertical","glyph-orientation-vertical"],["horizAdvX","horiz-adv-x"],["horizOriginX","horiz-origin-x"],["imageRendering","image-rendering"],["letterSpacing","letter-spacing"],["lightingColor","lighting-color"],["markerEnd","marker-end"],["markerMid","marker-mid"],["markerStart","marker-start"],["overlinePosition","overline-position"],["overlineThickness","overline-thickness"],["paintOrder","paint-order"],["panose-1","panose-1"],["pointerEvents","pointer-events"],["renderingIntent","rendering-intent"],["shapeRendering","shape-rendering"],["stopColor","stop-color"],["stopOpacity","stop-opacity"],["strikethroughPosition","strikethrough-position"],["strikethroughThickness","strikethrough-thickness"],["strokeDasharray","stroke-dasharray"],["strokeDashoffset","stroke-dashoffset"],["strokeLinecap","stroke-linecap"],["strokeLinejoin","stroke-linejoin"],["strokeMiterlimit","stroke-miterlimit"],["strokeOpacity","stroke-opacity"],["strokeWidth","stroke-width"],["textAnchor","text-anchor"],["textDecoration","text-decoration"],["textRendering","text-rendering"],["transformOrigin","transform-origin"],["underlinePosition","underline-position"],["underlineThickness","underline-thickness"],["unicodeBidi","unicode-bidi"],["unicodeRange","unicode-range"],["unitsPerEm","units-per-em"],["vAlphabetic","v-alphabetic"],["vHanging","v-hanging"],["vIdeographic","v-ideographic"],["vMathematical","v-mathematical"],["vectorEffect","vector-effect"],["vertAdvY","vert-adv-y"],["vertOriginX","vert-origin-x"],["vertOriginY","vert-origin-y"],["wordSpacing","word-spacing"],["writingMode","writing-mode"],["xmlnsXlink","xmlns:xlink"],["xHeight","x-height"]]),FV=/^[\u0000-\u001F ]*j[\r\n\t]*a[\r\n\t]*v[\r\n\t]*a[\r\n\t]*s[\r\n\t]*c[\r\n\t]*r[\r\n\t]*i[\r\n\t]*p[\r\n\t]*t[\r\n\t]*:/i;function z8(m){return FV.test(""+m)?"javascript:throw new Error('React has blocked a javascript: URL as a security precaution.')":m}function cm(){}var LM=null;function PM(m){return m=m.target||m.srcElement||window,m.correspondingUseElement&&(m=m.correspondingUseElement),m.nodeType===3?m.parentNode:m}var i4=null,r4=null;function XI(m){var y=n2(m);if(y&&(m=y.stateNode)){var O=m[ph]||null;e:switch(m=y.stateNode,y.type){case"input":if(Ry(m,O.value,O.defaultValue,O.defaultValue,O.checked,O.defaultChecked,O.type,O.name),y=O.name,O.type==="radio"&&y!=null){for(O=m;O.parentNode;)O=O.parentNode;for(O=O.querySelectorAll('input[name="'+Cd(""+y)+'"][type="radio"]'),y=0;y<O.length;y++){var N=O[y];if(N!==m&&N.form===m.form){var $=N[ph]||null;if(!$)throw Error(h(90));Ry(N,$.value,$.defaultValue,$.defaultValue,$.checked,$.defaultChecked,$.type,$.name)}}for(y=0;y<O.length;y++)N=O[y],N.form===m.form&&$8(N)}break e;case"textarea":QI(m,O.value,O.defaultValue);break e;case"select":y=O.value,y!=null&&om(m,!!O.multiple,y,!1)}}}var IM=!1;function VI(m,y,O){if(IM)return m(y,O);IM=!0;try{var N=m(y);return N}finally{if(IM=!1,(i4!==null||r4!==null)&&(Ej(),i4&&(y=i4,m=r4,r4=i4=null,XI(y),m)))for(y=0;y<m.length;y++)XI(m[y])}}function xO(m,y){var O=m.stateNode;if(O===null)return null;var N=O[ph]||null;if(N===null)return null;O=N[y];e:switch(y){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":case"onMouseEnter":(N=!N.disabled)||(m=m.type,N=!(m==="button"||m==="input"||m==="select"||m==="textarea")),m=!N;break e;default:m=!1}if(m)return null;if(O&&typeof O!="function")throw Error(h(231,y,typeof O));return O}var lm=!(typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"),RM=!1;if(lm)try{var kO={};Object.defineProperty(kO,"passive",{get:function(){RM=!0}}),window.addEventListener("test",kO,kO),window.removeEventListener("test",kO,kO)}catch{RM=!1}var c2=null,$M=null,F8=null;function WI(){if(F8)return F8;var m,y=$M,O=y.length,N,$="value"in c2?c2.value:c2.textContent,q=$.length;for(m=0;m<O&&y[m]===$[m];m++);var le=O-m;for(N=1;N<=le&&y[O-N]===$[q-N];N++);return F8=$.slice(m,1<N?1-N:void 0)}function q8(m){var y=m.keyCode;return"charCode"in m?(m=m.charCode,m===0&&y===13&&(m=13)):m=y,m===10&&(m=13),32<=m||m===13?m:0}function H8(){return!0}function KI(){return!1}function Md(m){function y(O,N,$,q,le){this._reactName=O,this._targetInst=$,this.type=N,this.nativeEvent=q,this.target=le,this.currentTarget=null;for(var Ce in m)m.hasOwnProperty(Ce)&&(O=m[Ce],this[Ce]=O?O(q):q[Ce]);return this.isDefaultPrevented=(q.defaultPrevented!=null?q.defaultPrevented:q.returnValue===!1)?H8:KI,this.isPropagationStopped=KI,this}return D(y.prototype,{preventDefault:function(){this.defaultPrevented=!0;var O=this.nativeEvent;O&&(O.preventDefault?O.preventDefault():typeof O.returnValue!="unknown"&&(O.returnValue=!1),this.isDefaultPrevented=H8)},stopPropagation:function(){var O=this.nativeEvent;O&&(O.stopPropagation?O.stopPropagation():typeof O.cancelBubble!="unknown"&&(O.cancelBubble=!0),this.isPropagationStopped=H8)},persist:function(){},isPersistent:H8}),y}var $y={eventPhase:0,bubbles:0,cancelable:0,timeStamp:function(m){return m.timeStamp||Date.now()},defaultPrevented:0,isTrusted:0},Q8=Md($y),OO=D({},$y,{view:0,detail:0}),qV=Md(OO),BM,zM,SO,G8=D({},OO,{screenX:0,screenY:0,clientX:0,clientY:0,pageX:0,pageY:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,getModifierState:qM,button:0,buttons:0,relatedTarget:function(m){return m.relatedTarget===void 0?m.fromElement===m.srcElement?m.toElement:m.fromElement:m.relatedTarget},movementX:function(m){return"movementX"in m?m.movementX:(m!==SO&&(SO&&m.type==="mousemove"?(BM=m.screenX-SO.screenX,zM=m.screenY-SO.screenY):zM=BM=0,SO=m),BM)},movementY:function(m){return"movementY"in m?m.movementY:zM}}),YI=Md(G8),HV=D({},G8,{dataTransfer:0}),QV=Md(HV),GV=D({},OO,{relatedTarget:0}),FM=Md(GV),UV=D({},$y,{animationName:0,elapsedTime:0,pseudoElement:0}),JV=Md(UV),XV=D({},$y,{clipboardData:function(m){return"clipboardData"in m?m.clipboardData:window.clipboardData}}),VV=Md(XV),WV=D({},$y,{data:0}),ZI=Md(WV),KV={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},YV={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},ZV={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function eW(m){var y=this.nativeEvent;return y.getModifierState?y.getModifierState(m):(m=ZV[m])?!!y[m]:!1}function qM(){return eW}var tW=D({},OO,{key:function(m){if(m.key){var y=KV[m.key]||m.key;if(y!=="Unidentified")return y}return m.type==="keypress"?(m=q8(m),m===13?"Enter":String.fromCharCode(m)):m.type==="keydown"||m.type==="keyup"?YV[m.keyCode]||"Unidentified":""},code:0,location:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,repeat:0,locale:0,getModifierState:qM,charCode:function(m){return m.type==="keypress"?q8(m):0},keyCode:function(m){return m.type==="keydown"||m.type==="keyup"?m.keyCode:0},which:function(m){return m.type==="keypress"?q8(m):m.type==="keydown"||m.type==="keyup"?m.keyCode:0}}),nW=Md(tW),iW=D({},G8,{pointerId:0,width:0,height:0,pressure:0,tangentialPressure:0,tiltX:0,tiltY:0,twist:0,pointerType:0,isPrimary:0}),eR=Md(iW),rW=D({},OO,{touches:0,targetTouches:0,changedTouches:0,altKey:0,metaKey:0,ctrlKey:0,shiftKey:0,getModifierState:qM}),sW=Md(rW),oW=D({},$y,{propertyName:0,elapsedTime:0,pseudoElement:0}),cW=Md(oW),lW=D({},G8,{deltaX:function(m){return"deltaX"in m?m.deltaX:"wheelDeltaX"in m?-m.wheelDeltaX:0},deltaY:function(m){return"deltaY"in m?m.deltaY:"wheelDeltaY"in m?-m.wheelDeltaY:"wheelDelta"in m?-m.wheelDelta:0},deltaZ:0,deltaMode:0}),uW=Md(lW),aW=D({},$y,{newState:0,oldState:0}),fW=Md(aW),hW=[9,13,27,32],HM=lm&&"CompositionEvent"in window,jO=null;lm&&"documentMode"in document&&(jO=document.documentMode);var dW=lm&&"TextEvent"in window&&!jO,tR=lm&&(!HM||jO&&8<jO&&11>=jO),nR=" ",iR=!1;function rR(m,y){switch(m){case"keyup":return hW.indexOf(y.keyCode)!==-1;case"keydown":return y.keyCode!==229;case"keypress":case"mousedown":case"focusout":return!0;default:return!1}}function sR(m){return m=m.detail,typeof m=="object"&&"data"in m?m.data:null}var s4=!1;function gW(m,y){switch(m){case"compositionend":return sR(y);case"keypress":return y.which!==32?null:(iR=!0,nR);case"textInput":return m=y.data,m===nR&&iR?null:m;default:return null}}function pW(m,y){if(s4)return m==="compositionend"||!HM&&rR(m,y)?(m=WI(),F8=$M=c2=null,s4=!1,m):null;switch(m){case"paste":return null;case"keypress":if(!(y.ctrlKey||y.altKey||y.metaKey)||y.ctrlKey&&y.altKey){if(y.char&&1<y.char.length)return y.char;if(y.which)return String.fromCharCode(y.which)}return null;case"compositionend":return tR&&y.locale!=="ko"?null:y.data;default:return null}}var bW={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function oR(m){var y=m&&m.nodeName&&m.nodeName.toLowerCase();return y==="input"?!!bW[m.type]:y==="textarea"}function cR(m,y,O,N){i4?r4?r4.push(N):r4=[N]:i4=N,y=Lj(y,"onChange"),0<y.length&&(O=new Q8("onChange","change",null,O,N),m.push({event:O,listeners:y}))}var TO=null,EO=null;function mW(m){LB(m,0)}function U8(m){var y=i2(m);if($8(y))return m}function lR(m,y){if(m==="change")return y}var QM=!1;if(lm){var GM;if(lm){var UM="oninput"in document;if(!UM){var uR=document.createElement("div");uR.setAttribute("oninput","return;"),UM=typeof uR.oninput=="function"}GM=UM}else GM=!1;QM=GM&&(!document.documentMode||9<document.documentMode)}function aR(){TO&&(TO.detachEvent("onpropertychange",fR),EO=TO=null)}function fR(m){if(m.propertyName==="value"&&U8(EO)){var y=[];cR(y,EO,m,PM(m)),VI(mW,y)}}function wW(m,y,O){m==="focusin"?(aR(),TO=y,EO=O,TO.attachEvent("onpropertychange",fR)):m==="focusout"&&aR()}function vW(m){if(m==="selectionchange"||m==="keyup"||m==="keydown")return U8(EO)}function yW(m,y){if(m==="click")return U8(y)}function xW(m,y){if(m==="input"||m==="change")return U8(y)}function kW(m,y){return m===y&&(m!==0||1/m===1/y)||m!==m&&y!==y}var h1=typeof Object.is=="function"?Object.is:kW;function CO(m,y){if(h1(m,y))return!0;if(typeof m!="object"||m===null||typeof y!="object"||y===null)return!1;var O=Object.keys(m),N=Object.keys(y);if(O.length!==N.length)return!1;for(N=0;N<O.length;N++){var $=O[N];if(!Zl.call(y,$)||!h1(m[$],y[$]))return!1}return!0}function hR(m){for(;m&&m.firstChild;)m=m.firstChild;return m}function dR(m,y){var O=hR(m);m=0;for(var N;O;){if(O.nodeType===3){if(N=m+O.textContent.length,m<=y&&N>=y)return{node:O,offset:y-m};m=N}e:{for(;O;){if(O.nextSibling){O=O.nextSibling;break e}O=O.parentNode}O=void 0}O=hR(O)}}function gR(m,y){return m&&y?m===y?!0:m&&m.nodeType===3?!1:y&&y.nodeType===3?gR(m,y.parentNode):"contains"in m?m.contains(y):m.compareDocumentPosition?!!(m.compareDocumentPosition(y)&16):!1:!1}function pR(m){m=m!=null&&m.ownerDocument!=null&&m.ownerDocument.defaultView!=null?m.ownerDocument.defaultView:window;for(var y=Iy(m.document);y instanceof m.HTMLIFrameElement;){try{var O=typeof y.contentWindow.location.href=="string"}catch{O=!1}if(O)m=y.contentWindow;else break;y=Iy(m.document)}return y}function JM(m){var y=m&&m.nodeName&&m.nodeName.toLowerCase();return y&&(y==="input"&&(m.type==="text"||m.type==="search"||m.type==="tel"||m.type==="url"||m.type==="password")||y==="textarea"||m.contentEditable==="true")}var OW=lm&&"documentMode"in document&&11>=document.documentMode,o4=null,XM=null,MO=null,VM=!1;function bR(m,y,O){var N=O.window===O?O.document:O.nodeType===9?O:O.ownerDocument;VM||o4==null||o4!==Iy(N)||(N=o4,"selectionStart"in N&&JM(N)?N={start:N.selectionStart,end:N.selectionEnd}:(N=(N.ownerDocument&&N.ownerDocument.defaultView||window).getSelection(),N={anchorNode:N.anchorNode,anchorOffset:N.anchorOffset,focusNode:N.focusNode,focusOffset:N.focusOffset}),MO&&CO(MO,N)||(MO=N,N=Lj(XM,"onSelect"),0<N.length&&(y=new Q8("onSelect","select",null,y,O),m.push({event:y,listeners:N}),y.target=o4)))}function By(m,y){var O={};return O[m.toLowerCase()]=y.toLowerCase(),O["Webkit"+m]="webkit"+y,O["Moz"+m]="moz"+y,O}var c4={animationend:By("Animation","AnimationEnd"),animationiteration:By("Animation","AnimationIteration"),animationstart:By("Animation","AnimationStart"),transitionrun:By("Transition","TransitionRun"),transitionstart:By("Transition","TransitionStart"),transitioncancel:By("Transition","TransitionCancel"),transitionend:By("Transition","TransitionEnd")},WM={},mR={};lm&&(mR=document.createElement("div").style,"AnimationEvent"in window||(delete c4.animationend.animation,delete c4.animationiteration.animation,delete c4.animationstart.animation),"TransitionEvent"in window||delete c4.transitionend.transition);function zy(m){if(WM[m])return WM[m];if(!c4[m])return m;var y=c4[m],O;for(O in y)if(y.hasOwnProperty(O)&&O in mR)return WM[m]=y[O];return m}var wR=zy("animationend"),vR=zy("animationiteration"),yR=zy("animationstart"),SW=zy("transitionrun"),jW=zy("transitionstart"),TW=zy("transitioncancel"),xR=zy("transitionend"),kR=new Map,KM="abort auxClick beforeToggle cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll toggle touchMove waiting wheel".split(" ");KM.push("scrollEnd");function g0(m,y){kR.set(m,y),sm(y,[m])}var J8=typeof reportError=="function"?reportError:function(m){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var y=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof m=="object"&&m!==null&&typeof m.message=="string"?String(m.message):String(m),error:m});if(!window.dispatchEvent(y))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",m);return}console.error(m)},ug=[],l4=0,YM=0;function X8(){for(var m=l4,y=YM=l4=0;y<m;){var O=ug[y];ug[y++]=null;var N=ug[y];ug[y++]=null;var $=ug[y];ug[y++]=null;var q=ug[y];if(ug[y++]=null,N!==null&&$!==null){var le=N.pending;le===null?$.next=$:($.next=le.next,le.next=$),N.pending=$}q!==0&&OR(O,$,q)}}function V8(m,y,O,N){ug[l4++]=m,ug[l4++]=y,ug[l4++]=O,ug[l4++]=N,YM|=N,m.lanes|=N,m=m.alternate,m!==null&&(m.lanes|=N)}function ZM(m,y,O,N){return V8(m,y,O,N),W8(m)}function Fy(m,y){return V8(m,null,null,y),W8(m)}function OR(m,y,O){m.lanes|=O;var N=m.alternate;N!==null&&(N.lanes|=O);for(var $=!1,q=m.return;q!==null;)q.childLanes|=O,N=q.alternate,N!==null&&(N.childLanes|=O),q.tag===22&&(m=q.stateNode,m===null||m._visibility&1||($=!0)),m=q,q=q.return;return m.tag===3?(q=m.stateNode,$&&y!==null&&($=31-qf(O),m=q.hiddenUpdates,N=m[$],N===null?m[$]=[y]:N.push(y),y.lane=O|536870912),q):null}function W8(m){if(50<e6)throw e6=0,uN=null,Error(h(185));for(var y=m.return;y!==null;)m=y,y=m.return;return m.tag===3?m.stateNode:null}var u4={};function EW(m,y,O,N){this.tag=m,this.key=O,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.refCleanup=this.ref=null,this.pendingProps=y,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=N,this.subtreeFlags=this.flags=0,this.deletions=null,this.childLanes=this.lanes=0,this.alternate=null}function d1(m,y,O,N){return new EW(m,y,O,N)}function eA(m){return m=m.prototype,!(!m||!m.isReactComponent)}function um(m,y){var O=m.alternate;return O===null?(O=d1(m.tag,y,m.key,m.mode),O.elementType=m.elementType,O.type=m.type,O.stateNode=m.stateNode,O.alternate=m,m.alternate=O):(O.pendingProps=y,O.type=m.type,O.flags=0,O.subtreeFlags=0,O.deletions=null),O.flags=m.flags&65011712,O.childLanes=m.childLanes,O.lanes=m.lanes,O.child=m.child,O.memoizedProps=m.memoizedProps,O.memoizedState=m.memoizedState,O.updateQueue=m.updateQueue,y=m.dependencies,O.dependencies=y===null?null:{lanes:y.lanes,firstContext:y.firstContext},O.sibling=m.sibling,O.index=m.index,O.ref=m.ref,O.refCleanup=m.refCleanup,O}function SR(m,y){m.flags&=65011714;var O=m.alternate;return O===null?(m.childLanes=0,m.lanes=y,m.child=null,m.subtreeFlags=0,m.memoizedProps=null,m.memoizedState=null,m.updateQueue=null,m.dependencies=null,m.stateNode=null):(m.childLanes=O.childLanes,m.lanes=O.lanes,m.child=O.child,m.subtreeFlags=0,m.deletions=null,m.memoizedProps=O.memoizedProps,m.memoizedState=O.memoizedState,m.updateQueue=O.updateQueue,m.type=O.type,y=O.dependencies,m.dependencies=y===null?null:{lanes:y.lanes,firstContext:y.firstContext}),m}function K8(m,y,O,N,$,q){var le=0;if(N=m,typeof m=="function")eA(m)&&(le=1);else if(typeof m=="string")le=kK(m,O,Ue.current)?26:m==="html"||m==="head"||m==="body"?27:5;else e:switch(m){case Te:return m=d1(31,O,y,$),m.elementType=Te,m.lanes=q,m;case U:return qy(O.children,$,q,y);case K:le=8,$|=24;break;case Y:return m=d1(12,O,y,$|2),m.elementType=Y,m.lanes=q,m;case fe:return m=d1(13,O,y,$),m.elementType=fe,m.lanes=q,m;case be:return m=d1(19,O,y,$),m.elementType=be,m.lanes=q,m;default:if(typeof m=="object"&&m!==null)switch(m.$$typeof){case ee:le=10;break e;case Z:le=9;break e;case ce:le=11;break e;case me:le=14;break e;case Re:le=16,N=null;break e}le=29,O=Error(h(130,m===null?"null":typeof m,"")),N=null}return y=d1(le,O,y,$),y.elementType=m,y.type=N,y.lanes=q,y}function qy(m,y,O,N){return m=d1(7,m,N,y),m.lanes=O,m}function tA(m,y,O){return m=d1(6,m,null,y),m.lanes=O,m}function jR(m){var y=d1(18,null,null,0);return y.stateNode=m,y}function nA(m,y,O){return y=d1(4,m.children!==null?m.children:[],m.key,y),y.lanes=O,y.stateNode={containerInfo:m.containerInfo,pendingChildren:null,implementation:m.implementation},y}var TR=new WeakMap;function ag(m,y){if(typeof m=="object"&&m!==null){var O=TR.get(m);return O!==void 0?O:(y={value:m,source:y,stack:Bl(y)},TR.set(m,y),y)}return{value:m,source:y,stack:Bl(y)}}var a4=[],f4=0,Y8=null,AO=0,fg=[],hg=0,l2=null,Np=1,_p="";function am(m,y){a4[f4++]=AO,a4[f4++]=Y8,Y8=m,AO=y}function ER(m,y,O){fg[hg++]=Np,fg[hg++]=_p,fg[hg++]=l2,l2=m;var N=Np;m=_p;var $=32-qf(N)-1;N&=~(1<<$),O+=1;var q=32-qf(y)+$;if(30<q){var le=$-$%5;q=(N&(1<<le)-1).toString(32),N>>=le,$-=le,Np=1<<32-qf(y)+$|O<<$|N,_p=q+m}else Np=1<<q|O<<$|N,_p=m}function iA(m){m.return!==null&&(am(m,1),ER(m,1,0))}function rA(m){for(;m===Y8;)Y8=a4[--f4],a4[f4]=null,AO=a4[--f4],a4[f4]=null;for(;m===l2;)l2=fg[--hg],fg[hg]=null,_p=fg[--hg],fg[hg]=null,Np=fg[--hg],fg[hg]=null}function CR(m,y){fg[hg++]=Np,fg[hg++]=_p,fg[hg++]=l2,Np=y.id,_p=y.overflow,l2=m}var cf=null,Sl=null,ko=!1,u2=null,dg=!1,sA=Error(h(519));function a2(m){var y=Error(h(418,1<arguments.length&&arguments[1]!==void 0&&arguments[1]?"text":"HTML",""));throw f2(ag(y,m)),sA}function MR(m){var y=m.stateNode,O=m.type,N=m.memoizedProps;switch(y[Pa]=m,y[ph]=N,O){case"dialog":so("cancel",y),so("close",y);break;case"iframe":case"object":case"embed":so("load",y);break;case"video":case"audio":for(O=0;O<n6.length;O++)so(n6[O],y);break;case"source":so("error",y);break;case"img":case"image":case"link":so("error",y),so("load",y);break;case"details":so("toggle",y);break;case"input":so("invalid",y),B8(y,N.value,N.defaultValue,N.checked,N.defaultChecked,N.type,N.name,!0);break;case"select":so("invalid",y);break;case"textarea":so("invalid",y),GI(y,N.value,N.defaultValue,N.children)}O=N.children,typeof O!="string"&&typeof O!="number"&&typeof O!="bigint"||y.textContent===""+O||N.suppressHydrationWarning===!0||$B(y.textContent,O)?(N.popover!=null&&(so("beforetoggle",y),so("toggle",y)),N.onScroll!=null&&so("scroll",y),N.onScrollEnd!=null&&so("scrollend",y),N.onClick!=null&&(y.onclick=cm),y=!0):y=!1,y||a2(m,!0)}function AR(m){for(cf=m.return;cf;)switch(cf.tag){case 5:case 31:case 13:dg=!1;return;case 27:case 3:dg=!0;return;default:cf=cf.return}}function h4(m){if(m!==cf)return!1;if(!ko)return AR(m),ko=!0,!1;var y=m.tag,O;if((O=y!==3&&y!==27)&&((O=y===5)&&(O=m.type,O=!(O!=="form"&&O!=="button")||jN(m.type,m.memoizedProps)),O=!O),O&&Sl&&a2(m),AR(m),y===13){if(m=m.memoizedState,m=m!==null?m.dehydrated:null,!m)throw Error(h(317));Sl=NN(m)}else if(y===31){if(m=m.memoizedState,m=m!==null?m.dehydrated:null,!m)throw Error(h(317));Sl=NN(m)}else y===27?(y=Sl,E2(m.type)?(m=AN,AN=null,Sl=m):Sl=y):Sl=cf?bg(m.stateNode.nextSibling):null;return!0}function Hy(){Sl=cf=null,ko=!1}function d4(){var m=u2;return m!==null&&(_d===null?_d=m:_d.push.apply(_d,m),u2=null),m}function f2(m){u2===null?u2=[m]:u2.push(m)}var oA=Ae(null),Qy=null,Dp=null;function h2(m,y,O){mt(oA,y._currentValue),y._currentValue=O}function fm(m){m._currentValue=oA.current,Ye(oA)}function cA(m,y,O){for(;m!==null;){var N=m.alternate;if((m.childLanes&y)!==y?(m.childLanes|=y,N!==null&&(N.childLanes|=y)):N!==null&&(N.childLanes&y)!==y&&(N.childLanes|=y),m===O)break;m=m.return}}function lA(m,y,O,N){var $=m.child;for($!==null&&($.return=m);$!==null;){var q=$.dependencies;if(q!==null){var le=$.child;q=q.firstContext;e:for(;q!==null;){var Ce=q;q=$;for(var dt=0;dt<y.length;dt++)if(Ce.context===y[dt]){q.lanes|=O,Ce=q.alternate,Ce!==null&&(Ce.lanes|=O),cA(q.return,O,m),N||(le=null);break e}q=Ce.next}}else if($.tag===18){if(le=$.return,le===null)throw Error(h(341));le.lanes|=O,q=le.alternate,q!==null&&(q.lanes|=O),cA(le,O,m),le=null}else le=$.child;if(le!==null)le.return=$;else for(le=$;le!==null;){if(le===m){le=null;break}if($=le.sibling,$!==null){$.return=le.return,le=$;break}le=le.return}$=le}}function g4(m,y,O,N){m=null;for(var $=y,q=!1;$!==null;){if(!q){if(($.flags&524288)!==0)q=!0;else if(($.flags&262144)!==0)break}if($.tag===10){var le=$.alternate;if(le===null)throw Error(h(387));if(le=le.memoizedProps,le!==null){var Ce=$.type;h1($.pendingProps.value,le.value)||(m!==null?m.push(Ce):m=[Ce])}}else if($===Cn.current){if(le=$.alternate,le===null)throw Error(h(387));le.memoizedState.memoizedState!==$.memoizedState.memoizedState&&(m!==null?m.push(o6):m=[o6])}$=$.return}m!==null&&lA(y,m,O,N),y.flags|=262144}function NO(m){for(m=m.firstContext;m!==null;){if(!h1(m.context._currentValue,m.memoizedValue))return!0;m=m.next}return!1}function d2(m){Qy=m,Dp=null,m=m.dependencies,m!==null&&(m.firstContext=null)}function Hf(m){return uA(Qy,m)}function _O(m,y){return Qy===null&&d2(m),uA(m,y)}function uA(m,y){var O=y._currentValue;if(y={context:y,memoizedValue:O,next:null},Dp===null){if(m===null)throw Error(h(308));Dp=y,m.dependencies={lanes:0,firstContext:y},m.flags|=524288}else Dp=Dp.next=y;return O}var CW=typeof AbortController<"u"?AbortController:function(){var m=[],y=this.signal={aborted:!1,addEventListener:function(O,N){m.push(N)}};this.abort=function(){y.aborted=!0,m.forEach(function(O){return O()})}},MW=l.unstable_scheduleCallback,DO=l.unstable_NormalPriority,sa={$$typeof:ee,Consumer:null,Provider:null,_currentValue:null,_currentValue2:null,_threadCount:0};function aA(){return{controller:new CW,data:new Map,refCount:0}}function LO(m){m.refCount--,m.refCount===0&&MW(DO,function(){m.controller.abort()})}var PO=null,fA=0,p4=0,b4=null;function AW(m,y){if(PO===null){var O=PO=[];fA=0,p4=pN(),b4={status:"pending",value:void 0,then:function(N){O.push(N)}}}return fA++,y.then(NR,NR),y}function NR(){if(--fA===0&&PO!==null){b4!==null&&(b4.status="fulfilled");var m=PO;PO=null,p4=0,b4=null;for(var y=0;y<m.length;y++)(0,m[y])()}}function NW(m,y){var O=[],N={status:"pending",value:null,reason:null,then:function($){O.push($)}};return m.then(function(){N.status="fulfilled",N.value=y;for(var $=0;$<O.length;$++)(0,O[$])(y)},function($){for(N.status="rejected",N.reason=$,$=0;$<O.length;$++)(0,O[$])(void 0)}),N}var _R=ae.S;ae.S=function(m,y){cB=eu(),typeof y=="object"&&y!==null&&typeof y.then=="function"&&AW(m,y),_R!==null&&_R(m,y)};var Gy=Ae(null);function hA(){var m=Gy.current;return m!==null?m:Yc.pooledCache}function Z8(m,y){y===null?mt(Gy,Gy.current):mt(Gy,y.pool)}function DR(){var m=hA();return m===null?null:{parent:sa._currentValue,pool:m}}var m4=Error(h(460)),dA=Error(h(474)),ej=Error(h(542)),tj={then:function(){}};function gA(m){return m=m.status,m==="fulfilled"||m==="rejected"}function LR(m,y,O){switch(O=m[O],O===void 0?m.push(y):O!==y&&(y.then(cm,cm),y=O),y.status){case"fulfilled":return y.value;case"rejected":throw m=y.reason,IR(m),m;default:if(typeof y.status=="string")y.then(cm,cm);else{if(m=Yc,m!==null&&100<m.shellSuspendCounter)throw Error(h(482));m=y,m.status="pending",m.then(function(N){if(y.status==="pending"){var $=y;$.status="fulfilled",$.value=N}},function(N){if(y.status==="pending"){var $=y;$.status="rejected",$.reason=N}})}switch(y.status){case"fulfilled":return y.value;case"rejected":throw m=y.reason,IR(m),m}throw Jy=y,m4}}function Uy(m){try{var y=m._init;return y(m._payload)}catch(O){throw O!==null&&typeof O=="object"&&typeof O.then=="function"?(Jy=O,m4):O}}var Jy=null;function PR(){if(Jy===null)throw Error(h(459));var m=Jy;return Jy=null,m}function IR(m){if(m===m4||m===ej)throw Error(h(483))}var w4=null,IO=0;function nj(m){var y=IO;return IO+=1,w4===null&&(w4=[]),LR(w4,m,y)}function RO(m,y){y=y.props.ref,m.ref=y!==void 0?y:null}function ij(m,y){throw y.$$typeof===I?Error(h(525)):(m=Object.prototype.toString.call(y),Error(h(31,m==="[object Object]"?"object with keys {"+Object.keys(y).join(", ")+"}":m)))}function RR(m){function y(At,yt){if(m){var $t=At.deletions;$t===null?(At.deletions=[yt],At.flags|=16):$t.push(yt)}}function O(At,yt){if(!m)return null;for(;yt!==null;)y(At,yt),yt=yt.sibling;return null}function N(At){for(var yt=new Map;At!==null;)At.key!==null?yt.set(At.key,At):yt.set(At.index,At),At=At.sibling;return yt}function $(At,yt){return At=um(At,yt),At.index=0,At.sibling=null,At}function q(At,yt,$t){return At.index=$t,m?($t=At.alternate,$t!==null?($t=$t.index,$t<yt?(At.flags|=67108866,yt):$t):(At.flags|=67108866,yt)):(At.flags|=1048576,yt)}function le(At){return m&&At.alternate===null&&(At.flags|=67108866),At}function Ce(At,yt,$t,an){return yt===null||yt.tag!==6?(yt=tA($t,At.mode,an),yt.return=At,yt):(yt=$(yt,$t),yt.return=At,yt)}function dt(At,yt,$t,an){var mr=$t.type;return mr===U?gn(At,yt,$t.props.children,an,$t.key):yt!==null&&(yt.elementType===mr||typeof mr=="object"&&mr!==null&&mr.$$typeof===Re&&Uy(mr)===yt.type)?(yt=$(yt,$t.props),RO(yt,$t),yt.return=At,yt):(yt=K8($t.type,$t.key,$t.props,null,At.mode,an),RO(yt,$t),yt.return=At,yt)}function Ft(At,yt,$t,an){return yt===null||yt.tag!==4||yt.stateNode.containerInfo!==$t.containerInfo||yt.stateNode.implementation!==$t.implementation?(yt=nA($t,At.mode,an),yt.return=At,yt):(yt=$(yt,$t.children||[]),yt.return=At,yt)}function gn(At,yt,$t,an,mr){return yt===null||yt.tag!==7?(yt=qy($t,At.mode,an,mr),yt.return=At,yt):(yt=$(yt,$t),yt.return=At,yt)}function xn(At,yt,$t){if(typeof yt=="string"&&yt!==""||typeof yt=="number"||typeof yt=="bigint")return yt=tA(""+yt,At.mode,$t),yt.return=At,yt;if(typeof yt=="object"&&yt!==null){switch(yt.$$typeof){case B:return $t=K8(yt.type,yt.key,yt.props,null,At.mode,$t),RO($t,yt),$t.return=At,$t;case F:return yt=nA(yt,At.mode,$t),yt.return=At,yt;case Re:return yt=Uy(yt),xn(At,yt,$t)}if(He(yt)||je(yt))return yt=qy(yt,At.mode,$t,null),yt.return=At,yt;if(typeof yt.then=="function")return xn(At,nj(yt),$t);if(yt.$$typeof===ee)return xn(At,_O(At,yt),$t);ij(At,yt)}return null}function Zt(At,yt,$t,an){var mr=yt!==null?yt.key:null;if(typeof $t=="string"&&$t!==""||typeof $t=="number"||typeof $t=="bigint")return mr!==null?null:Ce(At,yt,""+$t,an);if(typeof $t=="object"&&$t!==null){switch($t.$$typeof){case B:return $t.key===mr?dt(At,yt,$t,an):null;case F:return $t.key===mr?Ft(At,yt,$t,an):null;case Re:return $t=Uy($t),Zt(At,yt,$t,an)}if(He($t)||je($t))return mr!==null?null:gn(At,yt,$t,an,null);if(typeof $t.then=="function")return Zt(At,yt,nj($t),an);if($t.$$typeof===ee)return Zt(At,yt,_O(At,$t),an);ij(At,$t)}return null}function on(At,yt,$t,an,mr){if(typeof an=="string"&&an!==""||typeof an=="number"||typeof an=="bigint")return At=At.get($t)||null,Ce(yt,At,""+an,mr);if(typeof an=="object"&&an!==null){switch(an.$$typeof){case B:return At=At.get(an.key===null?$t:an.key)||null,dt(yt,At,an,mr);case F:return At=At.get(an.key===null?$t:an.key)||null,Ft(yt,At,an,mr);case Re:return an=Uy(an),on(At,yt,$t,an,mr)}if(He(an)||je(an))return At=At.get($t)||null,gn(yt,At,an,mr,null);if(typeof an.then=="function")return on(At,yt,$t,nj(an),mr);if(an.$$typeof===ee)return on(At,yt,$t,_O(yt,an),mr);ij(yt,an)}return null}function Wi(At,yt,$t,an){for(var mr=null,Fo=null,rr=yt,ds=yt=0,Fs=null;rr!==null&&ds<$t.length;ds++){rr.index>ds?(Fs=rr,rr=null):Fs=rr.sibling;var qo=Zt(At,rr,$t[ds],an);if(qo===null){rr===null&&(rr=Fs);break}m&&rr&&qo.alternate===null&&y(At,rr),yt=q(qo,yt,ds),Fo===null?mr=qo:Fo.sibling=qo,Fo=qo,rr=Fs}if(ds===$t.length)return O(At,rr),ko&&am(At,ds),mr;if(rr===null){for(;ds<$t.length;ds++)rr=xn(At,$t[ds],an),rr!==null&&(yt=q(rr,yt,ds),Fo===null?mr=rr:Fo.sibling=rr,Fo=rr);return ko&&am(At,ds),mr}for(rr=N(rr);ds<$t.length;ds++)Fs=on(rr,At,ds,$t[ds],an),Fs!==null&&(m&&Fs.alternate!==null&&rr.delete(Fs.key===null?ds:Fs.key),yt=q(Fs,yt,ds),Fo===null?mr=Fs:Fo.sibling=Fs,Fo=Fs);return m&&rr.forEach(function(xm){return y(At,xm)}),ko&&am(At,ds),mr}function qr(At,yt,$t,an){if($t==null)throw Error(h(151));for(var mr=null,Fo=null,rr=yt,ds=yt=0,Fs=null,qo=$t.next();rr!==null&&!qo.done;ds++,qo=$t.next()){rr.index>ds?(Fs=rr,rr=null):Fs=rr.sibling;var xm=Zt(At,rr,qo.value,an);if(xm===null){rr===null&&(rr=Fs);break}m&&rr&&xm.alternate===null&&y(At,rr),yt=q(xm,yt,ds),Fo===null?mr=xm:Fo.sibling=xm,Fo=xm,rr=Fs}if(qo.done)return O(At,rr),ko&&am(At,ds),mr;if(rr===null){for(;!qo.done;ds++,qo=$t.next())qo=xn(At,qo.value,an),qo!==null&&(yt=q(qo,yt,ds),Fo===null?mr=qo:Fo.sibling=qo,Fo=qo);return ko&&am(At,ds),mr}for(rr=N(rr);!qo.done;ds++,qo=$t.next())qo=on(rr,At,ds,qo.value,an),qo!==null&&(m&&qo.alternate!==null&&rr.delete(qo.key===null?ds:qo.key),yt=q(qo,yt,ds),Fo===null?mr=qo:Fo.sibling=qo,Fo=qo);return m&&rr.forEach(function(Bp){return y(At,Bp)}),ko&&am(At,ds),mr}function Zc(At,yt,$t,an){if(typeof $t=="object"&&$t!==null&&$t.type===U&&$t.key===null&&($t=$t.props.children),typeof $t=="object"&&$t!==null){switch($t.$$typeof){case B:e:{for(var mr=$t.key;yt!==null;){if(yt.key===mr){if(mr=$t.type,mr===U){if(yt.tag===7){O(At,yt.sibling),an=$(yt,$t.props.children),an.return=At,At=an;break e}}else if(yt.elementType===mr||typeof mr=="object"&&mr!==null&&mr.$$typeof===Re&&Uy(mr)===yt.type){O(At,yt.sibling),an=$(yt,$t.props),RO(an,$t),an.return=At,At=an;break e}O(At,yt);break}else y(At,yt);yt=yt.sibling}$t.type===U?(an=qy($t.props.children,At.mode,an,$t.key),an.return=At,At=an):(an=K8($t.type,$t.key,$t.props,null,At.mode,an),RO(an,$t),an.return=At,At=an)}return le(At);case F:e:{for(mr=$t.key;yt!==null;){if(yt.key===mr)if(yt.tag===4&&yt.stateNode.containerInfo===$t.containerInfo&&yt.stateNode.implementation===$t.implementation){O(At,yt.sibling),an=$(yt,$t.children||[]),an.return=At,At=an;break e}else{O(At,yt);break}else y(At,yt);yt=yt.sibling}an=nA($t,At.mode,an),an.return=At,At=an}return le(At);case Re:return $t=Uy($t),Zc(At,yt,$t,an)}if(He($t))return Wi(At,yt,$t,an);if(je($t)){if(mr=je($t),typeof mr!="function")throw Error(h(150));return $t=mr.call($t),qr(At,yt,$t,an)}if(typeof $t.then=="function")return Zc(At,yt,nj($t),an);if($t.$$typeof===ee)return Zc(At,yt,_O(At,$t),an);ij(At,$t)}return typeof $t=="string"&&$t!==""||typeof $t=="number"||typeof $t=="bigint"?($t=""+$t,yt!==null&&yt.tag===6?(O(At,yt.sibling),an=$(yt,$t),an.return=At,At=an):(O(At,yt),an=tA($t,At.mode,an),an.return=At,At=an),le(At)):O(At,yt)}return function(At,yt,$t,an){try{IO=0;var mr=Zc(At,yt,$t,an);return w4=null,mr}catch(rr){if(rr===m4||rr===ej)throw rr;var Fo=d1(29,rr,null,At.mode);return Fo.lanes=an,Fo.return=At,Fo}finally{}}}var Xy=RR(!0),$R=RR(!1),g2=!1;function pA(m){m.updateQueue={baseState:m.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null,lanes:0,hiddenCallbacks:null},callbacks:null}}function bA(m,y){m=m.updateQueue,y.updateQueue===m&&(y.updateQueue={baseState:m.baseState,firstBaseUpdate:m.firstBaseUpdate,lastBaseUpdate:m.lastBaseUpdate,shared:m.shared,callbacks:null})}function p2(m){return{lane:m,tag:0,payload:null,callback:null,next:null}}function b2(m,y,O){var N=m.updateQueue;if(N===null)return null;if(N=N.shared,(rc&2)!==0){var $=N.pending;return $===null?y.next=y:(y.next=$.next,$.next=y),N.pending=y,y=W8(m),OR(m,null,O),y}return V8(m,N,y,O),W8(m)}function $O(m,y,O){if(y=y.updateQueue,y!==null&&(y=y.shared,(O&4194048)!==0)){var N=y.lanes;N&=m.pendingLanes,O|=N,y.lanes=O,pO(m,O)}}function mA(m,y){var O=m.updateQueue,N=m.alternate;if(N!==null&&(N=N.updateQueue,O===N)){var $=null,q=null;if(O=O.firstBaseUpdate,O!==null){do{var le={lane:O.lane,tag:O.tag,payload:O.payload,callback:null,next:null};q===null?$=q=le:q=q.next=le,O=O.next}while(O!==null);q===null?$=q=y:q=q.next=y}else $=q=y;O={baseState:N.baseState,firstBaseUpdate:$,lastBaseUpdate:q,shared:N.shared,callbacks:N.callbacks},m.updateQueue=O;return}m=O.lastBaseUpdate,m===null?O.firstBaseUpdate=y:m.next=y,O.lastBaseUpdate=y}var wA=!1;function BO(){if(wA){var m=b4;if(m!==null)throw m}}function zO(m,y,O,N){wA=!1;var $=m.updateQueue;g2=!1;var q=$.firstBaseUpdate,le=$.lastBaseUpdate,Ce=$.shared.pending;if(Ce!==null){$.shared.pending=null;var dt=Ce,Ft=dt.next;dt.next=null,le===null?q=Ft:le.next=Ft,le=dt;var gn=m.alternate;gn!==null&&(gn=gn.updateQueue,Ce=gn.lastBaseUpdate,Ce!==le&&(Ce===null?gn.firstBaseUpdate=Ft:Ce.next=Ft,gn.lastBaseUpdate=dt))}if(q!==null){var xn=$.baseState;le=0,gn=Ft=dt=null,Ce=q;do{var Zt=Ce.lane&-536870913,on=Zt!==Ce.lane;if(on?(wo&Zt)===Zt:(N&Zt)===Zt){Zt!==0&&Zt===p4&&(wA=!0),gn!==null&&(gn=gn.next={lane:0,tag:Ce.tag,payload:Ce.payload,callback:null,next:null});e:{var Wi=m,qr=Ce;Zt=y;var Zc=O;switch(qr.tag){case 1:if(Wi=qr.payload,typeof Wi=="function"){xn=Wi.call(Zc,xn,Zt);break e}xn=Wi;break e;case 3:Wi.flags=Wi.flags&-65537|128;case 0:if(Wi=qr.payload,Zt=typeof Wi=="function"?Wi.call(Zc,xn,Zt):Wi,Zt==null)break e;xn=D({},xn,Zt);break e;case 2:g2=!0}}Zt=Ce.callback,Zt!==null&&(m.flags|=64,on&&(m.flags|=8192),on=$.callbacks,on===null?$.callbacks=[Zt]:on.push(Zt))}else on={lane:Zt,tag:Ce.tag,payload:Ce.payload,callback:Ce.callback,next:null},gn===null?(Ft=gn=on,dt=xn):gn=gn.next=on,le|=Zt;if(Ce=Ce.next,Ce===null){if(Ce=$.shared.pending,Ce===null)break;on=Ce,Ce=on.next,on.next=null,$.lastBaseUpdate=on,$.shared.pending=null}}while(!0);gn===null&&(dt=xn),$.baseState=dt,$.firstBaseUpdate=Ft,$.lastBaseUpdate=gn,q===null&&($.shared.lanes=0),k2|=le,m.lanes=le,m.memoizedState=xn}}function BR(m,y){if(typeof m!="function")throw Error(h(191,m));m.call(y)}function zR(m,y){var O=m.callbacks;if(O!==null)for(m.callbacks=null,m=0;m<O.length;m++)BR(O[m],y)}var v4=Ae(null),rj=Ae(0);function FR(m,y){m=wm,mt(rj,m),mt(v4,y),wm=m|y.baseLanes}function vA(){mt(rj,wm),mt(v4,v4.current)}function yA(){wm=rj.current,Ye(v4),Ye(rj)}var g1=Ae(null),gg=null;function m2(m){var y=m.alternate;mt(Nu,Nu.current&1),mt(g1,m),gg===null&&(y===null||v4.current!==null||y.memoizedState!==null)&&(gg=m)}function xA(m){mt(Nu,Nu.current),mt(g1,m),gg===null&&(gg=m)}function qR(m){m.tag===22?(mt(Nu,Nu.current),mt(g1,m),gg===null&&(gg=m)):w2()}function w2(){mt(Nu,Nu.current),mt(g1,g1.current)}function p1(m){Ye(g1),gg===m&&(gg=null),Ye(Nu)}var Nu=Ae(0);function sj(m){for(var y=m;y!==null;){if(y.tag===13){var O=y.memoizedState;if(O!==null&&(O=O.dehydrated,O===null||CN(O)||MN(O)))return y}else if(y.tag===19&&(y.memoizedProps.revealOrder==="forwards"||y.memoizedProps.revealOrder==="backwards"||y.memoizedProps.revealOrder==="unstable_legacy-backwards"||y.memoizedProps.revealOrder==="together")){if((y.flags&128)!==0)return y}else if(y.child!==null){y.child.return=y,y=y.child;continue}if(y===m)break;for(;y.sibling===null;){if(y.return===null||y.return===m)return null;y=y.return}y.sibling.return=y.return,y=y.sibling}return null}var hm=0,Ts=null,$c=null,oa=null,oj=!1,y4=!1,Vy=!1,cj=0,FO=0,x4=null,_W=0;function pu(){throw Error(h(321))}function kA(m,y){if(y===null)return!1;for(var O=0;O<y.length&&O<m.length;O++)if(!h1(m[O],y[O]))return!1;return!0}function OA(m,y,O,N,$,q){return hm=q,Ts=y,y.memoizedState=null,y.updateQueue=null,y.lanes=0,ae.H=m===null||m.memoizedState===null?j$:RA,Vy=!1,q=O(N,$),Vy=!1,y4&&(q=QR(y,O,N,$)),HR(m),q}function HR(m){ae.H=GO;var y=$c!==null&&$c.next!==null;if(hm=0,oa=$c=Ts=null,oj=!1,FO=0,x4=null,y)throw Error(h(300));m===null||Du||(m=m.dependencies,m!==null&&NO(m)&&(Du=!0))}function QR(m,y,O,N){Ts=m;var $=0;do{if(y4&&(x4=null),FO=0,y4=!1,25<=$)throw Error(h(301));if($+=1,oa=$c=null,m.updateQueue!=null){var q=m.updateQueue;q.lastEffect=null,q.events=null,q.stores=null,q.memoCache!=null&&(q.memoCache.index=0)}ae.H=BW,q=y(O,N)}while(y4);return q}function DW(){var m=ae.H,y=m.useState()[0];return y=typeof y.then=="function"?qO(y):y,m=m.useState()[0],($c!==null?$c.memoizedState:null)!==m&&(Ts.flags|=1024),y}function SA(){var m=cj!==0;return cj=0,m}function jA(m,y,O){y.updateQueue=m.updateQueue,y.flags&=-2053,m.lanes&=~O}function TA(m){if(oj){for(m=m.memoizedState;m!==null;){var y=m.queue;y!==null&&(y.pending=null),m=m.next}oj=!1}hm=0,oa=$c=Ts=null,y4=!1,FO=cj=0,x4=null}function Vh(){var m={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return oa===null?Ts.memoizedState=oa=m:oa=oa.next=m,oa}function _u(){if($c===null){var m=Ts.alternate;m=m!==null?m.memoizedState:null}else m=$c.next;var y=oa===null?Ts.memoizedState:oa.next;if(y!==null)oa=y,$c=m;else{if(m===null)throw Ts.alternate===null?Error(h(467)):Error(h(310));$c=m,m={memoizedState:$c.memoizedState,baseState:$c.baseState,baseQueue:$c.baseQueue,queue:$c.queue,next:null},oa===null?Ts.memoizedState=oa=m:oa=oa.next=m}return oa}function lj(){return{lastEffect:null,events:null,stores:null,memoCache:null}}function qO(m){var y=FO;return FO+=1,x4===null&&(x4=[]),m=LR(x4,m,y),y=Ts,(oa===null?y.memoizedState:oa.next)===null&&(y=y.alternate,ae.H=y===null||y.memoizedState===null?j$:RA),m}function uj(m){if(m!==null&&typeof m=="object"){if(typeof m.then=="function")return qO(m);if(m.$$typeof===ee)return Hf(m)}throw Error(h(438,String(m)))}function EA(m){var y=null,O=Ts.updateQueue;if(O!==null&&(y=O.memoCache),y==null){var N=Ts.alternate;N!==null&&(N=N.updateQueue,N!==null&&(N=N.memoCache,N!=null&&(y={data:N.data.map(function($){return $.slice()}),index:0})))}if(y==null&&(y={data:[],index:0}),O===null&&(O=lj(),Ts.updateQueue=O),O.memoCache=y,O=y.data[y.index],O===void 0)for(O=y.data[y.index]=Array(m),N=0;N<m;N++)O[N]=Ke;return y.index++,O}function dm(m,y){return typeof y=="function"?y(m):y}function aj(m){var y=_u();return CA(y,$c,m)}function CA(m,y,O){var N=m.queue;if(N===null)throw Error(h(311));N.lastRenderedReducer=O;var $=m.baseQueue,q=N.pending;if(q!==null){if($!==null){var le=$.next;$.next=q.next,q.next=le}y.baseQueue=$=q,N.pending=null}if(q=m.baseState,$===null)m.memoizedState=q;else{y=$.next;var Ce=le=null,dt=null,Ft=y,gn=!1;do{var xn=Ft.lane&-536870913;if(xn!==Ft.lane?(wo&xn)===xn:(hm&xn)===xn){var Zt=Ft.revertLane;if(Zt===0)dt!==null&&(dt=dt.next={lane:0,revertLane:0,gesture:null,action:Ft.action,hasEagerState:Ft.hasEagerState,eagerState:Ft.eagerState,next:null}),xn===p4&&(gn=!0);else if((hm&Zt)===Zt){Ft=Ft.next,Zt===p4&&(gn=!0);continue}else xn={lane:0,revertLane:Ft.revertLane,gesture:null,action:Ft.action,hasEagerState:Ft.hasEagerState,eagerState:Ft.eagerState,next:null},dt===null?(Ce=dt=xn,le=q):dt=dt.next=xn,Ts.lanes|=Zt,k2|=Zt;xn=Ft.action,Vy&&O(q,xn),q=Ft.hasEagerState?Ft.eagerState:O(q,xn)}else Zt={lane:xn,revertLane:Ft.revertLane,gesture:Ft.gesture,action:Ft.action,hasEagerState:Ft.hasEagerState,eagerState:Ft.eagerState,next:null},dt===null?(Ce=dt=Zt,le=q):dt=dt.next=Zt,Ts.lanes|=xn,k2|=xn;Ft=Ft.next}while(Ft!==null&&Ft!==y);if(dt===null?le=q:dt.next=Ce,!h1(q,m.memoizedState)&&(Du=!0,gn&&(O=b4,O!==null)))throw O;m.memoizedState=q,m.baseState=le,m.baseQueue=dt,N.lastRenderedState=q}return $===null&&(N.lanes=0),[m.memoizedState,N.dispatch]}function GR(m){var y=_u(),O=y.queue;if(O===null)throw Error(h(311));O.lastRenderedReducer=m;var N=O.dispatch,$=O.pending,q=y.memoizedState;if($!==null){O.pending=null;var le=$=$.next;do q=m(q,le.action),le=le.next;while(le!==$);h1(q,y.memoizedState)||(Du=!0),y.memoizedState=q,y.baseQueue===null&&(y.baseState=q),O.lastRenderedState=q}return[q,N]}function UR(m,y,O){var N=Ts,$=_u(),q=ko;if(q){if(O===void 0)throw Error(h(407));O=O()}else O=y();var le=!h1(($c||$).memoizedState,O);if(le&&($.memoizedState=O,Du=!0),$=$.queue,NA(VR.bind(null,N,$,m),[m]),$.getSnapshot!==y||le||oa!==null&&oa.memoizedState.tag&1){if(N.flags|=2048,k4(9,{destroy:void 0},XR.bind(null,N,$,O,y),null),Yc===null)throw Error(h(349));q||(hm&127)!==0||JR(N,y,O)}return O}function JR(m,y,O){m.flags|=16384,m={getSnapshot:y,value:O},y=Ts.updateQueue,y===null?(y=lj(),Ts.updateQueue=y,y.stores=[m]):(O=y.stores,O===null?y.stores=[m]:O.push(m))}function XR(m,y,O,N){y.value=O,y.getSnapshot=N,WR(y)&&KR(m)}function VR(m,y,O){return O(function(){WR(y)&&KR(m)})}function WR(m){var y=m.getSnapshot;m=m.value;try{var O=y();return!h1(m,O)}catch{return!0}}function KR(m){var y=Fy(m,2);y!==null&&Dd(y,m,2)}function MA(m){var y=Vh();if(typeof m=="function"){var O=m;if(m=O(),Vy){lg(!0);try{O()}finally{lg(!1)}}}return y.memoizedState=y.baseState=m,y.queue={pending:null,lanes:0,dispatch:null,lastRenderedReducer:dm,lastRenderedState:m},y}function YR(m,y,O,N){return m.baseState=O,CA(m,$c,typeof N=="function"?N:dm)}function LW(m,y,O,N,$){if(gj(m))throw Error(h(485));if(m=y.action,m!==null){var q={payload:$,action:m,next:null,isTransition:!0,status:"pending",value:null,reason:null,listeners:[],then:function(le){q.listeners.push(le)}};ae.T!==null?O(!0):q.isTransition=!1,N(q),O=y.pending,O===null?(q.next=y.pending=q,ZR(y,q)):(q.next=O.next,y.pending=O.next=q)}}function ZR(m,y){var O=y.action,N=y.payload,$=m.state;if(y.isTransition){var q=ae.T,le={};ae.T=le;try{var Ce=O($,N),dt=ae.S;dt!==null&&dt(le,Ce),e$(m,y,Ce)}catch(Ft){AA(m,y,Ft)}finally{q!==null&&le.types!==null&&(q.types=le.types),ae.T=q}}else try{q=O($,N),e$(m,y,q)}catch(Ft){AA(m,y,Ft)}}function e$(m,y,O){O!==null&&typeof O=="object"&&typeof O.then=="function"?O.then(function(N){t$(m,y,N)},function(N){return AA(m,y,N)}):t$(m,y,O)}function t$(m,y,O){y.status="fulfilled",y.value=O,n$(y),m.state=O,y=m.pending,y!==null&&(O=y.next,O===y?m.pending=null:(O=O.next,y.next=O,ZR(m,O)))}function AA(m,y,O){var N=m.pending;if(m.pending=null,N!==null){N=N.next;do y.status="rejected",y.reason=O,n$(y),y=y.next;while(y!==N)}m.action=null}function n$(m){m=m.listeners;for(var y=0;y<m.length;y++)(0,m[y])()}function i$(m,y){return y}function r$(m,y){if(ko){var O=Yc.formState;if(O!==null){e:{var N=Ts;if(ko){if(Sl){t:{for(var $=Sl,q=dg;$.nodeType!==8;){if(!q){$=null;break t}if($=bg($.nextSibling),$===null){$=null;break t}}q=$.data,$=q==="F!"||q==="F"?$:null}if($){Sl=bg($.nextSibling),N=$.data==="F!";break e}}a2(N)}N=!1}N&&(y=O[0])}}return O=Vh(),O.memoizedState=O.baseState=y,N={pending:null,lanes:0,dispatch:null,lastRenderedReducer:i$,lastRenderedState:y},O.queue=N,O=k$.bind(null,Ts,N),N.dispatch=O,N=MA(!1),q=IA.bind(null,Ts,!1,N.queue),N=Vh(),$={state:y,dispatch:null,action:m,pending:null},N.queue=$,O=LW.bind(null,Ts,$,q,O),$.dispatch=O,N.memoizedState=m,[y,O,!1]}function s$(m){var y=_u();return o$(y,$c,m)}function o$(m,y,O){if(y=CA(m,y,i$)[0],m=aj(dm)[0],typeof y=="object"&&y!==null&&typeof y.then=="function")try{var N=qO(y)}catch(le){throw le===m4?ej:le}else N=y;y=_u();var $=y.queue,q=$.dispatch;return O!==y.memoizedState&&(Ts.flags|=2048,k4(9,{destroy:void 0},PW.bind(null,$,O),null)),[N,q,m]}function PW(m,y){m.action=y}function c$(m){var y=_u(),O=$c;if(O!==null)return o$(y,O,m);_u(),y=y.memoizedState,O=_u();var N=O.queue.dispatch;return O.memoizedState=m,[y,N,!1]}function k4(m,y,O,N){return m={tag:m,create:O,deps:N,inst:y,next:null},y=Ts.updateQueue,y===null&&(y=lj(),Ts.updateQueue=y),O=y.lastEffect,O===null?y.lastEffect=m.next=m:(N=O.next,O.next=m,m.next=N,y.lastEffect=m),m}function l$(){return _u().memoizedState}function fj(m,y,O,N){var $=Vh();Ts.flags|=m,$.memoizedState=k4(1|y,{destroy:void 0},O,N===void 0?null:N)}function hj(m,y,O,N){var $=_u();N=N===void 0?null:N;var q=$.memoizedState.inst;$c!==null&&N!==null&&kA(N,$c.memoizedState.deps)?$.memoizedState=k4(y,q,O,N):(Ts.flags|=m,$.memoizedState=k4(1|y,q,O,N))}function u$(m,y){fj(8390656,8,m,y)}function NA(m,y){hj(2048,8,m,y)}function IW(m){Ts.flags|=4;var y=Ts.updateQueue;if(y===null)y=lj(),Ts.updateQueue=y,y.events=[m];else{var O=y.events;O===null?y.events=[m]:O.push(m)}}function a$(m){var y=_u().memoizedState;return IW({ref:y,nextImpl:m}),function(){if((rc&2)!==0)throw Error(h(440));return y.impl.apply(void 0,arguments)}}function f$(m,y){return hj(4,2,m,y)}function h$(m,y){return hj(4,4,m,y)}function d$(m,y){if(typeof y=="function"){m=m();var O=y(m);return function(){typeof O=="function"?O():y(null)}}if(y!=null)return m=m(),y.current=m,function(){y.current=null}}function g$(m,y,O){O=O!=null?O.concat([m]):null,hj(4,4,d$.bind(null,y,m),O)}function _A(){}function p$(m,y){var O=_u();y=y===void 0?null:y;var N=O.memoizedState;return y!==null&&kA(y,N[1])?N[0]:(O.memoizedState=[m,y],m)}function b$(m,y){var O=_u();y=y===void 0?null:y;var N=O.memoizedState;if(y!==null&&kA(y,N[1]))return N[0];if(N=m(),Vy){lg(!0);try{m()}finally{lg(!1)}}return O.memoizedState=[N,y],N}function DA(m,y,O){return O===void 0||(hm&1073741824)!==0&&(wo&261930)===0?m.memoizedState=y:(m.memoizedState=O,m=uB(),Ts.lanes|=m,k2|=m,O)}function m$(m,y,O,N){return h1(O,y)?O:v4.current!==null?(m=DA(m,O,N),h1(m,y)||(Du=!0),m):(hm&42)===0||(hm&1073741824)!==0&&(wo&261930)===0?(Du=!0,m.memoizedState=O):(m=uB(),Ts.lanes|=m,k2|=m,y)}function w$(m,y,O,N,$){var q=Le.p;Le.p=q!==0&&8>q?q:8;var le=ae.T,Ce={};ae.T=Ce,IA(m,!1,y,O);try{var dt=$(),Ft=ae.S;if(Ft!==null&&Ft(Ce,dt),dt!==null&&typeof dt=="object"&&typeof dt.then=="function"){var gn=NW(dt,N);QO(m,y,gn,v1(m))}else QO(m,y,N,v1(m))}catch(xn){QO(m,y,{then:function(){},status:"rejected",reason:xn},v1())}finally{Le.p=q,le!==null&&Ce.types!==null&&(le.types=Ce.types),ae.T=le}}function LA(){}function HO(m,y,O,N){if(m.tag!==5)throw Error(h(476));var $=v$(m).queue;w$(m,$,y,Oe,O===null?LA:function(){return dj(m),O(N)})}function v$(m){var y=m.memoizedState;if(y!==null)return y;y={memoizedState:Oe,baseState:Oe,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:dm,lastRenderedState:Oe},next:null};var O={};return y.next={memoizedState:O,baseState:O,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:dm,lastRenderedState:O},next:null},m.memoizedState=y,m=m.alternate,m!==null&&(m.memoizedState=y),y}function dj(m){var y=v$(m);y.next===null&&(y=m.alternate.memoizedState),QO(m,y.next.queue,{},v1())}function PA(){return Hf(o6)}function y$(){return _u().memoizedState}function x$(){return _u().memoizedState}function RW(m){for(var y=m.return;y!==null;){switch(y.tag){case 24:case 3:var O=v1();m=p2(O);var N=b2(y,m,O);N!==null&&(Dd(N,y,O),$O(N,y,O)),y={cache:aA()},m.payload=y;return}y=y.return}}function $W(m,y,O){var N=v1();O={lane:N,revertLane:0,gesture:null,action:O,hasEagerState:!1,eagerState:null,next:null},gj(m)?O$(y,O):(O=ZM(m,y,O,N),O!==null&&(Dd(O,m,N),S$(O,y,N)))}function k$(m,y,O){var N=v1();QO(m,y,O,N)}function QO(m,y,O,N){var $={lane:N,revertLane:0,gesture:null,action:O,hasEagerState:!1,eagerState:null,next:null};if(gj(m))O$(y,$);else{var q=m.alternate;if(m.lanes===0&&(q===null||q.lanes===0)&&(q=y.lastRenderedReducer,q!==null))try{var le=y.lastRenderedState,Ce=q(le,O);if($.hasEagerState=!0,$.eagerState=Ce,h1(Ce,le))return V8(m,y,$,0),Yc===null&&X8(),!1}catch{}finally{}if(O=ZM(m,y,$,N),O!==null)return Dd(O,m,N),S$(O,y,N),!0}return!1}function IA(m,y,O,N){if(N={lane:2,revertLane:pN(),gesture:null,action:N,hasEagerState:!1,eagerState:null,next:null},gj(m)){if(y)throw Error(h(479))}else y=ZM(m,O,N,2),y!==null&&Dd(y,m,2)}function gj(m){var y=m.alternate;return m===Ts||y!==null&&y===Ts}function O$(m,y){y4=oj=!0;var O=m.pending;O===null?y.next=y:(y.next=O.next,O.next=y),m.pending=y}function S$(m,y,O){if((O&4194048)!==0){var N=y.lanes;N&=m.pendingLanes,O|=N,y.lanes=O,pO(m,O)}}var GO={readContext:Hf,use:uj,useCallback:pu,useContext:pu,useEffect:pu,useImperativeHandle:pu,useLayoutEffect:pu,useInsertionEffect:pu,useMemo:pu,useReducer:pu,useRef:pu,useState:pu,useDebugValue:pu,useDeferredValue:pu,useTransition:pu,useSyncExternalStore:pu,useId:pu,useHostTransitionStatus:pu,useFormState:pu,useActionState:pu,useOptimistic:pu,useMemoCache:pu,useCacheRefresh:pu};GO.useEffectEvent=pu;var j$={readContext:Hf,use:uj,useCallback:function(m,y){return Vh().memoizedState=[m,y===void 0?null:y],m},useContext:Hf,useEffect:u$,useImperativeHandle:function(m,y,O){O=O!=null?O.concat([m]):null,fj(4194308,4,d$.bind(null,y,m),O)},useLayoutEffect:function(m,y){return fj(4194308,4,m,y)},useInsertionEffect:function(m,y){fj(4,2,m,y)},useMemo:function(m,y){var O=Vh();y=y===void 0?null:y;var N=m();if(Vy){lg(!0);try{m()}finally{lg(!1)}}return O.memoizedState=[N,y],N},useReducer:function(m,y,O){var N=Vh();if(O!==void 0){var $=O(y);if(Vy){lg(!0);try{O(y)}finally{lg(!1)}}}else $=y;return N.memoizedState=N.baseState=$,m={pending:null,lanes:0,dispatch:null,lastRenderedReducer:m,lastRenderedState:$},N.queue=m,m=m.dispatch=$W.bind(null,Ts,m),[N.memoizedState,m]},useRef:function(m){var y=Vh();return m={current:m},y.memoizedState=m},useState:function(m){m=MA(m);var y=m.queue,O=k$.bind(null,Ts,y);return y.dispatch=O,[m.memoizedState,O]},useDebugValue:_A,useDeferredValue:function(m,y){var O=Vh();return DA(O,m,y)},useTransition:function(){var m=MA(!1);return m=w$.bind(null,Ts,m.queue,!0,!1),Vh().memoizedState=m,[!1,m]},useSyncExternalStore:function(m,y,O){var N=Ts,$=Vh();if(ko){if(O===void 0)throw Error(h(407));O=O()}else{if(O=y(),Yc===null)throw Error(h(349));(wo&127)!==0||JR(N,y,O)}$.memoizedState=O;var q={value:O,getSnapshot:y};return $.queue=q,u$(VR.bind(null,N,q,m),[m]),N.flags|=2048,k4(9,{destroy:void 0},XR.bind(null,N,q,O,y),null),O},useId:function(){var m=Vh(),y=Yc.identifierPrefix;if(ko){var O=_p,N=Np;O=(N&~(1<<32-qf(N)-1)).toString(32)+O,y="_"+y+"R_"+O,O=cj++,0<O&&(y+="H"+O.toString(32)),y+="_"}else O=_W++,y="_"+y+"r_"+O.toString(32)+"_";return m.memoizedState=y},useHostTransitionStatus:PA,useFormState:r$,useActionState:r$,useOptimistic:function(m){var y=Vh();y.memoizedState=y.baseState=m;var O={pending:null,lanes:0,dispatch:null,lastRenderedReducer:null,lastRenderedState:null};return y.queue=O,y=IA.bind(null,Ts,!0,O),O.dispatch=y,[m,y]},useMemoCache:EA,useCacheRefresh:function(){return Vh().memoizedState=RW.bind(null,Ts)},useEffectEvent:function(m){var y=Vh(),O={impl:m};return y.memoizedState=O,function(){if((rc&2)!==0)throw Error(h(440));return O.impl.apply(void 0,arguments)}}},RA={readContext:Hf,use:uj,useCallback:p$,useContext:Hf,useEffect:NA,useImperativeHandle:g$,useInsertionEffect:f$,useLayoutEffect:h$,useMemo:b$,useReducer:aj,useRef:l$,useState:function(){return aj(dm)},useDebugValue:_A,useDeferredValue:function(m,y){var O=_u();return m$(O,$c.memoizedState,m,y)},useTransition:function(){var m=aj(dm)[0],y=_u().memoizedState;return[typeof m=="boolean"?m:qO(m),y]},useSyncExternalStore:UR,useId:y$,useHostTransitionStatus:PA,useFormState:s$,useActionState:s$,useOptimistic:function(m,y){var O=_u();return YR(O,$c,m,y)},useMemoCache:EA,useCacheRefresh:x$};RA.useEffectEvent=a$;var BW={readContext:Hf,use:uj,useCallback:p$,useContext:Hf,useEffect:NA,useImperativeHandle:g$,useInsertionEffect:f$,useLayoutEffect:h$,useMemo:b$,useReducer:GR,useRef:l$,useState:function(){return GR(dm)},useDebugValue:_A,useDeferredValue:function(m,y){var O=_u();return $c===null?DA(O,m,y):m$(O,$c.memoizedState,m,y)},useTransition:function(){var m=GR(dm)[0],y=_u().memoizedState;return[typeof m=="boolean"?m:qO(m),y]},useSyncExternalStore:UR,useId:y$,useHostTransitionStatus:PA,useFormState:c$,useActionState:c$,useOptimistic:function(m,y){var O=_u();return $c!==null?YR(O,$c,m,y):(O.baseState=m,[m,O.queue.dispatch])},useMemoCache:EA,useCacheRefresh:x$};BW.useEffectEvent=a$;function $A(m,y,O,N){y=m.memoizedState,O=O(N,y),O=O==null?y:D({},y,O),m.memoizedState=O,m.lanes===0&&(m.updateQueue.baseState=O)}var pj={enqueueSetState:function(m,y,O){m=m._reactInternals;var N=v1(),$=p2(N);$.payload=y,O!=null&&($.callback=O),y=b2(m,$,N),y!==null&&(Dd(y,m,N),$O(y,m,N))},enqueueReplaceState:function(m,y,O){m=m._reactInternals;var N=v1(),$=p2(N);$.tag=1,$.payload=y,O!=null&&($.callback=O),y=b2(m,$,N),y!==null&&(Dd(y,m,N),$O(y,m,N))},enqueueForceUpdate:function(m,y){m=m._reactInternals;var O=v1(),N=p2(O);N.tag=2,y!=null&&(N.callback=y),y=b2(m,N,O),y!==null&&(Dd(y,m,O),$O(y,m,O))}};function T$(m,y,O,N,$,q,le){return m=m.stateNode,typeof m.shouldComponentUpdate=="function"?m.shouldComponentUpdate(N,q,le):y.prototype&&y.prototype.isPureReactComponent?!CO(O,N)||!CO($,q):!0}function E$(m,y,O,N){m=y.state,typeof y.componentWillReceiveProps=="function"&&y.componentWillReceiveProps(O,N),typeof y.UNSAFE_componentWillReceiveProps=="function"&&y.UNSAFE_componentWillReceiveProps(O,N),y.state!==m&&pj.enqueueReplaceState(y,y.state,null)}function Wy(m,y){var O=y;if("ref"in y){O={};for(var N in y)N!=="ref"&&(O[N]=y[N])}if(m=m.defaultProps){O===y&&(O=D({},O));for(var $ in m)O[$]===void 0&&(O[$]=m[$])}return O}function C$(m){J8(m)}function M$(m){console.error(m)}function A$(m){J8(m)}function bj(m,y){try{var O=m.onUncaughtError;O(y.value,{componentStack:y.stack})}catch(N){setTimeout(function(){throw N})}}function N$(m,y,O){try{var N=m.onCaughtError;N(O.value,{componentStack:O.stack,errorBoundary:y.tag===1?y.stateNode:null})}catch($){setTimeout(function(){throw $})}}function BA(m,y,O){return O=p2(O),O.tag=3,O.payload={element:null},O.callback=function(){bj(m,y)},O}function _$(m){return m=p2(m),m.tag=3,m}function b1(m,y,O,N){var $=O.type.getDerivedStateFromError;if(typeof $=="function"){var q=N.value;m.payload=function(){return $(q)},m.callback=function(){N$(y,O,N)}}var le=O.stateNode;le!==null&&typeof le.componentDidCatch=="function"&&(m.callback=function(){N$(y,O,N),typeof $!="function"&&(O2===null?O2=new Set([this]):O2.add(this));var Ce=N.stack;this.componentDidCatch(N.value,{componentStack:Ce!==null?Ce:""})})}function zW(m,y,O,N,$){if(O.flags|=32768,N!==null&&typeof N=="object"&&typeof N.then=="function"){if(y=O.alternate,y!==null&&g4(y,O,$,!0),O=g1.current,O!==null){switch(O.tag){case 31:case 13:return gg===null?Cj():O.alternate===null&&bu===0&&(bu=3),O.flags&=-257,O.flags|=65536,O.lanes=$,N===tj?O.flags|=16384:(y=O.updateQueue,y===null?O.updateQueue=new Set([N]):y.add(N),hN(m,N,$)),!1;case 22:return O.flags|=65536,N===tj?O.flags|=16384:(y=O.updateQueue,y===null?(y={transitions:null,markerInstances:null,retryQueue:new Set([N])},O.updateQueue=y):(O=y.retryQueue,O===null?y.retryQueue=new Set([N]):O.add(N)),hN(m,N,$)),!1}throw Error(h(435,O.tag))}return hN(m,N,$),Cj(),!1}if(ko)return y=g1.current,y!==null?((y.flags&65536)===0&&(y.flags|=256),y.flags|=65536,y.lanes=$,N!==sA&&(m=Error(h(422),{cause:N}),f2(ag(m,O)))):(N!==sA&&(y=Error(h(423),{cause:N}),f2(ag(y,O))),m=m.current.alternate,m.flags|=65536,$&=-$,m.lanes|=$,N=ag(N,O),$=BA(m.stateNode,N,$),mA(m,$),bu!==4&&(bu=2)),!1;var q=Error(h(520),{cause:N});if(q=ag(q,O),ZO===null?ZO=[q]:ZO.push(q),bu!==4&&(bu=2),y===null)return!0;N=ag(N,O),O=y;do{switch(O.tag){case 3:return O.flags|=65536,m=$&-$,O.lanes|=m,m=BA(O.stateNode,N,m),mA(O,m),!1;case 1:if(y=O.type,q=O.stateNode,(O.flags&128)===0&&(typeof y.getDerivedStateFromError=="function"||q!==null&&typeof q.componentDidCatch=="function"&&(O2===null||!O2.has(q))))return O.flags|=65536,$&=-$,O.lanes|=$,$=_$($),b1($,m,O,N),mA(O,$),!1}O=O.return}while(O!==null);return!1}var Lp=Error(h(461)),Du=!1;function Qf(m,y,O,N){y.child=m===null?$R(y,null,O,N):Xy(y,m.child,O,N)}function D$(m,y,O,N,$){O=O.render;var q=y.ref;if("ref"in N){var le={};for(var Ce in N)Ce!=="ref"&&(le[Ce]=N[Ce])}else le=N;return d2(y),N=OA(m,y,O,le,q,$),Ce=SA(),m!==null&&!Du?(jA(m,y,$),gm(m,y,$)):(ko&&Ce&&iA(y),y.flags|=1,Qf(m,y,N,$),y.child)}function L$(m,y,O,N,$){if(m===null){var q=O.type;return typeof q=="function"&&!eA(q)&&q.defaultProps===void 0&&O.compare===null?(y.tag=15,y.type=q,P$(m,y,q,N,$)):(m=K8(O.type,null,N,y,y.mode,$),m.ref=y.ref,m.return=y,y.child=m)}if(q=m.child,!JA(m,$)){var le=q.memoizedProps;if(O=O.compare,O=O!==null?O:CO,O(le,N)&&m.ref===y.ref)return gm(m,y,$)}return y.flags|=1,m=um(q,N),m.ref=y.ref,m.return=y,y.child=m}function P$(m,y,O,N,$){if(m!==null){var q=m.memoizedProps;if(CO(q,N)&&m.ref===y.ref)if(Du=!1,y.pendingProps=N=q,JA(m,$))(m.flags&131072)!==0&&(Du=!0);else return y.lanes=m.lanes,gm(m,y,$)}return zA(m,y,O,N,$)}function I$(m,y,O,N){var $=N.children,q=m!==null?m.memoizedState:null;if(m===null&&y.stateNode===null&&(y.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),N.mode==="hidden"){if((y.flags&128)!==0){if(q=q!==null?q.baseLanes|O:O,m!==null){for(N=y.child=m.child,$=0;N!==null;)$=$|N.lanes|N.childLanes,N=N.sibling;N=$&~q}else N=0,y.child=null;return R$(m,y,q,O,N)}if((O&536870912)!==0)y.memoizedState={baseLanes:0,cachePool:null},m!==null&&Z8(y,q!==null?q.cachePool:null),q!==null?FR(y,q):vA(),qR(y);else return N=y.lanes=536870912,R$(m,y,q!==null?q.baseLanes|O:O,O,N)}else q!==null?(Z8(y,q.cachePool),FR(y,q),w2(),y.memoizedState=null):(m!==null&&Z8(y,null),vA(),w2());return Qf(m,y,$,O),y.child}function UO(m,y){return m!==null&&m.tag===22||y.stateNode!==null||(y.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),y.sibling}function R$(m,y,O,N,$){var q=hA();return q=q===null?null:{parent:sa._currentValue,pool:q},y.memoizedState={baseLanes:O,cachePool:q},m!==null&&Z8(y,null),vA(),qR(y),m!==null&&g4(m,y,N,!0),y.childLanes=$,null}function mj(m,y){return y=tt({mode:y.mode,children:y.children},m.mode),y.ref=m.ref,m.child=y,y.return=m,y}function $$(m,y,O){return Xy(y,m.child,null,O),m=mj(y,y.pendingProps),m.flags|=2,p1(y),y.memoizedState=null,m}function FW(m,y,O){var N=y.pendingProps,$=(y.flags&128)!==0;if(y.flags&=-129,m===null){if(ko){if(N.mode==="hidden")return m=mj(y,N),y.lanes=536870912,UO(null,m);if(xA(y),(m=Sl)?(m=UB(m,dg),m=m!==null&&m.data==="&"?m:null,m!==null&&(y.memoizedState={dehydrated:m,treeContext:l2!==null?{id:Np,overflow:_p}:null,retryLane:536870912,hydrationErrors:null},O=jR(m),O.return=y,y.child=O,cf=y,Sl=null)):m=null,m===null)throw a2(y);return y.lanes=536870912,null}return mj(y,N)}var q=m.memoizedState;if(q!==null){var le=q.dehydrated;if(xA(y),$)if(y.flags&256)y.flags&=-257,y=$$(m,y,O);else if(y.memoizedState!==null)y.child=m.child,y.flags|=128,y=null;else throw Error(h(558));else if(Du||g4(m,y,O,!1),$=(O&m.childLanes)!==0,Du||$){if(N=Yc,N!==null&&(le=M8(N,O),le!==0&&le!==q.retryLane))throw q.retryLane=le,Fy(m,le),Dd(N,m,le),Lp;Cj(),y=$$(m,y,O)}else m=q.treeContext,Sl=bg(le.nextSibling),cf=y,ko=!0,u2=null,dg=!1,m!==null&&CR(y,m),y=mj(y,N),y.flags|=4096;return y}return m=um(m.child,{mode:N.mode,children:N.children}),m.ref=y.ref,y.child=m,m.return=y,m}function wj(m,y){var O=y.ref;if(O===null)m!==null&&m.ref!==null&&(y.flags|=4194816);else{if(typeof O!="function"&&typeof O!="object")throw Error(h(284));(m===null||m.ref!==O)&&(y.flags|=4194816)}}function zA(m,y,O,N,$){return d2(y),O=OA(m,y,O,N,void 0,$),N=SA(),m!==null&&!Du?(jA(m,y,$),gm(m,y,$)):(ko&&N&&iA(y),y.flags|=1,Qf(m,y,O,$),y.child)}function B$(m,y,O,N,$,q){return d2(y),y.updateQueue=null,O=QR(y,N,O,$),HR(m),N=SA(),m!==null&&!Du?(jA(m,y,q),gm(m,y,q)):(ko&&N&&iA(y),y.flags|=1,Qf(m,y,O,q),y.child)}function z$(m,y,O,N,$){if(d2(y),y.stateNode===null){var q=u4,le=O.contextType;typeof le=="object"&&le!==null&&(q=Hf(le)),q=new O(N,q),y.memoizedState=q.state!==null&&q.state!==void 0?q.state:null,q.updater=pj,y.stateNode=q,q._reactInternals=y,q=y.stateNode,q.props=N,q.state=y.memoizedState,q.refs={},pA(y),le=O.contextType,q.context=typeof le=="object"&&le!==null?Hf(le):u4,q.state=y.memoizedState,le=O.getDerivedStateFromProps,typeof le=="function"&&($A(y,O,le,N),q.state=y.memoizedState),typeof O.getDerivedStateFromProps=="function"||typeof q.getSnapshotBeforeUpdate=="function"||typeof q.UNSAFE_componentWillMount!="function"&&typeof q.componentWillMount!="function"||(le=q.state,typeof q.componentWillMount=="function"&&q.componentWillMount(),typeof q.UNSAFE_componentWillMount=="function"&&q.UNSAFE_componentWillMount(),le!==q.state&&pj.enqueueReplaceState(q,q.state,null),zO(y,N,q,$),BO(),q.state=y.memoizedState),typeof q.componentDidMount=="function"&&(y.flags|=4194308),N=!0}else if(m===null){q=y.stateNode;var Ce=y.memoizedProps,dt=Wy(O,Ce);q.props=dt;var Ft=q.context,gn=O.contextType;le=u4,typeof gn=="object"&&gn!==null&&(le=Hf(gn));var xn=O.getDerivedStateFromProps;gn=typeof xn=="function"||typeof q.getSnapshotBeforeUpdate=="function",Ce=y.pendingProps!==Ce,gn||typeof q.UNSAFE_componentWillReceiveProps!="function"&&typeof q.componentWillReceiveProps!="function"||(Ce||Ft!==le)&&E$(y,q,N,le),g2=!1;var Zt=y.memoizedState;q.state=Zt,zO(y,N,q,$),BO(),Ft=y.memoizedState,Ce||Zt!==Ft||g2?(typeof xn=="function"&&($A(y,O,xn,N),Ft=y.memoizedState),(dt=g2||T$(y,O,dt,N,Zt,Ft,le))?(gn||typeof q.UNSAFE_componentWillMount!="function"&&typeof q.componentWillMount!="function"||(typeof q.componentWillMount=="function"&&q.componentWillMount(),typeof q.UNSAFE_componentWillMount=="function"&&q.UNSAFE_componentWillMount()),typeof q.componentDidMount=="function"&&(y.flags|=4194308)):(typeof q.componentDidMount=="function"&&(y.flags|=4194308),y.memoizedProps=N,y.memoizedState=Ft),q.props=N,q.state=Ft,q.context=le,N=dt):(typeof q.componentDidMount=="function"&&(y.flags|=4194308),N=!1)}else{q=y.stateNode,bA(m,y),le=y.memoizedProps,gn=Wy(O,le),q.props=gn,xn=y.pendingProps,Zt=q.context,Ft=O.contextType,dt=u4,typeof Ft=="object"&&Ft!==null&&(dt=Hf(Ft)),Ce=O.getDerivedStateFromProps,(Ft=typeof Ce=="function"||typeof q.getSnapshotBeforeUpdate=="function")||typeof q.UNSAFE_componentWillReceiveProps!="function"&&typeof q.componentWillReceiveProps!="function"||(le!==xn||Zt!==dt)&&E$(y,q,N,dt),g2=!1,Zt=y.memoizedState,q.state=Zt,zO(y,N,q,$),BO();var on=y.memoizedState;le!==xn||Zt!==on||g2||m!==null&&m.dependencies!==null&&NO(m.dependencies)?(typeof Ce=="function"&&($A(y,O,Ce,N),on=y.memoizedState),(gn=g2||T$(y,O,gn,N,Zt,on,dt)||m!==null&&m.dependencies!==null&&NO(m.dependencies))?(Ft||typeof q.UNSAFE_componentWillUpdate!="function"&&typeof q.componentWillUpdate!="function"||(typeof q.componentWillUpdate=="function"&&q.componentWillUpdate(N,on,dt),typeof q.UNSAFE_componentWillUpdate=="function"&&q.UNSAFE_componentWillUpdate(N,on,dt)),typeof q.componentDidUpdate=="function"&&(y.flags|=4),typeof q.getSnapshotBeforeUpdate=="function"&&(y.flags|=1024)):(typeof q.componentDidUpdate!="function"||le===m.memoizedProps&&Zt===m.memoizedState||(y.flags|=4),typeof q.getSnapshotBeforeUpdate!="function"||le===m.memoizedProps&&Zt===m.memoizedState||(y.flags|=1024),y.memoizedProps=N,y.memoizedState=on),q.props=N,q.state=on,q.context=dt,N=gn):(typeof q.componentDidUpdate!="function"||le===m.memoizedProps&&Zt===m.memoizedState||(y.flags|=4),typeof q.getSnapshotBeforeUpdate!="function"||le===m.memoizedProps&&Zt===m.memoizedState||(y.flags|=1024),N=!1)}return q=N,wj(m,y),N=(y.flags&128)!==0,q||N?(q=y.stateNode,O=N&&typeof O.getDerivedStateFromError!="function"?null:q.render(),y.flags|=1,m!==null&&N?(y.child=Xy(y,m.child,null,$),y.child=Xy(y,null,O,$)):Qf(m,y,O,$),y.memoizedState=q.state,m=y.child):m=gm(m,y,$),m}function F$(m,y,O,N){return Hy(),y.flags|=256,Qf(m,y,O,N),y.child}var FA={dehydrated:null,treeContext:null,retryLane:0,hydrationErrors:null};function qA(m){return{baseLanes:m,cachePool:DR()}}function HA(m,y,O){return m=m!==null?m.childLanes&~O:0,y&&(m|=w1),m}function q$(m,y,O){var N=y.pendingProps,$=!1,q=(y.flags&128)!==0,le;if((le=q)||(le=m!==null&&m.memoizedState===null?!1:(Nu.current&2)!==0),le&&($=!0,y.flags&=-129),le=(y.flags&32)!==0,y.flags&=-33,m===null){if(ko){if($?m2(y):w2(),(m=Sl)?(m=UB(m,dg),m=m!==null&&m.data!=="&"?m:null,m!==null&&(y.memoizedState={dehydrated:m,treeContext:l2!==null?{id:Np,overflow:_p}:null,retryLane:536870912,hydrationErrors:null},O=jR(m),O.return=y,y.child=O,cf=y,Sl=null)):m=null,m===null)throw a2(y);return MN(m)?y.lanes=32:y.lanes=536870912,null}var Ce=N.children;return N=N.fallback,$?(w2(),$=y.mode,Ce=tt({mode:"hidden",children:Ce},$),N=qy(N,$,O,null),Ce.return=y,N.return=y,Ce.sibling=N,y.child=Ce,N=y.child,N.memoizedState=qA(O),N.childLanes=HA(m,le,O),y.memoizedState=FA,UO(null,N)):(m2(y),QA(y,Ce))}var dt=m.memoizedState;if(dt!==null&&(Ce=dt.dehydrated,Ce!==null)){if(q)y.flags&256?(m2(y),y.flags&=-257,y=GA(m,y,O)):y.memoizedState!==null?(w2(),y.child=m.child,y.flags|=128,y=null):(w2(),Ce=N.fallback,$=y.mode,N=tt({mode:"visible",children:N.children},$),Ce=qy(Ce,$,O,null),Ce.flags|=2,N.return=y,Ce.return=y,N.sibling=Ce,y.child=N,Xy(y,m.child,null,O),N=y.child,N.memoizedState=qA(O),N.childLanes=HA(m,le,O),y.memoizedState=FA,y=UO(null,N));else if(m2(y),MN(Ce)){if(le=Ce.nextSibling&&Ce.nextSibling.dataset,le)var Ft=le.dgst;le=Ft,N=Error(h(419)),N.stack="",N.digest=le,f2({value:N,source:null,stack:null}),y=GA(m,y,O)}else if(Du||g4(m,y,O,!1),le=(O&m.childLanes)!==0,Du||le){if(le=Yc,le!==null&&(N=M8(le,O),N!==0&&N!==dt.retryLane))throw dt.retryLane=N,Fy(m,N),Dd(le,m,N),Lp;CN(Ce)||Cj(),y=GA(m,y,O)}else CN(Ce)?(y.flags|=192,y.child=m.child,y=null):(m=dt.treeContext,Sl=bg(Ce.nextSibling),cf=y,ko=!0,u2=null,dg=!1,m!==null&&CR(y,m),y=QA(y,N.children),y.flags|=4096);return y}return $?(w2(),Ce=N.fallback,$=y.mode,dt=m.child,Ft=dt.sibling,N=um(dt,{mode:"hidden",children:N.children}),N.subtreeFlags=dt.subtreeFlags&65011712,Ft!==null?Ce=um(Ft,Ce):(Ce=qy(Ce,$,O,null),Ce.flags|=2),Ce.return=y,N.return=y,N.sibling=Ce,y.child=N,UO(null,N),N=y.child,Ce=m.child.memoizedState,Ce===null?Ce=qA(O):($=Ce.cachePool,$!==null?(dt=sa._currentValue,$=$.parent!==dt?{parent:dt,pool:dt}:$):$=DR(),Ce={baseLanes:Ce.baseLanes|O,cachePool:$}),N.memoizedState=Ce,N.childLanes=HA(m,le,O),y.memoizedState=FA,UO(m.child,N)):(m2(y),O=m.child,m=O.sibling,O=um(O,{mode:"visible",children:N.children}),O.return=y,O.sibling=null,m!==null&&(le=y.deletions,le===null?(y.deletions=[m],y.flags|=16):le.push(m)),y.child=O,y.memoizedState=null,O)}function QA(m,y){return y=tt({mode:"visible",children:y},m.mode),y.return=m,m.child=y}function tt(m,y){return m=d1(22,m,null,y),m.lanes=0,m}function GA(m,y,O){return Xy(y,m.child,null,O),m=QA(y,y.pendingProps.children),m.flags|=2,y.memoizedState=null,m}function H$(m,y,O){m.lanes|=y;var N=m.alternate;N!==null&&(N.lanes|=y),cA(m.return,y,O)}function UA(m,y,O,N,$,q){var le=m.memoizedState;le===null?m.memoizedState={isBackwards:y,rendering:null,renderingStartTime:0,last:N,tail:O,tailMode:$,treeForkCount:q}:(le.isBackwards=y,le.rendering=null,le.renderingStartTime=0,le.last=N,le.tail=O,le.tailMode=$,le.treeForkCount=q)}function Q$(m,y,O){var N=y.pendingProps,$=N.revealOrder,q=N.tail;N=N.children;var le=Nu.current,Ce=(le&2)!==0;if(Ce?(le=le&1|2,y.flags|=128):le&=1,mt(Nu,le),Qf(m,y,N,O),N=ko?AO:0,!Ce&&m!==null&&(m.flags&128)!==0)e:for(m=y.child;m!==null;){if(m.tag===13)m.memoizedState!==null&&H$(m,O,y);else if(m.tag===19)H$(m,O,y);else if(m.child!==null){m.child.return=m,m=m.child;continue}if(m===y)break e;for(;m.sibling===null;){if(m.return===null||m.return===y)break e;m=m.return}m.sibling.return=m.return,m=m.sibling}switch($){case"forwards":for(O=y.child,$=null;O!==null;)m=O.alternate,m!==null&&sj(m)===null&&($=O),O=O.sibling;O=$,O===null?($=y.child,y.child=null):($=O.sibling,O.sibling=null),UA(y,!1,$,O,q,N);break;case"backwards":case"unstable_legacy-backwards":for(O=null,$=y.child,y.child=null;$!==null;){if(m=$.alternate,m!==null&&sj(m)===null){y.child=$;break}m=$.sibling,$.sibling=O,O=$,$=m}UA(y,!0,O,null,q,N);break;case"together":UA(y,!1,null,null,void 0,N);break;default:y.memoizedState=null}return y.child}function gm(m,y,O){if(m!==null&&(y.dependencies=m.dependencies),k2|=y.lanes,(O&y.childLanes)===0)if(m!==null){if(g4(m,y,O,!1),(O&y.childLanes)===0)return null}else return null;if(m!==null&&y.child!==m.child)throw Error(h(153));if(y.child!==null){for(m=y.child,O=um(m,m.pendingProps),y.child=O,O.return=y;m.sibling!==null;)m=m.sibling,O=O.sibling=um(m,m.pendingProps),O.return=y;O.sibling=null}return y.child}function JA(m,y){return(m.lanes&y)!==0?!0:(m=m.dependencies,!!(m!==null&&NO(m)))}function qW(m,y,O){switch(y.tag){case 3:Pn(y,y.stateNode.containerInfo),h2(y,sa,m.memoizedState.cache),Hy();break;case 27:case 5:er(y);break;case 4:Pn(y,y.stateNode.containerInfo);break;case 10:h2(y,y.type,y.memoizedProps.value);break;case 31:if(y.memoizedState!==null)return y.flags|=128,xA(y),null;break;case 13:var N=y.memoizedState;if(N!==null)return N.dehydrated!==null?(m2(y),y.flags|=128,null):(O&y.child.childLanes)!==0?q$(m,y,O):(m2(y),m=gm(m,y,O),m!==null?m.sibling:null);m2(y);break;case 19:var $=(m.flags&128)!==0;if(N=(O&y.childLanes)!==0,N||(g4(m,y,O,!1),N=(O&y.childLanes)!==0),$){if(N)return Q$(m,y,O);y.flags|=128}if($=y.memoizedState,$!==null&&($.rendering=null,$.tail=null,$.lastEffect=null),mt(Nu,Nu.current),N)break;return null;case 22:return y.lanes=0,I$(m,y,O,y.pendingProps);case 24:h2(y,sa,m.memoizedState.cache)}return gm(m,y,O)}function G$(m,y,O){if(m!==null)if(m.memoizedProps!==y.pendingProps)Du=!0;else{if(!JA(m,O)&&(y.flags&128)===0)return Du=!1,qW(m,y,O);Du=(m.flags&131072)!==0}else Du=!1,ko&&(y.flags&1048576)!==0&&ER(y,AO,y.index);switch(y.lanes=0,y.tag){case 16:e:{var N=y.pendingProps;if(m=Uy(y.elementType),y.type=m,typeof m=="function")eA(m)?(N=Wy(m,N),y.tag=1,y=z$(null,y,m,N,O)):(y.tag=0,y=zA(null,y,m,N,O));else{if(m!=null){var $=m.$$typeof;if($===ce){y.tag=11,y=D$(null,y,m,N,O);break e}else if($===me){y.tag=14,y=L$(null,y,m,N,O);break e}}throw y=ge(m)||m,Error(h(306,y,""))}}return y;case 0:return zA(m,y,y.type,y.pendingProps,O);case 1:return N=y.type,$=Wy(N,y.pendingProps),z$(m,y,N,$,O);case 3:e:{if(Pn(y,y.stateNode.containerInfo),m===null)throw Error(h(387));N=y.pendingProps;var q=y.memoizedState;$=q.element,bA(m,y),zO(y,N,null,O);var le=y.memoizedState;if(N=le.cache,h2(y,sa,N),N!==q.cache&&lA(y,[sa],O,!0),BO(),N=le.element,q.isDehydrated)if(q={element:N,isDehydrated:!1,cache:le.cache},y.updateQueue.baseState=q,y.memoizedState=q,y.flags&256){y=F$(m,y,N,O);break e}else if(N!==$){$=ag(Error(h(424)),y),f2($),y=F$(m,y,N,O);break e}else{switch(m=y.stateNode.containerInfo,m.nodeType){case 9:m=m.body;break;default:m=m.nodeName==="HTML"?m.ownerDocument.body:m}for(Sl=bg(m.firstChild),cf=y,ko=!0,u2=null,dg=!0,O=$R(y,null,N,O),y.child=O;O;)O.flags=O.flags&-3|4096,O=O.sibling}else{if(Hy(),N===$){y=gm(m,y,O);break e}Qf(m,y,N,O)}y=y.child}return y;case 26:return wj(m,y),m===null?(O=YB(y.type,null,y.pendingProps,null))?y.memoizedState=O:ko||(O=y.type,m=y.pendingProps,N=Pj(rn.current).createElement(O),N[Pa]=y,N[ph]=m,Uf(N,O,m),ra(N),y.stateNode=N):y.memoizedState=YB(y.type,m.memoizedProps,y.pendingProps,m.memoizedState),null;case 27:return er(y),m===null&&ko&&(N=y.stateNode=XB(y.type,y.pendingProps,rn.current),cf=y,dg=!0,$=Sl,E2(y.type)?(AN=$,Sl=bg(N.firstChild)):Sl=$),Qf(m,y,y.pendingProps.children,O),wj(m,y),m===null&&(y.flags|=4194304),y.child;case 5:return m===null&&ko&&(($=N=Sl)&&(N=gK(N,y.type,y.pendingProps,dg),N!==null?(y.stateNode=N,cf=y,Sl=bg(N.firstChild),dg=!1,$=!0):$=!1),$||a2(y)),er(y),$=y.type,q=y.pendingProps,le=m!==null?m.memoizedProps:null,N=q.children,jN($,q)?N=null:le!==null&&jN($,le)&&(y.flags|=32),y.memoizedState!==null&&($=OA(m,y,DW,null,null,O),o6._currentValue=$),wj(m,y),Qf(m,y,N,O),y.child;case 6:return m===null&&ko&&((m=O=Sl)&&(O=pK(O,y.pendingProps,dg),O!==null?(y.stateNode=O,cf=y,Sl=null,m=!0):m=!1),m||a2(y)),null;case 13:return q$(m,y,O);case 4:return Pn(y,y.stateNode.containerInfo),N=y.pendingProps,m===null?y.child=Xy(y,null,N,O):Qf(m,y,N,O),y.child;case 11:return D$(m,y,y.type,y.pendingProps,O);case 7:return Qf(m,y,y.pendingProps,O),y.child;case 8:return Qf(m,y,y.pendingProps.children,O),y.child;case 12:return Qf(m,y,y.pendingProps.children,O),y.child;case 10:return N=y.pendingProps,h2(y,y.type,N.value),Qf(m,y,N.children,O),y.child;case 9:return $=y.type._context,N=y.pendingProps.children,d2(y),$=Hf($),N=N($),y.flags|=1,Qf(m,y,N,O),y.child;case 14:return L$(m,y,y.type,y.pendingProps,O);case 15:return P$(m,y,y.type,y.pendingProps,O);case 19:return Q$(m,y,O);case 31:return FW(m,y,O);case 22:return I$(m,y,O,y.pendingProps);case 24:return d2(y),N=Hf(sa),m===null?($=hA(),$===null&&($=Yc,q=aA(),$.pooledCache=q,q.refCount++,q!==null&&($.pooledCacheLanes|=O),$=q),y.memoizedState={parent:N,cache:$},pA(y),h2(y,sa,$)):((m.lanes&O)!==0&&(bA(m,y),zO(y,null,null,O),BO()),$=m.memoizedState,q=y.memoizedState,$.parent!==N?($={parent:N,cache:N},y.memoizedState=$,y.lanes===0&&(y.memoizedState=y.updateQueue.baseState=$),h2(y,sa,N)):(N=q.cache,h2(y,sa,N),N!==$.cache&&lA(y,[sa],O,!0))),Qf(m,y,y.pendingProps.children,O),y.child;case 29:throw y.pendingProps}throw Error(h(156,y.tag))}function pm(m){m.flags|=4}function XA(m,y,O,N,$){if((y=(m.mode&32)!==0)&&(y=!1),y){if(m.flags|=16777216,($&335544128)===$)if(m.stateNode.complete)m.flags|=8192;else if(dB())m.flags|=8192;else throw Jy=tj,dA}else m.flags&=-16777217}function U$(m,y){if(y.type!=="stylesheet"||(y.state.loading&4)!==0)m.flags&=-16777217;else if(m.flags|=16777216,!nz(y))if(dB())m.flags|=8192;else throw Jy=tj,dA}function O4(m,y){y!==null&&(m.flags|=4),m.flags&16384&&(y=m.tag!==22?_y():536870912,m.lanes|=y,C4|=y)}function JO(m,y){if(!ko)switch(m.tailMode){case"hidden":y=m.tail;for(var O=null;y!==null;)y.alternate!==null&&(O=y),y=y.sibling;O===null?m.tail=null:O.sibling=null;break;case"collapsed":O=m.tail;for(var N=null;O!==null;)O.alternate!==null&&(N=O),O=O.sibling;N===null?y||m.tail===null?m.tail=null:m.tail.sibling=null:N.sibling=null}}function jl(m){var y=m.alternate!==null&&m.alternate.child===m.child,O=0,N=0;if(y)for(var $=m.child;$!==null;)O|=$.lanes|$.childLanes,N|=$.subtreeFlags&65011712,N|=$.flags&65011712,$.return=m,$=$.sibling;else for($=m.child;$!==null;)O|=$.lanes|$.childLanes,N|=$.subtreeFlags,N|=$.flags,$.return=m,$=$.sibling;return m.subtreeFlags|=N,m.childLanes=O,y}function VA(m,y,O){var N=y.pendingProps;switch(rA(y),y.tag){case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return jl(y),null;case 1:return jl(y),null;case 3:return O=y.stateNode,N=null,m!==null&&(N=m.memoizedState.cache),y.memoizedState.cache!==N&&(y.flags|=2048),fm(sa),mi(),O.pendingContext&&(O.context=O.pendingContext,O.pendingContext=null),(m===null||m.child===null)&&(h4(y)?pm(y):m===null||m.memoizedState.isDehydrated&&(y.flags&256)===0||(y.flags|=1024,d4())),jl(y),null;case 26:var $=y.type,q=y.memoizedState;return m===null?(pm(y),q!==null?(jl(y),U$(y,q)):(jl(y),XA(y,$,null,N,O))):q?q!==m.memoizedState?(pm(y),jl(y),U$(y,q)):(jl(y),y.flags&=-16777217):(m=m.memoizedProps,m!==N&&pm(y),jl(y),XA(y,$,m,N,O)),null;case 27:if(Mr(y),O=rn.current,$=y.type,m!==null&&y.stateNode!=null)m.memoizedProps!==N&&pm(y);else{if(!N){if(y.stateNode===null)throw Error(h(166));return jl(y),null}m=Ue.current,h4(y)?MR(y):(m=XB($,N,O),y.stateNode=m,pm(y))}return jl(y),null;case 5:if(Mr(y),$=y.type,m!==null&&y.stateNode!=null)m.memoizedProps!==N&&pm(y);else{if(!N){if(y.stateNode===null)throw Error(h(166));return jl(y),null}if(q=Ue.current,h4(y))MR(y);else{var le=Pj(rn.current);switch(q){case 1:q=le.createElementNS("http://www.w3.org/2000/svg",$);break;case 2:q=le.createElementNS("http://www.w3.org/1998/Math/MathML",$);break;default:switch($){case"svg":q=le.createElementNS("http://www.w3.org/2000/svg",$);break;case"math":q=le.createElementNS("http://www.w3.org/1998/Math/MathML",$);break;case"script":q=le.createElement("div"),q.innerHTML="<script><\/script>",q=q.removeChild(q.firstChild);break;case"select":q=typeof N.is=="string"?le.createElement("select",{is:N.is}):le.createElement("select"),N.multiple?q.multiple=!0:N.size&&(q.size=N.size);break;default:q=typeof N.is=="string"?le.createElement($,{is:N.is}):le.createElement($)}}q[Pa]=y,q[ph]=N;e:for(le=y.child;le!==null;){if(le.tag===5||le.tag===6)q.appendChild(le.stateNode);else if(le.tag!==4&&le.tag!==27&&le.child!==null){le.child.return=le,le=le.child;continue}if(le===y)break e;for(;le.sibling===null;){if(le.return===null||le.return===y)break e;le=le.return}le.sibling.return=le.return,le=le.sibling}y.stateNode=q;e:switch(Uf(q,$,N),$){case"button":case"input":case"select":case"textarea":N=!!N.autoFocus;break e;case"img":N=!0;break e;default:N=!1}N&&pm(y)}}return jl(y),XA(y,y.type,m===null?null:m.memoizedProps,y.pendingProps,O),null;case 6:if(m&&y.stateNode!=null)m.memoizedProps!==N&&pm(y);else{if(typeof N!="string"&&y.stateNode===null)throw Error(h(166));if(m=rn.current,h4(y)){if(m=y.stateNode,O=y.memoizedProps,N=null,$=cf,$!==null)switch($.tag){case 27:case 5:N=$.memoizedProps}m[Pa]=y,m=!!(m.nodeValue===O||N!==null&&N.suppressHydrationWarning===!0||$B(m.nodeValue,O)),m||a2(y,!0)}else m=Pj(m).createTextNode(N),m[Pa]=y,y.stateNode=m}return jl(y),null;case 31:if(O=y.memoizedState,m===null||m.memoizedState!==null){if(N=h4(y),O!==null){if(m===null){if(!N)throw Error(h(318));if(m=y.memoizedState,m=m!==null?m.dehydrated:null,!m)throw Error(h(557));m[Pa]=y}else Hy(),(y.flags&128)===0&&(y.memoizedState=null),y.flags|=4;jl(y),m=!1}else O=d4(),m!==null&&m.memoizedState!==null&&(m.memoizedState.hydrationErrors=O),m=!0;if(!m)return y.flags&256?(p1(y),y):(p1(y),null);if((y.flags&128)!==0)throw Error(h(558))}return jl(y),null;case 13:if(N=y.memoizedState,m===null||m.memoizedState!==null&&m.memoizedState.dehydrated!==null){if($=h4(y),N!==null&&N.dehydrated!==null){if(m===null){if(!$)throw Error(h(318));if($=y.memoizedState,$=$!==null?$.dehydrated:null,!$)throw Error(h(317));$[Pa]=y}else Hy(),(y.flags&128)===0&&(y.memoizedState=null),y.flags|=4;jl(y),$=!1}else $=d4(),m!==null&&m.memoizedState!==null&&(m.memoizedState.hydrationErrors=$),$=!0;if(!$)return y.flags&256?(p1(y),y):(p1(y),null)}return p1(y),(y.flags&128)!==0?(y.lanes=O,y):(O=N!==null,m=m!==null&&m.memoizedState!==null,O&&(N=y.child,$=null,N.alternate!==null&&N.alternate.memoizedState!==null&&N.alternate.memoizedState.cachePool!==null&&($=N.alternate.memoizedState.cachePool.pool),q=null,N.memoizedState!==null&&N.memoizedState.cachePool!==null&&(q=N.memoizedState.cachePool.pool),q!==$&&(N.flags|=2048)),O!==m&&O&&(y.child.flags|=8192),O4(y,y.updateQueue),jl(y),null);case 4:return mi(),m===null&&yN(y.stateNode.containerInfo),jl(y),null;case 10:return fm(y.type),jl(y),null;case 19:if(Ye(Nu),N=y.memoizedState,N===null)return jl(y),null;if($=(y.flags&128)!==0,q=N.rendering,q===null)if($)JO(N,!1);else{if(bu!==0||m!==null&&(m.flags&128)!==0)for(m=y.child;m!==null;){if(q=sj(m),q!==null){for(y.flags|=128,JO(N,!1),m=q.updateQueue,y.updateQueue=m,O4(y,m),y.subtreeFlags=0,m=O,O=y.child;O!==null;)SR(O,m),O=O.sibling;return mt(Nu,Nu.current&1|2),ko&&am(y,N.treeForkCount),y.child}m=m.sibling}N.tail!==null&&eu()>jj&&(y.flags|=128,$=!0,JO(N,!1),y.lanes=4194304)}else{if(!$)if(m=sj(q),m!==null){if(y.flags|=128,$=!0,m=m.updateQueue,y.updateQueue=m,O4(y,m),JO(N,!0),N.tail===null&&N.tailMode==="hidden"&&!q.alternate&&!ko)return jl(y),null}else 2*eu()-N.renderingStartTime>jj&&O!==536870912&&(y.flags|=128,$=!0,JO(N,!1),y.lanes=4194304);N.isBackwards?(q.sibling=y.child,y.child=q):(m=N.last,m!==null?m.sibling=q:y.child=q,N.last=q)}return N.tail!==null?(m=N.tail,N.rendering=m,N.tail=m.sibling,N.renderingStartTime=eu(),m.sibling=null,O=Nu.current,mt(Nu,$?O&1|2:O&1),ko&&am(y,N.treeForkCount),m):(jl(y),null);case 22:case 23:return p1(y),yA(),N=y.memoizedState!==null,m!==null?m.memoizedState!==null!==N&&(y.flags|=8192):N&&(y.flags|=8192),N?(O&536870912)!==0&&(y.flags&128)===0&&(jl(y),y.subtreeFlags&6&&(y.flags|=8192)):jl(y),O=y.updateQueue,O!==null&&O4(y,O.retryQueue),O=null,m!==null&&m.memoizedState!==null&&m.memoizedState.cachePool!==null&&(O=m.memoizedState.cachePool.pool),N=null,y.memoizedState!==null&&y.memoizedState.cachePool!==null&&(N=y.memoizedState.cachePool.pool),N!==O&&(y.flags|=2048),m!==null&&Ye(Gy),null;case 24:return O=null,m!==null&&(O=m.memoizedState.cache),y.memoizedState.cache!==O&&(y.flags|=2048),fm(sa),jl(y),null;case 25:return null;case 30:return null}throw Error(h(156,y.tag))}function HW(m,y){switch(rA(y),y.tag){case 1:return m=y.flags,m&65536?(y.flags=m&-65537|128,y):null;case 3:return fm(sa),mi(),m=y.flags,(m&65536)!==0&&(m&128)===0?(y.flags=m&-65537|128,y):null;case 26:case 27:case 5:return Mr(y),null;case 31:if(y.memoizedState!==null){if(p1(y),y.alternate===null)throw Error(h(340));Hy()}return m=y.flags,m&65536?(y.flags=m&-65537|128,y):null;case 13:if(p1(y),m=y.memoizedState,m!==null&&m.dehydrated!==null){if(y.alternate===null)throw Error(h(340));Hy()}return m=y.flags,m&65536?(y.flags=m&-65537|128,y):null;case 19:return Ye(Nu),null;case 4:return mi(),null;case 10:return fm(y.type),null;case 22:case 23:return p1(y),yA(),m!==null&&Ye(Gy),m=y.flags,m&65536?(y.flags=m&-65537|128,y):null;case 24:return fm(sa),null;case 25:return null;default:return null}}function J$(m,y){switch(rA(y),y.tag){case 3:fm(sa),mi();break;case 26:case 27:case 5:Mr(y);break;case 4:mi();break;case 31:y.memoizedState!==null&&p1(y);break;case 13:p1(y);break;case 19:Ye(Nu);break;case 10:fm(y.type);break;case 22:case 23:p1(y),yA(),m!==null&&Ye(Gy);break;case 24:fm(sa)}}function XO(m,y){try{var O=y.updateQueue,N=O!==null?O.lastEffect:null;if(N!==null){var $=N.next;O=$;do{if((O.tag&m)===m){N=void 0;var q=O.create,le=O.inst;N=q(),le.destroy=N}O=O.next}while(O!==$)}}catch(Ce){Oc(y,y.return,Ce)}}function v2(m,y,O){try{var N=y.updateQueue,$=N!==null?N.lastEffect:null;if($!==null){var q=$.next;N=q;do{if((N.tag&m)===m){var le=N.inst,Ce=le.destroy;if(Ce!==void 0){le.destroy=void 0,$=y;var dt=O,Ft=Ce;try{Ft()}catch(gn){Oc($,dt,gn)}}}N=N.next}while(N!==q)}}catch(gn){Oc(y,y.return,gn)}}function vj(m){var y=m.updateQueue;if(y!==null){var O=m.stateNode;try{zR(y,O)}catch(N){Oc(m,m.return,N)}}}function VO(m,y,O){O.props=Wy(m.type,m.memoizedProps),O.state=m.memoizedState;try{O.componentWillUnmount()}catch(N){Oc(m,y,N)}}function y2(m,y){try{var O=m.ref;if(O!==null){switch(m.tag){case 26:case 27:case 5:var N=m.stateNode;break;case 30:N=m.stateNode;break;default:N=m.stateNode}typeof O=="function"?m.refCleanup=O(N):O.current=N}}catch($){Oc(m,y,$)}}function Pp(m,y){var O=m.ref,N=m.refCleanup;if(O!==null)if(typeof N=="function")try{N()}catch($){Oc(m,y,$)}finally{m.refCleanup=null,m=m.alternate,m!=null&&(m.refCleanup=null)}else if(typeof O=="function")try{O(null)}catch($){Oc(m,y,$)}else O.current=null}function WA(m){var y=m.type,O=m.memoizedProps,N=m.stateNode;try{e:switch(y){case"button":case"input":case"select":case"textarea":O.autoFocus&&N.focus();break e;case"img":O.src?N.src=O.src:O.srcSet&&(N.srcset=O.srcSet)}}catch($){Oc(m,m.return,$)}}function KA(m,y,O){try{var N=m.stateNode;lK(N,m.type,O,y),N[ph]=y}catch($){Oc(m,m.return,$)}}function X$(m){return m.tag===5||m.tag===3||m.tag===26||m.tag===27&&E2(m.type)||m.tag===4}function S4(m){e:for(;;){for(;m.sibling===null;){if(m.return===null||X$(m.return))return null;m=m.return}for(m.sibling.return=m.return,m=m.sibling;m.tag!==5&&m.tag!==6&&m.tag!==18;){if(m.tag===27&&E2(m.type)||m.flags&2||m.child===null||m.tag===4)continue e;m.child.return=m,m=m.child}if(!(m.flags&2))return m.stateNode}}function YA(m,y,O){var N=m.tag;if(N===5||N===6)m=m.stateNode,y?(O.nodeType===9?O.body:O.nodeName==="HTML"?O.ownerDocument.body:O).insertBefore(m,y):(y=O.nodeType===9?O.body:O.nodeName==="HTML"?O.ownerDocument.body:O,y.appendChild(m),O=O._reactRootContainer,O!=null||y.onclick!==null||(y.onclick=cm));else if(N!==4&&(N===27&&E2(m.type)&&(O=m.stateNode,y=null),m=m.child,m!==null))for(YA(m,y,O),m=m.sibling;m!==null;)YA(m,y,O),m=m.sibling}function yj(m,y,O){var N=m.tag;if(N===5||N===6)m=m.stateNode,y?O.insertBefore(m,y):O.appendChild(m);else if(N!==4&&(N===27&&E2(m.type)&&(O=m.stateNode),m=m.child,m!==null))for(yj(m,y,O),m=m.sibling;m!==null;)yj(m,y,O),m=m.sibling}function V$(m){var y=m.stateNode,O=m.memoizedProps;try{for(var N=m.type,$=y.attributes;$.length;)y.removeAttributeNode($[0]);Uf(y,N,O),y[Pa]=m,y[ph]=O}catch(q){Oc(m,m.return,q)}}var pg=!1,ca=!1,ZA=!1,W$=typeof WeakSet=="function"?WeakSet:Set,lf=null;function xj(m,y){if(m=m.containerInfo,ON=l6,m=pR(m),JM(m)){if("selectionStart"in m)var O={start:m.selectionStart,end:m.selectionEnd};else e:{O=(O=m.ownerDocument)&&O.defaultView||window;var N=O.getSelection&&O.getSelection();if(N&&N.rangeCount!==0){O=N.anchorNode;var $=N.anchorOffset,q=N.focusNode;N=N.focusOffset;try{O.nodeType,q.nodeType}catch{O=null;break e}var le=0,Ce=-1,dt=-1,Ft=0,gn=0,xn=m,Zt=null;t:for(;;){for(var on;xn!==O||$!==0&&xn.nodeType!==3||(Ce=le+$),xn!==q||N!==0&&xn.nodeType!==3||(dt=le+N),xn.nodeType===3&&(le+=xn.nodeValue.length),(on=xn.firstChild)!==null;)Zt=xn,xn=on;for(;;){if(xn===m)break t;if(Zt===O&&++Ft===$&&(Ce=le),Zt===q&&++gn===N&&(dt=le),(on=xn.nextSibling)!==null)break;xn=Zt,Zt=xn.parentNode}xn=on}O=Ce===-1||dt===-1?null:{start:Ce,end:dt}}else O=null}O=O||{start:0,end:0}}else O=null;for(SN={focusedElem:m,selectionRange:O},l6=!1,lf=y;lf!==null;)if(y=lf,m=y.child,(y.subtreeFlags&1028)!==0&&m!==null)m.return=y,lf=m;else for(;lf!==null;){switch(y=lf,q=y.alternate,m=y.flags,y.tag){case 0:if((m&4)!==0&&(m=y.updateQueue,m=m!==null?m.events:null,m!==null))for(O=0;O<m.length;O++)$=m[O],$.ref.impl=$.nextImpl;break;case 11:case 15:break;case 1:if((m&1024)!==0&&q!==null){m=void 0,O=y,$=q.memoizedProps,q=q.memoizedState,N=O.stateNode;try{var Wi=Wy(O.type,$);m=N.getSnapshotBeforeUpdate(Wi,q),N.__reactInternalSnapshotBeforeUpdate=m}catch(qr){Oc(O,O.return,qr)}}break;case 3:if((m&1024)!==0){if(m=y.stateNode.containerInfo,O=m.nodeType,O===9)EN(m);else if(O===1)switch(m.nodeName){case"HEAD":case"HTML":case"BODY":EN(m);break;default:m.textContent=""}}break;case 5:case 26:case 27:case 6:case 4:case 17:break;default:if((m&1024)!==0)throw Error(h(163))}if(m=y.sibling,m!==null){m.return=y.return,lf=m;break}lf=y.return}}function K$(m,y,O){var N=O.flags;switch(O.tag){case 0:case 11:case 15:bm(m,O),N&4&&XO(5,O);break;case 1:if(bm(m,O),N&4)if(m=O.stateNode,y===null)try{m.componentDidMount()}catch(le){Oc(O,O.return,le)}else{var $=Wy(O.type,y.memoizedProps);y=y.memoizedState;try{m.componentDidUpdate($,y,m.__reactInternalSnapshotBeforeUpdate)}catch(le){Oc(O,O.return,le)}}N&64&&vj(O),N&512&&y2(O,O.return);break;case 3:if(bm(m,O),N&64&&(m=O.updateQueue,m!==null)){if(y=null,O.child!==null)switch(O.child.tag){case 27:case 5:y=O.child.stateNode;break;case 1:y=O.child.stateNode}try{zR(m,y)}catch(le){Oc(O,O.return,le)}}break;case 27:y===null&&N&4&&V$(O);case 26:case 5:bm(m,O),y===null&&N&4&&WA(O),N&512&&y2(O,O.return);break;case 12:bm(m,O);break;case 31:bm(m,O),N&4&&Z$(m,O);break;case 13:bm(m,O),N&4&&eB(m,O),N&64&&(m=O.memoizedState,m!==null&&(m=m.dehydrated,m!==null&&(O=YW.bind(null,O),bK(m,O))));break;case 22:if(N=O.memoizedState!==null||pg,!N){y=y!==null&&y.memoizedState!==null||ca,$=pg;var q=ca;pg=N,(ca=y)&&!q?mm(m,O,(O.subtreeFlags&8772)!==0):bm(m,O),pg=$,ca=q}break;case 30:break;default:bm(m,O)}}function eN(m){var y=m.alternate;y!==null&&(m.alternate=null,eN(y)),m.child=null,m.deletions=null,m.sibling=null,m.tag===5&&(y=m.stateNode,y!==null&&wO(y)),m.stateNode=null,m.return=null,m.dependencies=null,m.memoizedProps=null,m.memoizedState=null,m.pendingProps=null,m.stateNode=null,m.updateQueue=null}var zl=null,bh=!1;function Ip(m,y,O){for(O=O.child;O!==null;)Y$(m,y,O),O=O.sibling}function Y$(m,y,O){if(Ff&&typeof Ff.onCommitFiberUnmount=="function")try{Ff.onCommitFiberUnmount(Cp,O)}catch{}switch(O.tag){case 26:ca||Pp(O,y),Ip(m,y,O),O.memoizedState?O.memoizedState.count--:O.stateNode&&(O=O.stateNode,O.parentNode.removeChild(O));break;case 27:ca||Pp(O,y);var N=zl,$=bh;E2(O.type)&&(zl=O.stateNode,bh=!1),Ip(m,y,O),D4(O.stateNode),zl=N,bh=$;break;case 5:ca||Pp(O,y);case 6:if(N=zl,$=bh,zl=null,Ip(m,y,O),zl=N,bh=$,zl!==null)if(bh)try{(zl.nodeType===9?zl.body:zl.nodeName==="HTML"?zl.ownerDocument.body:zl).removeChild(O.stateNode)}catch(q){Oc(O,y,q)}else try{zl.removeChild(O.stateNode)}catch(q){Oc(O,y,q)}break;case 18:zl!==null&&(bh?(m=zl,QB(m.nodeType===9?m.body:m.nodeName==="HTML"?m.ownerDocument.body:m,O.stateNode),tx(m)):QB(zl,O.stateNode));break;case 4:N=zl,$=bh,zl=O.stateNode.containerInfo,bh=!0,Ip(m,y,O),zl=N,bh=$;break;case 0:case 11:case 14:case 15:v2(2,O,y),ca||v2(4,O,y),Ip(m,y,O);break;case 1:ca||(Pp(O,y),N=O.stateNode,typeof N.componentWillUnmount=="function"&&VO(O,y,N)),Ip(m,y,O);break;case 21:Ip(m,y,O);break;case 22:ca=(N=ca)||O.memoizedState!==null,Ip(m,y,O),ca=N;break;default:Ip(m,y,O)}}function Z$(m,y){if(y.memoizedState===null&&(m=y.alternate,m!==null&&(m=m.memoizedState,m!==null))){m=m.dehydrated;try{tx(m)}catch(O){Oc(y,y.return,O)}}}function eB(m,y){if(y.memoizedState===null&&(m=y.alternate,m!==null&&(m=m.memoizedState,m!==null&&(m=m.dehydrated,m!==null))))try{tx(m)}catch(O){Oc(y,y.return,O)}}function QW(m){switch(m.tag){case 31:case 13:case 19:var y=m.stateNode;return y===null&&(y=m.stateNode=new W$),y;case 22:return m=m.stateNode,y=m._retryCache,y===null&&(y=m._retryCache=new W$),y;default:throw Error(h(435,m.tag))}}function tN(m,y){var O=QW(m);y.forEach(function(N){if(!O.has(N)){O.add(N);var $=ZW.bind(null,m,N);N.then($,$)}})}function Ad(m,y){var O=y.deletions;if(O!==null)for(var N=0;N<O.length;N++){var $=O[N],q=m,le=y,Ce=le;e:for(;Ce!==null;){switch(Ce.tag){case 27:if(E2(Ce.type)){zl=Ce.stateNode,bh=!1;break e}break;case 5:zl=Ce.stateNode,bh=!1;break e;case 3:case 4:zl=Ce.stateNode.containerInfo,bh=!0;break e}Ce=Ce.return}if(zl===null)throw Error(h(160));Y$(q,le,$),zl=null,bh=!1,q=$.alternate,q!==null&&(q.return=null),$.return=null}if(y.subtreeFlags&13886)for(y=y.child;y!==null;)tB(y,m),y=y.sibling}var p0=null;function tB(m,y){var O=m.alternate,N=m.flags;switch(m.tag){case 0:case 11:case 14:case 15:Ad(y,m),Nd(m),N&4&&(v2(3,m,m.return),XO(3,m),v2(5,m,m.return));break;case 1:Ad(y,m),Nd(m),N&512&&(ca||O===null||Pp(O,O.return)),N&64&&pg&&(m=m.updateQueue,m!==null&&(N=m.callbacks,N!==null&&(O=m.shared.hiddenCallbacks,m.shared.hiddenCallbacks=O===null?N:O.concat(N))));break;case 26:var $=p0;if(Ad(y,m),Nd(m),N&512&&(ca||O===null||Pp(O,O.return)),N&4){var q=O!==null?O.memoizedState:null;if(N=m.memoizedState,O===null)if(N===null)if(m.stateNode===null){e:{N=m.type,O=m.memoizedProps,$=$.ownerDocument||$;t:switch(N){case"title":q=$.getElementsByTagName("title")[0],(!q||q[Ly]||q[Pa]||q.namespaceURI==="http://www.w3.org/2000/svg"||q.hasAttribute("itemprop"))&&(q=$.createElement(N),$.head.insertBefore(q,$.querySelector("head > title"))),Uf(q,N,O),q[Pa]=m,ra(q),N=q;break e;case"link":var le=tz("link","href",$).get(N+(O.href||""));if(le){for(var Ce=0;Ce<le.length;Ce++)if(q=le[Ce],q.getAttribute("href")===(O.href==null||O.href===""?null:O.href)&&q.getAttribute("rel")===(O.rel==null?null:O.rel)&&q.getAttribute("title")===(O.title==null?null:O.title)&&q.getAttribute("crossorigin")===(O.crossOrigin==null?null:O.crossOrigin)){le.splice(Ce,1);break t}}q=$.createElement(N),Uf(q,N,O),$.head.appendChild(q);break;case"meta":if(le=tz("meta","content",$).get(N+(O.content||""))){for(Ce=0;Ce<le.length;Ce++)if(q=le[Ce],q.getAttribute("content")===(O.content==null?null:""+O.content)&&q.getAttribute("name")===(O.name==null?null:O.name)&&q.getAttribute("property")===(O.property==null?null:O.property)&&q.getAttribute("http-equiv")===(O.httpEquiv==null?null:O.httpEquiv)&&q.getAttribute("charset")===(O.charSet==null?null:O.charSet)){le.splice(Ce,1);break t}}q=$.createElement(N),Uf(q,N,O),$.head.appendChild(q);break;default:throw Error(h(468,N))}q[Pa]=m,ra(q),N=q}m.stateNode=N}else $j($,m.type,m.stateNode);else m.stateNode=ez($,N,m.memoizedProps);else q!==N?(q===null?O.stateNode!==null&&(O=O.stateNode,O.parentNode.removeChild(O)):q.count--,N===null?$j($,m.type,m.stateNode):ez($,N,m.memoizedProps)):N===null&&m.stateNode!==null&&KA(m,m.memoizedProps,O.memoizedProps)}break;case 27:Ad(y,m),Nd(m),N&512&&(ca||O===null||Pp(O,O.return)),O!==null&&N&4&&KA(m,m.memoizedProps,O.memoizedProps);break;case 5:if(Ad(y,m),Nd(m),N&512&&(ca||O===null||Pp(O,O.return)),m.flags&32){$=m.stateNode;try{n4($,"")}catch(Wi){Oc(m,m.return,Wi)}}N&4&&m.stateNode!=null&&($=m.memoizedProps,KA(m,$,O!==null?O.memoizedProps:$)),N&1024&&(ZA=!0);break;case 6:if(Ad(y,m),Nd(m),N&4){if(m.stateNode===null)throw Error(h(162));N=m.memoizedProps,O=m.stateNode;try{O.nodeValue=N}catch(Wi){Oc(m,m.return,Wi)}}break;case 3:if($4=null,$=p0,p0=Ij(y.containerInfo),Ad(y,m),p0=$,Nd(m),N&4&&O!==null&&O.memoizedState.isDehydrated)try{tx(y.containerInfo)}catch(Wi){Oc(m,m.return,Wi)}ZA&&(ZA=!1,nB(m));break;case 4:N=p0,p0=Ij(m.stateNode.containerInfo),Ad(y,m),Nd(m),p0=N;break;case 12:Ad(y,m),Nd(m);break;case 31:Ad(y,m),Nd(m),N&4&&(N=m.updateQueue,N!==null&&(m.updateQueue=null,tN(m,N)));break;case 13:Ad(y,m),Nd(m),m.child.flags&8192&&m.memoizedState!==null!=(O!==null&&O.memoizedState!==null)&&(Sj=eu()),N&4&&(N=m.updateQueue,N!==null&&(m.updateQueue=null,tN(m,N)));break;case 22:$=m.memoizedState!==null;var dt=O!==null&&O.memoizedState!==null,Ft=pg,gn=ca;if(pg=Ft||$,ca=gn||dt,Ad(y,m),ca=gn,pg=Ft,Nd(m),N&8192)e:for(y=m.stateNode,y._visibility=$?y._visibility&-2:y._visibility|1,$&&(O===null||dt||pg||ca||Ky(m)),O=null,y=m;;){if(y.tag===5||y.tag===26){if(O===null){dt=O=y;try{if(q=dt.stateNode,$)le=q.style,typeof le.setProperty=="function"?le.setProperty("display","none","important"):le.display="none";else{Ce=dt.stateNode;var xn=dt.memoizedProps.style,Zt=xn!=null&&xn.hasOwnProperty("display")?xn.display:null;Ce.style.display=Zt==null||typeof Zt=="boolean"?"":(""+Zt).trim()}}catch(Wi){Oc(dt,dt.return,Wi)}}}else if(y.tag===6){if(O===null){dt=y;try{dt.stateNode.nodeValue=$?"":dt.memoizedProps}catch(Wi){Oc(dt,dt.return,Wi)}}}else if(y.tag===18){if(O===null){dt=y;try{var on=dt.stateNode;$?GB(on,!0):GB(dt.stateNode,!1)}catch(Wi){Oc(dt,dt.return,Wi)}}}else if((y.tag!==22&&y.tag!==23||y.memoizedState===null||y===m)&&y.child!==null){y.child.return=y,y=y.child;continue}if(y===m)break e;for(;y.sibling===null;){if(y.return===null||y.return===m)break e;O===y&&(O=null),y=y.return}O===y&&(O=null),y.sibling.return=y.return,y=y.sibling}N&4&&(N=m.updateQueue,N!==null&&(O=N.retryQueue,O!==null&&(N.retryQueue=null,tN(m,O))));break;case 19:Ad(y,m),Nd(m),N&4&&(N=m.updateQueue,N!==null&&(m.updateQueue=null,tN(m,N)));break;case 30:break;case 21:break;default:Ad(y,m),Nd(m)}}function Nd(m){var y=m.flags;if(y&2){try{for(var O,N=m.return;N!==null;){if(X$(N)){O=N;break}N=N.return}if(O==null)throw Error(h(160));switch(O.tag){case 27:var $=O.stateNode,q=S4(m);yj(m,q,$);break;case 5:var le=O.stateNode;O.flags&32&&(n4(le,""),O.flags&=-33);var Ce=S4(m);yj(m,Ce,le);break;case 3:case 4:var dt=O.stateNode.containerInfo,Ft=S4(m);YA(m,Ft,dt);break;default:throw Error(h(161))}}catch(gn){Oc(m,m.return,gn)}m.flags&=-3}y&4096&&(m.flags&=-4097)}function nB(m){if(m.subtreeFlags&1024)for(m=m.child;m!==null;){var y=m;nB(y),y.tag===5&&y.flags&1024&&y.stateNode.reset(),m=m.sibling}}function bm(m,y){if(y.subtreeFlags&8772)for(y=y.child;y!==null;)K$(m,y.alternate,y),y=y.sibling}function Ky(m){for(m=m.child;m!==null;){var y=m;switch(y.tag){case 0:case 11:case 14:case 15:v2(4,y,y.return),Ky(y);break;case 1:Pp(y,y.return);var O=y.stateNode;typeof O.componentWillUnmount=="function"&&VO(y,y.return,O),Ky(y);break;case 27:D4(y.stateNode);case 26:case 5:Pp(y,y.return),Ky(y);break;case 22:y.memoizedState===null&&Ky(y);break;case 30:Ky(y);break;default:Ky(y)}m=m.sibling}}function mm(m,y,O){for(O=O&&(y.subtreeFlags&8772)!==0,y=y.child;y!==null;){var N=y.alternate,$=m,q=y,le=q.flags;switch(q.tag){case 0:case 11:case 15:mm($,q,O),XO(4,q);break;case 1:if(mm($,q,O),N=q,$=N.stateNode,typeof $.componentDidMount=="function")try{$.componentDidMount()}catch(Ft){Oc(N,N.return,Ft)}if(N=q,$=N.updateQueue,$!==null){var Ce=N.stateNode;try{var dt=$.shared.hiddenCallbacks;if(dt!==null)for($.shared.hiddenCallbacks=null,$=0;$<dt.length;$++)BR(dt[$],Ce)}catch(Ft){Oc(N,N.return,Ft)}}O&&le&64&&vj(q),y2(q,q.return);break;case 27:V$(q);case 26:case 5:mm($,q,O),O&&N===null&&le&4&&WA(q),y2(q,q.return);break;case 12:mm($,q,O);break;case 31:mm($,q,O),O&&le&4&&Z$($,q);break;case 13:mm($,q,O),O&&le&4&&eB($,q);break;case 22:q.memoizedState===null&&mm($,q,O),y2(q,q.return);break;case 30:break;default:mm($,q,O)}y=y.sibling}}function nN(m,y){var O=null;m!==null&&m.memoizedState!==null&&m.memoizedState.cachePool!==null&&(O=m.memoizedState.cachePool.pool),m=null,y.memoizedState!==null&&y.memoizedState.cachePool!==null&&(m=y.memoizedState.cachePool.pool),m!==O&&(m!=null&&m.refCount++,O!=null&&LO(O))}function iN(m,y){m=null,y.alternate!==null&&(m=y.alternate.memoizedState.cache),y=y.memoizedState.cache,y!==m&&(y.refCount++,m!=null&&LO(m))}function Gf(m,y,O,N){if(y.subtreeFlags&10256)for(y=y.child;y!==null;)kj(m,y,O,N),y=y.sibling}function kj(m,y,O,N){var $=y.flags;switch(y.tag){case 0:case 11:case 15:Gf(m,y,O,N),$&2048&&XO(9,y);break;case 1:Gf(m,y,O,N);break;case 3:Gf(m,y,O,N),$&2048&&(m=null,y.alternate!==null&&(m=y.alternate.memoizedState.cache),y=y.memoizedState.cache,y!==m&&(y.refCount++,m!=null&&LO(m)));break;case 12:if($&2048){Gf(m,y,O,N),m=y.stateNode;try{var q=y.memoizedProps,le=q.id,Ce=q.onPostCommit;typeof Ce=="function"&&Ce(le,y.alternate===null?"mount":"update",m.passiveEffectDuration,-0)}catch(dt){Oc(y,y.return,dt)}}else Gf(m,y,O,N);break;case 31:Gf(m,y,O,N);break;case 13:Gf(m,y,O,N);break;case 23:break;case 22:q=y.stateNode,le=y.alternate,y.memoizedState!==null?q._visibility&2?Gf(m,y,O,N):WO(m,y):q._visibility&2?Gf(m,y,O,N):(q._visibility|=2,j4(m,y,O,N,(y.subtreeFlags&10256)!==0||!1)),$&2048&&nN(le,y);break;case 24:Gf(m,y,O,N),$&2048&&iN(y.alternate,y);break;default:Gf(m,y,O,N)}}function j4(m,y,O,N,$){for($=$&&((y.subtreeFlags&10256)!==0||!1),y=y.child;y!==null;){var q=m,le=y,Ce=O,dt=N,Ft=le.flags;switch(le.tag){case 0:case 11:case 15:j4(q,le,Ce,dt,$),XO(8,le);break;case 23:break;case 22:var gn=le.stateNode;le.memoizedState!==null?gn._visibility&2?j4(q,le,Ce,dt,$):WO(q,le):(gn._visibility|=2,j4(q,le,Ce,dt,$)),$&&Ft&2048&&nN(le.alternate,le);break;case 24:j4(q,le,Ce,dt,$),$&&Ft&2048&&iN(le.alternate,le);break;default:j4(q,le,Ce,dt,$)}y=y.sibling}}function WO(m,y){if(y.subtreeFlags&10256)for(y=y.child;y!==null;){var O=m,N=y,$=N.flags;switch(N.tag){case 22:WO(O,N),$&2048&&nN(N.alternate,N);break;case 24:WO(O,N),$&2048&&iN(N.alternate,N);break;default:WO(O,N)}y=y.sibling}}var KO=8192;function T4(m,y,O){if(m.subtreeFlags&KO)for(m=m.child;m!==null;)iB(m,y,O),m=m.sibling}function iB(m,y,O){switch(m.tag){case 26:T4(m,y,O),m.flags&KO&&m.memoizedState!==null&&OK(O,p0,m.memoizedState,m.memoizedProps);break;case 5:T4(m,y,O);break;case 3:case 4:var N=p0;p0=Ij(m.stateNode.containerInfo),T4(m,y,O),p0=N;break;case 22:m.memoizedState===null&&(N=m.alternate,N!==null&&N.memoizedState!==null?(N=KO,KO=16777216,T4(m,y,O),KO=N):T4(m,y,O));break;default:T4(m,y,O)}}function rB(m){var y=m.alternate;if(y!==null&&(m=y.child,m!==null)){y.child=null;do y=m.sibling,m.sibling=null,m=y;while(m!==null)}}function YO(m){var y=m.deletions;if((m.flags&16)!==0){if(y!==null)for(var O=0;O<y.length;O++){var N=y[O];lf=N,oB(N,m)}rB(m)}if(m.subtreeFlags&10256)for(m=m.child;m!==null;)sB(m),m=m.sibling}function sB(m){switch(m.tag){case 0:case 11:case 15:YO(m),m.flags&2048&&v2(9,m,m.return);break;case 3:YO(m);break;case 12:YO(m);break;case 22:var y=m.stateNode;m.memoizedState!==null&&y._visibility&2&&(m.return===null||m.return.tag!==13)?(y._visibility&=-3,Oj(m)):YO(m);break;default:YO(m)}}function Oj(m){var y=m.deletions;if((m.flags&16)!==0){if(y!==null)for(var O=0;O<y.length;O++){var N=y[O];lf=N,oB(N,m)}rB(m)}for(m=m.child;m!==null;){switch(y=m,y.tag){case 0:case 11:case 15:v2(8,y,y.return),Oj(y);break;case 22:O=y.stateNode,O._visibility&2&&(O._visibility&=-3,Oj(y));break;default:Oj(y)}m=m.sibling}}function oB(m,y){for(;lf!==null;){var O=lf;switch(O.tag){case 0:case 11:case 15:v2(8,O,y);break;case 23:case 22:if(O.memoizedState!==null&&O.memoizedState.cachePool!==null){var N=O.memoizedState.cachePool.pool;N!=null&&N.refCount++}break;case 24:LO(O.memoizedState.cache)}if(N=O.child,N!==null)N.return=O,lf=N;else e:for(O=m;lf!==null;){N=lf;var $=N.sibling,q=N.return;if(eN(N),N===O){lf=null;break e}if($!==null){$.return=q,lf=$;break e}lf=q}}}var GW={getCacheForType:function(m){var y=Hf(sa),O=y.data.get(m);return O===void 0&&(O=m(),y.data.set(m,O)),O},cacheSignal:function(){return Hf(sa).controller.signal}},UW=typeof WeakMap=="function"?WeakMap:Map,rc=0,Yc=null,ro=null,wo=0,kc=0,m1=null,x2=!1,E4=!1,rN=!1,wm=0,bu=0,k2=0,Yy=0,sN=0,w1=0,C4=0,ZO=null,_d=null,oN=!1,Sj=0,cB=0,jj=1/0,Tj=null,O2=null,Ia=0,S2=null,M4=null,vm=0,cN=0,lN=null,lB=null,e6=0,uN=null;function v1(){return(rc&2)!==0&&wo!==0?wo&-wo:ae.T!==null?pN():A8()}function uB(){if(w1===0)if((wo&536870912)===0||ko){var m=Zw;Zw<<=1,(Zw&3932160)===0&&(Zw=262144),w1=m}else w1=536870912;return m=g1.current,m!==null&&(m.flags|=32),w1}function Dd(m,y,O){(m===Yc&&(kc===2||kc===9)||m.cancelPendingCommit!==null)&&(A4(m,0),j2(m,wo,w1,!1)),gu(m,O),((rc&2)===0||m!==Yc)&&(m===Yc&&((rc&2)===0&&(Yy|=O),bu===4&&j2(m,wo,w1,!1)),Rp(m))}function aB(m,y,O){if((rc&6)!==0)throw Error(h(327));var N=!O&&(y&127)===0&&(y&m.expiredLanes)===0||im(m,y),$=N?VW(m,y):fN(m,y,!0),q=N;do{if($===0){E4&&!N&&j2(m,y,0,!1);break}else{if(O=m.current.alternate,q&&!JW(O)){$=fN(m,y,!1),q=!1;continue}if($===2){if(q=y,m.errorRecoveryDisabledLanes&q)var le=0;else le=m.pendingLanes&-536870913,le=le!==0?le:le&536870912?536870912:0;if(le!==0){y=le;e:{var Ce=m;$=ZO;var dt=Ce.current.memoizedState.isDehydrated;if(dt&&(A4(Ce,le).flags|=256),le=fN(Ce,le,!1),le!==2){if(rN&&!dt){Ce.errorRecoveryDisabledLanes|=q,Yy|=q,$=4;break e}q=_d,_d=$,q!==null&&(_d===null?_d=q:_d.push.apply(_d,q))}$=le}if(q=!1,$!==2)continue}}if($===1){A4(m,0),j2(m,y,0,!0);break}e:{switch(N=m,q=$,q){case 0:case 1:throw Error(h(345));case 4:if((y&4194048)!==y)break;case 6:j2(N,y,w1,!x2);break e;case 2:_d=null;break;case 3:case 5:break;default:throw Error(h(329))}if((y&62914560)===y&&($=Sj+300-eu(),10<$)){if(j2(N,y,w1,!x2),t2(N,0,!0)!==0)break e;vm=y,N.timeoutHandle=qB(fB.bind(null,N,O,_d,Tj,oN,y,w1,Yy,C4,x2,q,"Throttled",-0,0),$);break e}fB(N,O,_d,Tj,oN,y,w1,Yy,C4,x2,q,null,-0,0)}}break}while(!0);Rp(m)}function fB(m,y,O,N,$,q,le,Ce,dt,Ft,gn,xn,Zt,on){if(m.timeoutHandle=-1,xn=y.subtreeFlags,xn&8192||(xn&16785408)===16785408){xn={stylesheets:null,count:0,imgCount:0,imgBytes:0,suspenseyImages:[],waitingForImages:!0,waitingForViewTransition:!1,unsuspend:cm},iB(y,q,xn);var Wi=(q&62914560)===q?Sj-eu():(q&4194048)===q?cB-eu():0;if(Wi=SK(xn,Wi),Wi!==null){vm=q,m.cancelPendingCommit=Wi(vB.bind(null,m,y,q,O,N,$,le,Ce,dt,gn,xn,null,Zt,on)),j2(m,q,le,!Ft);return}}vB(m,y,q,O,N,$,le,Ce,dt)}function JW(m){for(var y=m;;){var O=y.tag;if((O===0||O===11||O===15)&&y.flags&16384&&(O=y.updateQueue,O!==null&&(O=O.stores,O!==null)))for(var N=0;N<O.length;N++){var $=O[N],q=$.getSnapshot;$=$.value;try{if(!h1(q(),$))return!1}catch{return!1}}if(O=y.child,y.subtreeFlags&16384&&O!==null)O.return=y,y=O;else{if(y===m)break;for(;y.sibling===null;){if(y.return===null||y.return===m)return!0;y=y.return}y.sibling.return=y.return,y=y.sibling}}return!0}function j2(m,y,O,N){y&=~sN,y&=~Yy,m.suspendedLanes|=y,m.pingedLanes&=~y,N&&(m.warmLanes|=y),N=m.expirationTimes;for(var $=y;0<$;){var q=31-qf($),le=1<<q;N[q]=-1,$&=~le}O!==0&&h0(m,O,y)}function Ej(){return(rc&6)===0?(t6(0),!1):!0}function aN(){if(ro!==null){if(kc===0)var m=ro.return;else m=ro,Dp=Qy=null,TA(m),w4=null,IO=0,m=ro;for(;m!==null;)J$(m.alternate,m),m=m.return;ro=null}}function A4(m,y){var O=m.timeoutHandle;O!==-1&&(m.timeoutHandle=-1,fK(O)),O=m.cancelPendingCommit,O!==null&&(m.cancelPendingCommit=null,O()),vm=0,aN(),Yc=m,ro=O=um(m.current,null),wo=y,kc=0,m1=null,x2=!1,E4=im(m,y),rN=!1,C4=w1=sN=Yy=k2=bu=0,_d=ZO=null,oN=!1,(y&8)!==0&&(y|=y&32);var N=m.entangledLanes;if(N!==0)for(m=m.entanglements,N&=y;0<N;){var $=31-qf(N),q=1<<$;y|=m[$],N&=~q}return wm=y,X8(),O}function hB(m,y){Ts=null,ae.H=GO,y===m4||y===ej?(y=PR(),kc=3):y===dA?(y=PR(),kc=4):kc=y===Lp?8:y!==null&&typeof y=="object"&&typeof y.then=="function"?6:1,m1=y,ro===null&&(bu=1,bj(m,ag(y,m.current)))}function dB(){var m=g1.current;return m===null?!0:(wo&4194048)===wo?gg===null:(wo&62914560)===wo||(wo&536870912)!==0?m===gg:!1}function gB(){var m=ae.H;return ae.H=GO,m===null?GO:m}function pB(){var m=ae.A;return ae.A=GW,m}function Cj(){bu=4,x2||(wo&4194048)!==wo&&g1.current!==null||(E4=!0),(k2&134217727)===0&&(Yy&134217727)===0||Yc===null||j2(Yc,wo,w1,!1)}function fN(m,y,O){var N=rc;rc|=2;var $=gB(),q=pB();(Yc!==m||wo!==y)&&(Tj=null,A4(m,y)),y=!1;var le=bu;e:do try{if(kc!==0&&ro!==null){var Ce=ro,dt=m1;switch(kc){case 8:aN(),le=6;break e;case 3:case 2:case 9:case 6:g1.current===null&&(y=!0);var Ft=kc;if(kc=0,m1=null,N4(m,Ce,dt,Ft),O&&E4){le=0;break e}break;default:Ft=kc,kc=0,m1=null,N4(m,Ce,dt,Ft)}}XW(),le=bu;break}catch(gn){hB(m,gn)}while(!0);return y&&m.shellSuspendCounter++,Dp=Qy=null,rc=N,ae.H=$,ae.A=q,ro===null&&(Yc=null,wo=0,X8()),le}function XW(){for(;ro!==null;)bB(ro)}function VW(m,y){var O=rc;rc|=2;var N=gB(),$=pB();Yc!==m||wo!==y?(Tj=null,jj=eu()+500,A4(m,y)):E4=im(m,y);e:do try{if(kc!==0&&ro!==null){y=ro;var q=m1;t:switch(kc){case 1:kc=0,m1=null,N4(m,y,q,1);break;case 2:case 9:if(gA(q)){kc=0,m1=null,mB(y);break}y=function(){kc!==2&&kc!==9||Yc!==m||(kc=7),Rp(m)},q.then(y,y);break e;case 3:kc=7;break e;case 4:kc=5;break e;case 7:gA(q)?(kc=0,m1=null,mB(y)):(kc=0,m1=null,N4(m,y,q,7));break;case 5:var le=null;switch(ro.tag){case 26:le=ro.memoizedState;case 5:case 27:var Ce=ro;if(le?nz(le):Ce.stateNode.complete){kc=0,m1=null;var dt=Ce.sibling;if(dt!==null)ro=dt;else{var Ft=Ce.return;Ft!==null?(ro=Ft,Mj(Ft)):ro=null}break t}}kc=0,m1=null,N4(m,y,q,5);break;case 6:kc=0,m1=null,N4(m,y,q,6);break;case 8:aN(),bu=6;break e;default:throw Error(h(462))}}WW();break}catch(gn){hB(m,gn)}while(!0);return Dp=Qy=null,ae.H=N,ae.A=$,rc=O,ro!==null?0:(Yc=null,wo=0,X8(),bu)}function WW(){for(;ro!==null&&!f1();)bB(ro)}function bB(m){var y=G$(m.alternate,m,wm);m.memoizedProps=m.pendingProps,y===null?Mj(m):ro=y}function mB(m){var y=m,O=y.alternate;switch(y.tag){case 15:case 0:y=B$(O,y,y.pendingProps,y.type,void 0,wo);break;case 11:y=B$(O,y,y.pendingProps,y.type.render,y.ref,wo);break;case 5:TA(y);default:J$(O,y),y=ro=SR(y,wm),y=G$(O,y,wm)}m.memoizedProps=m.pendingProps,y===null?Mj(m):ro=y}function N4(m,y,O,N){Dp=Qy=null,TA(y),w4=null,IO=0;var $=y.return;try{if(zW(m,$,y,O,wo)){bu=1,bj(m,ag(O,m.current)),ro=null;return}}catch(q){if($!==null)throw ro=$,q;bu=1,bj(m,ag(O,m.current)),ro=null;return}y.flags&32768?(ko||N===1?m=!0:E4||(wo&536870912)!==0?m=!1:(x2=m=!0,(N===2||N===9||N===3||N===6)&&(N=g1.current,N!==null&&N.tag===13&&(N.flags|=16384))),wB(y,m)):Mj(y)}function Mj(m){var y=m;do{if((y.flags&32768)!==0){wB(y,x2);return}m=y.return;var O=VA(y.alternate,y,wm);if(O!==null){ro=O;return}if(y=y.sibling,y!==null){ro=y;return}ro=y=m}while(y!==null);bu===0&&(bu=5)}function wB(m,y){do{var O=HW(m.alternate,m);if(O!==null){O.flags&=32767,ro=O;return}if(O=m.return,O!==null&&(O.flags|=32768,O.subtreeFlags=0,O.deletions=null),!y&&(m=m.sibling,m!==null)){ro=m;return}ro=m=O}while(m!==null);bu=6,ro=null}function vB(m,y,O,N,$,q,le,Ce,dt){m.cancelPendingCommit=null;do Aj();while(Ia!==0);if((rc&6)!==0)throw Error(h(327));if(y!==null){if(y===m.current)throw Error(h(177));if(q=y.lanes|y.childLanes,q|=YM,gh(m,O,q,le,Ce,dt),m===Yc&&(ro=Yc=null,wo=0),M4=y,S2=m,vm=O,cN=q,lN=$,lB=N,(y.subtreeFlags&10256)!==0||(y.flags&10256)!==0?(m.callbackNode=null,m.callbackPriority=0,eK(zf,function(){return SB(),null})):(m.callbackNode=null,m.callbackPriority=0),N=(y.flags&13878)!==0,(y.subtreeFlags&13878)!==0||N){N=ae.T,ae.T=null,$=Le.p,Le.p=2,le=rc,rc|=4;try{xj(m,y,O)}finally{rc=le,Le.p=$,ae.T=N}}Ia=1,yB(),xB(),kB()}}function yB(){if(Ia===1){Ia=0;var m=S2,y=M4,O=(y.flags&13878)!==0;if((y.subtreeFlags&13878)!==0||O){O=ae.T,ae.T=null;var N=Le.p;Le.p=2;var $=rc;rc|=4;try{tB(y,m);var q=SN,le=pR(m.containerInfo),Ce=q.focusedElem,dt=q.selectionRange;if(le!==Ce&&Ce&&Ce.ownerDocument&&gR(Ce.ownerDocument.documentElement,Ce)){if(dt!==null&&JM(Ce)){var Ft=dt.start,gn=dt.end;if(gn===void 0&&(gn=Ft),"selectionStart"in Ce)Ce.selectionStart=Ft,Ce.selectionEnd=Math.min(gn,Ce.value.length);else{var xn=Ce.ownerDocument||document,Zt=xn&&xn.defaultView||window;if(Zt.getSelection){var on=Zt.getSelection(),Wi=Ce.textContent.length,qr=Math.min(dt.start,Wi),Zc=dt.end===void 0?qr:Math.min(dt.end,Wi);!on.extend&&qr>Zc&&(le=Zc,Zc=qr,qr=le);var At=dR(Ce,qr),yt=dR(Ce,Zc);if(At&&yt&&(on.rangeCount!==1||on.anchorNode!==At.node||on.anchorOffset!==At.offset||on.focusNode!==yt.node||on.focusOffset!==yt.offset)){var $t=xn.createRange();$t.setStart(At.node,At.offset),on.removeAllRanges(),qr>Zc?(on.addRange($t),on.extend(yt.node,yt.offset)):($t.setEnd(yt.node,yt.offset),on.addRange($t))}}}}for(xn=[],on=Ce;on=on.parentNode;)on.nodeType===1&&xn.push({element:on,left:on.scrollLeft,top:on.scrollTop});for(typeof Ce.focus=="function"&&Ce.focus(),Ce=0;Ce<xn.length;Ce++){var an=xn[Ce];an.element.scrollLeft=an.left,an.element.scrollTop=an.top}}l6=!!ON,SN=ON=null}finally{rc=$,Le.p=N,ae.T=O}}m.current=y,Ia=2}}function xB(){if(Ia===2){Ia=0;var m=S2,y=M4,O=(y.flags&8772)!==0;if((y.subtreeFlags&8772)!==0||O){O=ae.T,ae.T=null;var N=Le.p;Le.p=2;var $=rc;rc|=4;try{K$(m,y.alternate,y)}finally{rc=$,Le.p=N,ae.T=O}}Ia=3}}function kB(){if(Ia===4||Ia===3){Ia=0,mo();var m=S2,y=M4,O=vm,N=lB;(y.subtreeFlags&10256)!==0||(y.flags&10256)!==0?Ia=5:(Ia=0,M4=S2=null,OB(m,m.pendingLanes));var $=m.pendingLanes;if($===0&&(O2=null),bO(O),y=y.stateNode,Ff&&typeof Ff.onCommitFiberRoot=="function")try{Ff.onCommitFiberRoot(Cp,y,void 0,(y.current.flags&128)===128)}catch{}if(N!==null){y=ae.T,$=Le.p,Le.p=2,ae.T=null;try{for(var q=m.onRecoverableError,le=0;le<N.length;le++){var Ce=N[le];q(Ce.value,{componentStack:Ce.stack})}}finally{ae.T=y,Le.p=$}}(vm&3)!==0&&Aj(),Rp(m),$=m.pendingLanes,(O&261930)!==0&&($&42)!==0?m===uN?e6++:(e6=0,uN=m):e6=0,t6(0)}}function OB(m,y){(m.pooledCacheLanes&=y)===0&&(y=m.pooledCache,y!=null&&(m.pooledCache=null,LO(y)))}function Aj(){return yB(),xB(),kB(),SB()}function SB(){if(Ia!==5)return!1;var m=S2,y=cN;cN=0;var O=bO(vm),N=ae.T,$=Le.p;try{Le.p=32>O?32:O,ae.T=null,O=lN,lN=null;var q=S2,le=vm;if(Ia=0,M4=S2=null,vm=0,(rc&6)!==0)throw Error(h(331));var Ce=rc;if(rc|=4,sB(q.current),kj(q,q.current,le,O),rc=Ce,t6(0,!1),Ff&&typeof Ff.onPostCommitFiberRoot=="function")try{Ff.onPostCommitFiberRoot(Cp,q)}catch{}return!0}finally{Le.p=$,ae.T=N,OB(m,y)}}function jB(m,y,O){y=ag(O,y),y=BA(m.stateNode,y,2),m=b2(m,y,2),m!==null&&(gu(m,2),Rp(m))}function Oc(m,y,O){if(m.tag===3)jB(m,m,O);else for(;y!==null;){if(y.tag===3){jB(y,m,O);break}else if(y.tag===1){var N=y.stateNode;if(typeof y.type.getDerivedStateFromError=="function"||typeof N.componentDidCatch=="function"&&(O2===null||!O2.has(N))){m=ag(O,m),O=_$(2),N=b2(y,O,2),N!==null&&(b1(O,N,y,m),gu(N,2),Rp(N));break}}y=y.return}}function hN(m,y,O){var N=m.pingCache;if(N===null){N=m.pingCache=new UW;var $=new Set;N.set(y,$)}else $=N.get(y),$===void 0&&($=new Set,N.set(y,$));$.has(O)||(rN=!0,$.add(O),m=KW.bind(null,m,y,O),y.then(m,m))}function KW(m,y,O){var N=m.pingCache;N!==null&&N.delete(y),m.pingedLanes|=m.suspendedLanes&O,m.warmLanes&=~O,Yc===m&&(wo&O)===O&&(bu===4||bu===3&&(wo&62914560)===wo&&300>eu()-Sj?(rc&2)===0&&A4(m,0):sN|=O,C4===wo&&(C4=0)),Rp(m)}function TB(m,y){y===0&&(y=_y()),m=Fy(m,y),m!==null&&(gu(m,y),Rp(m))}function YW(m){var y=m.memoizedState,O=0;y!==null&&(O=y.retryLane),TB(m,O)}function ZW(m,y){var O=0;switch(m.tag){case 31:case 13:var N=m.stateNode,$=m.memoizedState;$!==null&&(O=$.retryLane);break;case 19:N=m.stateNode;break;case 22:N=m.stateNode._retryCache;break;default:throw Error(h(314))}N!==null&&N.delete(y),TB(m,O)}function eK(m,y){return rs(m,y)}var Nj=null,_4=null,dN=!1,_j=!1,gN=!1,T2=0;function Rp(m){m!==_4&&m.next===null&&(_4===null?Nj=_4=m:_4=_4.next=m),_j=!0,dN||(dN=!0,nK())}function t6(m,y){if(!gN&&_j){gN=!0;do for(var O=!1,N=Nj;N!==null;){if(m!==0){var $=N.pendingLanes;if($===0)var q=0;else{var le=N.suspendedLanes,Ce=N.pingedLanes;q=(1<<31-qf(42|m)+1)-1,q&=$&~(le&~Ce),q=q&201326741?q&201326741|1:q?q|2:0}q!==0&&(O=!0,AB(N,q))}else q=wo,q=t2(N,N===Yc?q:0,N.cancelPendingCommit!==null||N.timeoutHandle!==-1),(q&3)===0||im(N,q)||(O=!0,AB(N,q));N=N.next}while(O);gN=!1}}function tK(){EB()}function EB(){_j=dN=!1;var m=0;T2!==0&&aK()&&(m=T2);for(var y=eu(),O=null,N=Nj;N!==null;){var $=N.next,q=CB(N,y);q===0?(N.next=null,O===null?Nj=$:O.next=$,$===null&&(_4=O)):(O=N,(m!==0||(q&3)!==0)&&(_j=!0)),N=$}Ia!==0&&Ia!==5||t6(m),T2!==0&&(T2=0)}function CB(m,y){for(var O=m.suspendedLanes,N=m.pingedLanes,$=m.expirationTimes,q=m.pendingLanes&-62914561;0<q;){var le=31-qf(q),Ce=1<<le,dt=$[le];dt===-1?((Ce&O)===0||(Ce&N)!==0)&&($[le]=gO(Ce,y)):dt<=y&&(m.expiredLanes|=Ce),q&=~Ce}if(y=Yc,O=wo,O=t2(m,m===y?O:0,m.cancelPendingCommit!==null||m.timeoutHandle!==-1),N=m.callbackNode,O===0||m===y&&(kc===2||kc===9)||m.cancelPendingCommit!==null)return N!==null&&N!==null&&Ls(N),m.callbackNode=null,m.callbackPriority=0;if((O&3)===0||im(m,O)){if(y=O&-O,y===m.callbackPriority)return y;switch(N!==null&&Ls(N),bO(O)){case 2:case 8:O=io;break;case 32:O=zf;break;case 268435456:O=Kw;break;default:O=zf}return N=MB.bind(null,m),O=rs(O,N),m.callbackPriority=y,m.callbackNode=O,y}return N!==null&&N!==null&&Ls(N),m.callbackPriority=2,m.callbackNode=null,2}function MB(m,y){if(Ia!==0&&Ia!==5)return m.callbackNode=null,m.callbackPriority=0,null;var O=m.callbackNode;if(Aj()&&m.callbackNode!==O)return null;var N=wo;return N=t2(m,m===Yc?N:0,m.cancelPendingCommit!==null||m.timeoutHandle!==-1),N===0?null:(aB(m,N,y),CB(m,eu()),m.callbackNode!=null&&m.callbackNode===O?MB.bind(null,m):null)}function AB(m,y){if(Aj())return null;aB(m,y,!0)}function nK(){hK(function(){(rc&6)!==0?rs(Rc,tK):EB()})}function pN(){if(T2===0){var m=p4;m===0&&(m=Yw,Yw<<=1,(Yw&261888)===0&&(Yw=256)),T2=m}return T2}function NB(m){return m==null||typeof m=="symbol"||typeof m=="boolean"?null:typeof m=="function"?m:z8(""+m)}function _B(m,y){var O=y.ownerDocument.createElement("input");return O.name=y.name,O.value=y.value,m.id&&O.setAttribute("form",m.id),y.parentNode.insertBefore(O,y),m=new FormData(m),O.parentNode.removeChild(O),m}function DB(m,y,O,N,$){if(y==="submit"&&O&&O.stateNode===$){var q=NB(($[ph]||null).action),le=N.submitter;le&&(y=(y=le[ph]||null)?NB(y.formAction):le.getAttribute("formAction"),y!==null&&(q=y,le=null));var Ce=new Q8("action","action",null,N,$);m.push({event:Ce,listeners:[{instance:null,listener:function(){if(N.defaultPrevented){if(T2!==0){var dt=le?_B($,le):new FormData($);HO(O,{pending:!0,data:dt,method:$.method,action:q},null,dt)}}else typeof q=="function"&&(Ce.preventDefault(),dt=le?_B($,le):new FormData($),HO(O,{pending:!0,data:dt,method:$.method,action:q},q,dt))},currentTarget:$}]})}}for(var bN=0;bN<KM.length;bN++){var mN=KM[bN],wN=mN.toLowerCase(),iK=mN[0].toUpperCase()+mN.slice(1);g0(wN,"on"+iK)}g0(wR,"onAnimationEnd"),g0(vR,"onAnimationIteration"),g0(yR,"onAnimationStart"),g0("dblclick","onDoubleClick"),g0("focusin","onFocus"),g0("focusout","onBlur"),g0(SW,"onTransitionRun"),g0(jW,"onTransitionStart"),g0(TW,"onTransitionCancel"),g0(xR,"onTransitionEnd"),s2("onMouseEnter",["mouseout","mouseover"]),s2("onMouseLeave",["mouseout","mouseover"]),s2("onPointerEnter",["pointerout","pointerover"]),s2("onPointerLeave",["pointerout","pointerover"]),sm("onChange","change click focusin focusout input keydown keyup selectionchange".split(" ")),sm("onSelect","focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")),sm("onBeforeInput",["compositionend","keypress","textInput","paste"]),sm("onCompositionEnd","compositionend focusout keydown keypress keyup mousedown".split(" ")),sm("onCompositionStart","compositionstart focusout keydown keypress keyup mousedown".split(" ")),sm("onCompositionUpdate","compositionupdate focusout keydown keypress keyup mousedown".split(" "));var n6="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "),rK=new Set("beforetoggle cancel close invalid load scroll scrollend toggle".split(" ").concat(n6));function LB(m,y){y=(y&4)!==0;for(var O=0;O<m.length;O++){var N=m[O],$=N.event;N=N.listeners;e:{var q=void 0;if(y)for(var le=N.length-1;0<=le;le--){var Ce=N[le],dt=Ce.instance,Ft=Ce.currentTarget;if(Ce=Ce.listener,dt!==q&&$.isPropagationStopped())break e;q=Ce,$.currentTarget=Ft;try{q($)}catch(gn){J8(gn)}$.currentTarget=null,q=dt}else for(le=0;le<N.length;le++){if(Ce=N[le],dt=Ce.instance,Ft=Ce.currentTarget,Ce=Ce.listener,dt!==q&&$.isPropagationStopped())break e;q=Ce,$.currentTarget=Ft;try{q($)}catch(gn){J8(gn)}$.currentTarget=null,q=dt}}}}function so(m,y){var O=y[e4];O===void 0&&(O=y[e4]=new Set);var N=m+"__bubble";O.has(N)||(PB(y,m,2,!1),O.add(N))}function vN(m,y,O){var N=0;y&&(N|=4),PB(O,m,N,y)}var Dj="_reactListening"+Math.random().toString(36).slice(2);function yN(m){if(!m[Dj]){m[Dj]=!0,D8.forEach(function(O){O!=="selectionchange"&&(rK.has(O)||vN(O,!1,m),vN(O,!0,m))});var y=m.nodeType===9?m:m.ownerDocument;y===null||y[Dj]||(y[Dj]=!0,vN("selectionchange",!1,y))}}function PB(m,y,O,N){switch(CK(y)){case 2:var $=mg;break;case 8:$=EK;break;default:$=oz}O=$.bind(null,y,O,m),$=void 0,!RM||y!=="touchstart"&&y!=="touchmove"&&y!=="wheel"||($=!0),N?$!==void 0?m.addEventListener(y,O,{capture:!0,passive:$}):m.addEventListener(y,O,!0):$!==void 0?m.addEventListener(y,O,{passive:$}):m.addEventListener(y,O,!1)}function xN(m,y,O,N,$){var q=N;if((y&1)===0&&(y&2)===0&&N!==null)e:for(;;){if(N===null)return;var le=N.tag;if(le===3||le===4){var Ce=N.stateNode.containerInfo;if(Ce===$)break;if(le===4)for(le=N.return;le!==null;){var dt=le.tag;if((dt===3||dt===4)&&le.stateNode.containerInfo===$)return;le=le.return}for(;Ce!==null;){if(le=Ap(Ce),le===null)return;if(dt=le.tag,dt===5||dt===6||dt===26||dt===27){N=q=le;continue e}Ce=Ce.parentNode}}N=N.return}VI(function(){var Ft=q,gn=PM(O),xn=[];e:{var Zt=kR.get(m);if(Zt!==void 0){var on=Q8,Wi=m;switch(m){case"keypress":if(q8(O)===0)break e;case"keydown":case"keyup":on=nW;break;case"focusin":Wi="focus",on=FM;break;case"focusout":Wi="blur",on=FM;break;case"beforeblur":case"afterblur":on=FM;break;case"click":if(O.button===2)break e;case"auxclick":case"dblclick":case"mousedown":case"mousemove":case"mouseup":case"mouseout":case"mouseover":case"contextmenu":on=YI;break;case"drag":case"dragend":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"dragstart":case"drop":on=QV;break;case"touchcancel":case"touchend":case"touchmove":case"touchstart":on=sW;break;case wR:case vR:case yR:on=JV;break;case xR:on=cW;break;case"scroll":case"scrollend":on=qV;break;case"wheel":on=uW;break;case"copy":case"cut":case"paste":on=VV;break;case"gotpointercapture":case"lostpointercapture":case"pointercancel":case"pointerdown":case"pointermove":case"pointerout":case"pointerover":case"pointerup":on=eR;break;case"toggle":case"beforetoggle":on=fW}var qr=(y&4)!==0,Zc=!qr&&(m==="scroll"||m==="scrollend"),At=qr?Zt!==null?Zt+"Capture":null:Zt;qr=[];for(var yt=Ft,$t;yt!==null;){var an=yt;if($t=an.stateNode,an=an.tag,an!==5&&an!==26&&an!==27||$t===null||At===null||(an=xO(yt,At),an!=null&&qr.push(i6(yt,an,$t))),Zc)break;yt=yt.return}0<qr.length&&(Zt=new on(Zt,Wi,null,O,gn),xn.push({event:Zt,listeners:qr}))}}if((y&7)===0){e:{if(Zt=m==="mouseover"||m==="pointerover",on=m==="mouseout"||m==="pointerout",Zt&&O!==LM&&(Wi=O.relatedTarget||O.fromElement)&&(Ap(Wi)||Wi[rm]))break e;if((on||Zt)&&(Zt=gn.window===gn?gn:(Zt=gn.ownerDocument)?Zt.defaultView||Zt.parentWindow:window,on?(Wi=O.relatedTarget||O.toElement,on=Ft,Wi=Wi?Ap(Wi):null,Wi!==null&&(Zc=w(Wi),qr=Wi.tag,Wi!==Zc||qr!==5&&qr!==27&&qr!==6)&&(Wi=null)):(on=null,Wi=Ft),on!==Wi)){if(qr=YI,an="onMouseLeave",At="onMouseEnter",yt="mouse",(m==="pointerout"||m==="pointerover")&&(qr=eR,an="onPointerLeave",At="onPointerEnter",yt="pointer"),Zc=on==null?Zt:i2(on),$t=Wi==null?Zt:i2(Wi),Zt=new qr(an,yt+"leave",on,O,gn),Zt.target=Zc,Zt.relatedTarget=$t,an=null,Ap(gn)===Ft&&(qr=new qr(At,yt+"enter",Wi,O,gn),qr.target=$t,qr.relatedTarget=Zc,an=qr),Zc=an,on&&Wi)t:{for(qr=sK,At=on,yt=Wi,$t=0,an=At;an;an=qr(an))$t++;an=0;for(var mr=yt;mr;mr=qr(mr))an++;for(;0<$t-an;)At=qr(At),$t--;for(;0<an-$t;)yt=qr(yt),an--;for(;$t--;){if(At===yt||yt!==null&&At===yt.alternate){qr=At;break t}At=qr(At),yt=qr(yt)}qr=null}else qr=null;on!==null&&IB(xn,Zt,on,qr,!1),Wi!==null&&Zc!==null&&IB(xn,Zc,Wi,qr,!0)}}e:{if(Zt=Ft?i2(Ft):window,on=Zt.nodeName&&Zt.nodeName.toLowerCase(),on==="select"||on==="input"&&Zt.type==="file")var Fo=lR;else if(oR(Zt))if(QM)Fo=xW;else{Fo=vW;var rr=wW}else on=Zt.nodeName,!on||on.toLowerCase()!=="input"||Zt.type!=="checkbox"&&Zt.type!=="radio"?Ft&&DM(Ft.elementType)&&(Fo=lR):Fo=yW;if(Fo&&(Fo=Fo(m,Ft))){cR(xn,Fo,O,gn);break e}rr&&rr(m,Zt,Ft),m==="focusout"&&Ft&&Zt.type==="number"&&Ft.memoizedProps.value!=null&&yO(Zt,"number",Zt.value)}switch(rr=Ft?i2(Ft):window,m){case"focusin":(oR(rr)||rr.contentEditable==="true")&&(o4=rr,XM=Ft,MO=null);break;case"focusout":MO=XM=o4=null;break;case"mousedown":VM=!0;break;case"contextmenu":case"mouseup":case"dragend":VM=!1,bR(xn,O,gn);break;case"selectionchange":if(OW)break;case"keydown":case"keyup":bR(xn,O,gn)}var ds;if(HM)e:{switch(m){case"compositionstart":var Fs="onCompositionStart";break e;case"compositionend":Fs="onCompositionEnd";break e;case"compositionupdate":Fs="onCompositionUpdate";break e}Fs=void 0}else s4?rR(m,O)&&(Fs="onCompositionEnd"):m==="keydown"&&O.keyCode===229&&(Fs="onCompositionStart");Fs&&(tR&&O.locale!=="ko"&&(s4||Fs!=="onCompositionStart"?Fs==="onCompositionEnd"&&s4&&(ds=WI()):(c2=gn,$M="value"in c2?c2.value:c2.textContent,s4=!0)),rr=Lj(Ft,Fs),0<rr.length&&(Fs=new ZI(Fs,m,null,O,gn),xn.push({event:Fs,listeners:rr}),ds?Fs.data=ds:(ds=sR(O),ds!==null&&(Fs.data=ds)))),(ds=dW?gW(m,O):pW(m,O))&&(Fs=Lj(Ft,"onBeforeInput"),0<Fs.length&&(rr=new ZI("onBeforeInput","beforeinput",null,O,gn),xn.push({event:rr,listeners:Fs}),rr.data=ds)),DB(xn,m,Ft,O,gn)}LB(xn,y)})}function i6(m,y,O){return{instance:m,listener:y,currentTarget:O}}function Lj(m,y){for(var O=y+"Capture",N=[];m!==null;){var $=m,q=$.stateNode;if($=$.tag,$!==5&&$!==26&&$!==27||q===null||($=xO(m,O),$!=null&&N.unshift(i6(m,$,q)),$=xO(m,y),$!=null&&N.push(i6(m,$,q))),m.tag===3)return N;m=m.return}return[]}function sK(m){if(m===null)return null;do m=m.return;while(m&&m.tag!==5&&m.tag!==27);return m||null}function IB(m,y,O,N,$){for(var q=y._reactName,le=[];O!==null&&O!==N;){var Ce=O,dt=Ce.alternate,Ft=Ce.stateNode;if(Ce=Ce.tag,dt!==null&&dt===N)break;Ce!==5&&Ce!==26&&Ce!==27||Ft===null||(dt=Ft,$?(Ft=xO(O,q),Ft!=null&&le.unshift(i6(O,Ft,dt))):$||(Ft=xO(O,q),Ft!=null&&le.push(i6(O,Ft,dt)))),O=O.return}le.length!==0&&m.push({event:y,listeners:le})}var oK=/\r\n?/g,cK=/\u0000|\uFFFD/g;function RB(m){return(typeof m=="string"?m:""+m).replace(oK,`
`).replace(cK,"")}function $B(m,y){return y=RB(y),RB(m)===y}function Bc(m,y,O,N,$,q){switch(O){case"children":typeof N=="string"?y==="body"||y==="textarea"&&N===""||n4(m,N):(typeof N=="number"||typeof N=="bigint")&&y!=="body"&&n4(m,""+N);break;case"className":t4(m,"class",N);break;case"tabIndex":t4(m,"tabindex",N);break;case"dir":case"role":case"viewBox":case"width":case"height":t4(m,O,N);break;case"style":JI(m,N,q);break;case"data":if(y!=="object"){t4(m,"data",N);break}case"src":case"href":if(N===""&&(y!=="a"||O!=="href")){m.removeAttribute(O);break}if(N==null||typeof N=="function"||typeof N=="symbol"||typeof N=="boolean"){m.removeAttribute(O);break}N=z8(""+N),m.setAttribute(O,N);break;case"action":case"formAction":if(typeof N=="function"){m.setAttribute(O,"javascript:throw new Error('A React form was unexpectedly submitted. If you called form.submit() manually, consider using form.requestSubmit() instead. If you\\'re trying to use event.stopPropagation() in a submit event handler, consider also calling event.preventDefault().')");break}else typeof q=="function"&&(O==="formAction"?(y!=="input"&&Bc(m,y,"name",$.name,$,null),Bc(m,y,"formEncType",$.formEncType,$,null),Bc(m,y,"formMethod",$.formMethod,$,null),Bc(m,y,"formTarget",$.formTarget,$,null)):(Bc(m,y,"encType",$.encType,$,null),Bc(m,y,"method",$.method,$,null),Bc(m,y,"target",$.target,$,null)));if(N==null||typeof N=="symbol"||typeof N=="boolean"){m.removeAttribute(O);break}N=z8(""+N),m.setAttribute(O,N);break;case"onClick":N!=null&&(m.onclick=cm);break;case"onScroll":N!=null&&so("scroll",m);break;case"onScrollEnd":N!=null&&so("scrollend",m);break;case"dangerouslySetInnerHTML":if(N!=null){if(typeof N!="object"||!("__html"in N))throw Error(h(61));if(O=N.__html,O!=null){if($.children!=null)throw Error(h(60));m.innerHTML=O}}break;case"multiple":m.multiple=N&&typeof N!="function"&&typeof N!="symbol";break;case"muted":m.muted=N&&typeof N!="function"&&typeof N!="symbol";break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"defaultValue":case"defaultChecked":case"innerHTML":case"ref":break;case"autoFocus":break;case"xlinkHref":if(N==null||typeof N=="function"||typeof N=="boolean"||typeof N=="symbol"){m.removeAttribute("xlink:href");break}O=z8(""+N),m.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",O);break;case"contentEditable":case"spellCheck":case"draggable":case"value":case"autoReverse":case"externalResourcesRequired":case"focusable":case"preserveAlpha":N!=null&&typeof N!="function"&&typeof N!="symbol"?m.setAttribute(O,""+N):m.removeAttribute(O);break;case"inert":case"allowFullScreen":case"async":case"autoPlay":case"controls":case"default":case"defer":case"disabled":case"disablePictureInPicture":case"disableRemotePlayback":case"formNoValidate":case"hidden":case"loop":case"noModule":case"noValidate":case"open":case"playsInline":case"readOnly":case"required":case"reversed":case"scoped":case"seamless":case"itemScope":N&&typeof N!="function"&&typeof N!="symbol"?m.setAttribute(O,""):m.removeAttribute(O);break;case"capture":case"download":N===!0?m.setAttribute(O,""):N!==!1&&N!=null&&typeof N!="function"&&typeof N!="symbol"?m.setAttribute(O,N):m.removeAttribute(O);break;case"cols":case"rows":case"size":case"span":N!=null&&typeof N!="function"&&typeof N!="symbol"&&!isNaN(N)&&1<=N?m.setAttribute(O,N):m.removeAttribute(O);break;case"rowSpan":case"start":N==null||typeof N=="function"||typeof N=="symbol"||isNaN(N)?m.removeAttribute(O):m.setAttribute(O,N);break;case"popover":so("beforetoggle",m),so("toggle",m),Py(m,"popover",N);break;case"xlinkActuate":d0(m,"http://www.w3.org/1999/xlink","xlink:actuate",N);break;case"xlinkArcrole":d0(m,"http://www.w3.org/1999/xlink","xlink:arcrole",N);break;case"xlinkRole":d0(m,"http://www.w3.org/1999/xlink","xlink:role",N);break;case"xlinkShow":d0(m,"http://www.w3.org/1999/xlink","xlink:show",N);break;case"xlinkTitle":d0(m,"http://www.w3.org/1999/xlink","xlink:title",N);break;case"xlinkType":d0(m,"http://www.w3.org/1999/xlink","xlink:type",N);break;case"xmlBase":d0(m,"http://www.w3.org/XML/1998/namespace","xml:base",N);break;case"xmlLang":d0(m,"http://www.w3.org/XML/1998/namespace","xml:lang",N);break;case"xmlSpace":d0(m,"http://www.w3.org/XML/1998/namespace","xml:space",N);break;case"is":Py(m,"is",N);break;case"innerText":case"textContent":break;default:(!(2<O.length)||O[0]!=="o"&&O[0]!=="O"||O[1]!=="n"&&O[1]!=="N")&&(O=zV.get(O)||O,Py(m,O,N))}}function kN(m,y,O,N,$,q){switch(O){case"style":JI(m,N,q);break;case"dangerouslySetInnerHTML":if(N!=null){if(typeof N!="object"||!("__html"in N))throw Error(h(61));if(O=N.__html,O!=null){if($.children!=null)throw Error(h(60));m.innerHTML=O}}break;case"children":typeof N=="string"?n4(m,N):(typeof N=="number"||typeof N=="bigint")&&n4(m,""+N);break;case"onScroll":N!=null&&so("scroll",m);break;case"onScrollEnd":N!=null&&so("scrollend",m);break;case"onClick":N!=null&&(m.onclick=cm);break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"innerHTML":case"ref":break;case"innerText":case"textContent":break;default:if(!L8.hasOwnProperty(O))e:{if(O[0]==="o"&&O[1]==="n"&&($=O.endsWith("Capture"),y=O.slice(2,$?O.length-7:void 0),q=m[ph]||null,q=q!=null?q[O]:null,typeof q=="function"&&m.removeEventListener(y,q,$),typeof N=="function")){typeof q!="function"&&q!==null&&(O in m?m[O]=null:m.hasAttribute(O)&&m.removeAttribute(O)),m.addEventListener(y,N,$);break e}O in m?m[O]=N:N===!0?m.setAttribute(O,""):Py(m,O,N)}}}function Uf(m,y,O){switch(y){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"img":so("error",m),so("load",m);var N=!1,$=!1,q;for(q in O)if(O.hasOwnProperty(q)){var le=O[q];if(le!=null)switch(q){case"src":N=!0;break;case"srcSet":$=!0;break;case"children":case"dangerouslySetInnerHTML":throw Error(h(137,y));default:Bc(m,y,q,le,O,null)}}$&&Bc(m,y,"srcSet",O.srcSet,O,null),N&&Bc(m,y,"src",O.src,O,null);return;case"input":so("invalid",m);var Ce=q=le=$=null,dt=null,Ft=null;for(N in O)if(O.hasOwnProperty(N)){var gn=O[N];if(gn!=null)switch(N){case"name":$=gn;break;case"type":le=gn;break;case"checked":dt=gn;break;case"defaultChecked":Ft=gn;break;case"value":q=gn;break;case"defaultValue":Ce=gn;break;case"children":case"dangerouslySetInnerHTML":if(gn!=null)throw Error(h(137,y));break;default:Bc(m,y,N,gn,O,null)}}B8(m,q,Ce,dt,Ft,le,$,!1);return;case"select":so("invalid",m),N=le=q=null;for($ in O)if(O.hasOwnProperty($)&&(Ce=O[$],Ce!=null))switch($){case"value":q=Ce;break;case"defaultValue":le=Ce;break;case"multiple":N=Ce;default:Bc(m,y,$,Ce,O,null)}y=q,O=le,m.multiple=!!N,y!=null?om(m,!!N,y,!1):O!=null&&om(m,!!N,O,!0);return;case"textarea":so("invalid",m),q=$=N=null;for(le in O)if(O.hasOwnProperty(le)&&(Ce=O[le],Ce!=null))switch(le){case"value":N=Ce;break;case"defaultValue":$=Ce;break;case"children":q=Ce;break;case"dangerouslySetInnerHTML":if(Ce!=null)throw Error(h(91));break;default:Bc(m,y,le,Ce,O,null)}GI(m,N,$,q);return;case"option":for(dt in O)if(O.hasOwnProperty(dt)&&(N=O[dt],N!=null))switch(dt){case"selected":m.selected=N&&typeof N!="function"&&typeof N!="symbol";break;default:Bc(m,y,dt,N,O,null)}return;case"dialog":so("beforetoggle",m),so("toggle",m),so("cancel",m),so("close",m);break;case"iframe":case"object":so("load",m);break;case"video":case"audio":for(N=0;N<n6.length;N++)so(n6[N],m);break;case"image":so("error",m),so("load",m);break;case"details":so("toggle",m);break;case"embed":case"source":case"link":so("error",m),so("load",m);case"area":case"base":case"br":case"col":case"hr":case"keygen":case"meta":case"param":case"track":case"wbr":case"menuitem":for(Ft in O)if(O.hasOwnProperty(Ft)&&(N=O[Ft],N!=null))switch(Ft){case"children":case"dangerouslySetInnerHTML":throw Error(h(137,y));default:Bc(m,y,Ft,N,O,null)}return;default:if(DM(y)){for(gn in O)O.hasOwnProperty(gn)&&(N=O[gn],N!==void 0&&kN(m,y,gn,N,O,void 0));return}}for(Ce in O)O.hasOwnProperty(Ce)&&(N=O[Ce],N!=null&&Bc(m,y,Ce,N,O,null))}function lK(m,y,O,N){switch(y){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"input":var $=null,q=null,le=null,Ce=null,dt=null,Ft=null,gn=null;for(on in O){var xn=O[on];if(O.hasOwnProperty(on)&&xn!=null)switch(on){case"checked":break;case"value":break;case"defaultValue":dt=xn;default:N.hasOwnProperty(on)||Bc(m,y,on,null,N,xn)}}for(var Zt in N){var on=N[Zt];if(xn=O[Zt],N.hasOwnProperty(Zt)&&(on!=null||xn!=null))switch(Zt){case"type":q=on;break;case"name":$=on;break;case"checked":Ft=on;break;case"defaultChecked":gn=on;break;case"value":le=on;break;case"defaultValue":Ce=on;break;case"children":case"dangerouslySetInnerHTML":if(on!=null)throw Error(h(137,y));break;default:on!==xn&&Bc(m,y,Zt,on,N,xn)}}Ry(m,le,Ce,dt,Ft,gn,q,$);return;case"select":on=le=Ce=Zt=null;for(q in O)if(dt=O[q],O.hasOwnProperty(q)&&dt!=null)switch(q){case"value":break;case"multiple":on=dt;default:N.hasOwnProperty(q)||Bc(m,y,q,null,N,dt)}for($ in N)if(q=N[$],dt=O[$],N.hasOwnProperty($)&&(q!=null||dt!=null))switch($){case"value":Zt=q;break;case"defaultValue":Ce=q;break;case"multiple":le=q;default:q!==dt&&Bc(m,y,$,q,N,dt)}y=Ce,O=le,N=on,Zt!=null?om(m,!!O,Zt,!1):!!N!=!!O&&(y!=null?om(m,!!O,y,!0):om(m,!!O,O?[]:"",!1));return;case"textarea":on=Zt=null;for(Ce in O)if($=O[Ce],O.hasOwnProperty(Ce)&&$!=null&&!N.hasOwnProperty(Ce))switch(Ce){case"value":break;case"children":break;default:Bc(m,y,Ce,null,N,$)}for(le in N)if($=N[le],q=O[le],N.hasOwnProperty(le)&&($!=null||q!=null))switch(le){case"value":Zt=$;break;case"defaultValue":on=$;break;case"children":break;case"dangerouslySetInnerHTML":if($!=null)throw Error(h(91));break;default:$!==q&&Bc(m,y,le,$,N,q)}QI(m,Zt,on);return;case"option":for(var Wi in O)if(Zt=O[Wi],O.hasOwnProperty(Wi)&&Zt!=null&&!N.hasOwnProperty(Wi))switch(Wi){case"selected":m.selected=!1;break;default:Bc(m,y,Wi,null,N,Zt)}for(dt in N)if(Zt=N[dt],on=O[dt],N.hasOwnProperty(dt)&&Zt!==on&&(Zt!=null||on!=null))switch(dt){case"selected":m.selected=Zt&&typeof Zt!="function"&&typeof Zt!="symbol";break;default:Bc(m,y,dt,Zt,N,on)}return;case"img":case"link":case"area":case"base":case"br":case"col":case"embed":case"hr":case"keygen":case"meta":case"param":case"source":case"track":case"wbr":case"menuitem":for(var qr in O)Zt=O[qr],O.hasOwnProperty(qr)&&Zt!=null&&!N.hasOwnProperty(qr)&&Bc(m,y,qr,null,N,Zt);for(Ft in N)if(Zt=N[Ft],on=O[Ft],N.hasOwnProperty(Ft)&&Zt!==on&&(Zt!=null||on!=null))switch(Ft){case"children":case"dangerouslySetInnerHTML":if(Zt!=null)throw Error(h(137,y));break;default:Bc(m,y,Ft,Zt,N,on)}return;default:if(DM(y)){for(var Zc in O)Zt=O[Zc],O.hasOwnProperty(Zc)&&Zt!==void 0&&!N.hasOwnProperty(Zc)&&kN(m,y,Zc,void 0,N,Zt);for(gn in N)Zt=N[gn],on=O[gn],!N.hasOwnProperty(gn)||Zt===on||Zt===void 0&&on===void 0||kN(m,y,gn,Zt,N,on);return}}for(var At in O)Zt=O[At],O.hasOwnProperty(At)&&Zt!=null&&!N.hasOwnProperty(At)&&Bc(m,y,At,null,N,Zt);for(xn in N)Zt=N[xn],on=O[xn],!N.hasOwnProperty(xn)||Zt===on||Zt==null&&on==null||Bc(m,y,xn,Zt,N,on)}function BB(m){switch(m){case"css":case"script":case"font":case"img":case"image":case"input":case"link":return!0;default:return!1}}function uK(){if(typeof performance.getEntriesByType=="function"){for(var m=0,y=0,O=performance.getEntriesByType("resource"),N=0;N<O.length;N++){var $=O[N],q=$.transferSize,le=$.initiatorType,Ce=$.duration;if(q&&Ce&&BB(le)){for(le=0,Ce=$.responseEnd,N+=1;N<O.length;N++){var dt=O[N],Ft=dt.startTime;if(Ft>Ce)break;var gn=dt.transferSize,xn=dt.initiatorType;gn&&BB(xn)&&(dt=dt.responseEnd,le+=gn*(dt<Ce?1:(Ce-Ft)/(dt-Ft)))}if(--N,y+=8*(q+le)/($.duration/1e3),m++,10<m)break}}if(0<m)return y/m/1e6}return navigator.connection&&(m=navigator.connection.downlink,typeof m=="number")?m:5}var ON=null,SN=null;function Pj(m){return m.nodeType===9?m:m.ownerDocument}function zB(m){switch(m){case"http://www.w3.org/2000/svg":return 1;case"http://www.w3.org/1998/Math/MathML":return 2;default:return 0}}function FB(m,y){if(m===0)switch(y){case"svg":return 1;case"math":return 2;default:return 0}return m===1&&y==="foreignObject"?0:m}function jN(m,y){return m==="textarea"||m==="noscript"||typeof y.children=="string"||typeof y.children=="number"||typeof y.children=="bigint"||typeof y.dangerouslySetInnerHTML=="object"&&y.dangerouslySetInnerHTML!==null&&y.dangerouslySetInnerHTML.__html!=null}var TN=null;function aK(){var m=window.event;return m&&m.type==="popstate"?m===TN?!1:(TN=m,!0):(TN=null,!1)}var qB=typeof setTimeout=="function"?setTimeout:void 0,fK=typeof clearTimeout=="function"?clearTimeout:void 0,HB=typeof Promise=="function"?Promise:void 0,hK=typeof queueMicrotask=="function"?queueMicrotask:typeof HB<"u"?function(m){return HB.resolve(null).then(m).catch(dK)}:qB;function dK(m){setTimeout(function(){throw m})}function E2(m){return m==="head"}function QB(m,y){var O=y,N=0;do{var $=O.nextSibling;if(m.removeChild(O),$&&$.nodeType===8)if(O=$.data,O==="/$"||O==="/&"){if(N===0){m.removeChild($),tx(y);return}N--}else if(O==="$"||O==="$?"||O==="$~"||O==="$!"||O==="&")N++;else if(O==="html")D4(m.ownerDocument.documentElement);else if(O==="head"){O=m.ownerDocument.head,D4(O);for(var q=O.firstChild;q;){var le=q.nextSibling,Ce=q.nodeName;q[Ly]||Ce==="SCRIPT"||Ce==="STYLE"||Ce==="LINK"&&q.rel.toLowerCase()==="stylesheet"||O.removeChild(q),q=le}}else O==="body"&&D4(m.ownerDocument.body);O=$}while(O);tx(y)}function GB(m,y){var O=m;m=0;do{var N=O.nextSibling;if(O.nodeType===1?y?(O._stashedDisplay=O.style.display,O.style.display="none"):(O.style.display=O._stashedDisplay||"",O.getAttribute("style")===""&&O.removeAttribute("style")):O.nodeType===3&&(y?(O._stashedText=O.nodeValue,O.nodeValue=""):O.nodeValue=O._stashedText||""),N&&N.nodeType===8)if(O=N.data,O==="/$"){if(m===0)break;m--}else O!=="$"&&O!=="$?"&&O!=="$~"&&O!=="$!"||m++;O=N}while(O)}function EN(m){var y=m.firstChild;for(y&&y.nodeType===10&&(y=y.nextSibling);y;){var O=y;switch(y=y.nextSibling,O.nodeName){case"HTML":case"HEAD":case"BODY":EN(O),wO(O);continue;case"SCRIPT":case"STYLE":continue;case"LINK":if(O.rel.toLowerCase()==="stylesheet")continue}m.removeChild(O)}}function gK(m,y,O,N){for(;m.nodeType===1;){var $=O;if(m.nodeName.toLowerCase()!==y.toLowerCase()){if(!N&&(m.nodeName!=="INPUT"||m.type!=="hidden"))break}else if(N){if(!m[Ly])switch(y){case"meta":if(!m.hasAttribute("itemprop"))break;return m;case"link":if(q=m.getAttribute("rel"),q==="stylesheet"&&m.hasAttribute("data-precedence"))break;if(q!==$.rel||m.getAttribute("href")!==($.href==null||$.href===""?null:$.href)||m.getAttribute("crossorigin")!==($.crossOrigin==null?null:$.crossOrigin)||m.getAttribute("title")!==($.title==null?null:$.title))break;return m;case"style":if(m.hasAttribute("data-precedence"))break;return m;case"script":if(q=m.getAttribute("src"),(q!==($.src==null?null:$.src)||m.getAttribute("type")!==($.type==null?null:$.type)||m.getAttribute("crossorigin")!==($.crossOrigin==null?null:$.crossOrigin))&&q&&m.hasAttribute("async")&&!m.hasAttribute("itemprop"))break;return m;default:return m}}else if(y==="input"&&m.type==="hidden"){var q=$.name==null?null:""+$.name;if($.type==="hidden"&&m.getAttribute("name")===q)return m}else return m;if(m=bg(m.nextSibling),m===null)break}return null}function pK(m,y,O){if(y==="")return null;for(;m.nodeType!==3;)if((m.nodeType!==1||m.nodeName!=="INPUT"||m.type!=="hidden")&&!O||(m=bg(m.nextSibling),m===null))return null;return m}function UB(m,y){for(;m.nodeType!==8;)if((m.nodeType!==1||m.nodeName!=="INPUT"||m.type!=="hidden")&&!y||(m=bg(m.nextSibling),m===null))return null;return m}function CN(m){return m.data==="$?"||m.data==="$~"}function MN(m){return m.data==="$!"||m.data==="$?"&&m.ownerDocument.readyState!=="loading"}function bK(m,y){var O=m.ownerDocument;if(m.data==="$~")m._reactRetry=y;else if(m.data!=="$?"||O.readyState!=="loading")y();else{var N=function(){y(),O.removeEventListener("DOMContentLoaded",N)};O.addEventListener("DOMContentLoaded",N),m._reactRetry=N}}function bg(m){for(;m!=null;m=m.nextSibling){var y=m.nodeType;if(y===1||y===3)break;if(y===8){if(y=m.data,y==="$"||y==="$!"||y==="$?"||y==="$~"||y==="&"||y==="F!"||y==="F")break;if(y==="/$"||y==="/&")return null}}return m}var AN=null;function NN(m){m=m.nextSibling;for(var y=0;m;){if(m.nodeType===8){var O=m.data;if(O==="/$"||O==="/&"){if(y===0)return bg(m.nextSibling);y--}else O!=="$"&&O!=="$!"&&O!=="$?"&&O!=="$~"&&O!=="&"||y++}m=m.nextSibling}return null}function JB(m){m=m.previousSibling;for(var y=0;m;){if(m.nodeType===8){var O=m.data;if(O==="$"||O==="$!"||O==="$?"||O==="$~"||O==="&"){if(y===0)return m;y--}else O!=="/$"&&O!=="/&"||y++}m=m.previousSibling}return null}function XB(m,y,O){switch(y=Pj(O),m){case"html":if(m=y.documentElement,!m)throw Error(h(452));return m;case"head":if(m=y.head,!m)throw Error(h(453));return m;case"body":if(m=y.body,!m)throw Error(h(454));return m;default:throw Error(h(451))}}function D4(m){for(var y=m.attributes;y.length;)m.removeAttributeNode(y[0]);wO(m)}var y1=new Map,la=new Set;function Ij(m){return typeof m.getRootNode=="function"?m.getRootNode():m.nodeType===9?m:m.ownerDocument}var $p=Le.d;Le.d={f:mK,r:Rj,D:wK,C:WB,L:KB,m:vK,X:yK,S:_N,M:xK};function mK(){var m=$p.f(),y=Ej();return m||y}function Rj(m){var y=n2(m);y!==null&&y.tag===5&&y.type==="form"?dj(y):$p.r(m)}var L4=typeof document>"u"?null:document;function VB(m,y,O){var N=L4;if(N&&typeof y=="string"&&y){var $=Cd(y);$='link[rel="'+m+'"][href="'+$+'"]',typeof O=="string"&&($+='[crossorigin="'+O+'"]'),la.has($)||(la.add($),m={rel:m,crossOrigin:O,href:y},N.querySelector($)===null&&(y=N.createElement("link"),Uf(y,"link",m),ra(y),N.head.appendChild(y)))}}function wK(m){$p.D(m),VB("dns-prefetch",m,null)}function WB(m,y){$p.C(m,y),VB("preconnect",m,y)}function KB(m,y,O){$p.L(m,y,O);var N=L4;if(N&&m&&y){var $='link[rel="preload"][as="'+Cd(y)+'"]';y==="image"&&O&&O.imageSrcSet?($+='[imagesrcset="'+Cd(O.imageSrcSet)+'"]',typeof O.imageSizes=="string"&&($+='[imagesizes="'+Cd(O.imageSizes)+'"]')):$+='[href="'+Cd(m)+'"]';var q=$;switch(y){case"style":q=P4(m);break;case"script":q=I4(m)}y1.has(q)||(m=D({rel:"preload",href:y==="image"&&O&&O.imageSrcSet?void 0:m,as:y},O),y1.set(q,m),N.querySelector($)!==null||y==="style"&&N.querySelector(r6(q))||y==="script"&&N.querySelector(s6(q))||(y=N.createElement("link"),Uf(y,"link",m),ra(y),N.head.appendChild(y)))}}function vK(m,y){$p.m(m,y);var O=L4;if(O&&m){var N=y&&typeof y.as=="string"?y.as:"script",$='link[rel="modulepreload"][as="'+Cd(N)+'"][href="'+Cd(m)+'"]',q=$;switch(N){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":q=I4(m)}if(!y1.has(q)&&(m=D({rel:"modulepreload",href:m},y),y1.set(q,m),O.querySelector($)===null)){switch(N){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":if(O.querySelector(s6(q)))return}N=O.createElement("link"),Uf(N,"link",m),ra(N),O.head.appendChild(N)}}}function _N(m,y,O){$p.S(m,y,O);var N=L4;if(N&&m){var $=r2(N).hoistableStyles,q=P4(m);y=y||"default";var le=$.get(q);if(!le){var Ce={loading:0,preload:null};if(le=N.querySelector(r6(q)))Ce.loading=5;else{m=D({rel:"stylesheet",href:m,"data-precedence":y},O),(O=y1.get(q))&&LN(m,O);var dt=le=N.createElement("link");ra(dt),Uf(dt,"link",m),dt._p=new Promise(function(Ft,gn){dt.onload=Ft,dt.onerror=gn}),dt.addEventListener("load",function(){Ce.loading|=1}),dt.addEventListener("error",function(){Ce.loading|=2}),Ce.loading|=4,R4(le,y,N)}le={type:"stylesheet",instance:le,count:1,state:Ce},$.set(q,le)}}}function yK(m,y){$p.X(m,y);var O=L4;if(O&&m){var N=r2(O).hoistableScripts,$=I4(m),q=N.get($);q||(q=O.querySelector(s6($)),q||(m=D({src:m,async:!0},y),(y=y1.get($))&&PN(m,y),q=O.createElement("script"),ra(q),Uf(q,"link",m),O.head.appendChild(q)),q={type:"script",instance:q,count:1,state:null},N.set($,q))}}function xK(m,y){$p.M(m,y);var O=L4;if(O&&m){var N=r2(O).hoistableScripts,$=I4(m),q=N.get($);q||(q=O.querySelector(s6($)),q||(m=D({src:m,async:!0,type:"module"},y),(y=y1.get($))&&PN(m,y),q=O.createElement("script"),ra(q),Uf(q,"link",m),O.head.appendChild(q)),q={type:"script",instance:q,count:1,state:null},N.set($,q))}}function YB(m,y,O,N){var $=($=rn.current)?Ij($):null;if(!$)throw Error(h(446));switch(m){case"meta":case"title":return null;case"style":return typeof O.precedence=="string"&&typeof O.href=="string"?(y=P4(O.href),O=r2($).hoistableStyles,N=O.get(y),N||(N={type:"style",instance:null,count:0,state:null},O.set(y,N)),N):{type:"void",instance:null,count:0,state:null};case"link":if(O.rel==="stylesheet"&&typeof O.href=="string"&&typeof O.precedence=="string"){m=P4(O.href);var q=r2($).hoistableStyles,le=q.get(m);if(le||($=$.ownerDocument||$,le={type:"stylesheet",instance:null,count:0,state:{loading:0,preload:null}},q.set(m,le),(q=$.querySelector(r6(m)))&&!q._p&&(le.instance=q,le.state.loading=5),y1.has(m)||(O={rel:"preload",as:"style",href:O.href,crossOrigin:O.crossOrigin,integrity:O.integrity,media:O.media,hrefLang:O.hrefLang,referrerPolicy:O.referrerPolicy},y1.set(m,O),q||DN($,m,O,le.state))),y&&N===null)throw Error(h(528,""));return le}if(y&&N!==null)throw Error(h(529,""));return null;case"script":return y=O.async,O=O.src,typeof O=="string"&&y&&typeof y!="function"&&typeof y!="symbol"?(y=I4(O),O=r2($).hoistableScripts,N=O.get(y),N||(N={type:"script",instance:null,count:0,state:null},O.set(y,N)),N):{type:"void",instance:null,count:0,state:null};default:throw Error(h(444,m))}}function P4(m){return'href="'+Cd(m)+'"'}function r6(m){return'link[rel="stylesheet"]['+m+"]"}function ZB(m){return D({},m,{"data-precedence":m.precedence,precedence:null})}function DN(m,y,O,N){m.querySelector('link[rel="preload"][as="style"]['+y+"]")?N.loading=1:(y=m.createElement("link"),N.preload=y,y.addEventListener("load",function(){return N.loading|=1}),y.addEventListener("error",function(){return N.loading|=2}),Uf(y,"link",O),ra(y),m.head.appendChild(y))}function I4(m){return'[src="'+Cd(m)+'"]'}function s6(m){return"script[async]"+m}function ez(m,y,O){if(y.count++,y.instance===null)switch(y.type){case"style":var N=m.querySelector('style[data-href~="'+Cd(O.href)+'"]');if(N)return y.instance=N,ra(N),N;var $=D({},O,{"data-href":O.href,"data-precedence":O.precedence,href:null,precedence:null});return N=(m.ownerDocument||m).createElement("style"),ra(N),Uf(N,"style",$),R4(N,O.precedence,m),y.instance=N;case"stylesheet":$=P4(O.href);var q=m.querySelector(r6($));if(q)return y.state.loading|=4,y.instance=q,ra(q),q;N=ZB(O),($=y1.get($))&&LN(N,$),q=(m.ownerDocument||m).createElement("link"),ra(q);var le=q;return le._p=new Promise(function(Ce,dt){le.onload=Ce,le.onerror=dt}),Uf(q,"link",N),y.state.loading|=4,R4(q,O.precedence,m),y.instance=q;case"script":return q=I4(O.src),($=m.querySelector(s6(q)))?(y.instance=$,ra($),$):(N=O,($=y1.get(q))&&(N=D({},O),PN(N,$)),m=m.ownerDocument||m,$=m.createElement("script"),ra($),Uf($,"link",N),m.head.appendChild($),y.instance=$);case"void":return null;default:throw Error(h(443,y.type))}else y.type==="stylesheet"&&(y.state.loading&4)===0&&(N=y.instance,y.state.loading|=4,R4(N,O.precedence,m));return y.instance}function R4(m,y,O){for(var N=O.querySelectorAll('link[rel="stylesheet"][data-precedence],style[data-precedence]'),$=N.length?N[N.length-1]:null,q=$,le=0;le<N.length;le++){var Ce=N[le];if(Ce.dataset.precedence===y)q=Ce;else if(q!==$)break}q?q.parentNode.insertBefore(m,q.nextSibling):(y=O.nodeType===9?O.head:O,y.insertBefore(m,y.firstChild))}function LN(m,y){m.crossOrigin==null&&(m.crossOrigin=y.crossOrigin),m.referrerPolicy==null&&(m.referrerPolicy=y.referrerPolicy),m.title==null&&(m.title=y.title)}function PN(m,y){m.crossOrigin==null&&(m.crossOrigin=y.crossOrigin),m.referrerPolicy==null&&(m.referrerPolicy=y.referrerPolicy),m.integrity==null&&(m.integrity=y.integrity)}var $4=null;function tz(m,y,O){if($4===null){var N=new Map,$=$4=new Map;$.set(O,N)}else $=$4,N=$.get(O),N||(N=new Map,$.set(O,N));if(N.has(m))return N;for(N.set(m,null),O=O.getElementsByTagName(m),$=0;$<O.length;$++){var q=O[$];if(!(q[Ly]||q[Pa]||m==="link"&&q.getAttribute("rel")==="stylesheet")&&q.namespaceURI!=="http://www.w3.org/2000/svg"){var le=q.getAttribute(y)||"";le=m+le;var Ce=N.get(le);Ce?Ce.push(q):N.set(le,[q])}}return N}function $j(m,y,O){m=m.ownerDocument||m,m.head.insertBefore(O,y==="title"?m.querySelector("head > title"):null)}function kK(m,y,O){if(O===1||y.itemProp!=null)return!1;switch(m){case"meta":case"title":return!0;case"style":if(typeof y.precedence!="string"||typeof y.href!="string"||y.href==="")break;return!0;case"link":if(typeof y.rel!="string"||typeof y.href!="string"||y.href===""||y.onLoad||y.onError)break;switch(y.rel){case"stylesheet":return m=y.disabled,typeof y.precedence=="string"&&m==null;default:return!0}case"script":if(y.async&&typeof y.async!="function"&&typeof y.async!="symbol"&&!y.onLoad&&!y.onError&&y.src&&typeof y.src=="string")return!0}return!1}function nz(m){return!(m.type==="stylesheet"&&(m.state.loading&3)===0)}function OK(m,y,O,N){if(O.type==="stylesheet"&&(typeof N.media!="string"||matchMedia(N.media).matches!==!1)&&(O.state.loading&4)===0){if(O.instance===null){var $=P4(N.href),q=y.querySelector(r6($));if(q){y=q._p,y!==null&&typeof y=="object"&&typeof y.then=="function"&&(m.count++,m=Bj.bind(m),y.then(m,m)),O.state.loading|=4,O.instance=q,ra(q);return}q=y.ownerDocument||y,N=ZB(N),($=y1.get($))&&LN(N,$),q=q.createElement("link"),ra(q);var le=q;le._p=new Promise(function(Ce,dt){le.onload=Ce,le.onerror=dt}),Uf(q,"link",N),O.instance=q}m.stylesheets===null&&(m.stylesheets=new Map),m.stylesheets.set(O,y),(y=O.state.preload)&&(O.state.loading&3)===0&&(m.count++,O=Bj.bind(m),y.addEventListener("load",O),y.addEventListener("error",O))}}var IN=0;function SK(m,y){return m.stylesheets&&m.count===0&&Fj(m,m.stylesheets),0<m.count||0<m.imgCount?function(O){var N=setTimeout(function(){if(m.stylesheets&&Fj(m,m.stylesheets),m.unsuspend){var q=m.unsuspend;m.unsuspend=null,q()}},6e4+y);0<m.imgBytes&&IN===0&&(IN=62500*uK());var $=setTimeout(function(){if(m.waitingForImages=!1,m.count===0&&(m.stylesheets&&Fj(m,m.stylesheets),m.unsuspend)){var q=m.unsuspend;m.unsuspend=null,q()}},(m.imgBytes>IN?50:800)+y);return m.unsuspend=O,function(){m.unsuspend=null,clearTimeout(N),clearTimeout($)}}:null}function Bj(){if(this.count--,this.count===0&&(this.imgCount===0||!this.waitingForImages)){if(this.stylesheets)Fj(this,this.stylesheets);else if(this.unsuspend){var m=this.unsuspend;this.unsuspend=null,m()}}}var zj=null;function Fj(m,y){m.stylesheets=null,m.unsuspend!==null&&(m.count++,zj=new Map,y.forEach(jK,m),zj=null,Bj.call(m))}function jK(m,y){if(!(y.state.loading&4)){var O=zj.get(m);if(O)var N=O.get(null);else{O=new Map,zj.set(m,O);for(var $=m.querySelectorAll("link[data-precedence],style[data-precedence]"),q=0;q<$.length;q++){var le=$[q];(le.nodeName==="LINK"||le.getAttribute("media")!=="not all")&&(O.set(le.dataset.precedence,le),N=le)}N&&O.set(null,N)}$=y.instance,le=$.getAttribute("data-precedence"),q=O.get(le)||N,q===N&&O.set(null,$),O.set(le,$),this.count++,N=Bj.bind(this),$.addEventListener("load",N),$.addEventListener("error",N),q?q.parentNode.insertBefore($,q.nextSibling):(m=m.nodeType===9?m.head:m,m.insertBefore($,m.firstChild)),y.state.loading|=4}}var o6={$$typeof:ee,Provider:null,Consumer:null,_currentValue:Oe,_currentValue2:Oe,_threadCount:0};function TK(m,y,O,N,$,q,le,Ce,dt){this.tag=1,this.containerInfo=m,this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=-1,this.callbackNode=this.next=this.pendingContext=this.context=this.cancelPendingCommit=null,this.callbackPriority=0,this.expirationTimes=Ti(-1),this.entangledLanes=this.shellSuspendCounter=this.errorRecoveryDisabledLanes=this.expiredLanes=this.warmLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=Ti(0),this.hiddenUpdates=Ti(null),this.identifierPrefix=N,this.onUncaughtError=$,this.onCaughtError=q,this.onRecoverableError=le,this.pooledCache=null,this.pooledCacheLanes=0,this.formState=dt,this.incompleteTransitions=new Map}function iz(m,y,O,N,$,q,le,Ce,dt,Ft,gn,xn){return m=new TK(m,y,O,le,dt,Ft,gn,xn,Ce),y=1,q===!0&&(y|=24),q=d1(3,null,null,y),m.current=q,q.stateNode=m,y=aA(),y.refCount++,m.pooledCache=y,y.refCount++,q.memoizedState={element:N,isDehydrated:O,cache:y},pA(q),m}function rz(m){return m?(m=u4,m):u4}function sz(m,y,O,N,$,q){$=rz($),N.context===null?N.context=$:N.pendingContext=$,N=p2(y),N.payload={element:O},q=q===void 0?null:q,q!==null&&(N.callback=q),O=b2(m,N,y),O!==null&&(Dd(O,m,y),$O(O,m,y))}function RN(m,y){if(m=m.memoizedState,m!==null&&m.dehydrated!==null){var O=m.retryLane;m.retryLane=O!==0&&O<y?O:y}}function qj(m,y){RN(m,y),(m=m.alternate)&&RN(m,y)}function c6(m){if(m.tag===13||m.tag===31){var y=Fy(m,67108864);y!==null&&Dd(y,m,67108864),qj(m,67108864)}}function B4(m){if(m.tag===13||m.tag===31){var y=v1();y=Dy(y);var O=Fy(m,y);O!==null&&Dd(O,m,y),qj(m,y)}}var l6=!0;function mg(m,y,O,N){var $=ae.T;ae.T=null;var q=Le.p;try{Le.p=2,oz(m,y,O,N)}finally{Le.p=q,ae.T=$}}function EK(m,y,O,N){var $=ae.T;ae.T=null;var q=Le.p;try{Le.p=8,oz(m,y,O,N)}finally{Le.p=q,ae.T=$}}function oz(m,y,O,N){if(l6){var $=cz(N);if($===null)xN(m,y,N,$N,O),MK(m,N);else if(BN($,m,y,O,N))N.stopPropagation();else if(MK(m,N),y&4&&-1<ode.indexOf(m)){for(;$!==null;){var q=n2($);if(q!==null)switch(q.tag){case 3:if(q=q.stateNode,q.current.memoizedState.isDehydrated){var le=f0(q.pendingLanes);if(le!==0){var Ce=q;for(Ce.pendingLanes|=2,Ce.entangledLanes|=2;le;){var dt=1<<31-qf(le);Ce.entanglements[1]|=dt,le&=~dt}Rp(q),(rc&6)===0&&(jj=eu()+500,t6(0))}}break;case 31:case 13:Ce=Fy(q,2),Ce!==null&&Dd(Ce,q,2),Ej(),qj(q,2)}if(q=cz(N),q===null&&xN(m,y,N,$N,O),q===$)break;$=q}$!==null&&N.stopPropagation()}else xN(m,y,N,null,O)}}function cz(m){return m=PM(m),lz(m)}var $N=null;function lz(m){if($N=null,m=Ap(m),m!==null){var y=w(m);if(y===null)m=null;else{var O=y.tag;if(O===13){if(m=p(y),m!==null)return m;m=null}else if(O===31){if(m=k(y),m!==null)return m;m=null}else if(O===3){if(y.stateNode.current.memoizedState.isDehydrated)return y.tag===3?y.stateNode.containerInfo:null;m=null}else y!==m&&(m=null)}}return $N=m,null}function CK(m){switch(m){case"beforetoggle":case"cancel":case"click":case"close":case"contextmenu":case"copy":case"cut":case"auxclick":case"dblclick":case"dragend":case"dragstart":case"drop":case"focusin":case"focusout":case"input":case"invalid":case"keydown":case"keypress":case"keyup":case"mousedown":case"mouseup":case"paste":case"pause":case"play":case"pointercancel":case"pointerdown":case"pointerup":case"ratechange":case"reset":case"resize":case"seeked":case"submit":case"toggle":case"touchcancel":case"touchend":case"touchstart":case"volumechange":case"change":case"selectionchange":case"textInput":case"compositionstart":case"compositionend":case"compositionupdate":case"beforeblur":case"afterblur":case"beforeinput":case"blur":case"fullscreenchange":case"focus":case"hashchange":case"popstate":case"select":case"selectstart":return 2;case"drag":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"mousemove":case"mouseout":case"mouseover":case"pointermove":case"pointerout":case"pointerover":case"scroll":case"touchmove":case"wheel":case"mouseenter":case"mouseleave":case"pointerenter":case"pointerleave":return 8;case"message":switch(Un()){case Rc:return 2;case io:return 8;case zf:case tu:return 32;case Kw:return 268435456;default:return 32}default:return 32}}var uz=!1,mu=null,ym=null,Zy=null,z4=new Map,F4=new Map,ex=[],ode="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset".split(" ");function MK(m,y){switch(m){case"focusin":case"focusout":mu=null;break;case"dragenter":case"dragleave":ym=null;break;case"mouseover":case"mouseout":Zy=null;break;case"pointerover":case"pointerout":z4.delete(y.pointerId);break;case"gotpointercapture":case"lostpointercapture":F4.delete(y.pointerId)}}function Hj(m,y,O,N,$,q){return m===null||m.nativeEvent!==q?(m={blockedOn:y,domEventName:O,eventSystemFlags:N,nativeEvent:q,targetContainers:[$]},y!==null&&(y=n2(y),y!==null&&c6(y)),m):(m.eventSystemFlags|=N,y=m.targetContainers,$!==null&&y.indexOf($)===-1&&y.push($),m)}function BN(m,y,O,N,$){switch(y){case"focusin":return mu=Hj(mu,m,y,O,N,$),!0;case"dragenter":return ym=Hj(ym,m,y,O,N,$),!0;case"mouseover":return Zy=Hj(Zy,m,y,O,N,$),!0;case"pointerover":var q=$.pointerId;return z4.set(q,Hj(z4.get(q)||null,m,y,O,N,$)),!0;case"gotpointercapture":return q=$.pointerId,F4.set(q,Hj(F4.get(q)||null,m,y,O,N,$)),!0}return!1}function u6(m){var y=Ap(m.target);if(y!==null){var O=w(y);if(O!==null){if(y=O.tag,y===13){if(y=p(O),y!==null){m.blockedOn=y,mO(m.priority,function(){B4(O)});return}}else if(y===31){if(y=k(O),y!==null){m.blockedOn=y,mO(m.priority,function(){B4(O)});return}}else if(y===3&&O.stateNode.current.memoizedState.isDehydrated){m.blockedOn=O.tag===3?O.stateNode.containerInfo:null;return}}}m.blockedOn=null}function a6(m){if(m.blockedOn!==null)return!1;for(var y=m.targetContainers;0<y.length;){var O=cz(m.nativeEvent);if(O===null){O=m.nativeEvent;var N=new O.constructor(O.type,O);LM=N,O.target.dispatchEvent(N),LM=null}else return y=n2(O),y!==null&&c6(y),m.blockedOn=O,!1;y.shift()}return!0}function AK(m,y,O){a6(m)&&O.delete(y)}function cde(){uz=!1,mu!==null&&a6(mu)&&(mu=null),ym!==null&&a6(ym)&&(ym=null),Zy!==null&&a6(Zy)&&(Zy=null),z4.forEach(AK),F4.forEach(AK)}function zN(m,y){m.blockedOn===y&&(m.blockedOn=null,uz||(uz=!0,l.unstable_scheduleCallback(l.unstable_NormalPriority,cde)))}var Qj=null;function NK(m){Qj!==m&&(Qj=m,l.unstable_scheduleCallback(l.unstable_NormalPriority,function(){Qj===m&&(Qj=null);for(var y=0;y<m.length;y+=3){var O=m[y],N=m[y+1],$=m[y+2];if(typeof N!="function"){if(lz(N||O)===null)continue;break}var q=n2(O);q!==null&&(m.splice(y,3),y-=3,HO(q,{pending:!0,data:$,method:O.method,action:N},N,$))}}))}function tx(m){function y(dt){return zN(dt,m)}mu!==null&&zN(mu,m),ym!==null&&zN(ym,m),Zy!==null&&zN(Zy,m),z4.forEach(y),F4.forEach(y);for(var O=0;O<ex.length;O++){var N=ex[O];N.blockedOn===m&&(N.blockedOn=null)}for(;0<ex.length&&(O=ex[0],O.blockedOn===null);)u6(O),O.blockedOn===null&&ex.shift();if(O=(m.ownerDocument||m).$$reactFormReplay,O!=null)for(N=0;N<O.length;N+=3){var $=O[N],q=O[N+1],le=$[ph]||null;if(typeof q=="function")le||NK(O);else if(le){var Ce=null;if(q&&q.hasAttribute("formAction")){if($=q,le=q[ph]||null)Ce=le.formAction;else if(lz($)!==null)continue}else Ce=le.action;typeof Ce=="function"?O[N+1]=Ce:(O.splice(N,3),N-=3),NK(O)}}}function _K(){function m(q){q.canIntercept&&q.info==="react-transition"&&q.intercept({handler:function(){return new Promise(function(le){return $=le})},focusReset:"manual",scroll:"manual"})}function y(){$!==null&&($(),$=null),N||setTimeout(O,20)}function O(){if(!N&&!navigation.transition){var q=navigation.currentEntry;q&&q.url!=null&&navigation.navigate(q.url,{state:q.getState(),info:"react-transition",history:"replace"})}}if(typeof navigation=="object"){var N=!1,$=null;return navigation.addEventListener("navigate",m),navigation.addEventListener("navigatesuccess",y),navigation.addEventListener("navigateerror",y),setTimeout(O,100),function(){N=!0,navigation.removeEventListener("navigate",m),navigation.removeEventListener("navigatesuccess",y),navigation.removeEventListener("navigateerror",y),$!==null&&($(),$=null)}}}function az(m){this._internalRoot=m}FN.prototype.render=az.prototype.render=function(m){var y=this._internalRoot;if(y===null)throw Error(h(409));var O=y.current,N=v1();sz(O,N,m,y,null,null)},FN.prototype.unmount=az.prototype.unmount=function(){var m=this._internalRoot;if(m!==null){this._internalRoot=null;var y=m.containerInfo;sz(m.current,2,null,m,null,null),Ej(),y[rm]=null}};function FN(m){this._internalRoot=m}FN.prototype.unstable_scheduleHydration=function(m){if(m){var y=A8();m={blockedOn:null,target:m,priority:y};for(var O=0;O<ex.length&&y!==0&&y<ex[O].priority;O++);ex.splice(O,0,m),O===0&&u6(m)}};var q4=s.version;if(q4!=="19.2.4")throw Error(h(527,q4,"19.2.4"));Le.findDOMNode=function(m){var y=m._reactInternals;if(y===void 0)throw typeof m.render=="function"?Error(h(188)):(m=Object.keys(m).join(","),Error(h(268,m)));return m=A(y),m=m!==null?_(m):null,m=m===null?null:m.stateNode,m};var qN={bundleType:0,version:"19.2.4",rendererPackageName:"react-dom",currentDispatcherRef:ae,reconcilerVersion:"19.2.4"};if(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__<"u"){var H4=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(!H4.isDisabled&&H4.supportsFiber)try{Cp=H4.inject(qN),Ff=H4}catch{}}return mX.createRoot=function(m,y){if(!g(m))throw Error(h(299));var O=!1,N="",$=C$,q=M$,le=A$;return y!=null&&(y.unstable_strictMode===!0&&(O=!0),y.identifierPrefix!==void 0&&(N=y.identifierPrefix),y.onUncaughtError!==void 0&&($=y.onUncaughtError),y.onCaughtError!==void 0&&(q=y.onCaughtError),y.onRecoverableError!==void 0&&(le=y.onRecoverableError)),y=iz(m,1,!1,null,null,O,N,null,$,q,le,_K),m[rm]=y.current,yN(m),new az(y)},mX.hydrateRoot=function(m,y,O){if(!g(m))throw Error(h(299));var N=!1,$="",q=C$,le=M$,Ce=A$,dt=null;return O!=null&&(O.unstable_strictMode===!0&&(N=!0),O.identifierPrefix!==void 0&&($=O.identifierPrefix),O.onUncaughtError!==void 0&&(q=O.onUncaughtError),O.onCaughtError!==void 0&&(le=O.onCaughtError),O.onRecoverableError!==void 0&&(Ce=O.onRecoverableError),O.formState!==void 0&&(dt=O.formState)),y=iz(m,1,!0,y,O??null,N,$,dt,q,le,Ce,_K),y.context=rz(null),O=y.current,N=v1(),N=Dy(N),$=p2(N),$.callback=null,b2(O,$,N),O=N,y.current.lanes=O,gu(y,O),Rp(y),m[rm]=y.current,yN(m),new FN(y)},mX.version="19.2.4",mX}var Gvt;function ynn(){if(Gvt)return uEe.exports;Gvt=1;function l(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(l)}catch(s){console.error(s)}}return l(),uEe.exports=vnn(),uEe.exports}var xnn=ynn();function dh(l){if(typeof l=="string"||typeof l=="number")return""+l;let s="";if(Array.isArray(l))for(let u=0,h;u<l.length;u++)(h=dh(l[u]))!==""&&(s+=(s&&" ")+h);else for(let u in l)l[u]&&(s+=(s&&" ")+u);return s}var knn={value:()=>{}};function The(){for(var l=0,s=arguments.length,u={},h;l<s;++l){if(!(h=arguments[l]+"")||h in u||/[\s.]/.test(h))throw new Error("illegal type: "+h);u[h]=[]}return new yfe(u)}function yfe(l){this._=l}function Onn(l,s){return l.trim().split(/^|\s+/).map(function(u){var h="",g=u.indexOf(".");if(g>=0&&(h=u.slice(g+1),u=u.slice(0,g)),u&&!s.hasOwnProperty(u))throw new Error("unknown type: "+u);return{type:u,name:h}})}yfe.prototype=The.prototype={constructor:yfe,on:function(l,s){var u=this._,h=Onn(l+"",u),g,w=-1,p=h.length;if(arguments.length<2){for(;++w<p;)if((g=(l=h[w]).type)&&(g=Snn(u[g],l.name)))return g;return}if(s!=null&&typeof s!="function")throw new Error("invalid callback: "+s);for(;++w<p;)if(g=(l=h[w]).type)u[g]=Uvt(u[g],l.name,s);else if(s==null)for(g in u)u[g]=Uvt(u[g],l.name,null);return this},copy:function(){var l={},s=this._;for(var u in s)l[u]=s[u].slice();return new yfe(l)},call:function(l,s){if((g=arguments.length-2)>0)for(var u=new Array(g),h=0,g,w;h<g;++h)u[h]=arguments[h+2];if(!this._.hasOwnProperty(l))throw new Error("unknown type: "+l);for(w=this._[l],h=0,g=w.length;h<g;++h)w[h].value.apply(s,u)},apply:function(l,s,u){if(!this._.hasOwnProperty(l))throw new Error("unknown type: "+l);for(var h=this._[l],g=0,w=h.length;g<w;++g)h[g].value.apply(s,u)}};function Snn(l,s){for(var u=0,h=l.length,g;u<h;++u)if((g=l[u]).name===s)return g.value}function Uvt(l,s,u){for(var h=0,g=l.length;h<g;++h)if(l[h].name===s){l[h]=knn,l=l.slice(0,h).concat(l.slice(h+1));break}return u!=null&&l.push({name:s,value:u}),l}var fCe="http://www.w3.org/1999/xhtml";const Jvt={svg:"http://www.w3.org/2000/svg",xhtml:fCe,xlink:"http://www.w3.org/1999/xlink",xml:"http://www.w3.org/XML/1998/namespace",xmlns:"http://www.w3.org/2000/xmlns/"};function Ehe(l){var s=l+="",u=s.indexOf(":");return u>=0&&(s=l.slice(0,u))!=="xmlns"&&(l=l.slice(u+1)),Jvt.hasOwnProperty(s)?{space:Jvt[s],local:l}:l}function jnn(l){return function(){var s=this.ownerDocument,u=this.namespaceURI;return u===fCe&&s.documentElement.namespaceURI===fCe?s.createElement(l):s.createElementNS(u,l)}}function Tnn(l){return function(){return this.ownerDocument.createElementNS(l.space,l.local)}}function u4t(l){var s=Ehe(l);return(s.local?Tnn:jnn)(s)}function Enn(){}function kMe(l){return l==null?Enn:function(){return this.querySelector(l)}}function Cnn(l){typeof l!="function"&&(l=kMe(l));for(var s=this._groups,u=s.length,h=new Array(u),g=0;g<u;++g)for(var w=s[g],p=w.length,k=h[g]=new Array(p),j,A,_=0;_<p;++_)(j=w[_])&&(A=l.call(j,j.__data__,_,w))&&("__data__"in j&&(A.__data__=j.__data__),k[_]=A);return new nm(h,this._parents)}function Mnn(l){return l==null?[]:Array.isArray(l)?l:Array.from(l)}function Ann(){return[]}function a4t(l){return l==null?Ann:function(){return this.querySelectorAll(l)}}function Nnn(l){return function(){return Mnn(l.apply(this,arguments))}}function _nn(l){typeof l=="function"?l=Nnn(l):l=a4t(l);for(var s=this._groups,u=s.length,h=[],g=[],w=0;w<u;++w)for(var p=s[w],k=p.length,j,A=0;A<k;++A)(j=p[A])&&(h.push(l.call(j,j.__data__,A,p)),g.push(j));return new nm(h,g)}function f4t(l){return function(){return this.matches(l)}}function h4t(l){return function(s){return s.matches(l)}}var Dnn=Array.prototype.find;function Lnn(l){return function(){return Dnn.call(this.children,l)}}function Pnn(){return this.firstElementChild}function Inn(l){return this.select(l==null?Pnn:Lnn(typeof l=="function"?l:h4t(l)))}var Rnn=Array.prototype.filter;function $nn(){return Array.from(this.children)}function Bnn(l){return function(){return Rnn.call(this.children,l)}}function znn(l){return this.selectAll(l==null?$nn:Bnn(typeof l=="function"?l:h4t(l)))}function Fnn(l){typeof l!="function"&&(l=f4t(l));for(var s=this._groups,u=s.length,h=new Array(u),g=0;g<u;++g)for(var w=s[g],p=w.length,k=h[g]=[],j,A=0;A<p;++A)(j=w[A])&&l.call(j,j.__data__,A,w)&&k.push(j);return new nm(h,this._parents)}function d4t(l){return new Array(l.length)}function qnn(){return new nm(this._enter||this._groups.map(d4t),this._parents)}function Ife(l,s){this.ownerDocument=l.ownerDocument,this.namespaceURI=l.namespaceURI,this._next=null,this._parent=l,this.__data__=s}Ife.prototype={constructor:Ife,appendChild:function(l){return this._parent.insertBefore(l,this._next)},insertBefore:function(l,s){return this._parent.insertBefore(l,s)},querySelector:function(l){return this._parent.querySelector(l)},querySelectorAll:function(l){return this._parent.querySelectorAll(l)}};function Hnn(l){return function(){return l}}function Qnn(l,s,u,h,g,w){for(var p=0,k,j=s.length,A=w.length;p<A;++p)(k=s[p])?(k.__data__=w[p],h[p]=k):u[p]=new Ife(l,w[p]);for(;p<j;++p)(k=s[p])&&(g[p]=k)}function Gnn(l,s,u,h,g,w,p){var k,j,A=new Map,_=s.length,D=w.length,I=new Array(_),B;for(k=0;k<_;++k)(j=s[k])&&(I[k]=B=p.call(j,j.__data__,k,s)+"",A.has(B)?g[k]=j:A.set(B,j));for(k=0;k<D;++k)B=p.call(l,w[k],k,w)+"",(j=A.get(B))?(h[k]=j,j.__data__=w[k],A.delete(B)):u[k]=new Ife(l,w[k]);for(k=0;k<_;++k)(j=s[k])&&A.get(I[k])===j&&(g[k]=j)}function Unn(l){return l.__data__}function Jnn(l,s){if(!arguments.length)return Array.from(this,Unn);var u=s?Gnn:Qnn,h=this._parents,g=this._groups;typeof l!="function"&&(l=Hnn(l));for(var w=g.length,p=new Array(w),k=new Array(w),j=new Array(w),A=0;A<w;++A){var _=h[A],D=g[A],I=D.length,B=Xnn(l.call(_,_&&_.__data__,A,h)),F=B.length,U=k[A]=new Array(F),K=p[A]=new Array(F),Y=j[A]=new Array(I);u(_,D,U,K,Y,B,s);for(var Z=0,ee=0,ce,fe;Z<F;++Z)if(ce=U[Z]){for(Z>=ee&&(ee=Z+1);!(fe=K[ee])&&++ee<F;);ce._next=fe||null}}return p=new nm(p,h),p._enter=k,p._exit=j,p}function Xnn(l){return typeof l=="object"&&"length"in l?l:Array.from(l)}function Vnn(){return new nm(this._exit||this._groups.map(d4t),this._parents)}function Wnn(l,s,u){var h=this.enter(),g=this,w=this.exit();return typeof l=="function"?(h=l(h),h&&(h=h.selection())):h=h.append(l+""),s!=null&&(g=s(g),g&&(g=g.selection())),u==null?w.remove():u(w),h&&g?h.merge(g).order():g}function Knn(l){for(var s=l.selection?l.selection():l,u=this._groups,h=s._groups,g=u.length,w=h.length,p=Math.min(g,w),k=new Array(g),j=0;j<p;++j)for(var A=u[j],_=h[j],D=A.length,I=k[j]=new Array(D),B,F=0;F<D;++F)(B=A[F]||_[F])&&(I[F]=B);for(;j<g;++j)k[j]=u[j];return new nm(k,this._parents)}function Ynn(){for(var l=this._groups,s=-1,u=l.length;++s<u;)for(var h=l[s],g=h.length-1,w=h[g],p;--g>=0;)(p=h[g])&&(w&&p.compareDocumentPosition(w)^4&&w.parentNode.insertBefore(p,w),w=p);return this}function Znn(l){l||(l=ein);function s(D,I){return D&&I?l(D.__data__,I.__data__):!D-!I}for(var u=this._groups,h=u.length,g=new Array(h),w=0;w<h;++w){for(var p=u[w],k=p.length,j=g[w]=new Array(k),A,_=0;_<k;++_)(A=p[_])&&(j[_]=A);j.sort(s)}return new nm(g,this._parents).order()}function ein(l,s){return l<s?-1:l>s?1:l>=s?0:NaN}function tin(){var l=arguments[0];return arguments[0]=this,l.apply(null,arguments),this}function nin(){return Array.from(this)}function iin(){for(var l=this._groups,s=0,u=l.length;s<u;++s)for(var h=l[s],g=0,w=h.length;g<w;++g){var p=h[g];if(p)return p}return null}function rin(){let l=0;for(const s of this)++l;return l}function sin(){return!this.node()}function oin(l){for(var s=this._groups,u=0,h=s.length;u<h;++u)for(var g=s[u],w=0,p=g.length,k;w<p;++w)(k=g[w])&&l.call(k,k.__data__,w,g);return this}function cin(l){return function(){this.removeAttribute(l)}}function lin(l){return function(){this.removeAttributeNS(l.space,l.local)}}function uin(l,s){return function(){this.setAttribute(l,s)}}function ain(l,s){return function(){this.setAttributeNS(l.space,l.local,s)}}function fin(l,s){return function(){var u=s.apply(this,arguments);u==null?this.removeAttribute(l):this.setAttribute(l,u)}}function hin(l,s){return function(){var u=s.apply(this,arguments);u==null?this.removeAttributeNS(l.space,l.local):this.setAttributeNS(l.space,l.local,u)}}function din(l,s){var u=Ehe(l);if(arguments.length<2){var h=this.node();return u.local?h.getAttributeNS(u.space,u.local):h.getAttribute(u)}return this.each((s==null?u.local?lin:cin:typeof s=="function"?u.local?hin:fin:u.local?ain:uin)(u,s))}function g4t(l){return l.ownerDocument&&l.ownerDocument.defaultView||l.document&&l||l.defaultView}function gin(l){return function(){this.style.removeProperty(l)}}function pin(l,s,u){return function(){this.style.setProperty(l,s,u)}}function bin(l,s,u){return function(){var h=s.apply(this,arguments);h==null?this.style.removeProperty(l):this.style.setProperty(l,h,u)}}function min(l,s,u){return arguments.length>1?this.each((s==null?gin:typeof s=="function"?bin:pin)(l,s,u??"")):OI(this.node(),l)}function OI(l,s){return l.style.getPropertyValue(s)||g4t(l).getComputedStyle(l,null).getPropertyValue(s)}function win(l){return function(){delete this[l]}}function vin(l,s){return function(){this[l]=s}}function yin(l,s){return function(){var u=s.apply(this,arguments);u==null?delete this[l]:this[l]=u}}function xin(l,s){return arguments.length>1?this.each((s==null?win:typeof s=="function"?yin:vin)(l,s)):this.node()[l]}function p4t(l){return l.trim().split(/^|\s+/)}function OMe(l){return l.classList||new b4t(l)}function b4t(l){this._node=l,this._names=p4t(l.getAttribute("class")||"")}b4t.prototype={add:function(l){var s=this._names.indexOf(l);s<0&&(this._names.push(l),this._node.setAttribute("class",this._names.join(" ")))},remove:function(l){var s=this._names.indexOf(l);s>=0&&(this._names.splice(s,1),this._node.setAttribute("class",this._names.join(" ")))},contains:function(l){return this._names.indexOf(l)>=0}};function m4t(l,s){for(var u=OMe(l),h=-1,g=s.length;++h<g;)u.add(s[h])}function w4t(l,s){for(var u=OMe(l),h=-1,g=s.length;++h<g;)u.remove(s[h])}function kin(l){return function(){m4t(this,l)}}function Oin(l){return function(){w4t(this,l)}}function Sin(l,s){return function(){(s.apply(this,arguments)?m4t:w4t)(this,l)}}function jin(l,s){var u=p4t(l+"");if(arguments.length<2){for(var h=OMe(this.node()),g=-1,w=u.length;++g<w;)if(!h.contains(u[g]))return!1;return!0}return this.each((typeof s=="function"?Sin:s?kin:Oin)(u,s))}function Tin(){this.textContent=""}function Ein(l){return function(){this.textContent=l}}function Cin(l){return function(){var s=l.apply(this,arguments);this.textContent=s??""}}function Min(l){return arguments.length?this.each(l==null?Tin:(typeof l=="function"?Cin:Ein)(l)):this.node().textContent}function Ain(){this.innerHTML=""}function Nin(l){return function(){this.innerHTML=l}}function _in(l){return function(){var s=l.apply(this,arguments);this.innerHTML=s??""}}function Din(l){return arguments.length?this.each(l==null?Ain:(typeof l=="function"?_in:Nin)(l)):this.node().innerHTML}function Lin(){this.nextSibling&&this.parentNode.appendChild(this)}function Pin(){return this.each(Lin)}function Iin(){this.previousSibling&&this.parentNode.insertBefore(this,this.parentNode.firstChild)}function Rin(){return this.each(Iin)}function $in(l){var s=typeof l=="function"?l:u4t(l);return this.select(function(){return this.appendChild(s.apply(this,arguments))})}function Bin(){return null}function zin(l,s){var u=typeof l=="function"?l:u4t(l),h=s==null?Bin:typeof s=="function"?s:kMe(s);return this.select(function(){return this.insertBefore(u.apply(this,arguments),h.apply(this,arguments)||null)})}function Fin(){var l=this.parentNode;l&&l.removeChild(this)}function qin(){return this.each(Fin)}function Hin(){var l=this.cloneNode(!1),s=this.parentNode;return s?s.insertBefore(l,this.nextSibling):l}function Qin(){var l=this.cloneNode(!0),s=this.parentNode;return s?s.insertBefore(l,this.nextSibling):l}function Gin(l){return this.select(l?Qin:Hin)}function Uin(l){return arguments.length?this.property("__data__",l):this.node().__data__}function Jin(l){return function(s){l.call(this,s,this.__data__)}}function Xin(l){return l.trim().split(/^|\s+/).map(function(s){var u="",h=s.indexOf(".");return h>=0&&(u=s.slice(h+1),s=s.slice(0,h)),{type:s,name:u}})}function Vin(l){return function(){var s=this.__on;if(s){for(var u=0,h=-1,g=s.length,w;u<g;++u)w=s[u],(!l.type||w.type===l.type)&&w.name===l.name?this.removeEventListener(w.type,w.listener,w.options):s[++h]=w;++h?s.length=h:delete this.__on}}}function Win(l,s,u){return function(){var h=this.__on,g,w=Jin(s);if(h){for(var p=0,k=h.length;p<k;++p)if((g=h[p]).type===l.type&&g.name===l.name){this.removeEventListener(g.type,g.listener,g.options),this.addEventListener(g.type,g.listener=w,g.options=u),g.value=s;return}}this.addEventListener(l.type,w,u),g={type:l.type,name:l.name,value:s,listener:w,options:u},h?h.push(g):this.__on=[g]}}function Kin(l,s,u){var h=Xin(l+""),g,w=h.length,p;if(arguments.length<2){var k=this.node().__on;if(k){for(var j=0,A=k.length,_;j<A;++j)for(g=0,_=k[j];g<w;++g)if((p=h[g]).type===_.type&&p.name===_.name)return _.value}return}for(k=s?Win:Vin,g=0;g<w;++g)this.each(k(h[g],s,u));return this}function v4t(l,s,u){var h=g4t(l),g=h.CustomEvent;typeof g=="function"?g=new g(s,u):(g=h.document.createEvent("Event"),u?(g.initEvent(s,u.bubbles,u.cancelable),g.detail=u.detail):g.initEvent(s,!1,!1)),l.dispatchEvent(g)}function Yin(l,s){return function(){return v4t(this,l,s)}}function Zin(l,s){return function(){return v4t(this,l,s.apply(this,arguments))}}function ern(l,s){return this.each((typeof s=="function"?Zin:Yin)(l,s))}function*trn(){for(var l=this._groups,s=0,u=l.length;s<u;++s)for(var h=l[s],g=0,w=h.length,p;g<w;++g)(p=h[g])&&(yield p)}var y4t=[null];function nm(l,s){this._groups=l,this._parents=s}function vV(){return new nm([[document.documentElement]],y4t)}function nrn(){return this}nm.prototype=vV.prototype={constructor:nm,select:Cnn,selectAll:_nn,selectChild:Inn,selectChildren:znn,filter:Fnn,data:Jnn,enter:qnn,exit:Vnn,join:Wnn,merge:Knn,selection:nrn,order:Ynn,sort:Znn,call:tin,nodes:nin,node:iin,size:rin,empty:sin,each:oin,attr:din,style:min,property:xin,classed:jin,text:Min,html:Din,raise:Pin,lower:Rin,append:$in,insert:zin,remove:qin,clone:Gin,datum:Uin,on:Kin,dispatch:ern,[Symbol.iterator]:trn};function tm(l){return typeof l=="string"?new nm([[document.querySelector(l)]],[document.documentElement]):new nm([[l]],y4t)}function irn(l){let s;for(;s=l.sourceEvent;)l=s;return l}function wy(l,s){if(l=irn(l),s===void 0&&(s=l.currentTarget),s){var u=s.ownerSVGElement||s;if(u.createSVGPoint){var h=u.createSVGPoint();return h.x=l.clientX,h.y=l.clientY,h=h.matrixTransform(s.getScreenCTM().inverse()),[h.x,h.y]}if(s.getBoundingClientRect){var g=s.getBoundingClientRect();return[l.clientX-g.left-s.clientLeft,l.clientY-g.top-s.clientTop]}}return[l.pageX,l.pageY]}const rrn={passive:!1},GX={capture:!0,passive:!1};function dEe(l){l.stopImmediatePropagation()}function gI(l){l.preventDefault(),l.stopImmediatePropagation()}function x4t(l){var s=l.document.documentElement,u=tm(l).on("dragstart.drag",gI,GX);"onselectstart"in s?u.on("selectstart.drag",gI,GX):(s.__noselect=s.style.MozUserSelect,s.style.MozUserSelect="none")}function k4t(l,s){var u=l.document.documentElement,h=tm(l).on("dragstart.drag",null);s&&(h.on("click.drag",gI,GX),setTimeout(function(){h.on("click.drag",null)},0)),"onselectstart"in u?h.on("selectstart.drag",null):(u.style.MozUserSelect=u.__noselect,delete u.__noselect)}const Iae=l=>()=>l;function hCe(l,{sourceEvent:s,subject:u,target:h,identifier:g,active:w,x:p,y:k,dx:j,dy:A,dispatch:_}){Object.defineProperties(this,{type:{value:l,enumerable:!0,configurable:!0},sourceEvent:{value:s,enumerable:!0,configurable:!0},subject:{value:u,enumerable:!0,configurable:!0},target:{value:h,enumerable:!0,configurable:!0},identifier:{value:g,enumerable:!0,configurable:!0},active:{value:w,enumerable:!0,configurable:!0},x:{value:p,enumerable:!0,configurable:!0},y:{value:k,enumerable:!0,configurable:!0},dx:{value:j,enumerable:!0,configurable:!0},dy:{value:A,enumerable:!0,configurable:!0},_:{value:_}})}hCe.prototype.on=function(){var l=this._.on.apply(this._,arguments);return l===this._?this:l};function srn(l){return!l.ctrlKey&&!l.button}function orn(){return this.parentNode}function crn(l,s){return s??{x:l.x,y:l.y}}function lrn(){return navigator.maxTouchPoints||"ontouchstart"in this}function O4t(){var l=srn,s=orn,u=crn,h=lrn,g={},w=The("start","drag","end"),p=0,k,j,A,_,D=0;function I(ce){ce.on("mousedown.drag",B).filter(h).on("touchstart.drag",K).on("touchmove.drag",Y,rrn).on("touchend.drag touchcancel.drag",Z).style("touch-action","none").style("-webkit-tap-highlight-color","rgba(0,0,0,0)")}function B(ce,fe){if(!(_||!l.call(this,ce,fe))){var be=ee(this,s.call(this,ce,fe),ce,fe,"mouse");be&&(tm(ce.view).on("mousemove.drag",F,GX).on("mouseup.drag",U,GX),x4t(ce.view),dEe(ce),A=!1,k=ce.clientX,j=ce.clientY,be("start",ce))}}function F(ce){if(gI(ce),!A){var fe=ce.clientX-k,be=ce.clientY-j;A=fe*fe+be*be>D}g.mouse("drag",ce)}function U(ce){tm(ce.view).on("mousemove.drag mouseup.drag",null),k4t(ce.view,A),gI(ce),g.mouse("end",ce)}function K(ce,fe){if(l.call(this,ce,fe)){var be=ce.changedTouches,me=s.call(this,ce,fe),Re=be.length,Te,Ke;for(Te=0;Te<Re;++Te)(Ke=ee(this,me,ce,fe,be[Te].identifier,be[Te]))&&(dEe(ce),Ke("start",ce,be[Te]))}}function Y(ce){var fe=ce.changedTouches,be=fe.length,me,Re;for(me=0;me<be;++me)(Re=g[fe[me].identifier])&&(gI(ce),Re("drag",ce,fe[me]))}function Z(ce){var fe=ce.changedTouches,be=fe.length,me,Re;for(_&&clearTimeout(_),_=setTimeout(function(){_=null},500),me=0;me<be;++me)(Re=g[fe[me].identifier])&&(dEe(ce),Re("end",ce,fe[me]))}function ee(ce,fe,be,me,Re,Te){var Ke=w.copy(),ze=wy(Te||be,fe),je,te,ge;if((ge=u.call(ce,new hCe("beforestart",{sourceEvent:be,target:I,identifier:Re,active:p,x:ze[0],y:ze[1],dx:0,dy:0,dispatch:Ke}),me))!=null)return je=ge.x-ze[0]||0,te=ge.y-ze[1]||0,function He(ae,Le,Oe){var Qe=ze,kt;switch(ae){case"start":g[Re]=He,kt=p++;break;case"end":delete g[Re],--p;case"drag":ze=wy(Oe||Le,fe),kt=p;break}Ke.call(ae,ce,new hCe(ae,{sourceEvent:Le,subject:ge,target:I,identifier:Re,active:kt,x:ze[0]+je,y:ze[1]+te,dx:ze[0]-Qe[0],dy:ze[1]-Qe[1],dispatch:Ke}),me)}}return I.filter=function(ce){return arguments.length?(l=typeof ce=="function"?ce:Iae(!!ce),I):l},I.container=function(ce){return arguments.length?(s=typeof ce=="function"?ce:Iae(ce),I):s},I.subject=function(ce){return arguments.length?(u=typeof ce=="function"?ce:Iae(ce),I):u},I.touchable=function(ce){return arguments.length?(h=typeof ce=="function"?ce:Iae(!!ce),I):h},I.on=function(){var ce=w.on.apply(w,arguments);return ce===w?I:ce},I.clickDistance=function(ce){return arguments.length?(D=(ce=+ce)*ce,I):Math.sqrt(D)},I}function SMe(l,s,u){l.prototype=s.prototype=u,u.constructor=l}function S4t(l,s){var u=Object.create(l.prototype);for(var h in s)u[h]=s[h];return u}function yV(){}var UX=.7,Rfe=1/UX,pI="\\s*([+-]?\\d+)\\s*",JX="\\s*([+-]?(?:\\d*\\.)?\\d+(?:[eE][+-]?\\d+)?)\\s*",X3="\\s*([+-]?(?:\\d*\\.)?\\d+(?:[eE][+-]?\\d+)?)%\\s*",urn=/^#([0-9a-f]{3,8})$/,arn=new RegExp(`^rgb\\(${pI},${pI},${pI}\\)$`),frn=new RegExp(`^rgb\\(${X3},${X3},${X3}\\)$`),hrn=new RegExp(`^rgba\\(${pI},${pI},${pI},${JX}\\)$`),drn=new RegExp(`^rgba\\(${X3},${X3},${X3},${JX}\\)$`),grn=new RegExp(`^hsl\\(${JX},${X3},${X3}\\)$`),prn=new RegExp(`^hsla\\(${JX},${X3},${X3},${JX}\\)$`),Xvt={aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074};SMe(yV,bM,{copy(l){return Object.assign(new this.constructor,this,l)},displayable(){return this.rgb().displayable()},hex:Vvt,formatHex:Vvt,formatHex8:brn,formatHsl:mrn,formatRgb:Wvt,toString:Wvt});function Vvt(){return this.rgb().formatHex()}function brn(){return this.rgb().formatHex8()}function mrn(){return j4t(this).formatHsl()}function Wvt(){return this.rgb().formatRgb()}function bM(l){var s,u;return l=(l+"").trim().toLowerCase(),(s=urn.exec(l))?(u=s[1].length,s=parseInt(s[1],16),u===6?Kvt(s):u===3?new xp(s>>8&15|s>>4&240,s>>4&15|s&240,(s&15)<<4|s&15,1):u===8?Rae(s>>24&255,s>>16&255,s>>8&255,(s&255)/255):u===4?Rae(s>>12&15|s>>8&240,s>>8&15|s>>4&240,s>>4&15|s&240,((s&15)<<4|s&15)/255):null):(s=arn.exec(l))?new xp(s[1],s[2],s[3],1):(s=frn.exec(l))?new xp(s[1]*255/100,s[2]*255/100,s[3]*255/100,1):(s=hrn.exec(l))?Rae(s[1],s[2],s[3],s[4]):(s=drn.exec(l))?Rae(s[1]*255/100,s[2]*255/100,s[3]*255/100,s[4]):(s=grn.exec(l))?eyt(s[1],s[2]/100,s[3]/100,1):(s=prn.exec(l))?eyt(s[1],s[2]/100,s[3]/100,s[4]):Xvt.hasOwnProperty(l)?Kvt(Xvt[l]):l==="transparent"?new xp(NaN,NaN,NaN,0):null}function Kvt(l){return new xp(l>>16&255,l>>8&255,l&255,1)}function Rae(l,s,u,h){return h<=0&&(l=s=u=NaN),new xp(l,s,u,h)}function wrn(l){return l instanceof yV||(l=bM(l)),l?(l=l.rgb(),new xp(l.r,l.g,l.b,l.opacity)):new xp}function dCe(l,s,u,h){return arguments.length===1?wrn(l):new xp(l,s,u,h??1)}function xp(l,s,u,h){this.r=+l,this.g=+s,this.b=+u,this.opacity=+h}SMe(xp,dCe,S4t(yV,{brighter(l){return l=l==null?Rfe:Math.pow(Rfe,l),new xp(this.r*l,this.g*l,this.b*l,this.opacity)},darker(l){return l=l==null?UX:Math.pow(UX,l),new xp(this.r*l,this.g*l,this.b*l,this.opacity)},rgb(){return this},clamp(){return new xp(hM(this.r),hM(this.g),hM(this.b),$fe(this.opacity))},displayable(){return-.5<=this.r&&this.r<255.5&&-.5<=this.g&&this.g<255.5&&-.5<=this.b&&this.b<255.5&&0<=this.opacity&&this.opacity<=1},hex:Yvt,formatHex:Yvt,formatHex8:vrn,formatRgb:Zvt,toString:Zvt}));function Yvt(){return`#${lM(this.r)}${lM(this.g)}${lM(this.b)}`}function vrn(){return`#${lM(this.r)}${lM(this.g)}${lM(this.b)}${lM((isNaN(this.opacity)?1:this.opacity)*255)}`}function Zvt(){const l=$fe(this.opacity);return`${l===1?"rgb(":"rgba("}${hM(this.r)}, ${hM(this.g)}, ${hM(this.b)}${l===1?")":`, ${l})`}`}function $fe(l){return isNaN(l)?1:Math.max(0,Math.min(1,l))}function hM(l){return Math.max(0,Math.min(255,Math.round(l)||0))}function lM(l){return l=hM(l),(l<16?"0":"")+l.toString(16)}function eyt(l,s,u,h){return h<=0?l=s=u=NaN:u<=0||u>=1?l=s=NaN:s<=0&&(l=NaN),new vy(l,s,u,h)}function j4t(l){if(l instanceof vy)return new vy(l.h,l.s,l.l,l.opacity);if(l instanceof yV||(l=bM(l)),!l)return new vy;if(l instanceof vy)return l;l=l.rgb();var s=l.r/255,u=l.g/255,h=l.b/255,g=Math.min(s,u,h),w=Math.max(s,u,h),p=NaN,k=w-g,j=(w+g)/2;return k?(s===w?p=(u-h)/k+(u<h)*6:u===w?p=(h-s)/k+2:p=(s-u)/k+4,k/=j<.5?w+g:2-w-g,p*=60):k=j>0&&j<1?0:p,new vy(p,k,j,l.opacity)}function yrn(l,s,u,h){return arguments.length===1?j4t(l):new vy(l,s,u,h??1)}function vy(l,s,u,h){this.h=+l,this.s=+s,this.l=+u,this.opacity=+h}SMe(vy,yrn,S4t(yV,{brighter(l){return l=l==null?Rfe:Math.pow(Rfe,l),new vy(this.h,this.s,this.l*l,this.opacity)},darker(l){return l=l==null?UX:Math.pow(UX,l),new vy(this.h,this.s,this.l*l,this.opacity)},rgb(){var l=this.h%360+(this.h<0)*360,s=isNaN(l)||isNaN(this.s)?0:this.s,u=this.l,h=u+(u<.5?u:1-u)*s,g=2*u-h;return new xp(gEe(l>=240?l-240:l+120,g,h),gEe(l,g,h),gEe(l<120?l+240:l-120,g,h),this.opacity)},clamp(){return new vy(tyt(this.h),$ae(this.s),$ae(this.l),$fe(this.opacity))},displayable(){return(0<=this.s&&this.s<=1||isNaN(this.s))&&0<=this.l&&this.l<=1&&0<=this.opacity&&this.opacity<=1},formatHsl(){const l=$fe(this.opacity);return`${l===1?"hsl(":"hsla("}${tyt(this.h)}, ${$ae(this.s)*100}%, ${$ae(this.l)*100}%${l===1?")":`, ${l})`}`}}));function tyt(l){return l=(l||0)%360,l<0?l+360:l}function $ae(l){return Math.max(0,Math.min(1,l||0))}function gEe(l,s,u){return(l<60?s+(u-s)*l/60:l<180?u:l<240?s+(u-s)*(240-l)/60:s)*255}const jMe=l=>()=>l;function xrn(l,s){return function(u){return l+u*s}}function krn(l,s,u){return l=Math.pow(l,u),s=Math.pow(s,u)-l,u=1/u,function(h){return Math.pow(l+h*s,u)}}function Orn(l){return(l=+l)==1?T4t:function(s,u){return u-s?krn(s,u,l):jMe(isNaN(s)?u:s)}}function T4t(l,s){var u=s-l;return u?xrn(l,u):jMe(isNaN(l)?s:l)}const Bfe=(function l(s){var u=Orn(s);function h(g,w){var p=u((g=dCe(g)).r,(w=dCe(w)).r),k=u(g.g,w.g),j=u(g.b,w.b),A=T4t(g.opacity,w.opacity);return function(_){return g.r=p(_),g.g=k(_),g.b=j(_),g.opacity=A(_),g+""}}return h.gamma=l,h})(1);function Srn(l,s){s||(s=[]);var u=l?Math.min(s.length,l.length):0,h=s.slice(),g;return function(w){for(g=0;g<u;++g)h[g]=l[g]*(1-w)+s[g]*w;return h}}function jrn(l){return ArrayBuffer.isView(l)&&!(l instanceof DataView)}function Trn(l,s){var u=s?s.length:0,h=l?Math.min(u,l.length):0,g=new Array(h),w=new Array(u),p;for(p=0;p<h;++p)g[p]=DX(l[p],s[p]);for(;p<u;++p)w[p]=s[p];return function(k){for(p=0;p<h;++p)w[p]=g[p](k);return w}}function Ern(l,s){var u=new Date;return l=+l,s=+s,function(h){return u.setTime(l*(1-h)+s*h),u}}function z3(l,s){return l=+l,s=+s,function(u){return l*(1-u)+s*u}}function Crn(l,s){var u={},h={},g;(l===null||typeof l!="object")&&(l={}),(s===null||typeof s!="object")&&(s={});for(g in s)g in l?u[g]=DX(l[g],s[g]):h[g]=s[g];return function(w){for(g in u)h[g]=u[g](w);return h}}var gCe=/[-+]?(?:\d+\.?\d*|\.?\d+)(?:[eE][-+]?\d+)?/g,pEe=new RegExp(gCe.source,"g");function Mrn(l){return function(){return l}}function Arn(l){return function(s){return l(s)+""}}function E4t(l,s){var u=gCe.lastIndex=pEe.lastIndex=0,h,g,w,p=-1,k=[],j=[];for(l=l+"",s=s+"";(h=gCe.exec(l))&&(g=pEe.exec(s));)(w=g.index)>u&&(w=s.slice(u,w),k[p]?k[p]+=w:k[++p]=w),(h=h[0])===(g=g[0])?k[p]?k[p]+=g:k[++p]=g:(k[++p]=null,j.push({i:p,x:z3(h,g)})),u=pEe.lastIndex;return u<s.length&&(w=s.slice(u),k[p]?k[p]+=w:k[++p]=w),k.length<2?j[0]?Arn(j[0].x):Mrn(s):(s=j.length,function(A){for(var _=0,D;_<s;++_)k[(D=j[_]).i]=D.x(A);return k.join("")})}function DX(l,s){var u=typeof s,h;return s==null||u==="boolean"?jMe(s):(u==="number"?z3:u==="string"?(h=bM(s))?(s=h,Bfe):E4t:s instanceof bM?Bfe:s instanceof Date?Ern:jrn(s)?Srn:Array.isArray(s)?Trn:typeof s.valueOf!="function"&&typeof s.toString!="function"||isNaN(s)?Crn:z3)(l,s)}var nyt=180/Math.PI,pCe={translateX:0,translateY:0,rotate:0,skewX:0,scaleX:1,scaleY:1};function C4t(l,s,u,h,g,w){var p,k,j;return(p=Math.sqrt(l*l+s*s))&&(l/=p,s/=p),(j=l*u+s*h)&&(u-=l*j,h-=s*j),(k=Math.sqrt(u*u+h*h))&&(u/=k,h/=k,j/=k),l*h<s*u&&(l=-l,s=-s,j=-j,p=-p),{translateX:g,translateY:w,rotate:Math.atan2(s,l)*nyt,skewX:Math.atan(j)*nyt,scaleX:p,scaleY:k}}var Bae;function Nrn(l){const s=new(typeof DOMMatrix=="function"?DOMMatrix:WebKitCSSMatrix)(l+"");return s.isIdentity?pCe:C4t(s.a,s.b,s.c,s.d,s.e,s.f)}function _rn(l){return l==null||(Bae||(Bae=document.createElementNS("http://www.w3.org/2000/svg","g")),Bae.setAttribute("transform",l),!(l=Bae.transform.baseVal.consolidate()))?pCe:(l=l.matrix,C4t(l.a,l.b,l.c,l.d,l.e,l.f))}function M4t(l,s,u,h){function g(A){return A.length?A.pop()+" ":""}function w(A,_,D,I,B,F){if(A!==D||_!==I){var U=B.push("translate(",null,s,null,u);F.push({i:U-4,x:z3(A,D)},{i:U-2,x:z3(_,I)})}else(D||I)&&B.push("translate("+D+s+I+u)}function p(A,_,D,I){A!==_?(A-_>180?_+=360:_-A>180&&(A+=360),I.push({i:D.push(g(D)+"rotate(",null,h)-2,x:z3(A,_)})):_&&D.push(g(D)+"rotate("+_+h)}function k(A,_,D,I){A!==_?I.push({i:D.push(g(D)+"skewX(",null,h)-2,x:z3(A,_)}):_&&D.push(g(D)+"skewX("+_+h)}function j(A,_,D,I,B,F){if(A!==D||_!==I){var U=B.push(g(B)+"scale(",null,",",null,")");F.push({i:U-4,x:z3(A,D)},{i:U-2,x:z3(_,I)})}else(D!==1||I!==1)&&B.push(g(B)+"scale("+D+","+I+")")}return function(A,_){var D=[],I=[];return A=l(A),_=l(_),w(A.translateX,A.translateY,_.translateX,_.translateY,D,I),p(A.rotate,_.rotate,D,I),k(A.skewX,_.skewX,D,I),j(A.scaleX,A.scaleY,_.scaleX,_.scaleY,D,I),A=_=null,function(B){for(var F=-1,U=I.length,K;++F<U;)D[(K=I[F]).i]=K.x(B);return D.join("")}}}var Drn=M4t(Nrn,"px, ","px)","deg)"),Lrn=M4t(_rn,", ",")",")"),Prn=1e-12;function iyt(l){return((l=Math.exp(l))+1/l)/2}function Irn(l){return((l=Math.exp(l))-1/l)/2}function Rrn(l){return((l=Math.exp(2*l))-1)/(l+1)}const xfe=(function l(s,u,h){function g(w,p){var k=w[0],j=w[1],A=w[2],_=p[0],D=p[1],I=p[2],B=_-k,F=D-j,U=B*B+F*F,K,Y;if(U<Prn)Y=Math.log(I/A)/s,K=function(me){return[k+me*B,j+me*F,A*Math.exp(s*me*Y)]};else{var Z=Math.sqrt(U),ee=(I*I-A*A+h*U)/(2*A*u*Z),ce=(I*I-A*A-h*U)/(2*I*u*Z),fe=Math.log(Math.sqrt(ee*ee+1)-ee),be=Math.log(Math.sqrt(ce*ce+1)-ce);Y=(be-fe)/s,K=function(me){var Re=me*Y,Te=iyt(fe),Ke=A/(u*Z)*(Te*Rrn(s*Re+fe)-Irn(fe));return[k+Ke*B,j+Ke*F,A*Te/iyt(s*Re+fe)]}}return K.duration=Y*1e3*s/Math.SQRT2,K}return g.rho=function(w){var p=Math.max(.001,+w),k=p*p,j=k*k;return l(p,k,j)},g})(Math.SQRT2,2,4);var SI=0,MX=0,wX=0,A4t=1e3,zfe,AX,Ffe=0,mM=0,Che=0,XX=typeof performance=="object"&&performance.now?performance:Date,N4t=typeof window=="object"&&window.requestAnimationFrame?window.requestAnimationFrame.bind(window):function(l){setTimeout(l,17)};function TMe(){return mM||(N4t($rn),mM=XX.now()+Che)}function $rn(){mM=0}function qfe(){this._call=this._time=this._next=null}qfe.prototype=_4t.prototype={constructor:qfe,restart:function(l,s,u){if(typeof l!="function")throw new TypeError("callback is not a function");u=(u==null?TMe():+u)+(s==null?0:+s),!this._next&&AX!==this&&(AX?AX._next=this:zfe=this,AX=this),this._call=l,this._time=u,bCe()},stop:function(){this._call&&(this._call=null,this._time=1/0,bCe())}};function _4t(l,s,u){var h=new qfe;return h.restart(l,s,u),h}function Brn(){TMe(),++SI;for(var l=zfe,s;l;)(s=mM-l._time)>=0&&l._call.call(void 0,s),l=l._next;--SI}function ryt(){mM=(Ffe=XX.now())+Che,SI=MX=0;try{Brn()}finally{SI=0,Frn(),mM=0}}function zrn(){var l=XX.now(),s=l-Ffe;s>A4t&&(Che-=s,Ffe=l)}function Frn(){for(var l,s=zfe,u,h=1/0;s;)s._call?(h>s._time&&(h=s._time),l=s,s=s._next):(u=s._next,s._next=null,s=l?l._next=u:zfe=u);AX=l,bCe(h)}function bCe(l){if(!SI){MX&&(MX=clearTimeout(MX));var s=l-mM;s>24?(l<1/0&&(MX=setTimeout(ryt,l-XX.now()-Che)),wX&&(wX=clearInterval(wX))):(wX||(Ffe=XX.now(),wX=setInterval(zrn,A4t)),SI=1,N4t(ryt))}}function syt(l,s,u){var h=new qfe;return s=s==null?0:+s,h.restart(g=>{h.stop(),l(g+s)},s,u),h}var qrn=The("start","end","cancel","interrupt"),Hrn=[],D4t=0,oyt=1,mCe=2,kfe=3,cyt=4,wCe=5,Ofe=6;function Mhe(l,s,u,h,g,w){var p=l.__transition;if(!p)l.__transition={};else if(u in p)return;Qrn(l,u,{name:s,index:h,group:g,on:qrn,tween:Hrn,time:w.time,delay:w.delay,duration:w.duration,ease:w.ease,timer:null,state:D4t})}function EMe(l,s){var u=My(l,s);if(u.state>D4t)throw new Error("too late; already scheduled");return u}function Y3(l,s){var u=My(l,s);if(u.state>kfe)throw new Error("too late; already running");return u}function My(l,s){var u=l.__transition;if(!u||!(u=u[s]))throw new Error("transition not found");return u}function Qrn(l,s,u){var h=l.__transition,g;h[s]=u,u.timer=_4t(w,0,u.time);function w(A){u.state=oyt,u.timer.restart(p,u.delay,u.time),u.delay<=A&&p(A-u.delay)}function p(A){var _,D,I,B;if(u.state!==oyt)return j();for(_ in h)if(B=h[_],B.name===u.name){if(B.state===kfe)return syt(p);B.state===cyt?(B.state=Ofe,B.timer.stop(),B.on.call("interrupt",l,l.__data__,B.index,B.group),delete h[_]):+_<s&&(B.state=Ofe,B.timer.stop(),B.on.call("cancel",l,l.__data__,B.index,B.group),delete h[_])}if(syt(function(){u.state===kfe&&(u.state=cyt,u.timer.restart(k,u.delay,u.time),k(A))}),u.state=mCe,u.on.call("start",l,l.__data__,u.index,u.group),u.state===mCe){for(u.state=kfe,g=new Array(I=u.tween.length),_=0,D=-1;_<I;++_)(B=u.tween[_].value.call(l,l.__data__,u.index,u.group))&&(g[++D]=B);g.length=D+1}}function k(A){for(var _=A<u.duration?u.ease.call(null,A/u.duration):(u.timer.restart(j),u.state=wCe,1),D=-1,I=g.length;++D<I;)g[D].call(l,_);u.state===wCe&&(u.on.call("end",l,l.__data__,u.index,u.group),j())}function j(){u.state=Ofe,u.timer.stop(),delete h[s];for(var A in h)return;delete l.__transition}}function Sfe(l,s){var u=l.__transition,h,g,w=!0,p;if(u){s=s==null?null:s+"";for(p in u){if((h=u[p]).name!==s){w=!1;continue}g=h.state>mCe&&h.state<wCe,h.state=Ofe,h.timer.stop(),h.on.call(g?"interrupt":"cancel",l,l.__data__,h.index,h.group),delete u[p]}w&&delete l.__transition}}function Grn(l){return this.each(function(){Sfe(this,l)})}function Urn(l,s){var u,h;return function(){var g=Y3(this,l),w=g.tween;if(w!==u){h=u=w;for(var p=0,k=h.length;p<k;++p)if(h[p].name===s){h=h.slice(),h.splice(p,1);break}}g.tween=h}}function Jrn(l,s,u){var h,g;if(typeof u!="function")throw new Error;return function(){var w=Y3(this,l),p=w.tween;if(p!==h){g=(h=p).slice();for(var k={name:s,value:u},j=0,A=g.length;j<A;++j)if(g[j].name===s){g[j]=k;break}j===A&&g.push(k)}w.tween=g}}function Xrn(l,s){var u=this._id;if(l+="",arguments.length<2){for(var h=My(this.node(),u).tween,g=0,w=h.length,p;g<w;++g)if((p=h[g]).name===l)return p.value;return null}return this.each((s==null?Urn:Jrn)(u,l,s))}function CMe(l,s,u){var h=l._id;return l.each(function(){var g=Y3(this,h);(g.value||(g.value={}))[s]=u.apply(this,arguments)}),function(g){return My(g,h).value[s]}}function L4t(l,s){var u;return(typeof s=="number"?z3:s instanceof bM?Bfe:(u=bM(s))?(s=u,Bfe):E4t)(l,s)}function Vrn(l){return function(){this.removeAttribute(l)}}function Wrn(l){return function(){this.removeAttributeNS(l.space,l.local)}}function Krn(l,s,u){var h,g=u+"",w;return function(){var p=this.getAttribute(l);return p===g?null:p===h?w:w=s(h=p,u)}}function Yrn(l,s,u){var h,g=u+"",w;return function(){var p=this.getAttributeNS(l.space,l.local);return p===g?null:p===h?w:w=s(h=p,u)}}function Zrn(l,s,u){var h,g,w;return function(){var p,k=u(this),j;return k==null?void this.removeAttribute(l):(p=this.getAttribute(l),j=k+"",p===j?null:p===h&&j===g?w:(g=j,w=s(h=p,k)))}}function esn(l,s,u){var h,g,w;return function(){var p,k=u(this),j;return k==null?void this.removeAttributeNS(l.space,l.local):(p=this.getAttributeNS(l.space,l.local),j=k+"",p===j?null:p===h&&j===g?w:(g=j,w=s(h=p,k)))}}function tsn(l,s){var u=Ehe(l),h=u==="transform"?Lrn:L4t;return this.attrTween(l,typeof s=="function"?(u.local?esn:Zrn)(u,h,CMe(this,"attr."+l,s)):s==null?(u.local?Wrn:Vrn)(u):(u.local?Yrn:Krn)(u,h,s))}function nsn(l,s){return function(u){this.setAttribute(l,s.call(this,u))}}function isn(l,s){return function(u){this.setAttributeNS(l.space,l.local,s.call(this,u))}}function rsn(l,s){var u,h;function g(){var w=s.apply(this,arguments);return w!==h&&(u=(h=w)&&isn(l,w)),u}return g._value=s,g}function ssn(l,s){var u,h;function g(){var w=s.apply(this,arguments);return w!==h&&(u=(h=w)&&nsn(l,w)),u}return g._value=s,g}function osn(l,s){var u="attr."+l;if(arguments.length<2)return(u=this.tween(u))&&u._value;if(s==null)return this.tween(u,null);if(typeof s!="function")throw new Error;var h=Ehe(l);return this.tween(u,(h.local?rsn:ssn)(h,s))}function csn(l,s){return function(){EMe(this,l).delay=+s.apply(this,arguments)}}function lsn(l,s){return s=+s,function(){EMe(this,l).delay=s}}function usn(l){var s=this._id;return arguments.length?this.each((typeof l=="function"?csn:lsn)(s,l)):My(this.node(),s).delay}function asn(l,s){return function(){Y3(this,l).duration=+s.apply(this,arguments)}}function fsn(l,s){return s=+s,function(){Y3(this,l).duration=s}}function hsn(l){var s=this._id;return arguments.length?this.each((typeof l=="function"?asn:fsn)(s,l)):My(this.node(),s).duration}function dsn(l,s){if(typeof s!="function")throw new Error;return function(){Y3(this,l).ease=s}}function gsn(l){var s=this._id;return arguments.length?this.each(dsn(s,l)):My(this.node(),s).ease}function psn(l,s){return function(){var u=s.apply(this,arguments);if(typeof u!="function")throw new Error;Y3(this,l).ease=u}}function bsn(l){if(typeof l!="function")throw new Error;return this.each(psn(this._id,l))}function msn(l){typeof l!="function"&&(l=f4t(l));for(var s=this._groups,u=s.length,h=new Array(u),g=0;g<u;++g)for(var w=s[g],p=w.length,k=h[g]=[],j,A=0;A<p;++A)(j=w[A])&&l.call(j,j.__data__,A,w)&&k.push(j);return new iO(h,this._parents,this._name,this._id)}function wsn(l){if(l._id!==this._id)throw new Error;for(var s=this._groups,u=l._groups,h=s.length,g=u.length,w=Math.min(h,g),p=new Array(h),k=0;k<w;++k)for(var j=s[k],A=u[k],_=j.length,D=p[k]=new Array(_),I,B=0;B<_;++B)(I=j[B]||A[B])&&(D[B]=I);for(;k<h;++k)p[k]=s[k];return new iO(p,this._parents,this._name,this._id)}function vsn(l){return(l+"").trim().split(/^|\s+/).every(function(s){var u=s.indexOf(".");return u>=0&&(s=s.slice(0,u)),!s||s==="start"})}function ysn(l,s,u){var h,g,w=vsn(s)?EMe:Y3;return function(){var p=w(this,l),k=p.on;k!==h&&(g=(h=k).copy()).on(s,u),p.on=g}}function xsn(l,s){var u=this._id;return arguments.length<2?My(this.node(),u).on.on(l):this.each(ysn(u,l,s))}function ksn(l){return function(){var s=this.parentNode;for(var u in this.__transition)if(+u!==l)return;s&&s.removeChild(this)}}function Osn(){return this.on("end.remove",ksn(this._id))}function Ssn(l){var s=this._name,u=this._id;typeof l!="function"&&(l=kMe(l));for(var h=this._groups,g=h.length,w=new Array(g),p=0;p<g;++p)for(var k=h[p],j=k.length,A=w[p]=new Array(j),_,D,I=0;I<j;++I)(_=k[I])&&(D=l.call(_,_.__data__,I,k))&&("__data__"in _&&(D.__data__=_.__data__),A[I]=D,Mhe(A[I],s,u,I,A,My(_,u)));return new iO(w,this._parents,s,u)}function jsn(l){var s=this._name,u=this._id;typeof l!="function"&&(l=a4t(l));for(var h=this._groups,g=h.length,w=[],p=[],k=0;k<g;++k)for(var j=h[k],A=j.length,_,D=0;D<A;++D)if(_=j[D]){for(var I=l.call(_,_.__data__,D,j),B,F=My(_,u),U=0,K=I.length;U<K;++U)(B=I[U])&&Mhe(B,s,u,U,I,F);w.push(I),p.push(_)}return new iO(w,p,s,u)}var Tsn=vV.prototype.constructor;function Esn(){return new Tsn(this._groups,this._parents)}function Csn(l,s){var u,h,g;return function(){var w=OI(this,l),p=(this.style.removeProperty(l),OI(this,l));return w===p?null:w===u&&p===h?g:g=s(u=w,h=p)}}function P4t(l){return function(){this.style.removeProperty(l)}}function Msn(l,s,u){var h,g=u+"",w;return function(){var p=OI(this,l);return p===g?null:p===h?w:w=s(h=p,u)}}function Asn(l,s,u){var h,g,w;return function(){var p=OI(this,l),k=u(this),j=k+"";return k==null&&(j=k=(this.style.removeProperty(l),OI(this,l))),p===j?null:p===h&&j===g?w:(g=j,w=s(h=p,k))}}function Nsn(l,s){var u,h,g,w="style."+s,p="end."+w,k;return function(){var j=Y3(this,l),A=j.on,_=j.value[w]==null?k||(k=P4t(s)):void 0;(A!==u||g!==_)&&(h=(u=A).copy()).on(p,g=_),j.on=h}}function _sn(l,s,u){var h=(l+="")=="transform"?Drn:L4t;return s==null?this.styleTween(l,Csn(l,h)).on("end.style."+l,P4t(l)):typeof s=="function"?this.styleTween(l,Asn(l,h,CMe(this,"style."+l,s))).each(Nsn(this._id,l)):this.styleTween(l,Msn(l,h,s),u).on("end.style."+l,null)}function Dsn(l,s,u){return function(h){this.style.setProperty(l,s.call(this,h),u)}}function Lsn(l,s,u){var h,g;function w(){var p=s.apply(this,arguments);return p!==g&&(h=(g=p)&&Dsn(l,p,u)),h}return w._value=s,w}function Psn(l,s,u){var h="style."+(l+="");if(arguments.length<2)return(h=this.tween(h))&&h._value;if(s==null)return this.tween(h,null);if(typeof s!="function")throw new Error;return this.tween(h,Lsn(l,s,u??""))}function Isn(l){return function(){this.textContent=l}}function Rsn(l){return function(){var s=l(this);this.textContent=s??""}}function $sn(l){return this.tween("text",typeof l=="function"?Rsn(CMe(this,"text",l)):Isn(l==null?"":l+""))}function Bsn(l){return function(s){this.textContent=l.call(this,s)}}function zsn(l){var s,u;function h(){var g=l.apply(this,arguments);return g!==u&&(s=(u=g)&&Bsn(g)),s}return h._value=l,h}function Fsn(l){var s="text";if(arguments.length<1)return(s=this.tween(s))&&s._value;if(l==null)return this.tween(s,null);if(typeof l!="function")throw new Error;return this.tween(s,zsn(l))}function qsn(){for(var l=this._name,s=this._id,u=I4t(),h=this._groups,g=h.length,w=0;w<g;++w)for(var p=h[w],k=p.length,j,A=0;A<k;++A)if(j=p[A]){var _=My(j,s);Mhe(j,l,u,A,p,{time:_.time+_.delay+_.duration,delay:0,duration:_.duration,ease:_.ease})}return new iO(h,this._parents,l,u)}function Hsn(){var l,s,u=this,h=u._id,g=u.size();return new Promise(function(w,p){var k={value:p},j={value:function(){--g===0&&w()}};u.each(function(){var A=Y3(this,h),_=A.on;_!==l&&(s=(l=_).copy(),s._.cancel.push(k),s._.interrupt.push(k),s._.end.push(j)),A.on=s}),g===0&&w()})}var Qsn=0;function iO(l,s,u,h){this._groups=l,this._parents=s,this._name=u,this._id=h}function I4t(){return++Qsn}var Gk=vV.prototype;iO.prototype={constructor:iO,select:Ssn,selectAll:jsn,selectChild:Gk.selectChild,selectChildren:Gk.selectChildren,filter:msn,merge:wsn,selection:Esn,transition:qsn,call:Gk.call,nodes:Gk.nodes,node:Gk.node,size:Gk.size,empty:Gk.empty,each:Gk.each,on:xsn,attr:tsn,attrTween:osn,style:_sn,styleTween:Psn,text:$sn,textTween:Fsn,remove:Osn,tween:Xrn,delay:usn,duration:hsn,ease:gsn,easeVarying:bsn,end:Hsn,[Symbol.iterator]:Gk[Symbol.iterator]};function Gsn(l){return((l*=2)<=1?l*l*l:(l-=2)*l*l+2)/2}var Usn={time:null,delay:0,duration:250,ease:Gsn};function Jsn(l,s){for(var u;!(u=l.__transition)||!(u=u[s]);)if(!(l=l.parentNode))throw new Error(`transition ${s} not found`);return u}function Xsn(l){var s,u;l instanceof iO?(s=l._id,l=l._name):(s=I4t(),(u=Usn).time=TMe(),l=l==null?null:l+"");for(var h=this._groups,g=h.length,w=0;w<g;++w)for(var p=h[w],k=p.length,j,A=0;A<k;++A)(j=p[A])&&Mhe(j,l,s,A,p,u||Jsn(j,s));return new iO(h,this._parents,l,s)}vV.prototype.interrupt=Grn;vV.prototype.transition=Xsn;const zae=l=>()=>l;function Vsn(l,{sourceEvent:s,target:u,transform:h,dispatch:g}){Object.defineProperties(this,{type:{value:l,enumerable:!0,configurable:!0},sourceEvent:{value:s,enumerable:!0,configurable:!0},target:{value:u,enumerable:!0,configurable:!0},transform:{value:h,enumerable:!0,configurable:!0},_:{value:g}})}function eO(l,s,u){this.k=l,this.x=s,this.y=u}eO.prototype={constructor:eO,scale:function(l){return l===1?this:new eO(this.k*l,this.x,this.y)},translate:function(l,s){return l===0&s===0?this:new eO(this.k,this.x+this.k*l,this.y+this.k*s)},apply:function(l){return[l[0]*this.k+this.x,l[1]*this.k+this.y]},applyX:function(l){return l*this.k+this.x},applyY:function(l){return l*this.k+this.y},invert:function(l){return[(l[0]-this.x)/this.k,(l[1]-this.y)/this.k]},invertX:function(l){return(l-this.x)/this.k},invertY:function(l){return(l-this.y)/this.k},rescaleX:function(l){return l.copy().domain(l.range().map(this.invertX,this).map(l.invert,l))},rescaleY:function(l){return l.copy().domain(l.range().map(this.invertY,this).map(l.invert,l))},toString:function(){return"translate("+this.x+","+this.y+") scale("+this.k+")"}};var Ahe=new eO(1,0,0);R4t.prototype=eO.prototype;function R4t(l){for(;!l.__zoom;)if(!(l=l.parentNode))return Ahe;return l.__zoom}function bEe(l){l.stopImmediatePropagation()}function vX(l){l.preventDefault(),l.stopImmediatePropagation()}function Wsn(l){return(!l.ctrlKey||l.type==="wheel")&&!l.button}function Ksn(){var l=this;return l instanceof SVGElement?(l=l.ownerSVGElement||l,l.hasAttribute("viewBox")?(l=l.viewBox.baseVal,[[l.x,l.y],[l.x+l.width,l.y+l.height]]):[[0,0],[l.width.baseVal.value,l.height.baseVal.value]]):[[0,0],[l.clientWidth,l.clientHeight]]}function lyt(){return this.__zoom||Ahe}function Ysn(l){return-l.deltaY*(l.deltaMode===1?.05:l.deltaMode?1:.002)*(l.ctrlKey?10:1)}function Zsn(){return navigator.maxTouchPoints||"ontouchstart"in this}function eon(l,s,u){var h=l.invertX(s[0][0])-u[0][0],g=l.invertX(s[1][0])-u[1][0],w=l.invertY(s[0][1])-u[0][1],p=l.invertY(s[1][1])-u[1][1];return l.translate(g>h?(h+g)/2:Math.min(0,h)||Math.max(0,g),p>w?(w+p)/2:Math.min(0,w)||Math.max(0,p))}function $4t(){var l=Wsn,s=Ksn,u=eon,h=Ysn,g=Zsn,w=[0,1/0],p=[[-1/0,-1/0],[1/0,1/0]],k=250,j=xfe,A=The("start","zoom","end"),_,D,I,B=500,F=150,U=0,K=10;function Y(ge){ge.property("__zoom",lyt).on("wheel.zoom",Re,{passive:!1}).on("mousedown.zoom",Te).on("dblclick.zoom",Ke).filter(g).on("touchstart.zoom",ze).on("touchmove.zoom",je).on("touchend.zoom touchcancel.zoom",te).style("-webkit-tap-highlight-color","rgba(0,0,0,0)")}Y.transform=function(ge,He,ae,Le){var Oe=ge.selection?ge.selection():ge;Oe.property("__zoom",lyt),ge!==Oe?fe(ge,He,ae,Le):Oe.interrupt().each(function(){be(this,arguments).event(Le).start().zoom(null,typeof He=="function"?He.apply(this,arguments):He).end()})},Y.scaleBy=function(ge,He,ae,Le){Y.scaleTo(ge,function(){var Oe=this.__zoom.k,Qe=typeof He=="function"?He.apply(this,arguments):He;return Oe*Qe},ae,Le)},Y.scaleTo=function(ge,He,ae,Le){Y.transform(ge,function(){var Oe=s.apply(this,arguments),Qe=this.__zoom,kt=ae==null?ce(Oe):typeof ae=="function"?ae.apply(this,arguments):ae,Ae=Qe.invert(kt),Ye=typeof He=="function"?He.apply(this,arguments):He;return u(ee(Z(Qe,Ye),kt,Ae),Oe,p)},ae,Le)},Y.translateBy=function(ge,He,ae,Le){Y.transform(ge,function(){return u(this.__zoom.translate(typeof He=="function"?He.apply(this,arguments):He,typeof ae=="function"?ae.apply(this,arguments):ae),s.apply(this,arguments),p)},null,Le)},Y.translateTo=function(ge,He,ae,Le,Oe){Y.transform(ge,function(){var Qe=s.apply(this,arguments),kt=this.__zoom,Ae=Le==null?ce(Qe):typeof Le=="function"?Le.apply(this,arguments):Le;return u(Ahe.translate(Ae[0],Ae[1]).scale(kt.k).translate(typeof He=="function"?-He.apply(this,arguments):-He,typeof ae=="function"?-ae.apply(this,arguments):-ae),Qe,p)},Le,Oe)};function Z(ge,He){return He=Math.max(w[0],Math.min(w[1],He)),He===ge.k?ge:new eO(He,ge.x,ge.y)}function ee(ge,He,ae){var Le=He[0]-ae[0]*ge.k,Oe=He[1]-ae[1]*ge.k;return Le===ge.x&&Oe===ge.y?ge:new eO(ge.k,Le,Oe)}function ce(ge){return[(+ge[0][0]+ +ge[1][0])/2,(+ge[0][1]+ +ge[1][1])/2]}function fe(ge,He,ae,Le){ge.on("start.zoom",function(){be(this,arguments).event(Le).start()}).on("interrupt.zoom end.zoom",function(){be(this,arguments).event(Le).end()}).tween("zoom",function(){var Oe=this,Qe=arguments,kt=be(Oe,Qe).event(Le),Ae=s.apply(Oe,Qe),Ye=ae==null?ce(Ae):typeof ae=="function"?ae.apply(Oe,Qe):ae,mt=Math.max(Ae[1][0]-Ae[0][0],Ae[1][1]-Ae[0][1]),Ue=Oe.__zoom,Pt=typeof He=="function"?He.apply(Oe,Qe):He,rn=j(Ue.invert(Ye).concat(mt/Ue.k),Pt.invert(Ye).concat(mt/Pt.k));return function(Cn){if(Cn===1)Cn=Pt;else{var Pn=rn(Cn),mi=mt/Pn[2];Cn=new eO(mi,Ye[0]-Pn[0]*mi,Ye[1]-Pn[1]*mi)}kt.zoom(null,Cn)}})}function be(ge,He,ae){return!ae&&ge.__zooming||new me(ge,He)}function me(ge,He){this.that=ge,this.args=He,this.active=0,this.sourceEvent=null,this.extent=s.apply(ge,He),this.taps=0}me.prototype={event:function(ge){return ge&&(this.sourceEvent=ge),this},start:function(){return++this.active===1&&(this.that.__zooming=this,this.emit("start")),this},zoom:function(ge,He){return this.mouse&&ge!=="mouse"&&(this.mouse[1]=He.invert(this.mouse[0])),this.touch0&&ge!=="touch"&&(this.touch0[1]=He.invert(this.touch0[0])),this.touch1&&ge!=="touch"&&(this.touch1[1]=He.invert(this.touch1[0])),this.that.__zoom=He,this.emit("zoom"),this},end:function(){return--this.active===0&&(delete this.that.__zooming,this.emit("end")),this},emit:function(ge){var He=tm(this.that).datum();A.call(ge,this.that,new Vsn(ge,{sourceEvent:this.sourceEvent,target:Y,transform:this.that.__zoom,dispatch:A}),He)}};function Re(ge,...He){if(!l.apply(this,arguments))return;var ae=be(this,He).event(ge),Le=this.__zoom,Oe=Math.max(w[0],Math.min(w[1],Le.k*Math.pow(2,h.apply(this,arguments)))),Qe=wy(ge);if(ae.wheel)(ae.mouse[0][0]!==Qe[0]||ae.mouse[0][1]!==Qe[1])&&(ae.mouse[1]=Le.invert(ae.mouse[0]=Qe)),clearTimeout(ae.wheel);else{if(Le.k===Oe)return;ae.mouse=[Qe,Le.invert(Qe)],Sfe(this),ae.start()}vX(ge),ae.wheel=setTimeout(kt,F),ae.zoom("mouse",u(ee(Z(Le,Oe),ae.mouse[0],ae.mouse[1]),ae.extent,p));function kt(){ae.wheel=null,ae.end()}}function Te(ge,...He){if(I||!l.apply(this,arguments))return;var ae=ge.currentTarget,Le=be(this,He,!0).event(ge),Oe=tm(ge.view).on("mousemove.zoom",Ye,!0).on("mouseup.zoom",mt,!0),Qe=wy(ge,ae),kt=ge.clientX,Ae=ge.clientY;x4t(ge.view),bEe(ge),Le.mouse=[Qe,this.__zoom.invert(Qe)],Sfe(this),Le.start();function Ye(Ue){if(vX(Ue),!Le.moved){var Pt=Ue.clientX-kt,rn=Ue.clientY-Ae;Le.moved=Pt*Pt+rn*rn>U}Le.event(Ue).zoom("mouse",u(ee(Le.that.__zoom,Le.mouse[0]=wy(Ue,ae),Le.mouse[1]),Le.extent,p))}function mt(Ue){Oe.on("mousemove.zoom mouseup.zoom",null),k4t(Ue.view,Le.moved),vX(Ue),Le.event(Ue).end()}}function Ke(ge,...He){if(l.apply(this,arguments)){var ae=this.__zoom,Le=wy(ge.changedTouches?ge.changedTouches[0]:ge,this),Oe=ae.invert(Le),Qe=ae.k*(ge.shiftKey?.5:2),kt=u(ee(Z(ae,Qe),Le,Oe),s.apply(this,He),p);vX(ge),k>0?tm(this).transition().duration(k).call(fe,kt,Le,ge):tm(this).call(Y.transform,kt,Le,ge)}}function ze(ge,...He){if(l.apply(this,arguments)){var ae=ge.touches,Le=ae.length,Oe=be(this,He,ge.changedTouches.length===Le).event(ge),Qe,kt,Ae,Ye;for(bEe(ge),kt=0;kt<Le;++kt)Ae=ae[kt],Ye=wy(Ae,this),Ye=[Ye,this.__zoom.invert(Ye),Ae.identifier],Oe.touch0?!Oe.touch1&&Oe.touch0[2]!==Ye[2]&&(Oe.touch1=Ye,Oe.taps=0):(Oe.touch0=Ye,Qe=!0,Oe.taps=1+!!_);_&&(_=clearTimeout(_)),Qe&&(Oe.taps<2&&(D=Ye[0],_=setTimeout(function(){_=null},B)),Sfe(this),Oe.start())}}function je(ge,...He){if(this.__zooming){var ae=be(this,He).event(ge),Le=ge.changedTouches,Oe=Le.length,Qe,kt,Ae,Ye;for(vX(ge),Qe=0;Qe<Oe;++Qe)kt=Le[Qe],Ae=wy(kt,this),ae.touch0&&ae.touch0[2]===kt.identifier?ae.touch0[0]=Ae:ae.touch1&&ae.touch1[2]===kt.identifier&&(ae.touch1[0]=Ae);if(kt=ae.that.__zoom,ae.touch1){var mt=ae.touch0[0],Ue=ae.touch0[1],Pt=ae.touch1[0],rn=ae.touch1[1],Cn=(Cn=Pt[0]-mt[0])*Cn+(Cn=Pt[1]-mt[1])*Cn,Pn=(Pn=rn[0]-Ue[0])*Pn+(Pn=rn[1]-Ue[1])*Pn;kt=Z(kt,Math.sqrt(Cn/Pn)),Ae=[(mt[0]+Pt[0])/2,(mt[1]+Pt[1])/2],Ye=[(Ue[0]+rn[0])/2,(Ue[1]+rn[1])/2]}else if(ae.touch0)Ae=ae.touch0[0],Ye=ae.touch0[1];else return;ae.zoom("touch",u(ee(kt,Ae,Ye),ae.extent,p))}}function te(ge,...He){if(this.__zooming){var ae=be(this,He).event(ge),Le=ge.changedTouches,Oe=Le.length,Qe,kt;for(bEe(ge),I&&clearTimeout(I),I=setTimeout(function(){I=null},B),Qe=0;Qe<Oe;++Qe)kt=Le[Qe],ae.touch0&&ae.touch0[2]===kt.identifier?delete ae.touch0:ae.touch1&&ae.touch1[2]===kt.identifier&&delete ae.touch1;if(ae.touch1&&!ae.touch0&&(ae.touch0=ae.touch1,delete ae.touch1),ae.touch0)ae.touch0[1]=this.__zoom.invert(ae.touch0[0]);else if(ae.end(),ae.taps===2&&(kt=wy(kt,this),Math.hypot(D[0]-kt[0],D[1]-kt[1])<K)){var Ae=tm(this).on("dblclick.zoom");Ae&&Ae.apply(this,arguments)}}}return Y.wheelDelta=function(ge){return arguments.length?(h=typeof ge=="function"?ge:zae(+ge),Y):h},Y.filter=function(ge){return arguments.length?(l=typeof ge=="function"?ge:zae(!!ge),Y):l},Y.touchable=function(ge){return arguments.length?(g=typeof ge=="function"?ge:zae(!!ge),Y):g},Y.extent=function(ge){return arguments.length?(s=typeof ge=="function"?ge:zae([[+ge[0][0],+ge[0][1]],[+ge[1][0],+ge[1][1]]]),Y):s},Y.scaleExtent=function(ge){return arguments.length?(w[0]=+ge[0],w[1]=+ge[1],Y):[w[0],w[1]]},Y.translateExtent=function(ge){return arguments.length?(p[0][0]=+ge[0][0],p[1][0]=+ge[1][0],p[0][1]=+ge[0][1],p[1][1]=+ge[1][1],Y):[[p[0][0],p[0][1]],[p[1][0],p[1][1]]]},Y.constrain=function(ge){return arguments.length?(u=ge,Y):u},Y.duration=function(ge){return arguments.length?(k=+ge,Y):k},Y.interpolate=function(ge){return arguments.length?(j=ge,Y):j},Y.on=function(){var ge=A.on.apply(A,arguments);return ge===A?Y:ge},Y.clickDistance=function(ge){return arguments.length?(U=(ge=+ge)*ge,Y):Math.sqrt(U)},Y.tapDistance=function(ge){return arguments.length?(K=+ge,Y):K},Y}const W3={error001:()=>"[React Flow]: Seems like you have not used zustand provider as an ancestor. Help: https://reactflow.dev/error#001",error002:()=>"It looks like you've created a new nodeTypes or edgeTypes object. If this wasn't on purpose please define the nodeTypes/edgeTypes outside of the component or memoize them.",error003:l=>`Node type "${l}" not found. Using fallback type "default".`,error004:()=>"The React Flow parent container needs a width and a height to render the graph.",error005:()=>"Only child nodes can use a parent extent.",error006:()=>"Can't create edge. An edge needs a source and a target.",error007:l=>`The old edge with id=${l} does not exist.`,error009:l=>`Marker type "${l}" doesn't exist.`,error008:(l,{id:s,sourceHandle:u,targetHandle:h})=>`Couldn't create edge for ${l} handle id: "${l==="source"?u:h}", edge id: ${s}.`,error010:()=>"Handle: No node id found. Make sure to only use a Handle inside a custom Node.",error011:l=>`Edge type "${l}" not found. Using fallback type "default".`,error012:l=>`Node with id "${l}" does not exist, it may have been removed. This can happen when a node is deleted before the "onNodeClick" handler is called.`,error013:(l="react")=>`It seems that you haven't loaded the styles. Please import '@xyflow/${l}/dist/style.css' or base.css to make sure everything is working properly.`,error014:()=>"useNodeConnections: No node ID found. Call useNodeConnections inside a custom Node or provide a node ID.",error015:()=>"It seems that you are trying to drag a node that is not initialized. Please use onNodesChange as explained in the docs."},VX=[[Number.NEGATIVE_INFINITY,Number.NEGATIVE_INFINITY],[Number.POSITIVE_INFINITY,Number.POSITIVE_INFINITY]],B4t=["Enter"," ","Escape"],z4t={"node.a11yDescription.default":"Press enter or space to select a node. Press delete to remove it and escape to cancel.","node.a11yDescription.keyboardDisabled":"Press enter or space to select a node. You can then use the arrow keys to move the node around. Press delete to remove it and escape to cancel.","node.a11yDescription.ariaLiveMessage":({direction:l,x:s,y:u})=>`Moved selected node ${l}. New position, x: ${s}, y: ${u}`,"edge.a11yDescription.default":"Press enter or space to select an edge. You can then press delete to remove it or escape to cancel.","controls.ariaLabel":"Control Panel","controls.zoomIn.ariaLabel":"Zoom In","controls.zoomOut.ariaLabel":"Zoom Out","controls.fitView.ariaLabel":"Fit View","controls.interactive.ariaLabel":"Toggle Interactivity","minimap.ariaLabel":"Mini Map","handle.ariaLabel":"Handle"};var jI;(function(l){l.Strict="strict",l.Loose="loose"})(jI||(jI={}));var dM;(function(l){l.Free="free",l.Vertical="vertical",l.Horizontal="horizontal"})(dM||(dM={}));var TI;(function(l){l.Partial="partial",l.Full="full"})(TI||(TI={}));const F4t={inProgress:!1,isValid:null,from:null,fromHandle:null,fromPosition:null,fromNode:null,to:null,toHandle:null,toPosition:null,toNode:null,pointer:null};var g8;(function(l){l.Bezier="default",l.Straight="straight",l.Step="step",l.SmoothStep="smoothstep",l.SimpleBezier="simplebezier"})(g8||(g8={}));var wM;(function(l){l.Arrow="arrow",l.ArrowClosed="arrowclosed"})(wM||(wM={}));var br;(function(l){l.Left="left",l.Top="top",l.Right="right",l.Bottom="bottom"})(br||(br={}));const uyt={[br.Left]:br.Right,[br.Right]:br.Left,[br.Top]:br.Bottom,[br.Bottom]:br.Top};function q4t(l){return l===null?null:l?"valid":"invalid"}const H4t=l=>"id"in l&&"source"in l&&"target"in l,ton=l=>"id"in l&&"position"in l&&!("source"in l)&&!("target"in l),MMe=l=>"id"in l&&"internals"in l&&!("source"in l)&&!("target"in l),xV=(l,s=[0,0])=>{const{width:u,height:h}=oO(l),g=l.origin??s,w=u*g[0],p=h*g[1];return{x:l.position.x-w,y:l.position.y-p}},non=(l,s={nodeOrigin:[0,0]})=>{if(l.length===0)return{x:0,y:0,width:0,height:0};const u=l.reduce((h,g)=>{const w=typeof g=="string";let p=!s.nodeLookup&&!w?g:void 0;s.nodeLookup&&(p=w?s.nodeLookup.get(g):MMe(g)?g:s.nodeLookup.get(g.id));const k=p?Hfe(p,s.nodeOrigin):{x:0,y:0,x2:0,y2:0};return Nhe(h,k)},{x:1/0,y:1/0,x2:-1/0,y2:-1/0});return _he(u)},kV=(l,s={})=>{let u={x:1/0,y:1/0,x2:-1/0,y2:-1/0},h=!1;return l.forEach(g=>{(s.filter===void 0||s.filter(g))&&(u=Nhe(u,Hfe(g)),h=!0)}),h?_he(u):{x:0,y:0,width:0,height:0}},AMe=(l,s,[u,h,g]=[0,0,1],w=!1,p=!1)=>{const k={...SV(s,[u,h,g]),width:s.width/g,height:s.height/g},j=[];for(const A of l.values()){const{measured:_,selectable:D=!0,hidden:I=!1}=A;if(p&&!D||I)continue;const B=_.width??A.width??A.initialWidth??null,F=_.height??A.height??A.initialHeight??null,U=WX(k,CI(A)),K=(B??0)*(F??0),Y=w&&U>0;(!A.internals.handleBounds||Y||U>=K||A.dragging)&&j.push(A)}return j},ion=(l,s)=>{const u=new Set;return l.forEach(h=>{u.add(h.id)}),s.filter(h=>u.has(h.source)||u.has(h.target))};function ron(l,s){const u=new Map,h=s!=null&&s.nodes?new Set(s.nodes.map(g=>g.id)):null;return l.forEach(g=>{g.measured.width&&g.measured.height&&((s==null?void 0:s.includeHiddenNodes)||!g.hidden)&&(!h||h.has(g.id))&&u.set(g.id,g)}),u}async function son({nodes:l,width:s,height:u,panZoom:h,minZoom:g,maxZoom:w},p){if(l.size===0)return Promise.resolve(!0);const k=ron(l,p),j=kV(k),A=NMe(j,s,u,(p==null?void 0:p.minZoom)??g,(p==null?void 0:p.maxZoom)??w,(p==null?void 0:p.padding)??.1);return await h.setViewport(A,{duration:p==null?void 0:p.duration,ease:p==null?void 0:p.ease,interpolate:p==null?void 0:p.interpolate}),Promise.resolve(!0)}function Q4t({nodeId:l,nextPosition:s,nodeLookup:u,nodeOrigin:h=[0,0],nodeExtent:g,onError:w}){const p=u.get(l),k=p.parentId?u.get(p.parentId):void 0,{x:j,y:A}=k?k.internals.positionAbsolute:{x:0,y:0},_=p.origin??h;let D=p.extent||g;if(p.extent==="parent"&&!p.expandParent)if(!k)w==null||w("005",W3.error005());else{const B=k.measured.width,F=k.measured.height;B&&F&&(D=[[j,A],[j+B,A+F]])}else k&&MI(p.extent)&&(D=[[p.extent[0][0]+j,p.extent[0][1]+A],[p.extent[1][0]+j,p.extent[1][1]+A]]);const I=MI(D)?vM(s,D,p.measured):s;return(p.measured.width===void 0||p.measured.height===void 0)&&(w==null||w("015",W3.error015())),{position:{x:I.x-j+(p.measured.width??0)*_[0],y:I.y-A+(p.measured.height??0)*_[1]},positionAbsolute:I}}async function oon({nodesToRemove:l=[],edgesToRemove:s=[],nodes:u,edges:h,onBeforeDelete:g}){const w=new Set(l.map(I=>I.id)),p=[];for(const I of u){if(I.deletable===!1)continue;const B=w.has(I.id),F=!B&&I.parentId&&p.find(U=>U.id===I.parentId);(B||F)&&p.push(I)}const k=new Set(s.map(I=>I.id)),j=h.filter(I=>I.deletable!==!1),_=ion(p,j);for(const I of j)k.has(I.id)&&!_.find(F=>F.id===I.id)&&_.push(I);if(!g)return{edges:_,nodes:p};const D=await g({nodes:p,edges:_});return typeof D=="boolean"?D?{edges:_,nodes:p}:{edges:[],nodes:[]}:D}const EI=(l,s=0,u=1)=>Math.min(Math.max(l,s),u),vM=(l={x:0,y:0},s,u)=>({x:EI(l.x,s[0][0],s[1][0]-((u==null?void 0:u.width)??0)),y:EI(l.y,s[0][1],s[1][1]-((u==null?void 0:u.height)??0))});function G4t(l,s,u){const{width:h,height:g}=oO(u),{x:w,y:p}=u.internals.positionAbsolute;return vM(l,[[w,p],[w+h,p+g]],s)}const ayt=(l,s,u)=>l<s?EI(Math.abs(l-s),1,s)/s:l>u?-EI(Math.abs(l-u),1,s)/s:0,U4t=(l,s,u=15,h=40)=>{const g=ayt(l.x,h,s.width-h)*u,w=ayt(l.y,h,s.height-h)*u;return[g,w]},Nhe=(l,s)=>({x:Math.min(l.x,s.x),y:Math.min(l.y,s.y),x2:Math.max(l.x2,s.x2),y2:Math.max(l.y2,s.y2)}),vCe=({x:l,y:s,width:u,height:h})=>({x:l,y:s,x2:l+u,y2:s+h}),_he=({x:l,y:s,x2:u,y2:h})=>({x:l,y:s,width:u-l,height:h-s}),CI=(l,s=[0,0])=>{var g,w;const{x:u,y:h}=MMe(l)?l.internals.positionAbsolute:xV(l,s);return{x:u,y:h,width:((g=l.measured)==null?void 0:g.width)??l.width??l.initialWidth??0,height:((w=l.measured)==null?void 0:w.height)??l.height??l.initialHeight??0}},Hfe=(l,s=[0,0])=>{var g,w;const{x:u,y:h}=MMe(l)?l.internals.positionAbsolute:xV(l,s);return{x:u,y:h,x2:u+(((g=l.measured)==null?void 0:g.width)??l.width??l.initialWidth??0),y2:h+(((w=l.measured)==null?void 0:w.height)??l.height??l.initialHeight??0)}},J4t=(l,s)=>_he(Nhe(vCe(l),vCe(s))),WX=(l,s)=>{const u=Math.max(0,Math.min(l.x+l.width,s.x+s.width)-Math.max(l.x,s.x)),h=Math.max(0,Math.min(l.y+l.height,s.y+s.height)-Math.max(l.y,s.y));return Math.ceil(u*h)},fyt=l=>xy(l.width)&&xy(l.height)&&xy(l.x)&&xy(l.y),xy=l=>!isNaN(l)&&isFinite(l),con=(l,s)=>{},OV=(l,s=[1,1])=>({x:s[0]*Math.round(l.x/s[0]),y:s[1]*Math.round(l.y/s[1])}),SV=({x:l,y:s},[u,h,g],w=!1,p=[1,1])=>{const k={x:(l-u)/g,y:(s-h)/g};return w?OV(k,p):k},Qfe=({x:l,y:s},[u,h,g])=>({x:l*g+u,y:s*g+h});function rI(l,s){if(typeof l=="number")return Math.floor((s-s/(1+l))*.5);if(typeof l=="string"&&l.endsWith("px")){const u=parseFloat(l);if(!Number.isNaN(u))return Math.floor(u)}if(typeof l=="string"&&l.endsWith("%")){const u=parseFloat(l);if(!Number.isNaN(u))return Math.floor(s*u*.01)}return console.error(`[React Flow] The padding value "${l}" is invalid. Please provide a number or a string with a valid unit (px or %).`),0}function lon(l,s,u){if(typeof l=="string"||typeof l=="number"){const h=rI(l,u),g=rI(l,s);return{top:h,right:g,bottom:h,left:g,x:g*2,y:h*2}}if(typeof l=="object"){const h=rI(l.top??l.y??0,u),g=rI(l.bottom??l.y??0,u),w=rI(l.left??l.x??0,s),p=rI(l.right??l.x??0,s);return{top:h,right:p,bottom:g,left:w,x:w+p,y:h+g}}return{top:0,right:0,bottom:0,left:0,x:0,y:0}}function uon(l,s,u,h,g,w){const{x:p,y:k}=Qfe(l,[s,u,h]),{x:j,y:A}=Qfe({x:l.x+l.width,y:l.y+l.height},[s,u,h]),_=g-j,D=w-A;return{left:Math.floor(p),top:Math.floor(k),right:Math.floor(_),bottom:Math.floor(D)}}const NMe=(l,s,u,h,g,w)=>{const p=lon(w,s,u),k=(s-p.x)/l.width,j=(u-p.y)/l.height,A=Math.min(k,j),_=EI(A,h,g),D=l.x+l.width/2,I=l.y+l.height/2,B=s/2-D*_,F=u/2-I*_,U=uon(l,B,F,_,s,u),K={left:Math.min(U.left-p.left,0),top:Math.min(U.top-p.top,0),right:Math.min(U.right-p.right,0),bottom:Math.min(U.bottom-p.bottom,0)};return{x:B-K.left+K.right,y:F-K.top+K.bottom,zoom:_}},KX=()=>{var l;return typeof navigator<"u"&&((l=navigator==null?void 0:navigator.userAgent)==null?void 0:l.indexOf("Mac"))>=0};function MI(l){return l!=null&&l!=="parent"}function oO(l){var s,u;return{width:((s=l.measured)==null?void 0:s.width)??l.width??l.initialWidth??0,height:((u=l.measured)==null?void 0:u.height)??l.height??l.initialHeight??0}}function X4t(l){var s,u;return(((s=l.measured)==null?void 0:s.width)??l.width??l.initialWidth)!==void 0&&(((u=l.measured)==null?void 0:u.height)??l.height??l.initialHeight)!==void 0}function V4t(l,s={width:0,height:0},u,h,g){const w={...l},p=h.get(u);if(p){const k=p.origin||g;w.x+=p.internals.positionAbsolute.x-(s.width??0)*k[0],w.y+=p.internals.positionAbsolute.y-(s.height??0)*k[1]}return w}function hyt(l,s){if(l.size!==s.size)return!1;for(const u of l)if(!s.has(u))return!1;return!0}function aon(){let l,s;return{promise:new Promise((h,g)=>{l=h,s=g}),resolve:l,reject:s}}function fon(l){return{...z4t,...l||{}}}function LX(l,{snapGrid:s=[0,0],snapToGrid:u=!1,transform:h,containerBounds:g}){const{x:w,y:p}=ky(l),k=SV({x:w-((g==null?void 0:g.left)??0),y:p-((g==null?void 0:g.top)??0)},h),{x:j,y:A}=u?OV(k,s):k;return{xSnapped:j,ySnapped:A,...k}}const _Me=l=>({width:l.offsetWidth,height:l.offsetHeight}),W4t=l=>{var s;return((s=l==null?void 0:l.getRootNode)==null?void 0:s.call(l))||(window==null?void 0:window.document)},hon=["INPUT","SELECT","TEXTAREA"];function K4t(l){var h,g;const s=((g=(h=l.composedPath)==null?void 0:h.call(l))==null?void 0:g[0])||l.target;return(s==null?void 0:s.nodeType)!==1?!1:hon.includes(s.nodeName)||s.hasAttribute("contenteditable")||!!s.closest(".nokey")}const Y4t=l=>"clientX"in l,ky=(l,s)=>{var w,p;const u=Y4t(l),h=u?l.clientX:(w=l.touches)==null?void 0:w[0].clientX,g=u?l.clientY:(p=l.touches)==null?void 0:p[0].clientY;return{x:h-((s==null?void 0:s.left)??0),y:g-((s==null?void 0:s.top)??0)}},dyt=(l,s,u,h,g)=>{const w=s.querySelectorAll(`.${l}`);return!w||!w.length?null:Array.from(w).map(p=>{const k=p.getBoundingClientRect();return{id:p.getAttribute("data-handleid"),type:l,nodeId:g,position:p.getAttribute("data-handlepos"),x:(k.left-u.left)/h,y:(k.top-u.top)/h,..._Me(p)}})};function Z4t({sourceX:l,sourceY:s,targetX:u,targetY:h,sourceControlX:g,sourceControlY:w,targetControlX:p,targetControlY:k}){const j=l*.125+g*.375+p*.375+u*.125,A=s*.125+w*.375+k*.375+h*.125,_=Math.abs(j-l),D=Math.abs(A-s);return[j,A,_,D]}function Fae(l,s){return l>=0?.5*l:s*25*Math.sqrt(-l)}function gyt({pos:l,x1:s,y1:u,x2:h,y2:g,c:w}){switch(l){case br.Left:return[s-Fae(s-h,w),u];case br.Right:return[s+Fae(h-s,w),u];case br.Top:return[s,u-Fae(u-g,w)];case br.Bottom:return[s,u+Fae(g-u,w)]}}function e5t({sourceX:l,sourceY:s,sourcePosition:u=br.Bottom,targetX:h,targetY:g,targetPosition:w=br.Top,curvature:p=.25}){const[k,j]=gyt({pos:u,x1:l,y1:s,x2:h,y2:g,c:p}),[A,_]=gyt({pos:w,x1:h,y1:g,x2:l,y2:s,c:p}),[D,I,B,F]=Z4t({sourceX:l,sourceY:s,targetX:h,targetY:g,sourceControlX:k,sourceControlY:j,targetControlX:A,targetControlY:_});return[`M${l},${s} C${k},${j} ${A},${_} ${h},${g}`,D,I,B,F]}function t5t({sourceX:l,sourceY:s,targetX:u,targetY:h}){const g=Math.abs(u-l)/2,w=u<l?u+g:u-g,p=Math.abs(h-s)/2,k=h<s?h+p:h-p;return[w,k,g,p]}function don({sourceNode:l,targetNode:s,selected:u=!1,zIndex:h=0,elevateOnSelect:g=!1,zIndexMode:w="basic"}){if(w==="manual")return h;const p=g&&u?h+1e3:h,k=Math.max(l.parentId||g&&l.selected?l.internals.z:0,s.parentId||g&&s.selected?s.internals.z:0);return p+k}function gon({sourceNode:l,targetNode:s,width:u,height:h,transform:g}){const w=Nhe(Hfe(l),Hfe(s));w.x===w.x2&&(w.x2+=1),w.y===w.y2&&(w.y2+=1);const p={x:-g[0]/g[2],y:-g[1]/g[2],width:u/g[2],height:h/g[2]};return WX(p,_he(w))>0}const pon=({source:l,sourceHandle:s,target:u,targetHandle:h})=>`xy-edge__${l}${s||""}-${u}${h||""}`,bon=(l,s)=>s.some(u=>u.source===l.source&&u.target===l.target&&(u.sourceHandle===l.sourceHandle||!u.sourceHandle&&!l.sourceHandle)&&(u.targetHandle===l.targetHandle||!u.targetHandle&&!l.targetHandle)),yCe=(l,s,u={})=>{if(!l.source||!l.target)return s;const h=u.getEdgeId||pon;let g;return H4t(l)?g={...l}:g={...l,id:h(l)},bon(g,s)?s:(g.sourceHandle===null&&delete g.sourceHandle,g.targetHandle===null&&delete g.targetHandle,s.concat(g))};function n5t({sourceX:l,sourceY:s,targetX:u,targetY:h}){const[g,w,p,k]=t5t({sourceX:l,sourceY:s,targetX:u,targetY:h});return[`M ${l},${s}L ${u},${h}`,g,w,p,k]}const pyt={[br.Left]:{x:-1,y:0},[br.Right]:{x:1,y:0},[br.Top]:{x:0,y:-1},[br.Bottom]:{x:0,y:1}},mon=({source:l,sourcePosition:s=br.Bottom,target:u})=>s===br.Left||s===br.Right?l.x<u.x?{x:1,y:0}:{x:-1,y:0}:l.y<u.y?{x:0,y:1}:{x:0,y:-1},byt=(l,s)=>Math.sqrt(Math.pow(s.x-l.x,2)+Math.pow(s.y-l.y,2));function won({source:l,sourcePosition:s=br.Bottom,target:u,targetPosition:h=br.Top,center:g,offset:w,stepPosition:p}){const k=pyt[s],j=pyt[h],A={x:l.x+k.x*w,y:l.y+k.y*w},_={x:u.x+j.x*w,y:u.y+j.y*w},D=mon({source:A,sourcePosition:s,target:_}),I=D.x!==0?"x":"y",B=D[I];let F=[],U,K;const Y={x:0,y:0},Z={x:0,y:0},[,,ee,ce]=t5t({sourceX:l.x,sourceY:l.y,targetX:u.x,targetY:u.y});if(k[I]*j[I]===-1){I==="x"?(U=g.x??A.x+(_.x-A.x)*p,K=g.y??(A.y+_.y)/2):(U=g.x??(A.x+_.x)/2,K=g.y??A.y+(_.y-A.y)*p);const be=[{x:U,y:A.y},{x:U,y:_.y}],me=[{x:A.x,y:K},{x:_.x,y:K}];k[I]===B?F=I==="x"?be:me:F=I==="x"?me:be}else{const be=[{x:A.x,y:_.y}],me=[{x:_.x,y:A.y}];if(I==="x"?F=k.x===B?me:be:F=k.y===B?be:me,s===h){const je=Math.abs(l[I]-u[I]);if(je<=w){const te=Math.min(w-1,w-je);k[I]===B?Y[I]=(A[I]>l[I]?-1:1)*te:Z[I]=(_[I]>u[I]?-1:1)*te}}if(s!==h){const je=I==="x"?"y":"x",te=k[I]===j[je],ge=A[je]>_[je],He=A[je]<_[je];(k[I]===1&&(!te&&ge||te&&He)||k[I]!==1&&(!te&&He||te&&ge))&&(F=I==="x"?be:me)}const Re={x:A.x+Y.x,y:A.y+Y.y},Te={x:_.x+Z.x,y:_.y+Z.y},Ke=Math.max(Math.abs(Re.x-F[0].x),Math.abs(Te.x-F[0].x)),ze=Math.max(Math.abs(Re.y-F[0].y),Math.abs(Te.y-F[0].y));Ke>=ze?(U=(Re.x+Te.x)/2,K=F[0].y):(U=F[0].x,K=(Re.y+Te.y)/2)}return[[l,{x:A.x+Y.x,y:A.y+Y.y},...F,{x:_.x+Z.x,y:_.y+Z.y},u],U,K,ee,ce]}function von(l,s,u,h){const g=Math.min(byt(l,s)/2,byt(s,u)/2,h),{x:w,y:p}=s;if(l.x===w&&w===u.x||l.y===p&&p===u.y)return`L${w} ${p}`;if(l.y===p){const A=l.x<u.x?-1:1,_=l.y<u.y?1:-1;return`L ${w+g*A},${p}Q ${w},${p} ${w},${p+g*_}`}const k=l.x<u.x?1:-1,j=l.y<u.y?-1:1;return`L ${w},${p+g*j}Q ${w},${p} ${w+g*k},${p}`}function xCe({sourceX:l,sourceY:s,sourcePosition:u=br.Bottom,targetX:h,targetY:g,targetPosition:w=br.Top,borderRadius:p=5,centerX:k,centerY:j,offset:A=20,stepPosition:_=.5}){const[D,I,B,F,U]=won({source:{x:l,y:s},sourcePosition:u,target:{x:h,y:g},targetPosition:w,center:{x:k,y:j},offset:A,stepPosition:_});return[D.reduce((Y,Z,ee)=>{let ce="";return ee>0&&ee<D.length-1?ce=von(D[ee-1],Z,D[ee+1],p):ce=`${ee===0?"M":"L"}${Z.x} ${Z.y}`,Y+=ce,Y},""),I,B,F,U]}function myt(l){var s;return l&&!!(l.internals.handleBounds||(s=l.handles)!=null&&s.length)&&!!(l.measured.width||l.width||l.initialWidth)}function yon(l){var D;const{sourceNode:s,targetNode:u}=l;if(!myt(s)||!myt(u))return null;const h=s.internals.handleBounds||wyt(s.handles),g=u.internals.handleBounds||wyt(u.handles),w=vyt((h==null?void 0:h.source)??[],l.sourceHandle),p=vyt(l.connectionMode===jI.Strict?(g==null?void 0:g.target)??[]:((g==null?void 0:g.target)??[]).concat((g==null?void 0:g.source)??[]),l.targetHandle);if(!w||!p)return(D=l.onError)==null||D.call(l,"008",W3.error008(w?"target":"source",{id:l.id,sourceHandle:l.sourceHandle,targetHandle:l.targetHandle})),null;const k=(w==null?void 0:w.position)||br.Bottom,j=(p==null?void 0:p.position)||br.Top,A=yM(s,w,k),_=yM(u,p,j);return{sourceX:A.x,sourceY:A.y,targetX:_.x,targetY:_.y,sourcePosition:k,targetPosition:j}}function wyt(l){if(!l)return null;const s=[],u=[];for(const h of l)h.width=h.width??1,h.height=h.height??1,h.type==="source"?s.push(h):h.type==="target"&&u.push(h);return{source:s,target:u}}function yM(l,s,u=br.Left,h=!1){const g=((s==null?void 0:s.x)??0)+l.internals.positionAbsolute.x,w=((s==null?void 0:s.y)??0)+l.internals.positionAbsolute.y,{width:p,height:k}=s??oO(l);if(h)return{x:g+p/2,y:w+k/2};switch((s==null?void 0:s.position)??u){case br.Top:return{x:g+p/2,y:w};case br.Right:return{x:g+p,y:w+k/2};case br.Bottom:return{x:g+p/2,y:w+k};case br.Left:return{x:g,y:w+k/2}}}function vyt(l,s){return l&&(s?l.find(u=>u.id===s):l[0])||null}function kCe(l,s){return l?typeof l=="string"?l:`${s?`${s}__`:""}${Object.keys(l).sort().map(h=>`${h}=${l[h]}`).join("&")}`:""}function xon(l,{id:s,defaultColor:u,defaultMarkerStart:h,defaultMarkerEnd:g}){const w=new Set;return l.reduce((p,k)=>([k.markerStart||h,k.markerEnd||g].forEach(j=>{if(j&&typeof j=="object"){const A=kCe(j,s);w.has(A)||(p.push({id:A,color:j.color||u,...j}),w.add(A))}}),p),[]).sort((p,k)=>p.id.localeCompare(k.id))}const i5t=1e3,kon=10,DMe={nodeOrigin:[0,0],nodeExtent:VX,elevateNodesOnSelect:!0,zIndexMode:"basic",defaults:{}},Oon={...DMe,checkEquality:!0};function LMe(l,s){const u={...l};for(const h in s)s[h]!==void 0&&(u[h]=s[h]);return u}function Son(l,s,u){const h=LMe(DMe,u);for(const g of l.values())if(g.parentId)IMe(g,l,s,h);else{const w=xV(g,h.nodeOrigin),p=MI(g.extent)?g.extent:h.nodeExtent,k=vM(w,p,oO(g));g.internals.positionAbsolute=k}}function jon(l,s){if(!l.handles)return l.measured?s==null?void 0:s.internals.handleBounds:void 0;const u=[],h=[];for(const g of l.handles){const w={id:g.id,width:g.width??1,height:g.height??1,nodeId:l.id,x:g.x,y:g.y,position:g.position,type:g.type};g.type==="source"?u.push(w):g.type==="target"&&h.push(w)}return{source:u,target:h}}function PMe(l){return l==="manual"}function OCe(l,s,u,h={}){var A,_;const g=LMe(Oon,h),w={i:0},p=new Map(s),k=g!=null&&g.elevateNodesOnSelect&&!PMe(g.zIndexMode)?i5t:0;let j=l.length>0;s.clear(),u.clear();for(const D of l){let I=p.get(D.id);if(g.checkEquality&&D===(I==null?void 0:I.internals.userNode))s.set(D.id,I);else{const B=xV(D,g.nodeOrigin),F=MI(D.extent)?D.extent:g.nodeExtent,U=vM(B,F,oO(D));I={...g.defaults,...D,measured:{width:(A=D.measured)==null?void 0:A.width,height:(_=D.measured)==null?void 0:_.height},internals:{positionAbsolute:U,handleBounds:jon(D,I),z:r5t(D,k,g.zIndexMode),userNode:D}},s.set(D.id,I)}(I.measured===void 0||I.measured.width===void 0||I.measured.height===void 0)&&!I.hidden&&(j=!1),D.parentId&&IMe(I,s,u,h,w)}return j}function Ton(l,s){if(!l.parentId)return;const u=s.get(l.parentId);u?u.set(l.id,l):s.set(l.parentId,new Map([[l.id,l]]))}function IMe(l,s,u,h,g){const{elevateNodesOnSelect:w,nodeOrigin:p,nodeExtent:k,zIndexMode:j}=LMe(DMe,h),A=l.parentId,_=s.get(A);if(!_){console.warn(`Parent node ${A} not found. Please make sure that parent nodes are in front of their child nodes in the nodes array.`);return}Ton(l,u),g&&!_.parentId&&_.internals.rootParentIndex===void 0&&j==="auto"&&(_.internals.rootParentIndex=++g.i,_.internals.z=_.internals.z+g.i*kon),g&&_.internals.rootParentIndex!==void 0&&(g.i=_.internals.rootParentIndex);const D=w&&!PMe(j)?i5t:0,{x:I,y:B,z:F}=Eon(l,_,p,k,D,j),{positionAbsolute:U}=l.internals,K=I!==U.x||B!==U.y;(K||F!==l.internals.z)&&s.set(l.id,{...l,internals:{...l.internals,positionAbsolute:K?{x:I,y:B}:U,z:F}})}function r5t(l,s,u){const h=xy(l.zIndex)?l.zIndex:0;return PMe(u)?h:h+(l.selected?s:0)}function Eon(l,s,u,h,g,w){const{x:p,y:k}=s.internals.positionAbsolute,j=oO(l),A=xV(l,u),_=MI(l.extent)?vM(A,l.extent,j):A;let D=vM({x:p+_.x,y:k+_.y},h,j);l.extent==="parent"&&(D=G4t(D,j,s));const I=r5t(l,g,w),B=s.internals.z??0;return{x:D.x,y:D.y,z:B>=I?B+1:I}}function RMe(l,s,u,h=[0,0]){var p;const g=[],w=new Map;for(const k of l){const j=s.get(k.parentId);if(!j)continue;const A=((p=w.get(k.parentId))==null?void 0:p.expandedRect)??CI(j),_=J4t(A,k.rect);w.set(k.parentId,{expandedRect:_,parent:j})}return w.size>0&&w.forEach(({expandedRect:k,parent:j},A)=>{var ee;const _=j.internals.positionAbsolute,D=oO(j),I=j.origin??h,B=k.x<_.x?Math.round(Math.abs(_.x-k.x)):0,F=k.y<_.y?Math.round(Math.abs(_.y-k.y)):0,U=Math.max(D.width,Math.round(k.width)),K=Math.max(D.height,Math.round(k.height)),Y=(U-D.width)*I[0],Z=(K-D.height)*I[1];(B>0||F>0||Y||Z)&&(g.push({id:A,type:"position",position:{x:j.position.x-B+Y,y:j.position.y-F+Z}}),(ee=u.get(A))==null||ee.forEach(ce=>{l.some(fe=>fe.id===ce.id)||g.push({id:ce.id,type:"position",position:{x:ce.position.x+B,y:ce.position.y+F}})})),(D.width<k.width||D.height<k.height||B||F)&&g.push({id:A,type:"dimensions",setAttributes:!0,dimensions:{width:U+(B?I[0]*B-Y:0),height:K+(F?I[1]*F-Z:0)}})}),g}function Con(l,s,u,h,g,w,p){const k=h==null?void 0:h.querySelector(".xyflow__viewport");let j=!1;if(!k)return{changes:[],updatedInternals:j};const A=[],_=window.getComputedStyle(k),{m22:D}=new window.DOMMatrixReadOnly(_.transform),I=[];for(const B of l.values()){const F=s.get(B.id);if(!F)continue;if(F.hidden){s.set(F.id,{...F,internals:{...F.internals,handleBounds:void 0}}),j=!0;continue}const U=_Me(B.nodeElement),K=F.measured.width!==U.width||F.measured.height!==U.height;if(!!(U.width&&U.height&&(K||!F.internals.handleBounds||B.force))){const Z=B.nodeElement.getBoundingClientRect(),ee=MI(F.extent)?F.extent:w;let{positionAbsolute:ce}=F.internals;F.parentId&&F.extent==="parent"?ce=G4t(ce,U,s.get(F.parentId)):ee&&(ce=vM(ce,ee,U));const fe={...F,measured:U,internals:{...F.internals,positionAbsolute:ce,handleBounds:{source:dyt("source",B.nodeElement,Z,D,F.id),target:dyt("target",B.nodeElement,Z,D,F.id)}}};s.set(F.id,fe),F.parentId&&IMe(fe,s,u,{nodeOrigin:g,zIndexMode:p}),j=!0,K&&(A.push({id:F.id,type:"dimensions",dimensions:U}),F.expandParent&&F.parentId&&I.push({id:F.id,parentId:F.parentId,rect:CI(fe,g)}))}}if(I.length>0){const B=RMe(I,s,u,g);A.push(...B)}return{changes:A,updatedInternals:j}}async function Mon({delta:l,panZoom:s,transform:u,translateExtent:h,width:g,height:w}){if(!s||!l.x&&!l.y)return Promise.resolve(!1);const p=await s.setViewportConstrained({x:u[0]+l.x,y:u[1]+l.y,zoom:u[2]},[[0,0],[g,w]],h),k=!!p&&(p.x!==u[0]||p.y!==u[1]||p.k!==u[2]);return Promise.resolve(k)}function yyt(l,s,u,h,g,w){let p=g;const k=h.get(p)||new Map;h.set(p,k.set(u,s)),p=`${g}-${l}`;const j=h.get(p)||new Map;if(h.set(p,j.set(u,s)),w){p=`${g}-${l}-${w}`;const A=h.get(p)||new Map;h.set(p,A.set(u,s))}}function s5t(l,s,u){l.clear(),s.clear();for(const h of u){const{source:g,target:w,sourceHandle:p=null,targetHandle:k=null}=h,j={edgeId:h.id,source:g,target:w,sourceHandle:p,targetHandle:k},A=`${g}-${p}--${w}-${k}`,_=`${w}-${k}--${g}-${p}`;yyt("source",j,_,l,g,p),yyt("target",j,A,l,w,k),s.set(h.id,h)}}function o5t(l,s){if(!l.parentId)return!1;const u=s.get(l.parentId);return u?u.selected?!0:o5t(u,s):!1}function xyt(l,s,u){var g;let h=l;do{if((g=h==null?void 0:h.matches)!=null&&g.call(h,s))return!0;if(h===u)return!1;h=h==null?void 0:h.parentElement}while(h);return!1}function Aon(l,s,u,h){const g=new Map;for(const[w,p]of l)if((p.selected||p.id===h)&&(!p.parentId||!o5t(p,l))&&(p.draggable||s&&typeof p.draggable>"u")){const k=l.get(w);k&&g.set(w,{id:w,position:k.position||{x:0,y:0},distance:{x:u.x-k.internals.positionAbsolute.x,y:u.y-k.internals.positionAbsolute.y},extent:k.extent,parentId:k.parentId,origin:k.origin,expandParent:k.expandParent,internals:{positionAbsolute:k.internals.positionAbsolute||{x:0,y:0}},measured:{width:k.measured.width??0,height:k.measured.height??0}})}return g}function mEe({nodeId:l,dragItems:s,nodeLookup:u,dragging:h=!0}){var p,k,j;const g=[];for(const[A,_]of s){const D=(p=u.get(A))==null?void 0:p.internals.userNode;D&&g.push({...D,position:_.position,dragging:h})}if(!l)return[g[0],g];const w=(k=u.get(l))==null?void 0:k.internals.userNode;return[w?{...w,position:((j=s.get(l))==null?void 0:j.position)||w.position,dragging:h}:g[0],g]}function Non({dragItems:l,snapGrid:s,x:u,y:h}){const g=l.values().next().value;if(!g)return null;const w={x:u-g.distance.x,y:h-g.distance.y},p=OV(w,s);return{x:p.x-w.x,y:p.y-w.y}}function _on({onNodeMouseDown:l,getStoreItems:s,onDragStart:u,onDrag:h,onDragStop:g}){let w={x:null,y:null},p=0,k=new Map,j=!1,A={x:0,y:0},_=null,D=!1,I=null,B=!1,F=!1,U=null;function K({noDragClassName:Z,handleSelector:ee,domNode:ce,isSelectable:fe,nodeId:be,nodeClickDistance:me=0}){I=tm(ce);function Re({x:je,y:te}){const{nodeLookup:ge,nodeExtent:He,snapGrid:ae,snapToGrid:Le,nodeOrigin:Oe,onNodeDrag:Qe,onSelectionDrag:kt,onError:Ae,updateNodePositions:Ye}=s();w={x:je,y:te};let mt=!1;const Ue=k.size>1,Pt=Ue&&He?vCe(kV(k)):null,rn=Ue&&Le?Non({dragItems:k,snapGrid:ae,x:je,y:te}):null;for(const[Cn,Pn]of k){if(!ge.has(Cn))continue;let mi={x:je-Pn.distance.x,y:te-Pn.distance.y};Le&&(mi=rn?{x:Math.round(mi.x+rn.x),y:Math.round(mi.y+rn.y)}:OV(mi,ae));let er=null;if(Ue&&He&&!Pn.extent&&Pt){const{positionAbsolute:Gn}=Pn.internals,Ir=Gn.x-Pt.x+He[0][0],is=Gn.x+Pn.measured.width-Pt.x2+He[1][0],bs=Gn.y-Pt.y+He[0][1],bo=Gn.y+Pn.measured.height-Pt.y2+He[1][1];er=[[Ir,bs],[is,bo]]}const{position:Mr,positionAbsolute:hr}=Q4t({nodeId:Cn,nextPosition:mi,nodeLookup:ge,nodeExtent:er||He,nodeOrigin:Oe,onError:Ae});mt=mt||Pn.position.x!==Mr.x||Pn.position.y!==Mr.y,Pn.position=Mr,Pn.internals.positionAbsolute=hr}if(F=F||mt,!!mt&&(Ye(k,!0),U&&(h||Qe||!be&&kt))){const[Cn,Pn]=mEe({nodeId:be,dragItems:k,nodeLookup:ge});h==null||h(U,k,Cn,Pn),Qe==null||Qe(U,Cn,Pn),be||kt==null||kt(U,Pn)}}async function Te(){if(!_)return;const{transform:je,panBy:te,autoPanSpeed:ge,autoPanOnNodeDrag:He}=s();if(!He){j=!1,cancelAnimationFrame(p);return}const[ae,Le]=U4t(A,_,ge);(ae!==0||Le!==0)&&(w.x=(w.x??0)-ae/je[2],w.y=(w.y??0)-Le/je[2],await te({x:ae,y:Le})&&Re(w)),p=requestAnimationFrame(Te)}function Ke(je){var Ue;const{nodeLookup:te,multiSelectionActive:ge,nodesDraggable:He,transform:ae,snapGrid:Le,snapToGrid:Oe,selectNodesOnDrag:Qe,onNodeDragStart:kt,onSelectionDragStart:Ae,unselectNodesAndEdges:Ye}=s();D=!0,(!Qe||!fe)&&!ge&&be&&((Ue=te.get(be))!=null&&Ue.selected||Ye()),fe&&Qe&&be&&(l==null||l(be));const mt=LX(je.sourceEvent,{transform:ae,snapGrid:Le,snapToGrid:Oe,containerBounds:_});if(w=mt,k=Aon(te,He,mt,be),k.size>0&&(u||kt||!be&&Ae)){const[Pt,rn]=mEe({nodeId:be,dragItems:k,nodeLookup:te});u==null||u(je.sourceEvent,k,Pt,rn),kt==null||kt(je.sourceEvent,Pt,rn),be||Ae==null||Ae(je.sourceEvent,rn)}}const ze=O4t().clickDistance(me).on("start",je=>{const{domNode:te,nodeDragThreshold:ge,transform:He,snapGrid:ae,snapToGrid:Le}=s();_=(te==null?void 0:te.getBoundingClientRect())||null,B=!1,F=!1,U=je.sourceEvent,ge===0&&Ke(je),w=LX(je.sourceEvent,{transform:He,snapGrid:ae,snapToGrid:Le,containerBounds:_}),A=ky(je.sourceEvent,_)}).on("drag",je=>{const{autoPanOnNodeDrag:te,transform:ge,snapGrid:He,snapToGrid:ae,nodeDragThreshold:Le,nodeLookup:Oe}=s(),Qe=LX(je.sourceEvent,{transform:ge,snapGrid:He,snapToGrid:ae,containerBounds:_});if(U=je.sourceEvent,(je.sourceEvent.type==="touchmove"&&je.sourceEvent.touches.length>1||be&&!Oe.has(be))&&(B=!0),!B){if(!j&&te&&D&&(j=!0,Te()),!D){const kt=ky(je.sourceEvent,_),Ae=kt.x-A.x,Ye=kt.y-A.y;Math.sqrt(Ae*Ae+Ye*Ye)>Le&&Ke(je)}(w.x!==Qe.xSnapped||w.y!==Qe.ySnapped)&&k&&D&&(A=ky(je.sourceEvent,_),Re(Qe))}}).on("end",je=>{if(!(!D||B)&&(j=!1,D=!1,cancelAnimationFrame(p),k.size>0)){const{nodeLookup:te,updateNodePositions:ge,onNodeDragStop:He,onSelectionDragStop:ae}=s();if(F&&(ge(k,!1),F=!1),g||He||!be&&ae){const[Le,Oe]=mEe({nodeId:be,dragItems:k,nodeLookup:te,dragging:!1});g==null||g(je.sourceEvent,k,Le,Oe),He==null||He(je.sourceEvent,Le,Oe),be||ae==null||ae(je.sourceEvent,Oe)}}}).filter(je=>{const te=je.target;return!je.button&&(!Z||!xyt(te,`.${Z}`,ce))&&(!ee||xyt(te,ee,ce))});I.call(ze)}function Y(){I==null||I.on(".drag",null)}return{update:K,destroy:Y}}function Don(l,s,u){const h=[],g={x:l.x-u,y:l.y-u,width:u*2,height:u*2};for(const w of s.values())WX(g,CI(w))>0&&h.push(w);return h}const Lon=250;function Pon(l,s,u,h){var k,j;let g=[],w=1/0;const p=Don(l,u,s+Lon);for(const A of p){const _=[...((k=A.internals.handleBounds)==null?void 0:k.source)??[],...((j=A.internals.handleBounds)==null?void 0:j.target)??[]];for(const D of _){if(h.nodeId===D.nodeId&&h.type===D.type&&h.id===D.id)continue;const{x:I,y:B}=yM(A,D,D.position,!0),F=Math.sqrt(Math.pow(I-l.x,2)+Math.pow(B-l.y,2));F>s||(F<w?(g=[{...D,x:I,y:B}],w=F):F===w&&g.push({...D,x:I,y:B}))}}if(!g.length)return null;if(g.length>1){const A=h.type==="source"?"target":"source";return g.find(_=>_.type===A)??g[0]}return g[0]}function c5t(l,s,u,h,g,w=!1){var A,_,D;const p=h.get(l);if(!p)return null;const k=g==="strict"?(A=p.internals.handleBounds)==null?void 0:A[s]:[...((_=p.internals.handleBounds)==null?void 0:_.source)??[],...((D=p.internals.handleBounds)==null?void 0:D.target)??[]],j=(u?k==null?void 0:k.find(I=>I.id===u):k==null?void 0:k[0])??null;return j&&w?{...j,...yM(p,j,j.position,!0)}:j}function l5t(l,s){return l||(s!=null&&s.classList.contains("target")?"target":s!=null&&s.classList.contains("source")?"source":null)}function Ion(l,s){let u=null;return s?u=!0:l&&!s&&(u=!1),u}const u5t=()=>!0;function Ron(l,{connectionMode:s,connectionRadius:u,handleId:h,nodeId:g,edgeUpdaterType:w,isTarget:p,domNode:k,nodeLookup:j,lib:A,autoPanOnConnect:_,flowId:D,panBy:I,cancelConnection:B,onConnectStart:F,onConnect:U,onConnectEnd:K,isValidConnection:Y=u5t,onReconnectEnd:Z,updateConnection:ee,getTransform:ce,getFromHandle:fe,autoPanSpeed:be,dragThreshold:me=1,handleDomNode:Re}){const Te=W4t(l.target);let Ke=0,ze;const{x:je,y:te}=ky(l),ge=l5t(w,Re),He=k==null?void 0:k.getBoundingClientRect();let ae=!1;if(!He||!ge)return;const Le=c5t(g,ge,h,j,s);if(!Le)return;let Oe=ky(l,He),Qe=!1,kt=null,Ae=!1,Ye=null;function mt(){if(!_||!He)return;const[Mr,hr]=U4t(Oe,He,be);I({x:Mr,y:hr}),Ke=requestAnimationFrame(mt)}const Ue={...Le,nodeId:g,type:ge,position:Le.position},Pt=j.get(g);let Cn={inProgress:!0,isValid:null,from:yM(Pt,Ue,br.Left,!0),fromHandle:Ue,fromPosition:Ue.position,fromNode:Pt,to:Oe,toHandle:null,toPosition:uyt[Ue.position],toNode:null,pointer:Oe};function Pn(){ae=!0,ee(Cn),F==null||F(l,{nodeId:g,handleId:h,handleType:ge})}me===0&&Pn();function mi(Mr){if(!ae){const{x:bo,y:Bl}=ky(Mr),Zl=bo-je,rs=Bl-te;if(!(Zl*Zl+rs*rs>me*me))return;Pn()}if(!fe()||!Ue){er(Mr);return}const hr=ce();Oe=ky(Mr,He),ze=Pon(SV(Oe,hr,!1,[1,1]),u,j,Ue),Qe||(mt(),Qe=!0);const Gn=a5t(Mr,{handle:ze,connectionMode:s,fromNodeId:g,fromHandleId:h,fromType:p?"target":"source",isValidConnection:Y,doc:Te,lib:A,flowId:D,nodeLookup:j});Ye=Gn.handleDomNode,kt=Gn.connection,Ae=Ion(!!ze,Gn.isValid);const Ir=j.get(g),is=Ir?yM(Ir,Ue,br.Left,!0):Cn.from,bs={...Cn,from:is,isValid:Ae,to:Gn.toHandle&&Ae?Qfe({x:Gn.toHandle.x,y:Gn.toHandle.y},hr):Oe,toHandle:Gn.toHandle,toPosition:Ae&&Gn.toHandle?Gn.toHandle.position:uyt[Ue.position],toNode:Gn.toHandle?j.get(Gn.toHandle.nodeId):null,pointer:Oe};ee(bs),Cn=bs}function er(Mr){if(!("touches"in Mr&&Mr.touches.length>0)){if(ae){(ze||Ye)&&kt&&Ae&&(U==null||U(kt));const{inProgress:hr,...Gn}=Cn,Ir={...Gn,toPosition:Cn.toHandle?Cn.toPosition:null};K==null||K(Mr,Ir),w&&(Z==null||Z(Mr,Ir))}B(),cancelAnimationFrame(Ke),Qe=!1,Ae=!1,kt=null,Ye=null,Te.removeEventListener("mousemove",mi),Te.removeEventListener("mouseup",er),Te.removeEventListener("touchmove",mi),Te.removeEventListener("touchend",er)}}Te.addEventListener("mousemove",mi),Te.addEventListener("mouseup",er),Te.addEventListener("touchmove",mi),Te.addEventListener("touchend",er)}function a5t(l,{handle:s,connectionMode:u,fromNodeId:h,fromHandleId:g,fromType:w,doc:p,lib:k,flowId:j,isValidConnection:A=u5t,nodeLookup:_}){const D=w==="target",I=s?p.querySelector(`.${k}-flow__handle[data-id="${j}-${s==null?void 0:s.nodeId}-${s==null?void 0:s.id}-${s==null?void 0:s.type}"]`):null,{x:B,y:F}=ky(l),U=p.elementFromPoint(B,F),K=U!=null&&U.classList.contains(`${k}-flow__handle`)?U:I,Y={handleDomNode:K,isValid:!1,connection:null,toHandle:null};if(K){const Z=l5t(void 0,K),ee=K.getAttribute("data-nodeid"),ce=K.getAttribute("data-handleid"),fe=K.classList.contains("connectable"),be=K.classList.contains("connectableend");if(!ee||!Z)return Y;const me={source:D?ee:h,sourceHandle:D?ce:g,target:D?h:ee,targetHandle:D?g:ce};Y.connection=me;const Te=fe&&be&&(u===jI.Strict?D&&Z==="source"||!D&&Z==="target":ee!==h||ce!==g);Y.isValid=Te&&A(me),Y.toHandle=c5t(ee,Z,ce,_,u,!0)}return Y}const SCe={onPointerDown:Ron,isValid:a5t};function $on({domNode:l,panZoom:s,getTransform:u,getViewScale:h}){const g=tm(l);function w({translateExtent:k,width:j,height:A,zoomStep:_=1,pannable:D=!0,zoomable:I=!0,inversePan:B=!1}){const F=ee=>{if(ee.sourceEvent.type!=="wheel"||!s)return;const ce=u(),fe=ee.sourceEvent.ctrlKey&&KX()?10:1,be=-ee.sourceEvent.deltaY*(ee.sourceEvent.deltaMode===1?.05:ee.sourceEvent.deltaMode?1:.002)*_,me=ce[2]*Math.pow(2,be*fe);s.scaleTo(me)};let U=[0,0];const K=ee=>{(ee.sourceEvent.type==="mousedown"||ee.sourceEvent.type==="touchstart")&&(U=[ee.sourceEvent.clientX??ee.sourceEvent.touches[0].clientX,ee.sourceEvent.clientY??ee.sourceEvent.touches[0].clientY])},Y=ee=>{const ce=u();if(ee.sourceEvent.type!=="mousemove"&&ee.sourceEvent.type!=="touchmove"||!s)return;const fe=[ee.sourceEvent.clientX??ee.sourceEvent.touches[0].clientX,ee.sourceEvent.clientY??ee.sourceEvent.touches[0].clientY],be=[fe[0]-U[0],fe[1]-U[1]];U=fe;const me=h()*Math.max(ce[2],Math.log(ce[2]))*(B?-1:1),Re={x:ce[0]-be[0]*me,y:ce[1]-be[1]*me},Te=[[0,0],[j,A]];s.setViewportConstrained({x:Re.x,y:Re.y,zoom:ce[2]},Te,k)},Z=$4t().on("start",K).on("zoom",D?Y:null).on("zoom.wheel",I?F:null);g.call(Z,{})}function p(){g.on("zoom",null)}return{update:w,destroy:p,pointer:wy}}const Dhe=l=>({x:l.x,y:l.y,zoom:l.k}),wEe=({x:l,y:s,zoom:u})=>Ahe.translate(l,s).scale(u),lI=(l,s)=>l.target.closest(`.${s}`),f5t=(l,s)=>s===2&&Array.isArray(l)&&l.includes(2),Bon=l=>((l*=2)<=1?l*l*l:(l-=2)*l*l+2)/2,vEe=(l,s=0,u=Bon,h=()=>{})=>{const g=typeof s=="number"&&s>0;return g||h(),g?l.transition().duration(s).ease(u).on("end",h):l},h5t=l=>{const s=l.ctrlKey&&KX()?10:1;return-l.deltaY*(l.deltaMode===1?.05:l.deltaMode?1:.002)*s};function zon({zoomPanValues:l,noWheelClassName:s,d3Selection:u,d3Zoom:h,panOnScrollMode:g,panOnScrollSpeed:w,zoomOnPinch:p,onPanZoomStart:k,onPanZoom:j,onPanZoomEnd:A}){return _=>{if(lI(_,s))return _.ctrlKey&&_.preventDefault(),!1;_.preventDefault(),_.stopImmediatePropagation();const D=u.property("__zoom").k||1;if(_.ctrlKey&&p){const K=wy(_),Y=h5t(_),Z=D*Math.pow(2,Y);h.scaleTo(u,Z,K,_);return}const I=_.deltaMode===1?20:1;let B=g===dM.Vertical?0:_.deltaX*I,F=g===dM.Horizontal?0:_.deltaY*I;!KX()&&_.shiftKey&&g!==dM.Vertical&&(B=_.deltaY*I,F=0),h.translateBy(u,-(B/D)*w,-(F/D)*w,{internal:!0});const U=Dhe(u.property("__zoom"));clearTimeout(l.panScrollTimeout),l.isPanScrolling?(j==null||j(_,U),l.panScrollTimeout=setTimeout(()=>{A==null||A(_,U),l.isPanScrolling=!1},150)):(l.isPanScrolling=!0,k==null||k(_,U))}}function Fon({noWheelClassName:l,preventScrolling:s,d3ZoomHandler:u}){return function(h,g){const w=h.type==="wheel",p=!s&&w&&!h.ctrlKey,k=lI(h,l);if(h.ctrlKey&&w&&k&&h.preventDefault(),p||k)return null;h.preventDefault(),u.call(this,h,g)}}function qon({zoomPanValues:l,onDraggingChange:s,onPanZoomStart:u}){return h=>{var w,p,k;if((w=h.sourceEvent)!=null&&w.internal)return;const g=Dhe(h.transform);l.mouseButton=((p=h.sourceEvent)==null?void 0:p.button)||0,l.isZoomingOrPanning=!0,l.prevViewport=g,((k=h.sourceEvent)==null?void 0:k.type)==="mousedown"&&s(!0),u&&(u==null||u(h.sourceEvent,g))}}function Hon({zoomPanValues:l,panOnDrag:s,onPaneContextMenu:u,onTransformChange:h,onPanZoom:g}){return w=>{var p,k;l.usedRightMouseButton=!!(u&&f5t(s,l.mouseButton??0)),(p=w.sourceEvent)!=null&&p.sync||h([w.transform.x,w.transform.y,w.transform.k]),g&&!((k=w.sourceEvent)!=null&&k.internal)&&(g==null||g(w.sourceEvent,Dhe(w.transform)))}}function Qon({zoomPanValues:l,panOnDrag:s,panOnScroll:u,onDraggingChange:h,onPanZoomEnd:g,onPaneContextMenu:w}){return p=>{var k;if(!((k=p.sourceEvent)!=null&&k.internal)&&(l.isZoomingOrPanning=!1,w&&f5t(s,l.mouseButton??0)&&!l.usedRightMouseButton&&p.sourceEvent&&w(p.sourceEvent),l.usedRightMouseButton=!1,h(!1),g)){const j=Dhe(p.transform);l.prevViewport=j,clearTimeout(l.timerId),l.timerId=setTimeout(()=>{g==null||g(p.sourceEvent,j)},u?150:0)}}}function Gon({zoomActivationKeyPressed:l,zoomOnScroll:s,zoomOnPinch:u,panOnDrag:h,panOnScroll:g,zoomOnDoubleClick:w,userSelectionActive:p,noWheelClassName:k,noPanClassName:j,lib:A,connectionInProgress:_}){return D=>{var K;const I=l||s,B=u&&D.ctrlKey,F=D.type==="wheel";if(D.button===1&&D.type==="mousedown"&&(lI(D,`${A}-flow__node`)||lI(D,`${A}-flow__edge`)))return!0;if(!h&&!I&&!g&&!w&&!u||p||_&&!F||lI(D,k)&&F||lI(D,j)&&(!F||g&&F&&!l)||!u&&D.ctrlKey&&F)return!1;if(!u&&D.type==="touchstart"&&((K=D.touches)==null?void 0:K.length)>1)return D.preventDefault(),!1;if(!I&&!g&&!B&&F||!h&&(D.type==="mousedown"||D.type==="touchstart")||Array.isArray(h)&&!h.includes(D.button)&&D.type==="mousedown")return!1;const U=Array.isArray(h)&&h.includes(D.button)||!D.button||D.button<=1;return(!D.ctrlKey||F)&&U}}function Uon({domNode:l,minZoom:s,maxZoom:u,translateExtent:h,viewport:g,onPanZoom:w,onPanZoomStart:p,onPanZoomEnd:k,onDraggingChange:j}){const A={isZoomingOrPanning:!1,usedRightMouseButton:!1,prevViewport:{},mouseButton:0,timerId:void 0,panScrollTimeout:void 0,isPanScrolling:!1},_=l.getBoundingClientRect(),D=$4t().scaleExtent([s,u]).translateExtent(h),I=tm(l).call(D);Z({x:g.x,y:g.y,zoom:EI(g.zoom,s,u)},[[0,0],[_.width,_.height]],h);const B=I.on("wheel.zoom"),F=I.on("dblclick.zoom");D.wheelDelta(h5t);function U(ze,je){return I?new Promise(te=>{D==null||D.interpolate((je==null?void 0:je.interpolate)==="linear"?DX:xfe).transform(vEe(I,je==null?void 0:je.duration,je==null?void 0:je.ease,()=>te(!0)),ze)}):Promise.resolve(!1)}function K({noWheelClassName:ze,noPanClassName:je,onPaneContextMenu:te,userSelectionActive:ge,panOnScroll:He,panOnDrag:ae,panOnScrollMode:Le,panOnScrollSpeed:Oe,preventScrolling:Qe,zoomOnPinch:kt,zoomOnScroll:Ae,zoomOnDoubleClick:Ye,zoomActivationKeyPressed:mt,lib:Ue,onTransformChange:Pt,connectionInProgress:rn,paneClickDistance:Cn,selectionOnDrag:Pn}){ge&&!A.isZoomingOrPanning&&Y();const mi=He&&!mt&&!ge;D.clickDistance(Pn?1/0:!xy(Cn)||Cn<0?0:Cn);const er=mi?zon({zoomPanValues:A,noWheelClassName:ze,d3Selection:I,d3Zoom:D,panOnScrollMode:Le,panOnScrollSpeed:Oe,zoomOnPinch:kt,onPanZoomStart:p,onPanZoom:w,onPanZoomEnd:k}):Fon({noWheelClassName:ze,preventScrolling:Qe,d3ZoomHandler:B});if(I.on("wheel.zoom",er,{passive:!1}),!ge){const hr=qon({zoomPanValues:A,onDraggingChange:j,onPanZoomStart:p});D.on("start",hr);const Gn=Hon({zoomPanValues:A,panOnDrag:ae,onPaneContextMenu:!!te,onPanZoom:w,onTransformChange:Pt});D.on("zoom",Gn);const Ir=Qon({zoomPanValues:A,panOnDrag:ae,panOnScroll:He,onPaneContextMenu:te,onPanZoomEnd:k,onDraggingChange:j});D.on("end",Ir)}const Mr=Gon({zoomActivationKeyPressed:mt,panOnDrag:ae,zoomOnScroll:Ae,panOnScroll:He,zoomOnDoubleClick:Ye,zoomOnPinch:kt,userSelectionActive:ge,noPanClassName:je,noWheelClassName:ze,lib:Ue,connectionInProgress:rn});D.filter(Mr),Ye?I.on("dblclick.zoom",F):I.on("dblclick.zoom",null)}function Y(){D.on("zoom",null)}async function Z(ze,je,te){const ge=wEe(ze),He=D==null?void 0:D.constrain()(ge,je,te);return He&&await U(He),new Promise(ae=>ae(He))}async function ee(ze,je){const te=wEe(ze);return await U(te,je),new Promise(ge=>ge(te))}function ce(ze){if(I){const je=wEe(ze),te=I.property("__zoom");(te.k!==ze.zoom||te.x!==ze.x||te.y!==ze.y)&&(D==null||D.transform(I,je,null,{sync:!0}))}}function fe(){const ze=I?R4t(I.node()):{x:0,y:0,k:1};return{x:ze.x,y:ze.y,zoom:ze.k}}function be(ze,je){return I?new Promise(te=>{D==null||D.interpolate((je==null?void 0:je.interpolate)==="linear"?DX:xfe).scaleTo(vEe(I,je==null?void 0:je.duration,je==null?void 0:je.ease,()=>te(!0)),ze)}):Promise.resolve(!1)}function me(ze,je){return I?new Promise(te=>{D==null||D.interpolate((je==null?void 0:je.interpolate)==="linear"?DX:xfe).scaleBy(vEe(I,je==null?void 0:je.duration,je==null?void 0:je.ease,()=>te(!0)),ze)}):Promise.resolve(!1)}function Re(ze){D==null||D.scaleExtent(ze)}function Te(ze){D==null||D.translateExtent(ze)}function Ke(ze){const je=!xy(ze)||ze<0?0:ze;D==null||D.clickDistance(je)}return{update:K,destroy:Y,setViewport:ee,setViewportConstrained:Z,getViewport:fe,scaleTo:be,scaleBy:me,setScaleExtent:Re,setTranslateExtent:Te,syncViewport:ce,setClickDistance:Ke}}var AI;(function(l){l.Line="line",l.Handle="handle"})(AI||(AI={}));function Jon({width:l,prevWidth:s,height:u,prevHeight:h,affectsX:g,affectsY:w}){const p=l-s,k=u-h,j=[p>0?1:p<0?-1:0,k>0?1:k<0?-1:0];return p&&g&&(j[0]=j[0]*-1),k&&w&&(j[1]=j[1]*-1),j}function kyt(l){const s=l.includes("right")||l.includes("left"),u=l.includes("bottom")||l.includes("top"),h=l.includes("left"),g=l.includes("top");return{isHorizontal:s,isVertical:u,affectsX:h,affectsY:g}}function a8(l,s){return Math.max(0,s-l)}function f8(l,s){return Math.max(0,l-s)}function qae(l,s,u){return Math.max(0,s-l,l-u)}function Oyt(l,s){return l?!s:s}function Xon(l,s,u,h,g,w,p,k){let{affectsX:j,affectsY:A}=s;const{isHorizontal:_,isVertical:D}=s,I=_&&D,{xSnapped:B,ySnapped:F}=u,{minWidth:U,maxWidth:K,minHeight:Y,maxHeight:Z}=h,{x:ee,y:ce,width:fe,height:be,aspectRatio:me}=l;let Re=Math.floor(_?B-l.pointerX:0),Te=Math.floor(D?F-l.pointerY:0);const Ke=fe+(j?-Re:Re),ze=be+(A?-Te:Te),je=-w[0]*fe,te=-w[1]*be;let ge=qae(Ke,U,K),He=qae(ze,Y,Z);if(p){let Oe=0,Qe=0;j&&Re<0?Oe=a8(ee+Re+je,p[0][0]):!j&&Re>0&&(Oe=f8(ee+Ke+je,p[1][0])),A&&Te<0?Qe=a8(ce+Te+te,p[0][1]):!A&&Te>0&&(Qe=f8(ce+ze+te,p[1][1])),ge=Math.max(ge,Oe),He=Math.max(He,Qe)}if(k){let Oe=0,Qe=0;j&&Re>0?Oe=f8(ee+Re,k[0][0]):!j&&Re<0&&(Oe=a8(ee+Ke,k[1][0])),A&&Te>0?Qe=f8(ce+Te,k[0][1]):!A&&Te<0&&(Qe=a8(ce+ze,k[1][1])),ge=Math.max(ge,Oe),He=Math.max(He,Qe)}if(g){if(_){const Oe=qae(Ke/me,Y,Z)*me;if(ge=Math.max(ge,Oe),p){let Qe=0;!j&&!A||j&&!A&&I?Qe=f8(ce+te+Ke/me,p[1][1])*me:Qe=a8(ce+te+(j?Re:-Re)/me,p[0][1])*me,ge=Math.max(ge,Qe)}if(k){let Qe=0;!j&&!A||j&&!A&&I?Qe=a8(ce+Ke/me,k[1][1])*me:Qe=f8(ce+(j?Re:-Re)/me,k[0][1])*me,ge=Math.max(ge,Qe)}}if(D){const Oe=qae(ze*me,U,K)/me;if(He=Math.max(He,Oe),p){let Qe=0;!j&&!A||A&&!j&&I?Qe=f8(ee+ze*me+je,p[1][0])/me:Qe=a8(ee+(A?Te:-Te)*me+je,p[0][0])/me,He=Math.max(He,Qe)}if(k){let Qe=0;!j&&!A||A&&!j&&I?Qe=a8(ee+ze*me,k[1][0])/me:Qe=f8(ee+(A?Te:-Te)*me,k[0][0])/me,He=Math.max(He,Qe)}}}Te=Te+(Te<0?He:-He),Re=Re+(Re<0?ge:-ge),g&&(I?Ke>ze*me?Te=(Oyt(j,A)?-Re:Re)/me:Re=(Oyt(j,A)?-Te:Te)*me:_?(Te=Re/me,A=j):(Re=Te*me,j=A));const ae=j?ee+Re:ee,Le=A?ce+Te:ce;return{width:fe+(j?-Re:Re),height:be+(A?-Te:Te),x:w[0]*Re*(j?-1:1)+ae,y:w[1]*Te*(A?-1:1)+Le}}const d5t={width:0,height:0,x:0,y:0},Von={...d5t,pointerX:0,pointerY:0,aspectRatio:1};function Won(l){return[[0,0],[l.measured.width,l.measured.height]]}function Kon(l,s,u){const h=s.position.x+l.position.x,g=s.position.y+l.position.y,w=l.measured.width??0,p=l.measured.height??0,k=u[0]*w,j=u[1]*p;return[[h-k,g-j],[h+w-k,g+p-j]]}function Yon({domNode:l,nodeId:s,getStoreItems:u,onChange:h,onEnd:g}){const w=tm(l);let p={controlDirection:kyt("bottom-right"),boundaries:{minWidth:0,minHeight:0,maxWidth:Number.MAX_VALUE,maxHeight:Number.MAX_VALUE},resizeDirection:void 0,keepAspectRatio:!1};function k({controlPosition:A,boundaries:_,keepAspectRatio:D,resizeDirection:I,onResizeStart:B,onResize:F,onResizeEnd:U,shouldResize:K}){let Y={...d5t},Z={...Von};p={boundaries:_,resizeDirection:I,keepAspectRatio:D,controlDirection:kyt(A)};let ee,ce=null,fe=[],be,me,Re,Te=!1;const Ke=O4t().on("start",ze=>{const{nodeLookup:je,transform:te,snapGrid:ge,snapToGrid:He,nodeOrigin:ae,paneDomNode:Le}=u();if(ee=je.get(s),!ee)return;ce=(Le==null?void 0:Le.getBoundingClientRect())??null;const{xSnapped:Oe,ySnapped:Qe}=LX(ze.sourceEvent,{transform:te,snapGrid:ge,snapToGrid:He,containerBounds:ce});Y={width:ee.measured.width??0,height:ee.measured.height??0,x:ee.position.x??0,y:ee.position.y??0},Z={...Y,pointerX:Oe,pointerY:Qe,aspectRatio:Y.width/Y.height},be=void 0,ee.parentId&&(ee.extent==="parent"||ee.expandParent)&&(be=je.get(ee.parentId),me=be&&ee.extent==="parent"?Won(be):void 0),fe=[],Re=void 0;for(const[kt,Ae]of je)if(Ae.parentId===s&&(fe.push({id:kt,position:{...Ae.position},extent:Ae.extent}),Ae.extent==="parent"||Ae.expandParent)){const Ye=Kon(Ae,ee,Ae.origin??ae);Re?Re=[[Math.min(Ye[0][0],Re[0][0]),Math.min(Ye[0][1],Re[0][1])],[Math.max(Ye[1][0],Re[1][0]),Math.max(Ye[1][1],Re[1][1])]]:Re=Ye}B==null||B(ze,{...Y})}).on("drag",ze=>{const{transform:je,snapGrid:te,snapToGrid:ge,nodeOrigin:He}=u(),ae=LX(ze.sourceEvent,{transform:je,snapGrid:te,snapToGrid:ge,containerBounds:ce}),Le=[];if(!ee)return;const{x:Oe,y:Qe,width:kt,height:Ae}=Y,Ye={},mt=ee.origin??He,{width:Ue,height:Pt,x:rn,y:Cn}=Xon(Z,p.controlDirection,ae,p.boundaries,p.keepAspectRatio,mt,me,Re),Pn=Ue!==kt,mi=Pt!==Ae,er=rn!==Oe&&Pn,Mr=Cn!==Qe&&mi;if(!er&&!Mr&&!Pn&&!mi)return;if((er||Mr||mt[0]===1||mt[1]===1)&&(Ye.x=er?rn:Y.x,Ye.y=Mr?Cn:Y.y,Y.x=Ye.x,Y.y=Ye.y,fe.length>0)){const is=rn-Oe,bs=Cn-Qe;for(const bo of fe)bo.position={x:bo.position.x-is+mt[0]*(Ue-kt),y:bo.position.y-bs+mt[1]*(Pt-Ae)},Le.push(bo)}if((Pn||mi)&&(Ye.width=Pn&&(!p.resizeDirection||p.resizeDirection==="horizontal")?Ue:Y.width,Ye.height=mi&&(!p.resizeDirection||p.resizeDirection==="vertical")?Pt:Y.height,Y.width=Ye.width,Y.height=Ye.height),be&&ee.expandParent){const is=mt[0]*(Ye.width??0);Ye.x&&Ye.x<is&&(Y.x=is,Z.x=Z.x-(Ye.x-is));const bs=mt[1]*(Ye.height??0);Ye.y&&Ye.y<bs&&(Y.y=bs,Z.y=Z.y-(Ye.y-bs))}const hr=Jon({width:Y.width,prevWidth:kt,height:Y.height,prevHeight:Ae,affectsX:p.controlDirection.affectsX,affectsY:p.controlDirection.affectsY}),Gn={...Y,direction:hr};(K==null?void 0:K(ze,Gn))!==!1&&(Te=!0,F==null||F(ze,Gn),h(Ye,Le))}).on("end",ze=>{Te&&(U==null||U(ze,{...Y}),g==null||g({...Y}),Te=!1)});w.call(Ke)}function j(){w.on(".drag",null)}return{update:k,destroy:j}}var yEe={exports:{}},xEe={},kEe={exports:{}},OEe={};/**
 * @license React
 * use-sync-external-store-shim.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Syt;function Zon(){if(Syt)return OEe;Syt=1;var l=wV();function s(D,I){return D===I&&(D!==0||1/D===1/I)||D!==D&&I!==I}var u=typeof Object.is=="function"?Object.is:s,h=l.useState,g=l.useEffect,w=l.useLayoutEffect,p=l.useDebugValue;function k(D,I){var B=I(),F=h({inst:{value:B,getSnapshot:I}}),U=F[0].inst,K=F[1];return w(function(){U.value=B,U.getSnapshot=I,j(U)&&K({inst:U})},[D,B,I]),g(function(){return j(U)&&K({inst:U}),D(function(){j(U)&&K({inst:U})})},[D]),p(B),B}function j(D){var I=D.getSnapshot;D=D.value;try{var B=I();return!u(D,B)}catch{return!0}}function A(D,I){return I()}var _=typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"?A:k;return OEe.useSyncExternalStore=l.useSyncExternalStore!==void 0?l.useSyncExternalStore:_,OEe}var jyt;function ecn(){return jyt||(jyt=1,kEe.exports=Zon()),kEe.exports}/**
 * @license React
 * use-sync-external-store-shim/with-selector.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Tyt;function tcn(){if(Tyt)return xEe;Tyt=1;var l=wV(),s=ecn();function u(A,_){return A===_&&(A!==0||1/A===1/_)||A!==A&&_!==_}var h=typeof Object.is=="function"?Object.is:u,g=s.useSyncExternalStore,w=l.useRef,p=l.useEffect,k=l.useMemo,j=l.useDebugValue;return xEe.useSyncExternalStoreWithSelector=function(A,_,D,I,B){var F=w(null);if(F.current===null){var U={hasValue:!1,value:null};F.current=U}else U=F.current;F=k(function(){function Y(be){if(!Z){if(Z=!0,ee=be,be=I(be),B!==void 0&&U.hasValue){var me=U.value;if(B(me,be))return ce=me}return ce=be}if(me=ce,h(ee,be))return me;var Re=I(be);return B!==void 0&&B(me,Re)?(ee=be,me):(ee=be,ce=Re)}var Z=!1,ee,ce,fe=D===void 0?null:D;return[function(){return Y(_())},fe===null?void 0:function(){return Y(fe())}]},[_,D,I,B]);var K=g(A,F[0],F[1]);return p(function(){U.hasValue=!0,U.value=K},[K]),j(K),K},xEe}var Eyt;function ncn(){return Eyt||(Eyt=1,yEe.exports=tcn()),yEe.exports}var icn=ncn();const rcn=xMe(icn),scn={},Cyt=l=>{let s;const u=new Set,h=(_,D)=>{const I=typeof _=="function"?_(s):_;if(!Object.is(I,s)){const B=s;s=D??(typeof I!="object"||I===null)?I:Object.assign({},s,I),u.forEach(F=>F(s,B))}},g=()=>s,j={setState:h,getState:g,getInitialState:()=>A,subscribe:_=>(u.add(_),()=>u.delete(_)),destroy:()=>{(scn?"production":void 0)!=="production"&&console.warn("[DEPRECATED] The `destroy` method will be unsupported in a future version. Instead use unsubscribe function returned by subscribe. Everything will be garbage-collected if store is garbage-collected."),u.clear()}},A=s=l(h,g,j);return j},ocn=l=>l?Cyt(l):Cyt,{useDebugValue:ccn}=CX,{useSyncExternalStoreWithSelector:lcn}=rcn,ucn=l=>l;function g5t(l,s=ucn,u){const h=lcn(l.subscribe,l.getState,l.getServerState||l.getInitialState,s,u);return ccn(h),h}const Myt=(l,s)=>{const u=ocn(l),h=(g,w=s)=>g5t(u,g,w);return Object.assign(h,u),h},acn=(l,s)=>l?Myt(l,s):Myt;function ta(l,s){if(Object.is(l,s))return!0;if(typeof l!="object"||l===null||typeof s!="object"||s===null)return!1;if(l instanceof Map&&s instanceof Map){if(l.size!==s.size)return!1;for(const[h,g]of l)if(!Object.is(g,s.get(h)))return!1;return!0}if(l instanceof Set&&s instanceof Set){if(l.size!==s.size)return!1;for(const h of l)if(!s.has(h))return!1;return!0}const u=Object.keys(l);if(u.length!==Object.keys(s).length)return!1;for(const h of u)if(!Object.prototype.hasOwnProperty.call(s,h)||!Object.is(l[h],s[h]))return!1;return!0}l4t();const Lhe=pe.createContext(null),fcn=Lhe.Provider,p5t=W3.error001();function ac(l,s){const u=pe.useContext(Lhe);if(u===null)throw new Error(p5t);return g5t(u,l,s)}function na(){const l=pe.useContext(Lhe);if(l===null)throw new Error(p5t);return pe.useMemo(()=>({getState:l.getState,setState:l.setState,subscribe:l.subscribe}),[l])}const Ayt={display:"none"},hcn={position:"absolute",width:1,height:1,margin:-1,border:0,padding:0,overflow:"hidden",clip:"rect(0px, 0px, 0px, 0px)",clipPath:"inset(100%)"},b5t="react-flow__node-desc",m5t="react-flow__edge-desc",dcn="react-flow__aria-live",gcn=l=>l.ariaLiveMessage,pcn=l=>l.ariaLabelConfig;function bcn({rfId:l}){const s=ac(gcn);return E.jsx("div",{id:`${dcn}-${l}`,"aria-live":"assertive","aria-atomic":"true",style:hcn,children:s})}function mcn({rfId:l,disableKeyboardA11y:s}){const u=ac(pcn);return E.jsxs(E.Fragment,{children:[E.jsx("div",{id:`${b5t}-${l}`,style:Ayt,children:s?u["node.a11yDescription.default"]:u["node.a11yDescription.keyboardDisabled"]}),E.jsx("div",{id:`${m5t}-${l}`,style:Ayt,children:u["edge.a11yDescription.default"]}),!s&&E.jsx(bcn,{rfId:l})]})}const Phe=pe.forwardRef(({position:l="top-left",children:s,className:u,style:h,...g},w)=>{const p=`${l}`.split("-");return E.jsx("div",{className:dh(["react-flow__panel",u,...p]),style:h,ref:w,...g,children:s})});Phe.displayName="Panel";function wcn({proOptions:l,position:s="bottom-right"}){return l!=null&&l.hideAttribution?null:E.jsx(Phe,{position:s,className:"react-flow__attribution","data-message":"Please only hide this attribution when you are subscribed to React Flow Pro: https://pro.reactflow.dev",children:E.jsx("a",{href:"https://reactflow.dev",target:"_blank",rel:"noopener noreferrer","aria-label":"React Flow attribution",children:"React Flow"})})}const vcn=l=>{const s=[],u=[];for(const[,h]of l.nodeLookup)h.selected&&s.push(h.internals.userNode);for(const[,h]of l.edgeLookup)h.selected&&u.push(h);return{selectedNodes:s,selectedEdges:u}},Hae=l=>l.id;function ycn(l,s){return ta(l.selectedNodes.map(Hae),s.selectedNodes.map(Hae))&&ta(l.selectedEdges.map(Hae),s.selectedEdges.map(Hae))}function xcn({onSelectionChange:l}){const s=na(),{selectedNodes:u,selectedEdges:h}=ac(vcn,ycn);return pe.useEffect(()=>{const g={nodes:u,edges:h};l==null||l(g),s.getState().onSelectionChangeHandlers.forEach(w=>w(g))},[u,h,l]),null}const kcn=l=>!!l.onSelectionChangeHandlers;function Ocn({onSelectionChange:l}){const s=ac(kcn);return l||s?E.jsx(xcn,{onSelectionChange:l}):null}const w5t=[0,0],Scn={x:0,y:0,zoom:1},jcn=["nodes","edges","defaultNodes","defaultEdges","onConnect","onConnectStart","onConnectEnd","onClickConnectStart","onClickConnectEnd","nodesDraggable","autoPanOnNodeFocus","nodesConnectable","nodesFocusable","edgesFocusable","edgesReconnectable","elevateNodesOnSelect","elevateEdgesOnSelect","minZoom","maxZoom","nodeExtent","onNodesChange","onEdgesChange","elementsSelectable","connectionMode","snapGrid","snapToGrid","translateExtent","connectOnClick","defaultEdgeOptions","fitView","fitViewOptions","onNodesDelete","onEdgesDelete","onDelete","onNodeDrag","onNodeDragStart","onNodeDragStop","onSelectionDrag","onSelectionDragStart","onSelectionDragStop","onMoveStart","onMove","onMoveEnd","noPanClassName","nodeOrigin","autoPanOnConnect","autoPanOnNodeDrag","onError","connectionRadius","isValidConnection","selectNodesOnDrag","nodeDragThreshold","connectionDragThreshold","onBeforeDelete","debug","autoPanSpeed","ariaLabelConfig","zIndexMode"],Nyt=[...jcn,"rfId"],Tcn=l=>({setNodes:l.setNodes,setEdges:l.setEdges,setMinZoom:l.setMinZoom,setMaxZoom:l.setMaxZoom,setTranslateExtent:l.setTranslateExtent,setNodeExtent:l.setNodeExtent,reset:l.reset,setDefaultNodesAndEdges:l.setDefaultNodesAndEdges}),_yt={translateExtent:VX,nodeOrigin:w5t,minZoom:.5,maxZoom:2,elementsSelectable:!0,noPanClassName:"nopan",rfId:"1"};function Ecn(l){const{setNodes:s,setEdges:u,setMinZoom:h,setMaxZoom:g,setTranslateExtent:w,setNodeExtent:p,reset:k,setDefaultNodesAndEdges:j}=ac(Tcn,ta),A=na();pe.useEffect(()=>(j(l.defaultNodes,l.defaultEdges),()=>{_.current=_yt,k()}),[]);const _=pe.useRef(_yt);return pe.useEffect(()=>{for(const D of Nyt){const I=l[D],B=_.current[D];I!==B&&(typeof l[D]>"u"||(D==="nodes"?s(I):D==="edges"?u(I):D==="minZoom"?h(I):D==="maxZoom"?g(I):D==="translateExtent"?w(I):D==="nodeExtent"?p(I):D==="ariaLabelConfig"?A.setState({ariaLabelConfig:fon(I)}):D==="fitView"?A.setState({fitViewQueued:I}):D==="fitViewOptions"?A.setState({fitViewOptions:I}):A.setState({[D]:I})))}_.current=l},Nyt.map(D=>l[D])),null}function Dyt(){return typeof window>"u"||!window.matchMedia?null:window.matchMedia("(prefers-color-scheme: dark)")}function Ccn(l){var h;const[s,u]=pe.useState(l==="system"?null:l);return pe.useEffect(()=>{if(l!=="system"){u(l);return}const g=Dyt(),w=()=>u(g!=null&&g.matches?"dark":"light");return w(),g==null||g.addEventListener("change",w),()=>{g==null||g.removeEventListener("change",w)}},[l]),s!==null?s:(h=Dyt())!=null&&h.matches?"dark":"light"}const Lyt=typeof document<"u"?document:null;function YX(l=null,s={target:Lyt,actInsideInputWithModifier:!0}){const[u,h]=pe.useState(!1),g=pe.useRef(!1),w=pe.useRef(new Set([])),[p,k]=pe.useMemo(()=>{if(l!==null){const A=(Array.isArray(l)?l:[l]).filter(D=>typeof D=="string").map(D=>D.replace("+",`
`).replace(`

`,`
+`).split(`
`)),_=A.reduce((D,I)=>D.concat(...I),[]);return[A,_]}return[[],[]]},[l]);return pe.useEffect(()=>{const j=(s==null?void 0:s.target)??Lyt,A=(s==null?void 0:s.actInsideInputWithModifier)??!0;if(l!==null){const _=B=>{var K,Y;if(g.current=B.ctrlKey||B.metaKey||B.shiftKey||B.altKey,(!g.current||g.current&&!A)&&K4t(B))return!1;const U=Iyt(B.code,k);if(w.current.add(B[U]),Pyt(p,w.current,!1)){const Z=((Y=(K=B.composedPath)==null?void 0:K.call(B))==null?void 0:Y[0])||B.target,ee=(Z==null?void 0:Z.nodeName)==="BUTTON"||(Z==null?void 0:Z.nodeName)==="A";s.preventDefault!==!1&&(g.current||!ee)&&B.preventDefault(),h(!0)}},D=B=>{const F=Iyt(B.code,k);Pyt(p,w.current,!0)?(h(!1),w.current.clear()):w.current.delete(B[F]),B.key==="Meta"&&w.current.clear(),g.current=!1},I=()=>{w.current.clear(),h(!1)};return j==null||j.addEventListener("keydown",_),j==null||j.addEventListener("keyup",D),window.addEventListener("blur",I),window.addEventListener("contextmenu",I),()=>{j==null||j.removeEventListener("keydown",_),j==null||j.removeEventListener("keyup",D),window.removeEventListener("blur",I),window.removeEventListener("contextmenu",I)}}},[l,h]),u}function Pyt(l,s,u){return l.filter(h=>u||h.length===s.size).some(h=>h.every(g=>s.has(g)))}function Iyt(l,s){return s.includes(l)?"code":"key"}const Mcn=()=>{const l=na();return pe.useMemo(()=>({zoomIn:s=>{const{panZoom:u}=l.getState();return u?u.scaleBy(1.2,{duration:s==null?void 0:s.duration}):Promise.resolve(!1)},zoomOut:s=>{const{panZoom:u}=l.getState();return u?u.scaleBy(1/1.2,{duration:s==null?void 0:s.duration}):Promise.resolve(!1)},zoomTo:(s,u)=>{const{panZoom:h}=l.getState();return h?h.scaleTo(s,{duration:u==null?void 0:u.duration}):Promise.resolve(!1)},getZoom:()=>l.getState().transform[2],setViewport:async(s,u)=>{const{transform:[h,g,w],panZoom:p}=l.getState();return p?(await p.setViewport({x:s.x??h,y:s.y??g,zoom:s.zoom??w},u),Promise.resolve(!0)):Promise.resolve(!1)},getViewport:()=>{const[s,u,h]=l.getState().transform;return{x:s,y:u,zoom:h}},setCenter:async(s,u,h)=>l.getState().setCenter(s,u,h),fitBounds:async(s,u)=>{const{width:h,height:g,minZoom:w,maxZoom:p,panZoom:k}=l.getState(),j=NMe(s,h,g,w,p,(u==null?void 0:u.padding)??.1);return k?(await k.setViewport(j,{duration:u==null?void 0:u.duration,ease:u==null?void 0:u.ease,interpolate:u==null?void 0:u.interpolate}),Promise.resolve(!0)):Promise.resolve(!1)},screenToFlowPosition:(s,u={})=>{const{transform:h,snapGrid:g,snapToGrid:w,domNode:p}=l.getState();if(!p)return s;const{x:k,y:j}=p.getBoundingClientRect(),A={x:s.x-k,y:s.y-j},_=u.snapGrid??g,D=u.snapToGrid??w;return SV(A,h,D,_)},flowToScreenPosition:s=>{const{transform:u,domNode:h}=l.getState();if(!h)return s;const{x:g,y:w}=h.getBoundingClientRect(),p=Qfe(s,u);return{x:p.x+g,y:p.y+w}}}),[])};function v5t(l,s){const u=[],h=new Map,g=[];for(const w of l)if(w.type==="add"){g.push(w);continue}else if(w.type==="remove"||w.type==="replace")h.set(w.id,[w]);else{const p=h.get(w.id);p?p.push(w):h.set(w.id,[w])}for(const w of s){const p=h.get(w.id);if(!p){u.push(w);continue}if(p[0].type==="remove")continue;if(p[0].type==="replace"){u.push({...p[0].item});continue}const k={...w};for(const j of p)Acn(j,k);u.push(k)}return g.length&&g.forEach(w=>{w.index!==void 0?u.splice(w.index,0,{...w.item}):u.push({...w.item})}),u}function Acn(l,s){switch(l.type){case"select":{s.selected=l.selected;break}case"position":{typeof l.position<"u"&&(s.position=l.position),typeof l.dragging<"u"&&(s.dragging=l.dragging);break}case"dimensions":{typeof l.dimensions<"u"&&(s.measured={...l.dimensions},l.setAttributes&&((l.setAttributes===!0||l.setAttributes==="width")&&(s.width=l.dimensions.width),(l.setAttributes===!0||l.setAttributes==="height")&&(s.height=l.dimensions.height))),typeof l.resizing=="boolean"&&(s.resizing=l.resizing);break}}}function y5t(l,s){return v5t(l,s)}function x5t(l,s){return v5t(l,s)}function rM(l,s){return{id:l,type:"select",selected:s}}function uI(l,s=new Set,u=!1){const h=[];for(const[g,w]of l){const p=s.has(g);!(w.selected===void 0&&!p)&&w.selected!==p&&(u&&(w.selected=p),h.push(rM(w.id,p)))}return h}function Ryt({items:l=[],lookup:s}){var g;const u=[],h=new Map(l.map(w=>[w.id,w]));for(const[w,p]of l.entries()){const k=s.get(p.id),j=((g=k==null?void 0:k.internals)==null?void 0:g.userNode)??k;j!==void 0&&j!==p&&u.push({id:p.id,item:p,type:"replace"}),j===void 0&&u.push({item:p,type:"add",index:w})}for(const[w]of s)h.get(w)===void 0&&u.push({id:w,type:"remove"});return u}function $yt(l){return{id:l.id,type:"remove"}}const Byt=l=>ton(l),Ncn=l=>H4t(l);function k5t(l){return pe.forwardRef(l)}const _cn=typeof window<"u"?pe.useLayoutEffect:pe.useEffect;function zyt(l){const[s,u]=pe.useState(BigInt(0)),[h]=pe.useState(()=>Dcn(()=>u(g=>g+BigInt(1))));return _cn(()=>{const g=h.get();g.length&&(l(g),h.reset())},[s]),h}function Dcn(l){let s=[];return{get:()=>s,reset:()=>{s=[]},push:u=>{s.push(u),l()}}}const O5t=pe.createContext(null);function Lcn({children:l}){const s=na(),u=pe.useCallback(k=>{const{nodes:j=[],setNodes:A,hasDefaultNodes:_,onNodesChange:D,nodeLookup:I,fitViewQueued:B,onNodesChangeMiddlewareMap:F}=s.getState();let U=j;for(const Y of k)U=typeof Y=="function"?Y(U):Y;let K=Ryt({items:U,lookup:I});for(const Y of F.values())K=Y(K);_&&A(U),K.length>0?D==null||D(K):B&&window.requestAnimationFrame(()=>{const{fitViewQueued:Y,nodes:Z,setNodes:ee}=s.getState();Y&&ee(Z)})},[]),h=zyt(u),g=pe.useCallback(k=>{const{edges:j=[],setEdges:A,hasDefaultEdges:_,onEdgesChange:D,edgeLookup:I}=s.getState();let B=j;for(const F of k)B=typeof F=="function"?F(B):F;_?A(B):D&&D(Ryt({items:B,lookup:I}))},[]),w=zyt(g),p=pe.useMemo(()=>({nodeQueue:h,edgeQueue:w}),[]);return E.jsx(O5t.Provider,{value:p,children:l})}function Pcn(){const l=pe.useContext(O5t);if(!l)throw new Error("useBatchContext must be used within a BatchProvider");return l}const Icn=l=>!!l.panZoom;function Ihe(){const l=Mcn(),s=na(),u=Pcn(),h=ac(Icn),g=pe.useMemo(()=>{const w=D=>s.getState().nodeLookup.get(D),p=D=>{u.nodeQueue.push(D)},k=D=>{u.edgeQueue.push(D)},j=D=>{var Y,Z;const{nodeLookup:I,nodeOrigin:B}=s.getState(),F=Byt(D)?D:I.get(D.id),U=F.parentId?V4t(F.position,F.measured,F.parentId,I,B):F.position,K={...F,position:U,width:((Y=F.measured)==null?void 0:Y.width)??F.width,height:((Z=F.measured)==null?void 0:Z.height)??F.height};return CI(K)},A=(D,I,B={replace:!1})=>{p(F=>F.map(U=>{if(U.id===D){const K=typeof I=="function"?I(U):I;return B.replace&&Byt(K)?K:{...U,...K}}return U}))},_=(D,I,B={replace:!1})=>{k(F=>F.map(U=>{if(U.id===D){const K=typeof I=="function"?I(U):I;return B.replace&&Ncn(K)?K:{...U,...K}}return U}))};return{getNodes:()=>s.getState().nodes.map(D=>({...D})),getNode:D=>{var I;return(I=w(D))==null?void 0:I.internals.userNode},getInternalNode:w,getEdges:()=>{const{edges:D=[]}=s.getState();return D.map(I=>({...I}))},getEdge:D=>s.getState().edgeLookup.get(D),setNodes:p,setEdges:k,addNodes:D=>{const I=Array.isArray(D)?D:[D];u.nodeQueue.push(B=>[...B,...I])},addEdges:D=>{const I=Array.isArray(D)?D:[D];u.edgeQueue.push(B=>[...B,...I])},toObject:()=>{const{nodes:D=[],edges:I=[],transform:B}=s.getState(),[F,U,K]=B;return{nodes:D.map(Y=>({...Y})),edges:I.map(Y=>({...Y})),viewport:{x:F,y:U,zoom:K}}},deleteElements:async({nodes:D=[],edges:I=[]})=>{const{nodes:B,edges:F,onNodesDelete:U,onEdgesDelete:K,triggerNodeChanges:Y,triggerEdgeChanges:Z,onDelete:ee,onBeforeDelete:ce}=s.getState(),{nodes:fe,edges:be}=await oon({nodesToRemove:D,edgesToRemove:I,nodes:B,edges:F,onBeforeDelete:ce}),me=be.length>0,Re=fe.length>0;if(me){const Te=be.map($yt);K==null||K(be),Z(Te)}if(Re){const Te=fe.map($yt);U==null||U(fe),Y(Te)}return(Re||me)&&(ee==null||ee({nodes:fe,edges:be})),{deletedNodes:fe,deletedEdges:be}},getIntersectingNodes:(D,I=!0,B)=>{const F=fyt(D),U=F?D:j(D),K=B!==void 0;return U?(B||s.getState().nodes).filter(Y=>{const Z=s.getState().nodeLookup.get(Y.id);if(Z&&!F&&(Y.id===D.id||!Z.internals.positionAbsolute))return!1;const ee=CI(K?Y:Z),ce=WX(ee,U);return I&&ce>0||ce>=ee.width*ee.height||ce>=U.width*U.height}):[]},isNodeIntersecting:(D,I,B=!0)=>{const U=fyt(D)?D:j(D);if(!U)return!1;const K=WX(U,I);return B&&K>0||K>=I.width*I.height||K>=U.width*U.height},updateNode:A,updateNodeData:(D,I,B={replace:!1})=>{A(D,F=>{const U=typeof I=="function"?I(F):I;return B.replace?{...F,data:U}:{...F,data:{...F.data,...U}}},B)},updateEdge:_,updateEdgeData:(D,I,B={replace:!1})=>{_(D,F=>{const U=typeof I=="function"?I(F):I;return B.replace?{...F,data:U}:{...F,data:{...F.data,...U}}},B)},getNodesBounds:D=>{const{nodeLookup:I,nodeOrigin:B}=s.getState();return non(D,{nodeLookup:I,nodeOrigin:B})},getHandleConnections:({type:D,id:I,nodeId:B})=>{var F;return Array.from(((F=s.getState().connectionLookup.get(`${B}-${D}${I?`-${I}`:""}`))==null?void 0:F.values())??[])},getNodeConnections:({type:D,handleId:I,nodeId:B})=>{var F;return Array.from(((F=s.getState().connectionLookup.get(`${B}${D?I?`-${D}-${I}`:`-${D}`:""}`))==null?void 0:F.values())??[])},fitView:async D=>{const I=s.getState().fitViewResolver??aon();return s.setState({fitViewQueued:!0,fitViewOptions:D,fitViewResolver:I}),u.nodeQueue.push(B=>[...B]),I.promise}}},[]);return pe.useMemo(()=>({...g,...l,viewportInitialized:h}),[h])}const Fyt=l=>l.selected,Rcn=typeof window<"u"?window:void 0;function $cn({deleteKeyCode:l,multiSelectionKeyCode:s}){const u=na(),{deleteElements:h}=Ihe(),g=YX(l,{actInsideInputWithModifier:!1}),w=YX(s,{target:Rcn});pe.useEffect(()=>{if(g){const{edges:p,nodes:k}=u.getState();h({nodes:k.filter(Fyt),edges:p.filter(Fyt)}),u.setState({nodesSelectionActive:!1})}},[g]),pe.useEffect(()=>{u.setState({multiSelectionActive:w})},[w])}function Bcn(l){const s=na();pe.useEffect(()=>{const u=()=>{var g,w,p,k;if(!l.current||!(((w=(g=l.current).checkVisibility)==null?void 0:w.call(g))??!0))return!1;const h=_Me(l.current);(h.height===0||h.width===0)&&((k=(p=s.getState()).onError)==null||k.call(p,"004",W3.error004())),s.setState({width:h.width||500,height:h.height||500})};if(l.current){u(),window.addEventListener("resize",u);const h=new ResizeObserver(()=>u());return h.observe(l.current),()=>{window.removeEventListener("resize",u),h&&l.current&&h.unobserve(l.current)}}},[])}const Rhe={position:"absolute",width:"100%",height:"100%",top:0,left:0},zcn=l=>({userSelectionActive:l.userSelectionActive,lib:l.lib,connectionInProgress:l.connection.inProgress});function Fcn({onPaneContextMenu:l,zoomOnScroll:s=!0,zoomOnPinch:u=!0,panOnScroll:h=!1,panOnScrollSpeed:g=.5,panOnScrollMode:w=dM.Free,zoomOnDoubleClick:p=!0,panOnDrag:k=!0,defaultViewport:j,translateExtent:A,minZoom:_,maxZoom:D,zoomActivationKeyCode:I,preventScrolling:B=!0,children:F,noWheelClassName:U,noPanClassName:K,onViewportChange:Y,isControlledViewport:Z,paneClickDistance:ee,selectionOnDrag:ce}){const fe=na(),be=pe.useRef(null),{userSelectionActive:me,lib:Re,connectionInProgress:Te}=ac(zcn,ta),Ke=YX(I),ze=pe.useRef();Bcn(be);const je=pe.useCallback(te=>{Y==null||Y({x:te[0],y:te[1],zoom:te[2]}),Z||fe.setState({transform:te})},[Y,Z]);return pe.useEffect(()=>{if(be.current){ze.current=Uon({domNode:be.current,minZoom:_,maxZoom:D,translateExtent:A,viewport:j,onDraggingChange:ae=>fe.setState({paneDragging:ae}),onPanZoomStart:(ae,Le)=>{const{onViewportChangeStart:Oe,onMoveStart:Qe}=fe.getState();Qe==null||Qe(ae,Le),Oe==null||Oe(Le)},onPanZoom:(ae,Le)=>{const{onViewportChange:Oe,onMove:Qe}=fe.getState();Qe==null||Qe(ae,Le),Oe==null||Oe(Le)},onPanZoomEnd:(ae,Le)=>{const{onViewportChangeEnd:Oe,onMoveEnd:Qe}=fe.getState();Qe==null||Qe(ae,Le),Oe==null||Oe(Le)}});const{x:te,y:ge,zoom:He}=ze.current.getViewport();return fe.setState({panZoom:ze.current,transform:[te,ge,He],domNode:be.current.closest(".react-flow")}),()=>{var ae;(ae=ze.current)==null||ae.destroy()}}},[]),pe.useEffect(()=>{var te;(te=ze.current)==null||te.update({onPaneContextMenu:l,zoomOnScroll:s,zoomOnPinch:u,panOnScroll:h,panOnScrollSpeed:g,panOnScrollMode:w,zoomOnDoubleClick:p,panOnDrag:k,zoomActivationKeyPressed:Ke,preventScrolling:B,noPanClassName:K,userSelectionActive:me,noWheelClassName:U,lib:Re,onTransformChange:je,connectionInProgress:Te,selectionOnDrag:ce,paneClickDistance:ee})},[l,s,u,h,g,w,p,k,Ke,B,K,me,U,Re,je,Te,ce,ee]),E.jsx("div",{className:"react-flow__renderer",ref:be,style:Rhe,children:F})}const qcn=l=>({userSelectionActive:l.userSelectionActive,userSelectionRect:l.userSelectionRect});function Hcn(){const{userSelectionActive:l,userSelectionRect:s}=ac(qcn,ta);return l&&s?E.jsx("div",{className:"react-flow__selection react-flow__container",style:{width:s.width,height:s.height,transform:`translate(${s.x}px, ${s.y}px)`}}):null}const SEe=(l,s)=>u=>{u.target===s.current&&(l==null||l(u))},Qcn=l=>({userSelectionActive:l.userSelectionActive,elementsSelectable:l.elementsSelectable,connectionInProgress:l.connection.inProgress,dragging:l.paneDragging});function Gcn({isSelecting:l,selectionKeyPressed:s,selectionMode:u=TI.Full,panOnDrag:h,paneClickDistance:g,selectionOnDrag:w,onSelectionStart:p,onSelectionEnd:k,onPaneClick:j,onPaneContextMenu:A,onPaneScroll:_,onPaneMouseEnter:D,onPaneMouseMove:I,onPaneMouseLeave:B,children:F}){const U=na(),{userSelectionActive:K,elementsSelectable:Y,dragging:Z,connectionInProgress:ee}=ac(Qcn,ta),ce=Y&&(l||K),fe=pe.useRef(null),be=pe.useRef(),me=pe.useRef(new Set),Re=pe.useRef(new Set),Te=pe.useRef(!1),Ke=Oe=>{if(Te.current||ee){Te.current=!1;return}j==null||j(Oe),U.getState().resetSelectedElements(),U.setState({nodesSelectionActive:!1})},ze=Oe=>{if(Array.isArray(h)&&(h!=null&&h.includes(2))){Oe.preventDefault();return}A==null||A(Oe)},je=_?Oe=>_(Oe):void 0,te=Oe=>{Te.current&&(Oe.stopPropagation(),Te.current=!1)},ge=Oe=>{var Pt,rn;const{domNode:Qe}=U.getState();if(be.current=Qe==null?void 0:Qe.getBoundingClientRect(),!be.current)return;const kt=Oe.target===fe.current;if(!kt&&!!Oe.target.closest(".nokey")||!l||!(w&&kt||s)||Oe.button!==0||!Oe.isPrimary)return;(rn=(Pt=Oe.target)==null?void 0:Pt.setPointerCapture)==null||rn.call(Pt,Oe.pointerId),Te.current=!1;const{x:mt,y:Ue}=ky(Oe.nativeEvent,be.current);U.setState({userSelectionRect:{width:0,height:0,startX:mt,startY:Ue,x:mt,y:Ue}}),kt||(Oe.stopPropagation(),Oe.preventDefault())},He=Oe=>{const{userSelectionRect:Qe,transform:kt,nodeLookup:Ae,edgeLookup:Ye,connectionLookup:mt,triggerNodeChanges:Ue,triggerEdgeChanges:Pt,defaultEdgeOptions:rn,resetSelectedElements:Cn}=U.getState();if(!be.current||!Qe)return;const{x:Pn,y:mi}=ky(Oe.nativeEvent,be.current),{startX:er,startY:Mr}=Qe;if(!Te.current){const bs=s?0:g;if(Math.hypot(Pn-er,mi-Mr)<=bs)return;Cn(),p==null||p(Oe)}Te.current=!0;const hr={startX:er,startY:Mr,x:Pn<er?Pn:er,y:mi<Mr?mi:Mr,width:Math.abs(Pn-er),height:Math.abs(mi-Mr)},Gn=me.current,Ir=Re.current;me.current=new Set(AMe(Ae,hr,kt,u===TI.Partial,!0).map(bs=>bs.id)),Re.current=new Set;const is=(rn==null?void 0:rn.selectable)??!0;for(const bs of me.current){const bo=mt.get(bs);if(bo)for(const{edgeId:Bl}of bo.values()){const Zl=Ye.get(Bl);Zl&&(Zl.selectable??is)&&Re.current.add(Bl)}}if(!hyt(Gn,me.current)){const bs=uI(Ae,me.current,!0);Ue(bs)}if(!hyt(Ir,Re.current)){const bs=uI(Ye,Re.current);Pt(bs)}U.setState({userSelectionRect:hr,userSelectionActive:!0,nodesSelectionActive:!1})},ae=Oe=>{var Qe,kt;Oe.button===0&&((kt=(Qe=Oe.target)==null?void 0:Qe.releasePointerCapture)==null||kt.call(Qe,Oe.pointerId),!K&&Oe.target===fe.current&&U.getState().userSelectionRect&&(Ke==null||Ke(Oe)),U.setState({userSelectionActive:!1,userSelectionRect:null}),Te.current&&(k==null||k(Oe),U.setState({nodesSelectionActive:me.current.size>0})))},Le=h===!0||Array.isArray(h)&&h.includes(0);return E.jsxs("div",{className:dh(["react-flow__pane",{draggable:Le,dragging:Z,selection:l}]),onClick:ce?void 0:SEe(Ke,fe),onContextMenu:SEe(ze,fe),onWheel:SEe(je,fe),onPointerEnter:ce?void 0:D,onPointerMove:ce?He:I,onPointerUp:ce?ae:void 0,onPointerDownCapture:ce?ge:void 0,onClickCapture:ce?te:void 0,onPointerLeave:B,ref:fe,style:Rhe,children:[F,E.jsx(Hcn,{})]})}function jCe({id:l,store:s,unselect:u=!1,nodeRef:h}){const{addSelectedNodes:g,unselectNodesAndEdges:w,multiSelectionActive:p,nodeLookup:k,onError:j}=s.getState(),A=k.get(l);if(!A){j==null||j("012",W3.error012(l));return}s.setState({nodesSelectionActive:!1}),A.selected?(u||A.selected&&p)&&(w({nodes:[A],edges:[]}),requestAnimationFrame(()=>{var _;return(_=h==null?void 0:h.current)==null?void 0:_.blur()})):g([l])}function S5t({nodeRef:l,disabled:s=!1,noDragClassName:u,handleSelector:h,nodeId:g,isSelectable:w,nodeClickDistance:p}){const k=na(),[j,A]=pe.useState(!1),_=pe.useRef();return pe.useEffect(()=>{_.current=_on({getStoreItems:()=>k.getState(),onNodeMouseDown:D=>{jCe({id:D,store:k,nodeRef:l})},onDragStart:()=>{A(!0)},onDragStop:()=>{A(!1)}})},[]),pe.useEffect(()=>{var D,I;if(s)(D=_.current)==null||D.destroy();else if(l.current)return(I=_.current)==null||I.update({noDragClassName:u,handleSelector:h,domNode:l.current,isSelectable:w,nodeId:g,nodeClickDistance:p}),()=>{var B;(B=_.current)==null||B.destroy()}},[u,h,s,w,l,g]),j}const Ucn=l=>s=>s.selected&&(s.draggable||l&&typeof s.draggable>"u");function j5t(){const l=na();return pe.useCallback(u=>{const{nodeExtent:h,snapToGrid:g,snapGrid:w,nodesDraggable:p,onError:k,updateNodePositions:j,nodeLookup:A,nodeOrigin:_}=l.getState(),D=new Map,I=Ucn(p),B=g?w[0]:5,F=g?w[1]:5,U=u.direction.x*B*u.factor,K=u.direction.y*F*u.factor;for(const[,Y]of A){if(!I(Y))continue;let Z={x:Y.internals.positionAbsolute.x+U,y:Y.internals.positionAbsolute.y+K};g&&(Z=OV(Z,w));const{position:ee,positionAbsolute:ce}=Q4t({nodeId:Y.id,nextPosition:Z,nodeLookup:A,nodeExtent:h,nodeOrigin:_,onError:k});Y.position=ee,Y.internals.positionAbsolute=ce,D.set(Y.id,Y)}j(D)},[])}const $Me=pe.createContext(null),Jcn=$Me.Provider;$Me.Consumer;const T5t=()=>pe.useContext($Me),Xcn=l=>({connectOnClick:l.connectOnClick,noPanClassName:l.noPanClassName,rfId:l.rfId}),Vcn=(l,s,u)=>h=>{const{connectionClickStartHandle:g,connectionMode:w,connection:p}=h,{fromHandle:k,toHandle:j,isValid:A}=p,_=(j==null?void 0:j.nodeId)===l&&(j==null?void 0:j.id)===s&&(j==null?void 0:j.type)===u;return{connectingFrom:(k==null?void 0:k.nodeId)===l&&(k==null?void 0:k.id)===s&&(k==null?void 0:k.type)===u,connectingTo:_,clickConnecting:(g==null?void 0:g.nodeId)===l&&(g==null?void 0:g.id)===s&&(g==null?void 0:g.type)===u,isPossibleEndHandle:w===jI.Strict?(k==null?void 0:k.type)!==u:l!==(k==null?void 0:k.nodeId)||s!==(k==null?void 0:k.id),connectionInProcess:!!k,clickConnectionInProcess:!!g,valid:_&&A}};function Wcn({type:l="source",position:s=br.Top,isValidConnection:u,isConnectable:h=!0,isConnectableStart:g=!0,isConnectableEnd:w=!0,id:p,onConnect:k,children:j,className:A,onMouseDown:_,onTouchStart:D,...I},B){var He,ae;const F=p||null,U=l==="target",K=na(),Y=T5t(),{connectOnClick:Z,noPanClassName:ee,rfId:ce}=ac(Xcn,ta),{connectingFrom:fe,connectingTo:be,clickConnecting:me,isPossibleEndHandle:Re,connectionInProcess:Te,clickConnectionInProcess:Ke,valid:ze}=ac(Vcn(Y,F,l),ta);Y||(ae=(He=K.getState()).onError)==null||ae.call(He,"010",W3.error010());const je=Le=>{const{defaultEdgeOptions:Oe,onConnect:Qe,hasDefaultEdges:kt}=K.getState(),Ae={...Oe,...Le};if(kt){const{edges:Ye,setEdges:mt}=K.getState();mt(yCe(Ae,Ye))}Qe==null||Qe(Ae),k==null||k(Ae)},te=Le=>{if(!Y)return;const Oe=Y4t(Le.nativeEvent);if(g&&(Oe&&Le.button===0||!Oe)){const Qe=K.getState();SCe.onPointerDown(Le.nativeEvent,{handleDomNode:Le.currentTarget,autoPanOnConnect:Qe.autoPanOnConnect,connectionMode:Qe.connectionMode,connectionRadius:Qe.connectionRadius,domNode:Qe.domNode,nodeLookup:Qe.nodeLookup,lib:Qe.lib,isTarget:U,handleId:F,nodeId:Y,flowId:Qe.rfId,panBy:Qe.panBy,cancelConnection:Qe.cancelConnection,onConnectStart:Qe.onConnectStart,onConnectEnd:Qe.onConnectEnd,updateConnection:Qe.updateConnection,onConnect:je,isValidConnection:u||Qe.isValidConnection,getTransform:()=>K.getState().transform,getFromHandle:()=>K.getState().connection.fromHandle,autoPanSpeed:Qe.autoPanSpeed,dragThreshold:Qe.connectionDragThreshold})}Oe?_==null||_(Le):D==null||D(Le)},ge=Le=>{const{onClickConnectStart:Oe,onClickConnectEnd:Qe,connectionClickStartHandle:kt,connectionMode:Ae,isValidConnection:Ye,lib:mt,rfId:Ue,nodeLookup:Pt,connection:rn}=K.getState();if(!Y||!kt&&!g)return;if(!kt){Oe==null||Oe(Le.nativeEvent,{nodeId:Y,handleId:F,handleType:l}),K.setState({connectionClickStartHandle:{nodeId:Y,type:l,id:F}});return}const Cn=W4t(Le.target),Pn=u||Ye,{connection:mi,isValid:er}=SCe.isValid(Le.nativeEvent,{handle:{nodeId:Y,id:F,type:l},connectionMode:Ae,fromNodeId:kt.nodeId,fromHandleId:kt.id||null,fromType:kt.type,isValidConnection:Pn,flowId:Ue,doc:Cn,lib:mt,nodeLookup:Pt});er&&mi&&je(mi);const Mr=structuredClone(rn);delete Mr.inProgress,Mr.toPosition=Mr.toHandle?Mr.toHandle.position:null,Qe==null||Qe(Le,Mr),K.setState({connectionClickStartHandle:null})};return E.jsx("div",{"data-handleid":F,"data-nodeid":Y,"data-handlepos":s,"data-id":`${ce}-${Y}-${F}-${l}`,className:dh(["react-flow__handle",`react-flow__handle-${s}`,"nodrag",ee,A,{source:!U,target:U,connectable:h,connectablestart:g,connectableend:w,clickconnecting:me,connectingfrom:fe,connectingto:be,valid:ze,connectionindicator:h&&(!Te||Re)&&(Te||Ke?w:g)}]),onMouseDown:te,onTouchStart:te,onClick:Z?ge:void 0,ref:B,...I,children:j})}const Gw=pe.memo(k5t(Wcn));function Kcn({data:l,isConnectable:s,sourcePosition:u=br.Bottom}){return E.jsxs(E.Fragment,{children:[l==null?void 0:l.label,E.jsx(Gw,{type:"source",position:u,isConnectable:s})]})}function Ycn({data:l,isConnectable:s,targetPosition:u=br.Top,sourcePosition:h=br.Bottom}){return E.jsxs(E.Fragment,{children:[E.jsx(Gw,{type:"target",position:u,isConnectable:s}),l==null?void 0:l.label,E.jsx(Gw,{type:"source",position:h,isConnectable:s})]})}function Zcn(){return null}function eln({data:l,isConnectable:s,targetPosition:u=br.Top}){return E.jsxs(E.Fragment,{children:[E.jsx(Gw,{type:"target",position:u,isConnectable:s}),l==null?void 0:l.label]})}const Gfe={ArrowUp:{x:0,y:-1},ArrowDown:{x:0,y:1},ArrowLeft:{x:-1,y:0},ArrowRight:{x:1,y:0}},qyt={input:Kcn,default:Ycn,output:eln,group:Zcn};function tln(l){var s,u,h,g;return l.internals.handleBounds===void 0?{width:l.width??l.initialWidth??((s=l.style)==null?void 0:s.width),height:l.height??l.initialHeight??((u=l.style)==null?void 0:u.height)}:{width:l.width??((h=l.style)==null?void 0:h.width),height:l.height??((g=l.style)==null?void 0:g.height)}}const nln=l=>{const{width:s,height:u,x:h,y:g}=kV(l.nodeLookup,{filter:w=>!!w.selected});return{width:xy(s)?s:null,height:xy(u)?u:null,userSelectionActive:l.userSelectionActive,transformString:`translate(${l.transform[0]}px,${l.transform[1]}px) scale(${l.transform[2]}) translate(${h}px,${g}px)`}};function iln({onSelectionContextMenu:l,noPanClassName:s,disableKeyboardA11y:u}){const h=na(),{width:g,height:w,transformString:p,userSelectionActive:k}=ac(nln,ta),j=j5t(),A=pe.useRef(null);if(pe.useEffect(()=>{var I;u||(I=A.current)==null||I.focus({preventScroll:!0})},[u]),S5t({nodeRef:A}),k||!g||!w)return null;const _=l?I=>{const B=h.getState().nodes.filter(F=>F.selected);l(I,B)}:void 0,D=I=>{Object.prototype.hasOwnProperty.call(Gfe,I.key)&&(I.preventDefault(),j({direction:Gfe[I.key],factor:I.shiftKey?4:1}))};return E.jsx("div",{className:dh(["react-flow__nodesselection","react-flow__container",s]),style:{transform:p},children:E.jsx("div",{ref:A,className:"react-flow__nodesselection-rect",onContextMenu:_,tabIndex:u?void 0:-1,onKeyDown:u?void 0:D,style:{width:g,height:w}})})}const Hyt=typeof window<"u"?window:void 0,rln=l=>({nodesSelectionActive:l.nodesSelectionActive,userSelectionActive:l.userSelectionActive});function E5t({children:l,onPaneClick:s,onPaneMouseEnter:u,onPaneMouseMove:h,onPaneMouseLeave:g,onPaneContextMenu:w,onPaneScroll:p,paneClickDistance:k,deleteKeyCode:j,selectionKeyCode:A,selectionOnDrag:_,selectionMode:D,onSelectionStart:I,onSelectionEnd:B,multiSelectionKeyCode:F,panActivationKeyCode:U,zoomActivationKeyCode:K,elementsSelectable:Y,zoomOnScroll:Z,zoomOnPinch:ee,panOnScroll:ce,panOnScrollSpeed:fe,panOnScrollMode:be,zoomOnDoubleClick:me,panOnDrag:Re,defaultViewport:Te,translateExtent:Ke,minZoom:ze,maxZoom:je,preventScrolling:te,onSelectionContextMenu:ge,noWheelClassName:He,noPanClassName:ae,disableKeyboardA11y:Le,onViewportChange:Oe,isControlledViewport:Qe}){const{nodesSelectionActive:kt,userSelectionActive:Ae}=ac(rln,ta),Ye=YX(A,{target:Hyt}),mt=YX(U,{target:Hyt}),Ue=mt||Re,Pt=mt||ce,rn=_&&Ue!==!0,Cn=Ye||Ae||rn;return $cn({deleteKeyCode:j,multiSelectionKeyCode:F}),E.jsx(Fcn,{onPaneContextMenu:w,elementsSelectable:Y,zoomOnScroll:Z,zoomOnPinch:ee,panOnScroll:Pt,panOnScrollSpeed:fe,panOnScrollMode:be,zoomOnDoubleClick:me,panOnDrag:!Ye&&Ue,defaultViewport:Te,translateExtent:Ke,minZoom:ze,maxZoom:je,zoomActivationKeyCode:K,preventScrolling:te,noWheelClassName:He,noPanClassName:ae,onViewportChange:Oe,isControlledViewport:Qe,paneClickDistance:k,selectionOnDrag:rn,children:E.jsxs(Gcn,{onSelectionStart:I,onSelectionEnd:B,onPaneClick:s,onPaneMouseEnter:u,onPaneMouseMove:h,onPaneMouseLeave:g,onPaneContextMenu:w,onPaneScroll:p,panOnDrag:Ue,isSelecting:!!Cn,selectionMode:D,selectionKeyPressed:Ye,paneClickDistance:k,selectionOnDrag:rn,children:[l,kt&&E.jsx(iln,{onSelectionContextMenu:ge,noPanClassName:ae,disableKeyboardA11y:Le})]})})}E5t.displayName="FlowRenderer";const sln=pe.memo(E5t),oln=l=>s=>l?AMe(s.nodeLookup,{x:0,y:0,width:s.width,height:s.height},s.transform,!0).map(u=>u.id):Array.from(s.nodeLookup.keys());function cln(l){return ac(pe.useCallback(oln(l),[l]),ta)}const lln=l=>l.updateNodeInternals;function uln(){const l=ac(lln),[s]=pe.useState(()=>typeof ResizeObserver>"u"?null:new ResizeObserver(u=>{const h=new Map;u.forEach(g=>{const w=g.target.getAttribute("data-id");h.set(w,{id:w,nodeElement:g.target,force:!0})}),l(h)}));return pe.useEffect(()=>()=>{s==null||s.disconnect()},[s]),s}function aln({node:l,nodeType:s,hasDimensions:u,resizeObserver:h}){const g=na(),w=pe.useRef(null),p=pe.useRef(null),k=pe.useRef(l.sourcePosition),j=pe.useRef(l.targetPosition),A=pe.useRef(s),_=u&&!!l.internals.handleBounds;return pe.useEffect(()=>{w.current&&!l.hidden&&(!_||p.current!==w.current)&&(p.current&&(h==null||h.unobserve(p.current)),h==null||h.observe(w.current),p.current=w.current)},[_,l.hidden]),pe.useEffect(()=>()=>{p.current&&(h==null||h.unobserve(p.current),p.current=null)},[]),pe.useEffect(()=>{if(w.current){const D=A.current!==s,I=k.current!==l.sourcePosition,B=j.current!==l.targetPosition;(D||I||B)&&(A.current=s,k.current=l.sourcePosition,j.current=l.targetPosition,g.getState().updateNodeInternals(new Map([[l.id,{id:l.id,nodeElement:w.current,force:!0}]])))}},[l.id,s,l.sourcePosition,l.targetPosition]),w}function fln({id:l,onClick:s,onMouseEnter:u,onMouseMove:h,onMouseLeave:g,onContextMenu:w,onDoubleClick:p,nodesDraggable:k,elementsSelectable:j,nodesConnectable:A,nodesFocusable:_,resizeObserver:D,noDragClassName:I,noPanClassName:B,disableKeyboardA11y:F,rfId:U,nodeTypes:K,nodeClickDistance:Y,onError:Z}){const{node:ee,internals:ce,isParent:fe}=ac(Pn=>{const mi=Pn.nodeLookup.get(l),er=Pn.parentLookup.has(l);return{node:mi,internals:mi.internals,isParent:er}},ta);let be=ee.type||"default",me=(K==null?void 0:K[be])||qyt[be];me===void 0&&(Z==null||Z("003",W3.error003(be)),be="default",me=(K==null?void 0:K.default)||qyt.default);const Re=!!(ee.draggable||k&&typeof ee.draggable>"u"),Te=!!(ee.selectable||j&&typeof ee.selectable>"u"),Ke=!!(ee.connectable||A&&typeof ee.connectable>"u"),ze=!!(ee.focusable||_&&typeof ee.focusable>"u"),je=na(),te=X4t(ee),ge=aln({node:ee,nodeType:be,hasDimensions:te,resizeObserver:D}),He=S5t({nodeRef:ge,disabled:ee.hidden||!Re,noDragClassName:I,handleSelector:ee.dragHandle,nodeId:l,isSelectable:Te,nodeClickDistance:Y}),ae=j5t();if(ee.hidden)return null;const Le=oO(ee),Oe=tln(ee),Qe=Te||Re||s||u||h||g,kt=u?Pn=>u(Pn,{...ce.userNode}):void 0,Ae=h?Pn=>h(Pn,{...ce.userNode}):void 0,Ye=g?Pn=>g(Pn,{...ce.userNode}):void 0,mt=w?Pn=>w(Pn,{...ce.userNode}):void 0,Ue=p?Pn=>p(Pn,{...ce.userNode}):void 0,Pt=Pn=>{const{selectNodesOnDrag:mi,nodeDragThreshold:er}=je.getState();Te&&(!mi||!Re||er>0)&&jCe({id:l,store:je,nodeRef:ge}),s&&s(Pn,{...ce.userNode})},rn=Pn=>{if(!(K4t(Pn.nativeEvent)||F)){if(B4t.includes(Pn.key)&&Te){const mi=Pn.key==="Escape";jCe({id:l,store:je,unselect:mi,nodeRef:ge})}else if(Re&&ee.selected&&Object.prototype.hasOwnProperty.call(Gfe,Pn.key)){Pn.preventDefault();const{ariaLabelConfig:mi}=je.getState();je.setState({ariaLiveMessage:mi["node.a11yDescription.ariaLiveMessage"]({direction:Pn.key.replace("Arrow","").toLowerCase(),x:~~ce.positionAbsolute.x,y:~~ce.positionAbsolute.y})}),ae({direction:Gfe[Pn.key],factor:Pn.shiftKey?4:1})}}},Cn=()=>{var Ir;if(F||!((Ir=ge.current)!=null&&Ir.matches(":focus-visible")))return;const{transform:Pn,width:mi,height:er,autoPanOnNodeFocus:Mr,setCenter:hr}=je.getState();if(!Mr)return;AMe(new Map([[l,ee]]),{x:0,y:0,width:mi,height:er},Pn,!0).length>0||hr(ee.position.x+Le.width/2,ee.position.y+Le.height/2,{zoom:Pn[2]})};return E.jsx("div",{className:dh(["react-flow__node",`react-flow__node-${be}`,{[B]:Re},ee.className,{selected:ee.selected,selectable:Te,parent:fe,draggable:Re,dragging:He}]),ref:ge,style:{zIndex:ce.z,transform:`translate(${ce.positionAbsolute.x}px,${ce.positionAbsolute.y}px)`,pointerEvents:Qe?"all":"none",visibility:te?"visible":"hidden",...ee.style,...Oe},"data-id":l,"data-testid":`rf__node-${l}`,onMouseEnter:kt,onMouseMove:Ae,onMouseLeave:Ye,onContextMenu:mt,onClick:Pt,onDoubleClick:Ue,onKeyDown:ze?rn:void 0,tabIndex:ze?0:void 0,onFocus:ze?Cn:void 0,role:ee.ariaRole??(ze?"group":void 0),"aria-roledescription":"node","aria-describedby":F?void 0:`${b5t}-${U}`,"aria-label":ee.ariaLabel,...ee.domAttributes,children:E.jsx(Jcn,{value:l,children:E.jsx(me,{id:l,data:ee.data,type:be,positionAbsoluteX:ce.positionAbsolute.x,positionAbsoluteY:ce.positionAbsolute.y,selected:ee.selected??!1,selectable:Te,draggable:Re,deletable:ee.deletable??!0,isConnectable:Ke,sourcePosition:ee.sourcePosition,targetPosition:ee.targetPosition,dragging:He,dragHandle:ee.dragHandle,zIndex:ce.z,parentId:ee.parentId,...Le})})})}var hln=pe.memo(fln);const dln=l=>({nodesDraggable:l.nodesDraggable,nodesConnectable:l.nodesConnectable,nodesFocusable:l.nodesFocusable,elementsSelectable:l.elementsSelectable,onError:l.onError});function C5t(l){const{nodesDraggable:s,nodesConnectable:u,nodesFocusable:h,elementsSelectable:g,onError:w}=ac(dln,ta),p=cln(l.onlyRenderVisibleElements),k=uln();return E.jsx("div",{className:"react-flow__nodes",style:Rhe,children:p.map(j=>E.jsx(hln,{id:j,nodeTypes:l.nodeTypes,nodeExtent:l.nodeExtent,onClick:l.onNodeClick,onMouseEnter:l.onNodeMouseEnter,onMouseMove:l.onNodeMouseMove,onMouseLeave:l.onNodeMouseLeave,onContextMenu:l.onNodeContextMenu,onDoubleClick:l.onNodeDoubleClick,noDragClassName:l.noDragClassName,noPanClassName:l.noPanClassName,rfId:l.rfId,disableKeyboardA11y:l.disableKeyboardA11y,resizeObserver:k,nodesDraggable:s,nodesConnectable:u,nodesFocusable:h,elementsSelectable:g,nodeClickDistance:l.nodeClickDistance,onError:w},j))})}C5t.displayName="NodeRenderer";const gln=pe.memo(C5t);function pln(l){return ac(pe.useCallback(u=>{if(!l)return u.edges.map(g=>g.id);const h=[];if(u.width&&u.height)for(const g of u.edges){const w=u.nodeLookup.get(g.source),p=u.nodeLookup.get(g.target);w&&p&&gon({sourceNode:w,targetNode:p,width:u.width,height:u.height,transform:u.transform})&&h.push(g.id)}return h},[l]),ta)}const bln=({color:l="none",strokeWidth:s=1})=>{const u={strokeWidth:s,...l&&{stroke:l}};return E.jsx("polyline",{className:"arrow",style:u,strokeLinecap:"round",fill:"none",strokeLinejoin:"round",points:"-5,-4 0,0 -5,4"})},mln=({color:l="none",strokeWidth:s=1})=>{const u={strokeWidth:s,...l&&{stroke:l,fill:l}};return E.jsx("polyline",{className:"arrowclosed",style:u,strokeLinecap:"round",strokeLinejoin:"round",points:"-5,-4 0,0 -5,4 -5,-4"})},Qyt={[wM.Arrow]:bln,[wM.ArrowClosed]:mln};function wln(l){const s=na();return pe.useMemo(()=>{var g,w;return Object.prototype.hasOwnProperty.call(Qyt,l)?Qyt[l]:((w=(g=s.getState()).onError)==null||w.call(g,"009",W3.error009(l)),null)},[l])}const vln=({id:l,type:s,color:u,width:h=12.5,height:g=12.5,markerUnits:w="strokeWidth",strokeWidth:p,orient:k="auto-start-reverse"})=>{const j=wln(s);return j?E.jsx("marker",{className:"react-flow__arrowhead",id:l,markerWidth:`${h}`,markerHeight:`${g}`,viewBox:"-10 -10 20 20",markerUnits:w,orient:k,refX:"0",refY:"0",children:E.jsx(j,{color:u,strokeWidth:p})}):null},M5t=({defaultColor:l,rfId:s})=>{const u=ac(w=>w.edges),h=ac(w=>w.defaultEdgeOptions),g=pe.useMemo(()=>xon(u,{id:s,defaultColor:l,defaultMarkerStart:h==null?void 0:h.markerStart,defaultMarkerEnd:h==null?void 0:h.markerEnd}),[u,h,s,l]);return g.length?E.jsx("svg",{className:"react-flow__marker","aria-hidden":"true",children:E.jsx("defs",{children:g.map(w=>E.jsx(vln,{id:w.id,type:w.type,color:w.color,width:w.width,height:w.height,markerUnits:w.markerUnits,strokeWidth:w.strokeWidth,orient:w.orient},w.id))})}):null};M5t.displayName="MarkerDefinitions";var yln=pe.memo(M5t);function A5t({x:l,y:s,label:u,labelStyle:h,labelShowBg:g=!0,labelBgStyle:w,labelBgPadding:p=[2,4],labelBgBorderRadius:k=2,children:j,className:A,..._}){const[D,I]=pe.useState({x:1,y:0,width:0,height:0}),B=dh(["react-flow__edge-textwrapper",A]),F=pe.useRef(null);return pe.useEffect(()=>{if(F.current){const U=F.current.getBBox();I({x:U.x,y:U.y,width:U.width,height:U.height})}},[u]),u?E.jsxs("g",{transform:`translate(${l-D.width/2} ${s-D.height/2})`,className:B,visibility:D.width?"visible":"hidden",..._,children:[g&&E.jsx("rect",{width:D.width+2*p[0],x:-p[0],y:-p[1],height:D.height+2*p[1],className:"react-flow__edge-textbg",style:w,rx:k,ry:k}),E.jsx("text",{className:"react-flow__edge-text",y:D.height/2,dy:"0.3em",ref:F,style:h,children:u}),j]}):null}A5t.displayName="EdgeText";const xln=pe.memo(A5t);function $he({path:l,labelX:s,labelY:u,label:h,labelStyle:g,labelShowBg:w,labelBgStyle:p,labelBgPadding:k,labelBgBorderRadius:j,interactionWidth:A=20,..._}){return E.jsxs(E.Fragment,{children:[E.jsx("path",{..._,d:l,fill:"none",className:dh(["react-flow__edge-path",_.className])}),A?E.jsx("path",{d:l,fill:"none",strokeOpacity:0,strokeWidth:A,className:"react-flow__edge-interaction"}):null,h&&xy(s)&&xy(u)?E.jsx(xln,{x:s,y:u,label:h,labelStyle:g,labelShowBg:w,labelBgStyle:p,labelBgPadding:k,labelBgBorderRadius:j}):null]})}function Gyt({pos:l,x1:s,y1:u,x2:h,y2:g}){return l===br.Left||l===br.Right?[.5*(s+h),u]:[s,.5*(u+g)]}function N5t({sourceX:l,sourceY:s,sourcePosition:u=br.Bottom,targetX:h,targetY:g,targetPosition:w=br.Top}){const[p,k]=Gyt({pos:u,x1:l,y1:s,x2:h,y2:g}),[j,A]=Gyt({pos:w,x1:h,y1:g,x2:l,y2:s}),[_,D,I,B]=Z4t({sourceX:l,sourceY:s,targetX:h,targetY:g,sourceControlX:p,sourceControlY:k,targetControlX:j,targetControlY:A});return[`M${l},${s} C${p},${k} ${j},${A} ${h},${g}`,_,D,I,B]}function _5t(l){return pe.memo(({id:s,sourceX:u,sourceY:h,targetX:g,targetY:w,sourcePosition:p,targetPosition:k,label:j,labelStyle:A,labelShowBg:_,labelBgStyle:D,labelBgPadding:I,labelBgBorderRadius:B,style:F,markerEnd:U,markerStart:K,interactionWidth:Y})=>{const[Z,ee,ce]=N5t({sourceX:u,sourceY:h,sourcePosition:p,targetX:g,targetY:w,targetPosition:k}),fe=l.isInternal?void 0:s;return E.jsx($he,{id:fe,path:Z,labelX:ee,labelY:ce,label:j,labelStyle:A,labelShowBg:_,labelBgStyle:D,labelBgPadding:I,labelBgBorderRadius:B,style:F,markerEnd:U,markerStart:K,interactionWidth:Y})})}const kln=_5t({isInternal:!1}),D5t=_5t({isInternal:!0});kln.displayName="SimpleBezierEdge";D5t.displayName="SimpleBezierEdgeInternal";function L5t(l){return pe.memo(({id:s,sourceX:u,sourceY:h,targetX:g,targetY:w,label:p,labelStyle:k,labelShowBg:j,labelBgStyle:A,labelBgPadding:_,labelBgBorderRadius:D,style:I,sourcePosition:B=br.Bottom,targetPosition:F=br.Top,markerEnd:U,markerStart:K,pathOptions:Y,interactionWidth:Z})=>{const[ee,ce,fe]=xCe({sourceX:u,sourceY:h,sourcePosition:B,targetX:g,targetY:w,targetPosition:F,borderRadius:Y==null?void 0:Y.borderRadius,offset:Y==null?void 0:Y.offset,stepPosition:Y==null?void 0:Y.stepPosition}),be=l.isInternal?void 0:s;return E.jsx($he,{id:be,path:ee,labelX:ce,labelY:fe,label:p,labelStyle:k,labelShowBg:j,labelBgStyle:A,labelBgPadding:_,labelBgBorderRadius:D,style:I,markerEnd:U,markerStart:K,interactionWidth:Z})})}const P5t=L5t({isInternal:!1}),I5t=L5t({isInternal:!0});P5t.displayName="SmoothStepEdge";I5t.displayName="SmoothStepEdgeInternal";function R5t(l){return pe.memo(({id:s,...u})=>{var g;const h=l.isInternal?void 0:s;return E.jsx(P5t,{...u,id:h,pathOptions:pe.useMemo(()=>{var w;return{borderRadius:0,offset:(w=u.pathOptions)==null?void 0:w.offset}},[(g=u.pathOptions)==null?void 0:g.offset])})})}const Oln=R5t({isInternal:!1}),$5t=R5t({isInternal:!0});Oln.displayName="StepEdge";$5t.displayName="StepEdgeInternal";function B5t(l){return pe.memo(({id:s,sourceX:u,sourceY:h,targetX:g,targetY:w,label:p,labelStyle:k,labelShowBg:j,labelBgStyle:A,labelBgPadding:_,labelBgBorderRadius:D,style:I,markerEnd:B,markerStart:F,interactionWidth:U})=>{const[K,Y,Z]=n5t({sourceX:u,sourceY:h,targetX:g,targetY:w}),ee=l.isInternal?void 0:s;return E.jsx($he,{id:ee,path:K,labelX:Y,labelY:Z,label:p,labelStyle:k,labelShowBg:j,labelBgStyle:A,labelBgPadding:_,labelBgBorderRadius:D,style:I,markerEnd:B,markerStart:F,interactionWidth:U})})}const Sln=B5t({isInternal:!1}),z5t=B5t({isInternal:!0});Sln.displayName="StraightEdge";z5t.displayName="StraightEdgeInternal";function F5t(l){return pe.memo(({id:s,sourceX:u,sourceY:h,targetX:g,targetY:w,sourcePosition:p=br.Bottom,targetPosition:k=br.Top,label:j,labelStyle:A,labelShowBg:_,labelBgStyle:D,labelBgPadding:I,labelBgBorderRadius:B,style:F,markerEnd:U,markerStart:K,pathOptions:Y,interactionWidth:Z})=>{const[ee,ce,fe]=e5t({sourceX:u,sourceY:h,sourcePosition:p,targetX:g,targetY:w,targetPosition:k,curvature:Y==null?void 0:Y.curvature}),be=l.isInternal?void 0:s;return E.jsx($he,{id:be,path:ee,labelX:ce,labelY:fe,label:j,labelStyle:A,labelShowBg:_,labelBgStyle:D,labelBgPadding:I,labelBgBorderRadius:B,style:F,markerEnd:U,markerStart:K,interactionWidth:Z})})}const jln=F5t({isInternal:!1}),q5t=F5t({isInternal:!0});jln.displayName="BezierEdge";q5t.displayName="BezierEdgeInternal";const Uyt={default:q5t,straight:z5t,step:$5t,smoothstep:I5t,simplebezier:D5t},Jyt={sourceX:null,sourceY:null,targetX:null,targetY:null,sourcePosition:null,targetPosition:null},Tln=(l,s,u)=>u===br.Left?l-s:u===br.Right?l+s:l,Eln=(l,s,u)=>u===br.Top?l-s:u===br.Bottom?l+s:l,Xyt="react-flow__edgeupdater";function Vyt({position:l,centerX:s,centerY:u,radius:h=10,onMouseDown:g,onMouseEnter:w,onMouseOut:p,type:k}){return E.jsx("circle",{onMouseDown:g,onMouseEnter:w,onMouseOut:p,className:dh([Xyt,`${Xyt}-${k}`]),cx:Tln(s,h,l),cy:Eln(u,h,l),r:h,stroke:"transparent",fill:"transparent"})}function Cln({isReconnectable:l,reconnectRadius:s,edge:u,sourceX:h,sourceY:g,targetX:w,targetY:p,sourcePosition:k,targetPosition:j,onReconnect:A,onReconnectStart:_,onReconnectEnd:D,setReconnecting:I,setUpdateHover:B}){const F=na(),U=(ce,fe)=>{if(ce.button!==0)return;const{autoPanOnConnect:be,domNode:me,isValidConnection:Re,connectionMode:Te,connectionRadius:Ke,lib:ze,onConnectStart:je,onConnectEnd:te,cancelConnection:ge,nodeLookup:He,rfId:ae,panBy:Le,updateConnection:Oe}=F.getState(),Qe=fe.type==="target",kt=(mt,Ue)=>{I(!1),D==null||D(mt,u,fe.type,Ue)},Ae=mt=>A==null?void 0:A(u,mt),Ye=(mt,Ue)=>{I(!0),_==null||_(ce,u,fe.type),je==null||je(mt,Ue)};SCe.onPointerDown(ce.nativeEvent,{autoPanOnConnect:be,connectionMode:Te,connectionRadius:Ke,domNode:me,handleId:fe.id,nodeId:fe.nodeId,nodeLookup:He,isTarget:Qe,edgeUpdaterType:fe.type,lib:ze,flowId:ae,cancelConnection:ge,panBy:Le,isValidConnection:Re,onConnect:Ae,onConnectStart:Ye,onConnectEnd:te,onReconnectEnd:kt,updateConnection:Oe,getTransform:()=>F.getState().transform,getFromHandle:()=>F.getState().connection.fromHandle,dragThreshold:F.getState().connectionDragThreshold,handleDomNode:ce.currentTarget})},K=ce=>U(ce,{nodeId:u.target,id:u.targetHandle??null,type:"target"}),Y=ce=>U(ce,{nodeId:u.source,id:u.sourceHandle??null,type:"source"}),Z=()=>B(!0),ee=()=>B(!1);return E.jsxs(E.Fragment,{children:[(l===!0||l==="source")&&E.jsx(Vyt,{position:k,centerX:h,centerY:g,radius:s,onMouseDown:K,onMouseEnter:Z,onMouseOut:ee,type:"source"}),(l===!0||l==="target")&&E.jsx(Vyt,{position:j,centerX:w,centerY:p,radius:s,onMouseDown:Y,onMouseEnter:Z,onMouseOut:ee,type:"target"})]})}function Mln({id:l,edgesFocusable:s,edgesReconnectable:u,elementsSelectable:h,onClick:g,onDoubleClick:w,onContextMenu:p,onMouseEnter:k,onMouseMove:j,onMouseLeave:A,reconnectRadius:_,onReconnect:D,onReconnectStart:I,onReconnectEnd:B,rfId:F,edgeTypes:U,noPanClassName:K,onError:Y,disableKeyboardA11y:Z}){let ee=ac(hr=>hr.edgeLookup.get(l));const ce=ac(hr=>hr.defaultEdgeOptions);ee=ce?{...ce,...ee}:ee;let fe=ee.type||"default",be=(U==null?void 0:U[fe])||Uyt[fe];be===void 0&&(Y==null||Y("011",W3.error011(fe)),fe="default",be=(U==null?void 0:U.default)||Uyt.default);const me=!!(ee.focusable||s&&typeof ee.focusable>"u"),Re=typeof D<"u"&&(ee.reconnectable||u&&typeof ee.reconnectable>"u"),Te=!!(ee.selectable||h&&typeof ee.selectable>"u"),Ke=pe.useRef(null),[ze,je]=pe.useState(!1),[te,ge]=pe.useState(!1),He=na(),{zIndex:ae,sourceX:Le,sourceY:Oe,targetX:Qe,targetY:kt,sourcePosition:Ae,targetPosition:Ye}=ac(pe.useCallback(hr=>{const Gn=hr.nodeLookup.get(ee.source),Ir=hr.nodeLookup.get(ee.target);if(!Gn||!Ir)return{zIndex:ee.zIndex,...Jyt};const is=yon({id:l,sourceNode:Gn,targetNode:Ir,sourceHandle:ee.sourceHandle||null,targetHandle:ee.targetHandle||null,connectionMode:hr.connectionMode,onError:Y});return{zIndex:don({selected:ee.selected,zIndex:ee.zIndex,sourceNode:Gn,targetNode:Ir,elevateOnSelect:hr.elevateEdgesOnSelect,zIndexMode:hr.zIndexMode}),...is||Jyt}},[ee.source,ee.target,ee.sourceHandle,ee.targetHandle,ee.selected,ee.zIndex]),ta),mt=pe.useMemo(()=>ee.markerStart?`url('#${kCe(ee.markerStart,F)}')`:void 0,[ee.markerStart,F]),Ue=pe.useMemo(()=>ee.markerEnd?`url('#${kCe(ee.markerEnd,F)}')`:void 0,[ee.markerEnd,F]);if(ee.hidden||Le===null||Oe===null||Qe===null||kt===null)return null;const Pt=hr=>{var bs;const{addSelectedEdges:Gn,unselectNodesAndEdges:Ir,multiSelectionActive:is}=He.getState();Te&&(He.setState({nodesSelectionActive:!1}),ee.selected&&is?(Ir({nodes:[],edges:[ee]}),(bs=Ke.current)==null||bs.blur()):Gn([l])),g&&g(hr,ee)},rn=w?hr=>{w(hr,{...ee})}:void 0,Cn=p?hr=>{p(hr,{...ee})}:void 0,Pn=k?hr=>{k(hr,{...ee})}:void 0,mi=j?hr=>{j(hr,{...ee})}:void 0,er=A?hr=>{A(hr,{...ee})}:void 0,Mr=hr=>{var Gn;if(!Z&&B4t.includes(hr.key)&&Te){const{unselectNodesAndEdges:Ir,addSelectedEdges:is}=He.getState();hr.key==="Escape"?((Gn=Ke.current)==null||Gn.blur(),Ir({edges:[ee]})):is([l])}};return E.jsx("svg",{style:{zIndex:ae},children:E.jsxs("g",{className:dh(["react-flow__edge",`react-flow__edge-${fe}`,ee.className,K,{selected:ee.selected,animated:ee.animated,inactive:!Te&&!g,updating:ze,selectable:Te}]),onClick:Pt,onDoubleClick:rn,onContextMenu:Cn,onMouseEnter:Pn,onMouseMove:mi,onMouseLeave:er,onKeyDown:me?Mr:void 0,tabIndex:me?0:void 0,role:ee.ariaRole??(me?"group":"img"),"aria-roledescription":"edge","data-id":l,"data-testid":`rf__edge-${l}`,"aria-label":ee.ariaLabel===null?void 0:ee.ariaLabel||`Edge from ${ee.source} to ${ee.target}`,"aria-describedby":me?`${m5t}-${F}`:void 0,ref:Ke,...ee.domAttributes,children:[!te&&E.jsx(be,{id:l,source:ee.source,target:ee.target,type:ee.type,selected:ee.selected,animated:ee.animated,selectable:Te,deletable:ee.deletable??!0,label:ee.label,labelStyle:ee.labelStyle,labelShowBg:ee.labelShowBg,labelBgStyle:ee.labelBgStyle,labelBgPadding:ee.labelBgPadding,labelBgBorderRadius:ee.labelBgBorderRadius,sourceX:Le,sourceY:Oe,targetX:Qe,targetY:kt,sourcePosition:Ae,targetPosition:Ye,data:ee.data,style:ee.style,sourceHandleId:ee.sourceHandle,targetHandleId:ee.targetHandle,markerStart:mt,markerEnd:Ue,pathOptions:"pathOptions"in ee?ee.pathOptions:void 0,interactionWidth:ee.interactionWidth}),Re&&E.jsx(Cln,{edge:ee,isReconnectable:Re,reconnectRadius:_,onReconnect:D,onReconnectStart:I,onReconnectEnd:B,sourceX:Le,sourceY:Oe,targetX:Qe,targetY:kt,sourcePosition:Ae,targetPosition:Ye,setUpdateHover:je,setReconnecting:ge})]})})}var Aln=pe.memo(Mln);const Nln=l=>({edgesFocusable:l.edgesFocusable,edgesReconnectable:l.edgesReconnectable,elementsSelectable:l.elementsSelectable,connectionMode:l.connectionMode,onError:l.onError});function H5t({defaultMarkerColor:l,onlyRenderVisibleElements:s,rfId:u,edgeTypes:h,noPanClassName:g,onReconnect:w,onEdgeContextMenu:p,onEdgeMouseEnter:k,onEdgeMouseMove:j,onEdgeMouseLeave:A,onEdgeClick:_,reconnectRadius:D,onEdgeDoubleClick:I,onReconnectStart:B,onReconnectEnd:F,disableKeyboardA11y:U}){const{edgesFocusable:K,edgesReconnectable:Y,elementsSelectable:Z,onError:ee}=ac(Nln,ta),ce=pln(s);return E.jsxs("div",{className:"react-flow__edges",children:[E.jsx(yln,{defaultColor:l,rfId:u}),ce.map(fe=>E.jsx(Aln,{id:fe,edgesFocusable:K,edgesReconnectable:Y,elementsSelectable:Z,noPanClassName:g,onReconnect:w,onContextMenu:p,onMouseEnter:k,onMouseMove:j,onMouseLeave:A,onClick:_,reconnectRadius:D,onDoubleClick:I,onReconnectStart:B,onReconnectEnd:F,rfId:u,onError:ee,edgeTypes:h,disableKeyboardA11y:U},fe))]})}H5t.displayName="EdgeRenderer";const _ln=pe.memo(H5t),Dln=l=>`translate(${l.transform[0]}px,${l.transform[1]}px) scale(${l.transform[2]})`;function Lln({children:l}){const s=ac(Dln);return E.jsx("div",{className:"react-flow__viewport xyflow__viewport react-flow__container",style:{transform:s},children:l})}function Pln(l){const s=Ihe(),u=pe.useRef(!1);pe.useEffect(()=>{!u.current&&s.viewportInitialized&&l&&(setTimeout(()=>l(s),1),u.current=!0)},[l,s.viewportInitialized])}const Iln=l=>{var s;return(s=l.panZoom)==null?void 0:s.syncViewport};function Rln(l){const s=ac(Iln),u=na();return pe.useEffect(()=>{l&&(s==null||s(l),u.setState({transform:[l.x,l.y,l.zoom]}))},[l,s]),null}function $ln(l){return l.connection.inProgress?{...l.connection,to:SV(l.connection.to,l.transform)}:{...l.connection}}function Bln(l){return $ln}function zln(l){const s=Bln();return ac(s,ta)}const Fln=l=>({nodesConnectable:l.nodesConnectable,isValid:l.connection.isValid,inProgress:l.connection.inProgress,width:l.width,height:l.height});function qln({containerStyle:l,style:s,type:u,component:h}){const{nodesConnectable:g,width:w,height:p,isValid:k,inProgress:j}=ac(Fln,ta);return!(w&&g&&j)?null:E.jsx("svg",{style:l,width:w,height:p,className:"react-flow__connectionline react-flow__container",children:E.jsx("g",{className:dh(["react-flow__connection",q4t(k)]),children:E.jsx(Q5t,{style:s,type:u,CustomComponent:h,isValid:k})})})}const Q5t=({style:l,type:s=g8.Bezier,CustomComponent:u,isValid:h})=>{const{inProgress:g,from:w,fromNode:p,fromHandle:k,fromPosition:j,to:A,toNode:_,toHandle:D,toPosition:I,pointer:B}=zln();if(!g)return;if(u)return E.jsx(u,{connectionLineType:s,connectionLineStyle:l,fromNode:p,fromHandle:k,fromX:w.x,fromY:w.y,toX:A.x,toY:A.y,fromPosition:j,toPosition:I,connectionStatus:q4t(h),toNode:_,toHandle:D,pointer:B});let F="";const U={sourceX:w.x,sourceY:w.y,sourcePosition:j,targetX:A.x,targetY:A.y,targetPosition:I};switch(s){case g8.Bezier:[F]=e5t(U);break;case g8.SimpleBezier:[F]=N5t(U);break;case g8.Step:[F]=xCe({...U,borderRadius:0});break;case g8.SmoothStep:[F]=xCe(U);break;default:[F]=n5t(U)}return E.jsx("path",{d:F,fill:"none",className:"react-flow__connection-path",style:l})};Q5t.displayName="ConnectionLine";const Hln={};function Wyt(l=Hln){pe.useRef(l),na(),pe.useEffect(()=>{},[l])}function Qln(){na(),pe.useRef(!1),pe.useEffect(()=>{},[])}function G5t({nodeTypes:l,edgeTypes:s,onInit:u,onNodeClick:h,onEdgeClick:g,onNodeDoubleClick:w,onEdgeDoubleClick:p,onNodeMouseEnter:k,onNodeMouseMove:j,onNodeMouseLeave:A,onNodeContextMenu:_,onSelectionContextMenu:D,onSelectionStart:I,onSelectionEnd:B,connectionLineType:F,connectionLineStyle:U,connectionLineComponent:K,connectionLineContainerStyle:Y,selectionKeyCode:Z,selectionOnDrag:ee,selectionMode:ce,multiSelectionKeyCode:fe,panActivationKeyCode:be,zoomActivationKeyCode:me,deleteKeyCode:Re,onlyRenderVisibleElements:Te,elementsSelectable:Ke,defaultViewport:ze,translateExtent:je,minZoom:te,maxZoom:ge,preventScrolling:He,defaultMarkerColor:ae,zoomOnScroll:Le,zoomOnPinch:Oe,panOnScroll:Qe,panOnScrollSpeed:kt,panOnScrollMode:Ae,zoomOnDoubleClick:Ye,panOnDrag:mt,onPaneClick:Ue,onPaneMouseEnter:Pt,onPaneMouseMove:rn,onPaneMouseLeave:Cn,onPaneScroll:Pn,onPaneContextMenu:mi,paneClickDistance:er,nodeClickDistance:Mr,onEdgeContextMenu:hr,onEdgeMouseEnter:Gn,onEdgeMouseMove:Ir,onEdgeMouseLeave:is,reconnectRadius:bs,onReconnect:bo,onReconnectStart:Bl,onReconnectEnd:Zl,noDragClassName:rs,noWheelClassName:Ls,noPanClassName:f1,disableKeyboardA11y:mo,nodeExtent:eu,rfId:Un,viewport:Rc,onViewportChange:io}){return Wyt(l),Wyt(s),Qln(),Pln(u),Rln(Rc),E.jsx(sln,{onPaneClick:Ue,onPaneMouseEnter:Pt,onPaneMouseMove:rn,onPaneMouseLeave:Cn,onPaneContextMenu:mi,onPaneScroll:Pn,paneClickDistance:er,deleteKeyCode:Re,selectionKeyCode:Z,selectionOnDrag:ee,selectionMode:ce,onSelectionStart:I,onSelectionEnd:B,multiSelectionKeyCode:fe,panActivationKeyCode:be,zoomActivationKeyCode:me,elementsSelectable:Ke,zoomOnScroll:Le,zoomOnPinch:Oe,zoomOnDoubleClick:Ye,panOnScroll:Qe,panOnScrollSpeed:kt,panOnScrollMode:Ae,panOnDrag:mt,defaultViewport:ze,translateExtent:je,minZoom:te,maxZoom:ge,onSelectionContextMenu:D,preventScrolling:He,noDragClassName:rs,noWheelClassName:Ls,noPanClassName:f1,disableKeyboardA11y:mo,onViewportChange:io,isControlledViewport:!!Rc,children:E.jsxs(Lln,{children:[E.jsx(_ln,{edgeTypes:s,onEdgeClick:g,onEdgeDoubleClick:p,onReconnect:bo,onReconnectStart:Bl,onReconnectEnd:Zl,onlyRenderVisibleElements:Te,onEdgeContextMenu:hr,onEdgeMouseEnter:Gn,onEdgeMouseMove:Ir,onEdgeMouseLeave:is,reconnectRadius:bs,defaultMarkerColor:ae,noPanClassName:f1,disableKeyboardA11y:mo,rfId:Un}),E.jsx(qln,{style:U,type:F,component:K,containerStyle:Y}),E.jsx("div",{className:"react-flow__edgelabel-renderer"}),E.jsx(gln,{nodeTypes:l,onNodeClick:h,onNodeDoubleClick:w,onNodeMouseEnter:k,onNodeMouseMove:j,onNodeMouseLeave:A,onNodeContextMenu:_,nodeClickDistance:Mr,onlyRenderVisibleElements:Te,noPanClassName:f1,noDragClassName:rs,disableKeyboardA11y:mo,nodeExtent:eu,rfId:Un}),E.jsx("div",{className:"react-flow__viewport-portal"})]})})}G5t.displayName="GraphView";const Gln=pe.memo(G5t),Kyt=({nodes:l,edges:s,defaultNodes:u,defaultEdges:h,width:g,height:w,fitView:p,fitViewOptions:k,minZoom:j=.5,maxZoom:A=2,nodeOrigin:_,nodeExtent:D,zIndexMode:I="basic"}={})=>{const B=new Map,F=new Map,U=new Map,K=new Map,Y=h??s??[],Z=u??l??[],ee=_??[0,0],ce=D??VX;s5t(U,K,Y);const fe=OCe(Z,B,F,{nodeOrigin:ee,nodeExtent:ce,zIndexMode:I});let be=[0,0,1];if(p&&g&&w){const me=kV(B,{filter:ze=>!!((ze.width||ze.initialWidth)&&(ze.height||ze.initialHeight))}),{x:Re,y:Te,zoom:Ke}=NMe(me,g,w,j,A,(k==null?void 0:k.padding)??.1);be=[Re,Te,Ke]}return{rfId:"1",width:g??0,height:w??0,transform:be,nodes:Z,nodesInitialized:fe,nodeLookup:B,parentLookup:F,edges:Y,edgeLookup:K,connectionLookup:U,onNodesChange:null,onEdgesChange:null,hasDefaultNodes:u!==void 0,hasDefaultEdges:h!==void 0,panZoom:null,minZoom:j,maxZoom:A,translateExtent:VX,nodeExtent:ce,nodesSelectionActive:!1,userSelectionActive:!1,userSelectionRect:null,connectionMode:jI.Strict,domNode:null,paneDragging:!1,noPanClassName:"nopan",nodeOrigin:ee,nodeDragThreshold:1,connectionDragThreshold:1,snapGrid:[15,15],snapToGrid:!1,nodesDraggable:!0,nodesConnectable:!0,nodesFocusable:!0,edgesFocusable:!0,edgesReconnectable:!0,elementsSelectable:!0,elevateNodesOnSelect:!0,elevateEdgesOnSelect:!0,selectNodesOnDrag:!0,multiSelectionActive:!1,fitViewQueued:p??!1,fitViewOptions:k,fitViewResolver:null,connection:{...F4t},connectionClickStartHandle:null,connectOnClick:!0,ariaLiveMessage:"",autoPanOnConnect:!0,autoPanOnNodeDrag:!0,autoPanOnNodeFocus:!0,autoPanSpeed:15,connectionRadius:20,onError:con,isValidConnection:void 0,onSelectionChangeHandlers:[],lib:"react",debug:!1,ariaLabelConfig:z4t,zIndexMode:I,onNodesChangeMiddlewareMap:new Map,onEdgesChangeMiddlewareMap:new Map}},Uln=({nodes:l,edges:s,defaultNodes:u,defaultEdges:h,width:g,height:w,fitView:p,fitViewOptions:k,minZoom:j,maxZoom:A,nodeOrigin:_,nodeExtent:D,zIndexMode:I})=>acn((B,F)=>{async function U(){const{nodeLookup:K,panZoom:Y,fitViewOptions:Z,fitViewResolver:ee,width:ce,height:fe,minZoom:be,maxZoom:me}=F();Y&&(await son({nodes:K,width:ce,height:fe,panZoom:Y,minZoom:be,maxZoom:me},Z),ee==null||ee.resolve(!0),B({fitViewResolver:null}))}return{...Kyt({nodes:l,edges:s,width:g,height:w,fitView:p,fitViewOptions:k,minZoom:j,maxZoom:A,nodeOrigin:_,nodeExtent:D,defaultNodes:u,defaultEdges:h,zIndexMode:I}),setNodes:K=>{const{nodeLookup:Y,parentLookup:Z,nodeOrigin:ee,elevateNodesOnSelect:ce,fitViewQueued:fe,zIndexMode:be}=F(),me=OCe(K,Y,Z,{nodeOrigin:ee,nodeExtent:D,elevateNodesOnSelect:ce,checkEquality:!0,zIndexMode:be});fe&&me?(U(),B({nodes:K,nodesInitialized:me,fitViewQueued:!1,fitViewOptions:void 0})):B({nodes:K,nodesInitialized:me})},setEdges:K=>{const{connectionLookup:Y,edgeLookup:Z}=F();s5t(Y,Z,K),B({edges:K})},setDefaultNodesAndEdges:(K,Y)=>{if(K){const{setNodes:Z}=F();Z(K),B({hasDefaultNodes:!0})}if(Y){const{setEdges:Z}=F();Z(Y),B({hasDefaultEdges:!0})}},updateNodeInternals:K=>{const{triggerNodeChanges:Y,nodeLookup:Z,parentLookup:ee,domNode:ce,nodeOrigin:fe,nodeExtent:be,debug:me,fitViewQueued:Re,zIndexMode:Te}=F(),{changes:Ke,updatedInternals:ze}=Con(K,Z,ee,ce,fe,be,Te);ze&&(Son(Z,ee,{nodeOrigin:fe,nodeExtent:be,zIndexMode:Te}),Re?(U(),B({fitViewQueued:!1,fitViewOptions:void 0})):B({}),(Ke==null?void 0:Ke.length)>0&&(me&&console.log("React Flow: trigger node changes",Ke),Y==null||Y(Ke)))},updateNodePositions:(K,Y=!1)=>{const Z=[];let ee=[];const{nodeLookup:ce,triggerNodeChanges:fe,connection:be,updateConnection:me,onNodesChangeMiddlewareMap:Re}=F();for(const[Te,Ke]of K){const ze=ce.get(Te),je=!!(ze!=null&&ze.expandParent&&(ze!=null&&ze.parentId)&&(Ke!=null&&Ke.position)),te={id:Te,type:"position",position:je?{x:Math.max(0,Ke.position.x),y:Math.max(0,Ke.position.y)}:Ke.position,dragging:Y};if(ze&&be.inProgress&&be.fromNode.id===ze.id){const ge=yM(ze,be.fromHandle,br.Left,!0);me({...be,from:ge})}je&&ze.parentId&&Z.push({id:Te,parentId:ze.parentId,rect:{...Ke.internals.positionAbsolute,width:Ke.measured.width??0,height:Ke.measured.height??0}}),ee.push(te)}if(Z.length>0){const{parentLookup:Te,nodeOrigin:Ke}=F(),ze=RMe(Z,ce,Te,Ke);ee.push(...ze)}for(const Te of Re.values())ee=Te(ee);fe(ee)},triggerNodeChanges:K=>{const{onNodesChange:Y,setNodes:Z,nodes:ee,hasDefaultNodes:ce,debug:fe}=F();if(K!=null&&K.length){if(ce){const be=y5t(K,ee);Z(be)}fe&&console.log("React Flow: trigger node changes",K),Y==null||Y(K)}},triggerEdgeChanges:K=>{const{onEdgesChange:Y,setEdges:Z,edges:ee,hasDefaultEdges:ce,debug:fe}=F();if(K!=null&&K.length){if(ce){const be=x5t(K,ee);Z(be)}fe&&console.log("React Flow: trigger edge changes",K),Y==null||Y(K)}},addSelectedNodes:K=>{const{multiSelectionActive:Y,edgeLookup:Z,nodeLookup:ee,triggerNodeChanges:ce,triggerEdgeChanges:fe}=F();if(Y){const be=K.map(me=>rM(me,!0));ce(be);return}ce(uI(ee,new Set([...K]),!0)),fe(uI(Z))},addSelectedEdges:K=>{const{multiSelectionActive:Y,edgeLookup:Z,nodeLookup:ee,triggerNodeChanges:ce,triggerEdgeChanges:fe}=F();if(Y){const be=K.map(me=>rM(me,!0));fe(be);return}fe(uI(Z,new Set([...K]))),ce(uI(ee,new Set,!0))},unselectNodesAndEdges:({nodes:K,edges:Y}={})=>{const{edges:Z,nodes:ee,nodeLookup:ce,triggerNodeChanges:fe,triggerEdgeChanges:be}=F(),me=K||ee,Re=Y||Z,Te=me.map(ze=>{const je=ce.get(ze.id);return je&&(je.selected=!1),rM(ze.id,!1)}),Ke=Re.map(ze=>rM(ze.id,!1));fe(Te),be(Ke)},setMinZoom:K=>{const{panZoom:Y,maxZoom:Z}=F();Y==null||Y.setScaleExtent([K,Z]),B({minZoom:K})},setMaxZoom:K=>{const{panZoom:Y,minZoom:Z}=F();Y==null||Y.setScaleExtent([Z,K]),B({maxZoom:K})},setTranslateExtent:K=>{var Y;(Y=F().panZoom)==null||Y.setTranslateExtent(K),B({translateExtent:K})},resetSelectedElements:()=>{const{edges:K,nodes:Y,triggerNodeChanges:Z,triggerEdgeChanges:ee,elementsSelectable:ce}=F();if(!ce)return;const fe=Y.reduce((me,Re)=>Re.selected?[...me,rM(Re.id,!1)]:me,[]),be=K.reduce((me,Re)=>Re.selected?[...me,rM(Re.id,!1)]:me,[]);Z(fe),ee(be)},setNodeExtent:K=>{const{nodes:Y,nodeLookup:Z,parentLookup:ee,nodeOrigin:ce,elevateNodesOnSelect:fe,nodeExtent:be,zIndexMode:me}=F();K[0][0]===be[0][0]&&K[0][1]===be[0][1]&&K[1][0]===be[1][0]&&K[1][1]===be[1][1]||(OCe(Y,Z,ee,{nodeOrigin:ce,nodeExtent:K,elevateNodesOnSelect:fe,checkEquality:!1,zIndexMode:me}),B({nodeExtent:K}))},panBy:K=>{const{transform:Y,width:Z,height:ee,panZoom:ce,translateExtent:fe}=F();return Mon({delta:K,panZoom:ce,transform:Y,translateExtent:fe,width:Z,height:ee})},setCenter:async(K,Y,Z)=>{const{width:ee,height:ce,maxZoom:fe,panZoom:be}=F();if(!be)return Promise.resolve(!1);const me=typeof(Z==null?void 0:Z.zoom)<"u"?Z.zoom:fe;return await be.setViewport({x:ee/2-K*me,y:ce/2-Y*me,zoom:me},{duration:Z==null?void 0:Z.duration,ease:Z==null?void 0:Z.ease,interpolate:Z==null?void 0:Z.interpolate}),Promise.resolve(!0)},cancelConnection:()=>{B({connection:{...F4t}})},updateConnection:K=>{B({connection:K})},reset:()=>B({...Kyt()})}},Object.is);function U5t({initialNodes:l,initialEdges:s,defaultNodes:u,defaultEdges:h,initialWidth:g,initialHeight:w,initialMinZoom:p,initialMaxZoom:k,initialFitViewOptions:j,fitView:A,nodeOrigin:_,nodeExtent:D,zIndexMode:I,children:B}){const[F]=pe.useState(()=>Uln({nodes:l,edges:s,defaultNodes:u,defaultEdges:h,width:g,height:w,fitView:A,minZoom:p,maxZoom:k,fitViewOptions:j,nodeOrigin:_,nodeExtent:D,zIndexMode:I}));return E.jsx(fcn,{value:F,children:E.jsx(Lcn,{children:B})})}function Jln({children:l,nodes:s,edges:u,defaultNodes:h,defaultEdges:g,width:w,height:p,fitView:k,fitViewOptions:j,minZoom:A,maxZoom:_,nodeOrigin:D,nodeExtent:I,zIndexMode:B}){return pe.useContext(Lhe)?E.jsx(E.Fragment,{children:l}):E.jsx(U5t,{initialNodes:s,initialEdges:u,defaultNodes:h,defaultEdges:g,initialWidth:w,initialHeight:p,fitView:k,initialFitViewOptions:j,initialMinZoom:A,initialMaxZoom:_,nodeOrigin:D,nodeExtent:I,zIndexMode:B,children:l})}const Xln={width:"100%",height:"100%",overflow:"hidden",position:"relative",zIndex:0};function Vln({nodes:l,edges:s,defaultNodes:u,defaultEdges:h,className:g,nodeTypes:w,edgeTypes:p,onNodeClick:k,onEdgeClick:j,onInit:A,onMove:_,onMoveStart:D,onMoveEnd:I,onConnect:B,onConnectStart:F,onConnectEnd:U,onClickConnectStart:K,onClickConnectEnd:Y,onNodeMouseEnter:Z,onNodeMouseMove:ee,onNodeMouseLeave:ce,onNodeContextMenu:fe,onNodeDoubleClick:be,onNodeDragStart:me,onNodeDrag:Re,onNodeDragStop:Te,onNodesDelete:Ke,onEdgesDelete:ze,onDelete:je,onSelectionChange:te,onSelectionDragStart:ge,onSelectionDrag:He,onSelectionDragStop:ae,onSelectionContextMenu:Le,onSelectionStart:Oe,onSelectionEnd:Qe,onBeforeDelete:kt,connectionMode:Ae,connectionLineType:Ye=g8.Bezier,connectionLineStyle:mt,connectionLineComponent:Ue,connectionLineContainerStyle:Pt,deleteKeyCode:rn="Backspace",selectionKeyCode:Cn="Shift",selectionOnDrag:Pn=!1,selectionMode:mi=TI.Full,panActivationKeyCode:er="Space",multiSelectionKeyCode:Mr=KX()?"Meta":"Control",zoomActivationKeyCode:hr=KX()?"Meta":"Control",snapToGrid:Gn,snapGrid:Ir,onlyRenderVisibleElements:is=!1,selectNodesOnDrag:bs,nodesDraggable:bo,autoPanOnNodeFocus:Bl,nodesConnectable:Zl,nodesFocusable:rs,nodeOrigin:Ls=w5t,edgesFocusable:f1,edgesReconnectable:mo,elementsSelectable:eu=!0,defaultViewport:Un=Scn,minZoom:Rc=.5,maxZoom:io=2,translateExtent:zf=VX,preventScrolling:tu=!0,nodeExtent:Kw,defaultMarkerColor:uO="#b1b1b7",zoomOnScroll:aO=!0,zoomOnPinch:Cp=!0,panOnScroll:Ff=!1,panOnScrollSpeed:lg=.5,panOnScrollMode:qf=dM.Free,zoomOnDoubleClick:fO=!0,panOnDrag:hO=!0,onPaneClick:dO,onPaneMouseEnter:Yw,onPaneMouseMove:Zw,onPaneMouseLeave:e2,onPaneScroll:f0,onPaneContextMenu:t2,paneClickDistance:im=1,nodeClickDistance:gO=0,children:_y,onReconnect:Ti,onReconnectStart:gu,onReconnectEnd:gh,onEdgeContextMenu:h0,onEdgeDoubleClick:pO,onEdgeMouseEnter:M8,onEdgeMouseMove:Dy,onEdgeMouseLeave:bO,reconnectRadius:A8=10,onNodesChange:mO,onEdgesChange:Mp,noDragClassName:Pa="nodrag",noWheelClassName:ph="nowheel",noPanClassName:rm="nopan",fitView:e4,fitViewOptions:N8,connectOnClick:MM,attributionPosition:_8,proOptions:Ly,defaultEdgeOptions:wO,elevateNodesOnSelect:Ap=!0,elevateEdgesOnSelect:n2=!1,disableKeyboardA11y:i2=!1,autoPanOnConnect:r2,autoPanOnNodeDrag:ra,autoPanSpeed:D8,connectionRadius:L8,isValidConnection:sm,onError:s2,style:AM,id:vO,nodeDragThreshold:P8,connectionDragThreshold:I8,viewport:Py,onViewportChange:t4,width:d0,height:Ed,colorMode:R8="light",debug:NM,onScroll:o2,ariaLabelConfig:$8,zIndexMode:Iy="basic",..._M},Cd){const Ry=vO||"1",B8=Ccn(R8),yO=pe.useCallback(om=>{om.currentTarget.scrollTo({top:0,left:0,behavior:"instant"}),o2==null||o2(om)},[o2]);return E.jsx("div",{"data-testid":"rf__wrapper",..._M,onScroll:yO,style:{...AM,...Xln},ref:Cd,className:dh(["react-flow",g,B8]),id:vO,role:"application",children:E.jsxs(Jln,{nodes:l,edges:s,width:d0,height:Ed,fitView:e4,fitViewOptions:N8,minZoom:Rc,maxZoom:io,nodeOrigin:Ls,nodeExtent:Kw,zIndexMode:Iy,children:[E.jsx(Gln,{onInit:A,onNodeClick:k,onEdgeClick:j,onNodeMouseEnter:Z,onNodeMouseMove:ee,onNodeMouseLeave:ce,onNodeContextMenu:fe,onNodeDoubleClick:be,nodeTypes:w,edgeTypes:p,connectionLineType:Ye,connectionLineStyle:mt,connectionLineComponent:Ue,connectionLineContainerStyle:Pt,selectionKeyCode:Cn,selectionOnDrag:Pn,selectionMode:mi,deleteKeyCode:rn,multiSelectionKeyCode:Mr,panActivationKeyCode:er,zoomActivationKeyCode:hr,onlyRenderVisibleElements:is,defaultViewport:Un,translateExtent:zf,minZoom:Rc,maxZoom:io,preventScrolling:tu,zoomOnScroll:aO,zoomOnPinch:Cp,zoomOnDoubleClick:fO,panOnScroll:Ff,panOnScrollSpeed:lg,panOnScrollMode:qf,panOnDrag:hO,onPaneClick:dO,onPaneMouseEnter:Yw,onPaneMouseMove:Zw,onPaneMouseLeave:e2,onPaneScroll:f0,onPaneContextMenu:t2,paneClickDistance:im,nodeClickDistance:gO,onSelectionContextMenu:Le,onSelectionStart:Oe,onSelectionEnd:Qe,onReconnect:Ti,onReconnectStart:gu,onReconnectEnd:gh,onEdgeContextMenu:h0,onEdgeDoubleClick:pO,onEdgeMouseEnter:M8,onEdgeMouseMove:Dy,onEdgeMouseLeave:bO,reconnectRadius:A8,defaultMarkerColor:uO,noDragClassName:Pa,noWheelClassName:ph,noPanClassName:rm,rfId:Ry,disableKeyboardA11y:i2,nodeExtent:Kw,viewport:Py,onViewportChange:t4}),E.jsx(Ecn,{nodes:l,edges:s,defaultNodes:u,defaultEdges:h,onConnect:B,onConnectStart:F,onConnectEnd:U,onClickConnectStart:K,onClickConnectEnd:Y,nodesDraggable:bo,autoPanOnNodeFocus:Bl,nodesConnectable:Zl,nodesFocusable:rs,edgesFocusable:f1,edgesReconnectable:mo,elementsSelectable:eu,elevateNodesOnSelect:Ap,elevateEdgesOnSelect:n2,minZoom:Rc,maxZoom:io,nodeExtent:Kw,onNodesChange:mO,onEdgesChange:Mp,snapToGrid:Gn,snapGrid:Ir,connectionMode:Ae,translateExtent:zf,connectOnClick:MM,defaultEdgeOptions:wO,fitView:e4,fitViewOptions:N8,onNodesDelete:Ke,onEdgesDelete:ze,onDelete:je,onNodeDragStart:me,onNodeDrag:Re,onNodeDragStop:Te,onSelectionDrag:He,onSelectionDragStart:ge,onSelectionDragStop:ae,onMove:_,onMoveStart:D,onMoveEnd:I,noPanClassName:rm,nodeOrigin:Ls,rfId:Ry,autoPanOnConnect:r2,autoPanOnNodeDrag:ra,autoPanSpeed:D8,onError:s2,connectionRadius:L8,isValidConnection:sm,selectNodesOnDrag:bs,nodeDragThreshold:P8,connectionDragThreshold:I8,onBeforeDelete:kt,debug:NM,ariaLabelConfig:$8,zIndexMode:Iy}),E.jsx(Ocn,{onSelectionChange:te}),_y,E.jsx(wcn,{proOptions:Ly,position:_8}),E.jsx(mcn,{rfId:Ry,disableKeyboardA11y:i2})]})})}var Wln=k5t(Vln);function Kln(l){const[s,u]=pe.useState(l),h=pe.useCallback(g=>u(w=>y5t(g,w)),[]);return[s,u,h]}function Yln(l){const[s,u]=pe.useState(l),h=pe.useCallback(g=>u(w=>x5t(g,w)),[]);return[s,u,h]}function Zln({dimensions:l,lineWidth:s,variant:u,className:h}){return E.jsx("path",{strokeWidth:s,d:`M${l[0]/2} 0 V${l[1]} M0 ${l[1]/2} H${l[0]}`,className:dh(["react-flow__background-pattern",u,h])})}function eun({radius:l,className:s}){return E.jsx("circle",{cx:l,cy:l,r:l,className:dh(["react-flow__background-pattern","dots",s])})}var tO;(function(l){l.Lines="lines",l.Dots="dots",l.Cross="cross"})(tO||(tO={}));const tun={[tO.Dots]:1,[tO.Lines]:1,[tO.Cross]:6},nun=l=>({transform:l.transform,patternId:`pattern-${l.rfId}`});function J5t({id:l,variant:s=tO.Dots,gap:u=20,size:h,lineWidth:g=1,offset:w=0,color:p,bgColor:k,style:j,className:A,patternClassName:_}){const D=pe.useRef(null),{transform:I,patternId:B}=ac(nun,ta),F=h||tun[s],U=s===tO.Dots,K=s===tO.Cross,Y=Array.isArray(u)?u:[u,u],Z=[Y[0]*I[2]||1,Y[1]*I[2]||1],ee=F*I[2],ce=Array.isArray(w)?w:[w,w],fe=K?[ee,ee]:Z,be=[ce[0]*I[2]||1+fe[0]/2,ce[1]*I[2]||1+fe[1]/2],me=`${B}${l||""}`;return E.jsxs("svg",{className:dh(["react-flow__background",A]),style:{...j,...Rhe,"--xy-background-color-props":k,"--xy-background-pattern-color-props":p},ref:D,"data-testid":"rf__background",children:[E.jsx("pattern",{id:me,x:I[0]%Z[0],y:I[1]%Z[1],width:Z[0],height:Z[1],patternUnits:"userSpaceOnUse",patternTransform:`translate(-${be[0]},-${be[1]})`,children:U?E.jsx(eun,{radius:ee/2,className:_}):E.jsx(Zln,{dimensions:fe,lineWidth:g,variant:s,className:_})}),E.jsx("rect",{x:"0",y:"0",width:"100%",height:"100%",fill:`url(#${me})`})]})}J5t.displayName="Background";const iun=pe.memo(J5t);function run(){return E.jsx("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 32 32",children:E.jsx("path",{d:"M32 18.133H18.133V32h-4.266V18.133H0v-4.266h13.867V0h4.266v13.867H32z"})})}function sun(){return E.jsx("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 32 5",children:E.jsx("path",{d:"M0 0h32v4.2H0z"})})}function oun(){return E.jsx("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 32 30",children:E.jsx("path",{d:"M3.692 4.63c0-.53.4-.938.939-.938h5.215V0H4.708C2.13 0 0 2.054 0 4.63v5.216h3.692V4.631zM27.354 0h-5.2v3.692h5.17c.53 0 .984.4.984.939v5.215H32V4.631A4.624 4.624 0 0027.354 0zm.954 24.83c0 .532-.4.94-.939.94h-5.215v3.768h5.215c2.577 0 4.631-2.13 4.631-4.707v-5.139h-3.692v5.139zm-23.677.94c-.531 0-.939-.4-.939-.94v-5.138H0v5.139c0 2.577 2.13 4.707 4.708 4.707h5.138V25.77H4.631z"})})}function cun(){return E.jsx("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 25 32",children:E.jsx("path",{d:"M21.333 10.667H19.81V7.619C19.81 3.429 16.38 0 12.19 0 8 0 4.571 3.429 4.571 7.619v3.048H3.048A3.056 3.056 0 000 13.714v15.238A3.056 3.056 0 003.048 32h18.285a3.056 3.056 0 003.048-3.048V13.714a3.056 3.056 0 00-3.048-3.047zM12.19 24.533a3.056 3.056 0 01-3.047-3.047 3.056 3.056 0 013.047-3.048 3.056 3.056 0 013.048 3.048 3.056 3.056 0 01-3.048 3.047zm4.724-13.866H7.467V7.619c0-2.59 2.133-4.724 4.723-4.724 2.591 0 4.724 2.133 4.724 4.724v3.048z"})})}function lun(){return E.jsx("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 25 32",children:E.jsx("path",{d:"M21.333 10.667H19.81V7.619C19.81 3.429 16.38 0 12.19 0c-4.114 1.828-1.37 2.133.305 2.438 1.676.305 4.42 2.59 4.42 5.181v3.048H3.047A3.056 3.056 0 000 13.714v15.238A3.056 3.056 0 003.048 32h18.285a3.056 3.056 0 003.048-3.048V13.714a3.056 3.056 0 00-3.048-3.047zM12.19 24.533a3.056 3.056 0 01-3.047-3.047 3.056 3.056 0 013.047-3.048 3.056 3.056 0 013.048 3.048 3.056 3.056 0 01-3.048 3.047z"})})}function Qae({children:l,className:s,...u}){return E.jsx("button",{type:"button",className:dh(["react-flow__controls-button",s]),...u,children:l})}const uun=l=>({isInteractive:l.nodesDraggable||l.nodesConnectable||l.elementsSelectable,minZoomReached:l.transform[2]<=l.minZoom,maxZoomReached:l.transform[2]>=l.maxZoom,ariaLabelConfig:l.ariaLabelConfig});function X5t({style:l,showZoom:s=!0,showFitView:u=!0,showInteractive:h=!0,fitViewOptions:g,onZoomIn:w,onZoomOut:p,onFitView:k,onInteractiveChange:j,className:A,children:_,position:D="bottom-left",orientation:I="vertical","aria-label":B}){const F=na(),{isInteractive:U,minZoomReached:K,maxZoomReached:Y,ariaLabelConfig:Z}=ac(uun,ta),{zoomIn:ee,zoomOut:ce,fitView:fe}=Ihe(),be=()=>{ee(),w==null||w()},me=()=>{ce(),p==null||p()},Re=()=>{fe(g),k==null||k()},Te=()=>{F.setState({nodesDraggable:!U,nodesConnectable:!U,elementsSelectable:!U}),j==null||j(!U)},Ke=I==="horizontal"?"horizontal":"vertical";return E.jsxs(Phe,{className:dh(["react-flow__controls",Ke,A]),position:D,style:l,"data-testid":"rf__controls","aria-label":B??Z["controls.ariaLabel"],children:[s&&E.jsxs(E.Fragment,{children:[E.jsx(Qae,{onClick:be,className:"react-flow__controls-zoomin",title:Z["controls.zoomIn.ariaLabel"],"aria-label":Z["controls.zoomIn.ariaLabel"],disabled:Y,children:E.jsx(run,{})}),E.jsx(Qae,{onClick:me,className:"react-flow__controls-zoomout",title:Z["controls.zoomOut.ariaLabel"],"aria-label":Z["controls.zoomOut.ariaLabel"],disabled:K,children:E.jsx(sun,{})})]}),u&&E.jsx(Qae,{className:"react-flow__controls-fitview",onClick:Re,title:Z["controls.fitView.ariaLabel"],"aria-label":Z["controls.fitView.ariaLabel"],children:E.jsx(oun,{})}),h&&E.jsx(Qae,{className:"react-flow__controls-interactive",onClick:Te,title:Z["controls.interactive.ariaLabel"],"aria-label":Z["controls.interactive.ariaLabel"],children:U?E.jsx(lun,{}):E.jsx(cun,{})}),_]})}X5t.displayName="Controls";pe.memo(X5t);function aun({id:l,x:s,y:u,width:h,height:g,style:w,color:p,strokeColor:k,strokeWidth:j,className:A,borderRadius:_,shapeRendering:D,selected:I,onClick:B}){const{background:F,backgroundColor:U}=w||{},K=p||F||U;return E.jsx("rect",{className:dh(["react-flow__minimap-node",{selected:I},A]),x:s,y:u,rx:_,ry:_,width:h,height:g,style:{fill:K,stroke:k,strokeWidth:j},shapeRendering:D,onClick:B?Y=>B(Y,l):void 0})}const fun=pe.memo(aun),hun=l=>l.nodes.map(s=>s.id),jEe=l=>l instanceof Function?l:()=>l;function dun({nodeStrokeColor:l,nodeColor:s,nodeClassName:u="",nodeBorderRadius:h=5,nodeStrokeWidth:g,nodeComponent:w=fun,onClick:p}){const k=ac(hun,ta),j=jEe(s),A=jEe(l),_=jEe(u),D=typeof window>"u"||window.chrome?"crispEdges":"geometricPrecision";return E.jsx(E.Fragment,{children:k.map(I=>E.jsx(pun,{id:I,nodeColorFunc:j,nodeStrokeColorFunc:A,nodeClassNameFunc:_,nodeBorderRadius:h,nodeStrokeWidth:g,NodeComponent:w,onClick:p,shapeRendering:D},I))})}function gun({id:l,nodeColorFunc:s,nodeStrokeColorFunc:u,nodeClassNameFunc:h,nodeBorderRadius:g,nodeStrokeWidth:w,shapeRendering:p,NodeComponent:k,onClick:j}){const{node:A,x:_,y:D,width:I,height:B}=ac(F=>{const{internals:U}=F.nodeLookup.get(l),K=U.userNode,{x:Y,y:Z}=U.positionAbsolute,{width:ee,height:ce}=oO(K);return{node:K,x:Y,y:Z,width:ee,height:ce}},ta);return!A||A.hidden||!X4t(A)?null:E.jsx(k,{x:_,y:D,width:I,height:B,style:A.style,selected:!!A.selected,className:h(A),color:s(A),borderRadius:g,strokeColor:u(A),strokeWidth:w,shapeRendering:p,onClick:j,id:A.id})}const pun=pe.memo(gun);var bun=pe.memo(dun);const mun=200,wun=150,vun=l=>!l.hidden,yun=l=>{const s={x:-l.transform[0]/l.transform[2],y:-l.transform[1]/l.transform[2],width:l.width/l.transform[2],height:l.height/l.transform[2]};return{viewBB:s,boundingRect:l.nodeLookup.size>0?J4t(kV(l.nodeLookup,{filter:vun}),s):s,rfId:l.rfId,panZoom:l.panZoom,translateExtent:l.translateExtent,flowWidth:l.width,flowHeight:l.height,ariaLabelConfig:l.ariaLabelConfig}},xun="react-flow__minimap-desc";function V5t({style:l,className:s,nodeStrokeColor:u,nodeColor:h,nodeClassName:g="",nodeBorderRadius:w=5,nodeStrokeWidth:p,nodeComponent:k,bgColor:j,maskColor:A,maskStrokeColor:_,maskStrokeWidth:D,position:I="bottom-right",onClick:B,onNodeClick:F,pannable:U=!1,zoomable:K=!1,ariaLabel:Y,inversePan:Z,zoomStep:ee=1,offsetScale:ce=5}){const fe=na(),be=pe.useRef(null),{boundingRect:me,viewBB:Re,rfId:Te,panZoom:Ke,translateExtent:ze,flowWidth:je,flowHeight:te,ariaLabelConfig:ge}=ac(yun,ta),He=(l==null?void 0:l.width)??mun,ae=(l==null?void 0:l.height)??wun,Le=me.width/He,Oe=me.height/ae,Qe=Math.max(Le,Oe),kt=Qe*He,Ae=Qe*ae,Ye=ce*Qe,mt=me.x-(kt-me.width)/2-Ye,Ue=me.y-(Ae-me.height)/2-Ye,Pt=kt+Ye*2,rn=Ae+Ye*2,Cn=`${xun}-${Te}`,Pn=pe.useRef(0),mi=pe.useRef();Pn.current=Qe,pe.useEffect(()=>{if(be.current&&Ke)return mi.current=$on({domNode:be.current,panZoom:Ke,getTransform:()=>fe.getState().transform,getViewScale:()=>Pn.current}),()=>{var Gn;(Gn=mi.current)==null||Gn.destroy()}},[Ke]),pe.useEffect(()=>{var Gn;(Gn=mi.current)==null||Gn.update({translateExtent:ze,width:je,height:te,inversePan:Z,pannable:U,zoomStep:ee,zoomable:K})},[U,K,Z,ee,ze,je,te]);const er=B?Gn=>{var bs;const[Ir,is]=((bs=mi.current)==null?void 0:bs.pointer(Gn))||[0,0];B(Gn,{x:Ir,y:is})}:void 0,Mr=F?pe.useCallback((Gn,Ir)=>{const is=fe.getState().nodeLookup.get(Ir).internals.userNode;F(Gn,is)},[]):void 0,hr=Y??ge["minimap.ariaLabel"];return E.jsx(Phe,{position:I,style:{...l,"--xy-minimap-background-color-props":typeof j=="string"?j:void 0,"--xy-minimap-mask-background-color-props":typeof A=="string"?A:void 0,"--xy-minimap-mask-stroke-color-props":typeof _=="string"?_:void 0,"--xy-minimap-mask-stroke-width-props":typeof D=="number"?D*Qe:void 0,"--xy-minimap-node-background-color-props":typeof h=="string"?h:void 0,"--xy-minimap-node-stroke-color-props":typeof u=="string"?u:void 0,"--xy-minimap-node-stroke-width-props":typeof p=="number"?p:void 0},className:dh(["react-flow__minimap",s]),"data-testid":"rf__minimap",children:E.jsxs("svg",{width:He,height:ae,viewBox:`${mt} ${Ue} ${Pt} ${rn}`,className:"react-flow__minimap-svg",role:"img","aria-labelledby":Cn,ref:be,onClick:er,children:[hr&&E.jsx("title",{id:Cn,children:hr}),E.jsx(bun,{onClick:Mr,nodeColor:h,nodeStrokeColor:u,nodeBorderRadius:w,nodeClassName:g,nodeStrokeWidth:p,nodeComponent:k}),E.jsx("path",{className:"react-flow__minimap-mask",d:`M${mt-Ye},${Ue-Ye}h${Pt+Ye*2}v${rn+Ye*2}h${-Pt-Ye*2}z
        M${Re.x},${Re.y}h${Re.width}v${Re.height}h${-Re.width}z`,fillRule:"evenodd",pointerEvents:"none"})]})})}V5t.displayName="MiniMap";pe.memo(V5t);const kun=l=>s=>l?`${Math.max(1/s.transform[2],1)}`:void 0,Oun={[AI.Line]:"right",[AI.Handle]:"bottom-right"};function Sun({nodeId:l,position:s,variant:u=AI.Handle,className:h,style:g=void 0,children:w,color:p,minWidth:k=10,minHeight:j=10,maxWidth:A=Number.MAX_VALUE,maxHeight:_=Number.MAX_VALUE,keepAspectRatio:D=!1,resizeDirection:I,autoScale:B=!0,shouldResize:F,onResizeStart:U,onResize:K,onResizeEnd:Y}){const Z=T5t(),ee=typeof l=="string"?l:Z,ce=na(),fe=pe.useRef(null),be=u===AI.Handle,me=ac(pe.useCallback(kun(be&&B),[be,B]),ta),Re=pe.useRef(null),Te=s??Oun[u];pe.useEffect(()=>{if(!(!fe.current||!ee))return Re.current||(Re.current=Yon({domNode:fe.current,nodeId:ee,getStoreItems:()=>{const{nodeLookup:ze,transform:je,snapGrid:te,snapToGrid:ge,nodeOrigin:He,domNode:ae}=ce.getState();return{nodeLookup:ze,transform:je,snapGrid:te,snapToGrid:ge,nodeOrigin:He,paneDomNode:ae}},onChange:(ze,je)=>{const{triggerNodeChanges:te,nodeLookup:ge,parentLookup:He,nodeOrigin:ae}=ce.getState(),Le=[],Oe={x:ze.x,y:ze.y},Qe=ge.get(ee);if(Qe&&Qe.expandParent&&Qe.parentId){const kt=Qe.origin??ae,Ae=ze.width??Qe.measured.width??0,Ye=ze.height??Qe.measured.height??0,mt={id:Qe.id,parentId:Qe.parentId,rect:{width:Ae,height:Ye,...V4t({x:ze.x??Qe.position.x,y:ze.y??Qe.position.y},{width:Ae,height:Ye},Qe.parentId,ge,kt)}},Ue=RMe([mt],ge,He,ae);Le.push(...Ue),Oe.x=ze.x?Math.max(kt[0]*Ae,ze.x):void 0,Oe.y=ze.y?Math.max(kt[1]*Ye,ze.y):void 0}if(Oe.x!==void 0&&Oe.y!==void 0){const kt={id:ee,type:"position",position:{...Oe}};Le.push(kt)}if(ze.width!==void 0&&ze.height!==void 0){const Ae={id:ee,type:"dimensions",resizing:!0,setAttributes:I?I==="horizontal"?"width":"height":!0,dimensions:{width:ze.width,height:ze.height}};Le.push(Ae)}for(const kt of je){const Ae={...kt,type:"position"};Le.push(Ae)}te(Le)},onEnd:({width:ze,height:je})=>{const te={id:ee,type:"dimensions",resizing:!1,dimensions:{width:ze,height:je}};ce.getState().triggerNodeChanges([te])}})),Re.current.update({controlPosition:Te,boundaries:{minWidth:k,minHeight:j,maxWidth:A,maxHeight:_},keepAspectRatio:D,resizeDirection:I,onResizeStart:U,onResize:K,onResizeEnd:Y,shouldResize:F}),()=>{var ze;(ze=Re.current)==null||ze.destroy()}},[Te,k,j,A,_,D,U,K,Y,F]);const Ke=Te.split("-");return E.jsx("div",{className:dh(["react-flow__resize-control","nodrag",...Ke,u,h]),ref:fe,style:{...g,scale:me,...p&&{[be?"backgroundColor":"borderColor"]:p}},children:w})}pe.memo(Sun);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const W5t=(...l)=>l.filter((s,u,h)=>!!s&&s.trim()!==""&&h.indexOf(s)===u).join(" ").trim();/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const jun=l=>l.replace(/([a-z0-9])([A-Z])/g,"$1-$2").toLowerCase();/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Tun=l=>l.replace(/^([A-Z])|[\s-_]+(\w)/g,(s,u,h)=>h?h.toUpperCase():u.toLowerCase());/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Yyt=l=>{const s=Tun(l);return s.charAt(0).toUpperCase()+s.slice(1)};/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */var Eun={xmlns:"http://www.w3.org/2000/svg",width:24,height:24,viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:2,strokeLinecap:"round",strokeLinejoin:"round"};/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Cun=l=>{for(const s in l)if(s.startsWith("aria-")||s==="role"||s==="title")return!0;return!1};/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Mun=pe.forwardRef(({color:l="currentColor",size:s=24,strokeWidth:u=2,absoluteStrokeWidth:h,className:g="",children:w,iconNode:p,...k},j)=>pe.createElement("svg",{ref:j,...Eun,width:s,height:s,stroke:l,strokeWidth:h?Number(u)*24/Number(s):u,className:W5t("lucide",g),...!w&&!Cun(k)&&{"aria-hidden":"true"},...k},[...p.map(([A,_])=>pe.createElement(A,_)),...Array.isArray(w)?w:[w]]));/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Tr=(l,s)=>{const u=pe.forwardRef(({className:h,...g},w)=>pe.createElement(Mun,{ref:w,iconNode:s,className:W5t(`lucide-${jun(Yyt(l))}`,`lucide-${l}`,h),...g}));return u.displayName=Yyt(l),u};/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Aun=[["rect",{width:"20",height:"5",x:"2",y:"3",rx:"1",key:"1wp1u1"}],["path",{d:"M4 8v11a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V8",key:"1s80jp"}],["path",{d:"M10 12h4",key:"a56b0p"}]],Nun=Tr("archive",Aun);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const _un=[["path",{d:"M12 17V3",key:"1cwfxf"}],["path",{d:"m6 11 6 6 6-6",key:"12ii2o"}],["path",{d:"M19 21H5",key:"150jfl"}]],Dun=Tr("arrow-down-to-line",_un);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Lun=[["path",{d:"m12 19-7-7 7-7",key:"1l729n"}],["path",{d:"M19 12H5",key:"x3x0zl"}]],Pun=Tr("arrow-left",Lun);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Iun=[["path",{d:"M5 12h14",key:"1ays0h"}],["path",{d:"m12 5 7 7-7 7",key:"xquz4c"}]],K5t=Tr("arrow-right",Iun);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Run=[["path",{d:"M12 18V5",key:"adv99a"}],["path",{d:"M15 13a4.17 4.17 0 0 1-3-4 4.17 4.17 0 0 1-3 4",key:"1e3is1"}],["path",{d:"M17.598 6.5A3 3 0 1 0 12 5a3 3 0 1 0-5.598 1.5",key:"1gqd8o"}],["path",{d:"M17.997 5.125a4 4 0 0 1 2.526 5.77",key:"iwvgf7"}],["path",{d:"M18 18a4 4 0 0 0 2-7.464",key:"efp6ie"}],["path",{d:"M19.967 17.483A4 4 0 1 1 12 18a4 4 0 1 1-7.967-.517",key:"1gq6am"}],["path",{d:"M6 18a4 4 0 0 1-2-7.464",key:"k1g0md"}],["path",{d:"M6.003 5.125a4 4 0 0 0-2.526 5.77",key:"q97ue3"}]],$un=Tr("brain",Run);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Bun=[["path",{d:"M20 6 9 17l-5-5",key:"1gmf2c"}]],Ufe=Tr("check",Bun);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const zun=[["path",{d:"m6 9 6 6 6-6",key:"qrunsl"}]],Vw=Tr("chevron-down",zun);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Fun=[["path",{d:"m15 18-6-6 6-6",key:"1wnfg3"}]],qun=Tr("chevron-left",Fun);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Hun=[["path",{d:"m9 18 6-6-6-6",key:"mthhwq"}]],NI=Tr("chevron-right",Hun);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Qun=[["path",{d:"m18 15-6-6-6 6",key:"153udz"}]],Y5t=Tr("chevron-up",Qun);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Gun=[["circle",{cx:"12",cy:"12",r:"10",key:"1mglay"}],["line",{x1:"12",x2:"12",y1:"8",y2:"12",key:"1pkeuh"}],["line",{x1:"12",x2:"12.01",y1:"16",y2:"16",key:"4dfq90"}]],TCe=Tr("circle-alert",Gun);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Uun=[["circle",{cx:"12",cy:"12",r:"10",key:"1mglay"}],["path",{d:"m9 12 2 2 4-4",key:"dzmm74"}]],Z5t=Tr("circle-check",Uun);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Jun=[["circle",{cx:"12",cy:"12",r:"10",key:"1mglay"}],["circle",{cx:"12",cy:"12",r:"1",key:"41hilf"}]],Xun=Tr("circle-dot",Jun);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Vun=[["path",{d:"M12 6v6l4 2",key:"mmk7yg"}],["circle",{cx:"12",cy:"12",r:"10",key:"1mglay"}]],ekt=Tr("clock",Vun);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Wun=[["rect",{width:"14",height:"14",x:"8",y:"8",rx:"2",ry:"2",key:"17jyea"}],["path",{d:"M4 16c-1.1 0-2-.9-2-2V4c0-1.1.9-2 2-2h10c1.1 0 2 .9 2 2",key:"zix9uf"}]],Kun=Tr("copy",Wun);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Yun=[["circle",{cx:"12",cy:"12",r:"10",key:"1mglay"}],["line",{x1:"22",x2:"18",y1:"12",y2:"12",key:"l9bcsi"}],["line",{x1:"6",x2:"2",y1:"12",y2:"12",key:"13hhkx"}],["line",{x1:"12",x2:"12",y1:"6",y2:"2",key:"10w3f3"}],["line",{x1:"12",x2:"12",y1:"22",y2:"18",key:"15g9kq"}]],Zun=Tr("crosshair",Yun);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const ean=[["ellipse",{cx:"12",cy:"5",rx:"9",ry:"3",key:"msslwz"}],["path",{d:"M3 5V19A9 3 0 0 0 21 19V5",key:"1wlel7"}],["path",{d:"M3 12A9 3 0 0 0 21 12",key:"mv7ke4"}]],tkt=Tr("database",ean);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const tan=[["path",{d:"M12 15V3",key:"m9g1x1"}],["path",{d:"M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4",key:"ih7n3h"}],["path",{d:"m7 10 5 5 5-5",key:"brsn70"}]],nan=Tr("download",tan);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const ian=[["path",{d:"M15 3h6v6",key:"1q9fwt"}],["path",{d:"M10 14 21 3",key:"gplh6r"}],["path",{d:"M18 13v6a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h6",key:"a6xqqp"}]],ran=Tr("external-link",ian);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const san=[["path",{d:"M13.659 22H18a2 2 0 0 0 2-2V8a2.4 2.4 0 0 0-.706-1.706l-3.588-3.588A2.4 2.4 0 0 0 14 2H6a2 2 0 0 0-2 2v11.5",key:"4pqfef"}],["path",{d:"M14 2v5a1 1 0 0 0 1 1h5",key:"wfsgrz"}],["path",{d:"M8 12v-1",key:"1ej8lb"}],["path",{d:"M8 18v-2",key:"qcmpov"}],["path",{d:"M8 7V6",key:"1nbb54"}],["circle",{cx:"8",cy:"20",r:"2",key:"ckkr5m"}]],oan=Tr("file-archive",san);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const can=[["path",{d:"M4 12.15V4a2 2 0 0 1 2-2h8a2.4 2.4 0 0 1 1.706.706l3.588 3.588A2.4 2.4 0 0 1 20 8v12a2 2 0 0 1-2 2h-3.35",key:"1wthlu"}],["path",{d:"M14 2v5a1 1 0 0 0 1 1h5",key:"wfsgrz"}],["path",{d:"m5 16-3 3 3 3",key:"331omg"}],["path",{d:"m9 22 3-3-3-3",key:"lsp7cz"}]],nkt=Tr("file-code-corner",can);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const lan=[["path",{d:"M6 22a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h8a2.4 2.4 0 0 1 1.704.706l3.588 3.588A2.4 2.4 0 0 1 20 8v12a2 2 0 0 1-2 2z",key:"1oefj6"}],["path",{d:"M14 2v5a1 1 0 0 0 1 1h5",key:"wfsgrz"}],["path",{d:"M10 9H8",key:"b1mrlr"}],["path",{d:"M16 13H8",key:"t4e002"}],["path",{d:"M16 17H8",key:"z1uh3a"}]],ikt=Tr("file-text",lan);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const uan=[["path",{d:"M14 2v6a2 2 0 0 0 .245.96l5.51 10.08A2 2 0 0 1 18 22H6a2 2 0 0 1-1.755-2.96l5.51-10.08A2 2 0 0 0 10 8V2",key:"18mbvz"}],["path",{d:"M6.453 15h11.094",key:"3shlmq"}],["path",{d:"M8.5 2h7",key:"csnxdl"}]],BMe=Tr("flask-conical",uan);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const aan=[["path",{d:"M20 20a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2h-7.9a2 2 0 0 1-1.69-.9L9.6 3.9A2 2 0 0 0 7.93 3H4a2 2 0 0 0-2 2v13a2 2 0 0 0 2 2Z",key:"1kt360"}]],fan=Tr("folder",aan);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const han=[["line",{x1:"6",x2:"6",y1:"3",y2:"15",key:"17qcm7"}],["circle",{cx:"18",cy:"6",r:"3",key:"1h7g24"}],["circle",{cx:"6",cy:"18",r:"3",key:"fqmcym"}],["path",{d:"M18 9a9 9 0 0 1-9 9",key:"n2h4wq"}]],rkt=Tr("git-branch",han);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const dan=[["circle",{cx:"12",cy:"18",r:"3",key:"1mpf1b"}],["circle",{cx:"6",cy:"6",r:"3",key:"1lh9wr"}],["circle",{cx:"18",cy:"6",r:"3",key:"1h7g24"}],["path",{d:"M18 9v2c0 .6-.4 1-1 1H7c-.6 0-1-.4-1-1V9",key:"1uq4wg"}],["path",{d:"M12 12v3",key:"158kv8"}]],skt=Tr("git-fork",dan);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const gan=[["path",{d:"M12 2v8",key:"1q4o3n"}],["path",{d:"m16 6-4 4-4-4",key:"6wukr"}],["rect",{width:"20",height:"8",x:"2",y:"14",rx:"2",key:"w68u3i"}],["path",{d:"M6 18h.01",key:"uhywen"}],["path",{d:"M10 18h.01",key:"h775k"}]],Jfe=Tr("hard-drive-download",gan);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const pan=[["line",{x1:"22",x2:"2",y1:"12",y2:"12",key:"1y58io"}],["path",{d:"M5.45 5.11 2 12v6a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-6l-3.45-6.89A2 2 0 0 0 16.76 4H7.24a2 2 0 0 0-1.79 1.11z",key:"oot6mr"}],["line",{x1:"6",x2:"6.01",y1:"16",y2:"16",key:"sgf278"}],["line",{x1:"10",x2:"10.01",y1:"16",y2:"16",key:"1l4acy"}]],ban=Tr("hard-drive",pan);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const man=[["line",{x1:"4",x2:"20",y1:"9",y2:"9",key:"4lhtct"}],["line",{x1:"4",x2:"20",y1:"15",y2:"15",key:"vyu0kd"}],["line",{x1:"10",x2:"8",y1:"3",y2:"21",key:"1ggp8o"}],["line",{x1:"16",x2:"14",y1:"3",y2:"21",key:"weycgp"}]],wan=Tr("hash",man);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const van=[["circle",{cx:"12",cy:"12",r:"10",key:"1mglay"}],["path",{d:"M12 16v-4",key:"1dtifu"}],["path",{d:"M12 8h.01",key:"e9boi3"}]],yan=Tr("info",van);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const xan=[["path",{d:"M10 8h.01",key:"1r9ogq"}],["path",{d:"M12 12h.01",key:"1mp3jc"}],["path",{d:"M14 8h.01",key:"1primd"}],["path",{d:"M16 12h.01",key:"1l6xoz"}],["path",{d:"M18 8h.01",key:"emo2bl"}],["path",{d:"M6 8h.01",key:"x9i8wu"}],["path",{d:"M7 16h10",key:"wp8him"}],["path",{d:"M8 12h.01",key:"czm47f"}],["rect",{width:"20",height:"16",x:"2",y:"4",rx:"2",key:"18n3k1"}]],kan=Tr("keyboard",xan);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Oan=[["path",{d:"M12.83 2.18a2 2 0 0 0-1.66 0L2.6 6.08a1 1 0 0 0 0 1.83l8.58 3.91a2 2 0 0 0 1.66 0l8.58-3.9a1 1 0 0 0 0-1.83z",key:"zw3jo"}],["path",{d:"M2 12a1 1 0 0 0 .58.91l8.6 3.91a2 2 0 0 0 1.65 0l8.58-3.9A1 1 0 0 0 22 12",key:"1wduqc"}],["path",{d:"M2 17a1 1 0 0 0 .58.91l8.6 3.91a2 2 0 0 0 1.65 0l8.58-3.9A1 1 0 0 0 22 17",key:"kqbvx6"}]],okt=Tr("layers",Oan);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const San=[["path",{d:"M9 17H7A5 5 0 0 1 7 7h2",key:"8i5ue5"}],["path",{d:"M15 7h2a5 5 0 1 1 0 10h-2",key:"1b9ql8"}],["line",{x1:"8",x2:"16",y1:"12",y2:"12",key:"1jonct"}]],zMe=Tr("link-2",San);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const jan=[["path",{d:"M21 12a9 9 0 1 1-6.219-8.56",key:"13zald"}]],Ey=Tr("loader-circle",jan);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Tan=[["path",{d:"M11 21.73a2 2 0 0 0 2 0l7-4A2 2 0 0 0 21 16V8a2 2 0 0 0-1-1.73l-7-4a2 2 0 0 0-2 0l-7 4A2 2 0 0 0 3 8v8a2 2 0 0 0 1 1.73z",key:"1a0edw"}],["path",{d:"M12 22V12",key:"d0xqtd"}],["polyline",{points:"3.29 7 12 12 20.71 7",key:"ousv84"}],["path",{d:"m7.5 4.27 9 5.15",key:"1c824w"}]],jV=Tr("package",Tan);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Ean=[["rect",{width:"18",height:"18",x:"3",y:"3",rx:"2",key:"afitv7"}],["path",{d:"M9 3v18",key:"fh3hqa"}],["path",{d:"m16 15-3-3 3-3",key:"14y99z"}]],Can=Tr("panel-left-close",Ean);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Man=[["rect",{width:"18",height:"18",x:"3",y:"3",rx:"2",key:"afitv7"}],["path",{d:"M9 3v18",key:"fh3hqa"}],["path",{d:"m14 9 3 3-3 3",key:"8010ee"}]],Aan=Tr("panel-left-open",Man);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Nan=[["path",{d:"M5 5a2 2 0 0 1 3.008-1.728l11.997 6.998a2 2 0 0 1 .003 3.458l-12 7A2 2 0 0 1 5 19z",key:"10ikf1"}]],_an=Tr("play",Nan);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Dan=[["path",{d:"M5 12h14",key:"1ays0h"}],["path",{d:"M12 5v14",key:"s699le"}]],w8=Tr("plus",Dan);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Lan=[["path",{d:"M16.247 7.761a6 6 0 0 1 0 8.478",key:"1fwjs5"}],["path",{d:"M19.075 4.933a10 10 0 0 1 0 14.134",key:"ehdyv1"}],["path",{d:"M4.925 19.067a10 10 0 0 1 0-14.134",key:"1q22gi"}],["path",{d:"M7.753 16.239a6 6 0 0 1 0-8.478",key:"r2q7qm"}],["circle",{cx:"12",cy:"12",r:"2",key:"1c9p78"}]],FMe=Tr("radio",Lan);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Pan=[["path",{d:"m15 14 5-5-5-5",key:"12vg1m"}],["path",{d:"M20 9H9.5A5.5 5.5 0 0 0 4 14.5A5.5 5.5 0 0 0 9.5 20H13",key:"6uklza"}]],Ian=Tr("redo-2",Pan);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Ran=[["path",{d:"M3 12a9 9 0 0 1 9-9 9.75 9.75 0 0 1 6.74 2.74L21 8",key:"v9h5vc"}],["path",{d:"M21 3v5h-5",key:"1q7to0"}],["path",{d:"M21 12a9 9 0 0 1-9 9 9.75 9.75 0 0 1-6.74-2.74L3 16",key:"3uifl3"}],["path",{d:"M8 16H3v5",key:"1cv678"}]],qMe=Tr("refresh-cw",Ran);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const $an=[["path",{d:"M3 12a9 9 0 1 0 9-9 9.75 9.75 0 0 0-6.74 2.74L3 8",key:"1357e3"}],["path",{d:"M3 3v5h5",key:"1xhq8a"}]],Ban=Tr("rotate-ccw",$an);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const zan=[["rect",{width:"18",height:"18",x:"3",y:"3",rx:"2",key:"afitv7"}],["path",{d:"M21 9H3",key:"1338ky"}],["path",{d:"M21 15H3",key:"9uk58r"}]],Fan=Tr("rows-3",zan);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const qan=[["path",{d:"M15.2 3a2 2 0 0 1 1.4.6l3.8 3.8a2 2 0 0 1 .6 1.4V19a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2z",key:"1c8476"}],["path",{d:"M17 21v-7a1 1 0 0 0-1-1H8a1 1 0 0 0-1 1v7",key:"1ydtos"}],["path",{d:"M7 3v4a1 1 0 0 0 1 1h7",key:"t51u73"}]],Han=Tr("save",qan);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Qan=[["path",{d:"M3 7V5a2 2 0 0 1 2-2h2",key:"aa7l1z"}],["path",{d:"M17 3h2a2 2 0 0 1 2 2v2",key:"4qcy5o"}],["path",{d:"M21 17v2a2 2 0 0 1-2 2h-2",key:"6vwrx8"}],["path",{d:"M7 21H5a2 2 0 0 1-2-2v-2",key:"ioqczr"}]],Gan=Tr("scan",Qan);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Uan=[["path",{d:"m21 21-4.34-4.34",key:"14j7rj"}],["circle",{cx:"11",cy:"11",r:"8",key:"4ej97u"}]],Jan=Tr("search",Uan);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Xan=[["path",{d:"M10 5H3",key:"1qgfaw"}],["path",{d:"M12 19H3",key:"yhmn1j"}],["path",{d:"M14 3v4",key:"1sua03"}],["path",{d:"M16 17v4",key:"1q0r14"}],["path",{d:"M21 12h-9",key:"1o4lsq"}],["path",{d:"M21 19h-5",key:"1rlt1p"}],["path",{d:"M21 5h-7",key:"1oszz2"}],["path",{d:"M8 10v4",key:"tgpxqk"}],["path",{d:"M8 12H3",key:"a7s4jb"}]],ckt=Tr("sliders-horizontal",Xan);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Van=[["path",{d:"M9 3H5a2 2 0 0 0-2 2v4m6-6h10a2 2 0 0 1 2 2v4M9 3v18m0 0h10a2 2 0 0 0 2-2V9M9 21H5a2 2 0 0 1-2-2V9m0 0h18",key:"gugj83"}]],Xfe=Tr("table-2",Van);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Wan=[["path",{d:"M15 3v18",key:"14nvp0"}],["rect",{width:"18",height:"18",x:"3",y:"3",rx:"2",key:"afitv7"}],["path",{d:"M21 9H3",key:"1338ky"}],["path",{d:"M21 15H3",key:"9uk58r"}]],Kan=Tr("table-properties",Wan);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Yan=[["circle",{cx:"12",cy:"12",r:"10",key:"1mglay"}],["circle",{cx:"12",cy:"12",r:"6",key:"1vlfrh"}],["circle",{cx:"12",cy:"12",r:"2",key:"1c9p78"}]],PX=Tr("target",Yan);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Zan=[["line",{x1:"10",x2:"14",y1:"2",y2:"2",key:"14vaq8"}],["line",{x1:"12",x2:"15",y1:"14",y2:"11",key:"17fdiu"}],["circle",{cx:"12",cy:"14",r:"8",key:"1e1u0o"}]],efn=Tr("timer",Zan);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const tfn=[["circle",{cx:"9",cy:"12",r:"3",key:"u3jwor"}],["rect",{width:"20",height:"14",x:"2",y:"5",rx:"7",key:"g7kal2"}]],lkt=Tr("toggle-left",tfn);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const nfn=[["path",{d:"M10 11v6",key:"nco0om"}],["path",{d:"M14 11v6",key:"outv1u"}],["path",{d:"M19 6v14a2 2 0 0 1-2 2H7a2 2 0 0 1-2-2V6",key:"miytrc"}],["path",{d:"M3 6h18",key:"d0wm0j"}],["path",{d:"M8 6V4a2 2 0 0 1 2-2h4a2 2 0 0 1 2 2v2",key:"e791ji"}]],BI=Tr("trash-2",nfn);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const ifn=[["path",{d:"M19 6v14a2 2 0 0 1-2 2H7a2 2 0 0 1-2-2V6",key:"miytrc"}],["path",{d:"M3 6h18",key:"d0wm0j"}],["path",{d:"M8 6V4a2 2 0 0 1 2-2h4a2 2 0 0 1 2 2v2",key:"e791ji"}]],Zyt=Tr("trash",ifn);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const rfn=[["path",{d:"m21.73 18-8-14a2 2 0 0 0-3.48 0l-8 14A2 2 0 0 0 4 21h16a2 2 0 0 0 1.73-3",key:"wmoenq"}],["path",{d:"M12 9v4",key:"juzpu7"}],["path",{d:"M12 17h.01",key:"p32p05"}]],Oy=Tr("triangle-alert",rfn);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const sfn=[["path",{d:"M12 4v16",key:"1654pz"}],["path",{d:"M4 7V5a1 1 0 0 1 1-1h14a1 1 0 0 1 1 1v2",key:"e0r10z"}],["path",{d:"M9 20h6",key:"s66wpe"}]],ofn=Tr("type",sfn);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const cfn=[["path",{d:"M9 14 4 9l5-5",key:"102s5s"}],["path",{d:"M4 9h10.5a5.5 5.5 0 0 1 5.5 5.5a5.5 5.5 0 0 1-5.5 5.5H11",key:"f3b9sd"}]],lfn=Tr("undo-2",cfn);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const ufn=[["rect",{width:"8",height:"6",x:"5",y:"4",rx:"1",key:"nzclkv"}],["rect",{width:"8",height:"6",x:"11",y:"14",rx:"1",key:"4tytwb"}]],afn=Tr("ungroup",ufn);/**
 * @license lucide-react v0.563.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const ffn=[["path",{d:"M18 6 6 18",key:"1bl5f8"}],["path",{d:"m6 6 12 12",key:"d8bk6v"}]],jp=Tr("x",ffn);function hfn({size:l=16,color:s="currentColor",className:u,style:h}){return E.jsxs("svg",{width:l,height:l,viewBox:"0 0 16 16",fill:"none",xmlns:"http://www.w3.org/2000/svg",className:u,style:h,children:[E.jsx("rect",{x:"1",y:"8",width:"2",height:"6",rx:"0.5",fill:s,opacity:"0.7"}),E.jsx("rect",{x:"4",y:"4",width:"2",height:"10",rx:"0.5",fill:s,opacity:"0.85"}),E.jsx("rect",{x:"7",y:"2",width:"2",height:"12",rx:"0.5",fill:s}),E.jsx("rect",{x:"10",y:"5",width:"2",height:"9",rx:"0.5",fill:s,opacity:"0.85"}),E.jsx("rect",{x:"13",y:"7",width:"2",height:"7",rx:"0.5",fill:s,opacity:"0.7"})]})}const ukt=pe.memo(hfn),Ln={API_INPUT:"apiInput",DATA_SOURCE:"dataSource",TRANSFORM:"transform",MODEL_SCORE:"modelScore",BANDING:"banding",RATING_STEP:"ratingStep",OUTPUT:"output",DATA_SINK:"dataSink",EXTERNAL_FILE:"externalFile",LIVE_SWITCH:"liveSwitch",MODELLING:"modelling",OPTIMISER:"optimiser",OPTIMISER_APPLY:"optimiserApply",SCENARIO_EXPANDER:"scenarioExpander",CONSTANT:"constant",SUBMODEL:"submodel",SUBMODEL_PORT:"submodelPort"},zI={[Ln.API_INPUT]:{icon:FMe,color:"#22c55e",label:"API INPUT",name:"API Input",description:"Live API input for deployment (max 1)",defaultConfig:{path:""}},[Ln.OUTPUT]:{icon:Xun,color:"#f43f5e",label:"API OUTPUT",name:"API Output",description:"Final price / prediction",defaultConfig:{fields:[]}},[Ln.LIVE_SWITCH]:{icon:lkt,color:"#f59e0b",label:"SWITCH",name:"Source Switch",description:"Switch between live API and batch data",defaultConfig:{mode:"live"}},[Ln.DATA_SOURCE]:{icon:tkt,color:"#3b82f6",label:"SOURCE",name:"Data Source",description:"Read from parquet, CSV, or Databricks table",defaultConfig:{path:""}},[Ln.DATA_SINK]:{icon:Jfe,color:"#60a5fa",label:"SINK",name:"Data Sink",description:"Write to parquet, CSV, or directory",defaultConfig:{path:"",format:"parquet"}},[Ln.EXTERNAL_FILE]:{icon:oan,color:"#93c5fd",label:"LOAD FILE",name:"Load File",description:"Load a pickle, JSON, or joblib file and use in code",defaultConfig:{path:"",fileType:"pickle",code:""}},[Ln.CONSTANT]:{icon:wan,color:"#94a3b8",label:"CONSTANT",name:"Constant",description:"Named constant values (1-row DataFrame)",defaultConfig:{values:[{name:"constant_1",value:"1.0"}]}},[Ln.TRANSFORM]:{icon:ukt,color:"#06b6d4",label:"POLARS",name:"Polars",description:"Polars transform / feature engineering",defaultConfig:{}},[Ln.BANDING]:{icon:ckt,color:"#14b8a6",label:"BANDING",name:"Banding",description:"Group numerical or categorical values into bands",defaultConfig:{factors:[{banding:"continuous",column:"",outputColumn:"",rules:[],default:null}]}},[Ln.SCENARIO_EXPANDER]:{icon:Fan,color:"#0ea5e9",label:"EXPANDER",name:"Expander",description:"Cross-join rows with scenario values (price, tier, etc.)",defaultConfig:{quote_id:"quote_id",column_name:"scenario_value",min_value:.8,max_value:1.2,steps:21,step_column:"scenario_index"}},[Ln.RATING_STEP]:{icon:Kan,color:"#f59e0b",label:"RATING",name:"Rating Step",description:"Lookup, factor, cap/floor",defaultConfig:{tables:[{name:"Table 1",factors:[],outputColumn:"",defaultValue:"1.0",entries:[]}],operation:"multiply",combinedColumn:""}},[Ln.MODELLING]:{icon:BMe,color:"#8b5cf6",label:"TRAINING",name:"Model Training",description:"Train and evaluate a CatBoost model",defaultConfig:{algorithm:"catboost",task:"regression",target:"",weight:"",exclude:[],params:{iterations:1e3,learning_rate:.05,depth:6},split:{strategy:"random",test_size:.2,seed:42},metrics:["gini","rmse"]}},[Ln.MODEL_SCORE]:{icon:$un,color:"#a855f7",label:"SCORING",name:"Model Scoring",description:"Score using an MLflow model",defaultConfig:{sourceType:"registered",registered_model:"",version:"latest",task:"regression",output_column:"prediction",code:""}},[Ln.OPTIMISER]:{icon:PX,color:"#f97316",label:"OPTIMISATION",name:"Optimisation",description:"Price optimisation via Lagrangian solver",defaultConfig:{mode:"online",objective:"",constraints:{},quote_id:"quote_id",scenario_index:"scenario_index",scenario_value:"scenario_value",max_iter:50,tolerance:1e-6}},[Ln.OPTIMISER_APPLY]:{icon:Zun,color:"#fb923c",label:"APPLY OPT",name:"Apply Optimisation",description:"Apply saved optimisation results (lambdas or factor tables)",defaultConfig:{sourceType:"file",artifact_path:"",version_column:"__optimiser_version__"}},[Ln.SUBMODEL]:{icon:jV,color:"#ea580c",label:"SUBMODEL",name:"Submodel",description:"Reusable sub-pipeline",defaultConfig:{}},[Ln.SUBMODEL_PORT]:{icon:K5t,color:"#94a3b8",label:"PORT",name:"Port",description:"Submodel input/output port",defaultConfig:{}}},ext=new Set([Ln.API_INPUT,Ln.OUTPUT]),dfn=new Set([Ln.DATA_SOURCE,Ln.API_INPUT,Ln.CONSTANT]),gfn=new Set([Ln.OUTPUT,Ln.DATA_SINK,Ln.MODELLING,Ln.OPTIMISER]),pfn=[Ln.API_INPUT,Ln.OUTPUT,Ln.LIVE_SWITCH,Ln.DATA_SOURCE,Ln.DATA_SINK,Ln.EXTERNAL_FILE,Ln.CONSTANT,Ln.TRANSFORM,Ln.BANDING,Ln.SCENARIO_EXPANDER,Ln.RATING_STEP,Ln.MODELLING,Ln.MODEL_SCORE,Ln.OPTIMISER,Ln.OPTIMISER_APPLY],bfn=Object.fromEntries(Object.entries(zI).map(([l,s])=>[l,s.icon])),Vfe=Object.fromEntries(Object.entries(zI).map(([l,s])=>[l,s.color])),akt=Object.fromEntries(Object.entries(zI).map(([l,s])=>[l,s.label]));function HMe(l,s=4){return l==null?"null":typeof l=="number"?Number.isInteger(l)?l.toLocaleString():l.toLocaleString(void 0,{maximumFractionDigits:s}):String(l)}function mfn(l){const s=HMe(l);return s.length>20?s.slice(0,18)+"…":s}function yX(l){return Math.abs(l)>=1e6?(l/1e6).toFixed(2)+"M":Math.abs(l)>=1e3?(l/1e3).toFixed(1)+"K":l.toFixed(4)}function fkt(l){if(l<60)return`${l.toFixed(0)}s`;const s=Math.floor(l/60),u=Math.floor(l%60);return`${s}m ${u}s`}const txt=l=>{let s;const u=new Set,h=(A,_)=>{const D=typeof A=="function"?A(s):A;if(!Object.is(D,s)){const I=s;s=_??(typeof D!="object"||D===null)?D:Object.assign({},s,D),u.forEach(B=>B(s,I))}},g=()=>s,k={setState:h,getState:g,getInitialState:()=>j,subscribe:A=>(u.add(A),()=>u.delete(A))},j=s=l(h,g,k);return k},wfn=(l=>l?txt(l):txt),vfn=l=>l;function yfn(l,s=vfn){const u=CX.useSyncExternalStore(l.subscribe,CX.useCallback(()=>s(l.getState()),[l,s]),CX.useCallback(()=>s(l.getInitialState()),[l,s]));return CX.useDebugValue(u),u}const xfn=l=>{const s=wfn(l),u=h=>yfn(s,h);return Object.assign(u,s),u},Bhe=(l=>xfn);class v8 extends Error{constructor(u,h,g){super(u);oEe(this,"status");oEe(this,"detail");this.name="ApiError",this.status=h,this.detail=g}}async function Ol(l,s={}){const{timeout:u=3e4,signal:h,...g}=s,w=new AbortController,p=setTimeout(()=>w.abort(),u);h&&(h.aborted?w.abort():h.addEventListener("abort",()=>w.abort(),{once:!0}));try{const k=await fetch(l,{...g,signal:w.signal});if(!k.ok){let j;try{const A=await k.json();j=A.detail||JSON.stringify(A)}catch{j=k.statusText}throw new v8(`HTTP ${k.status}`,k.status,j)}return await k.json()}finally{clearTimeout(p)}}function ia(l,s,u={}){return Ol(l,{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify(s),...u})}function QMe(l,s={}){return Ol(l,{method:"DELETE",...s})}function kfn(l){return Ol("/api/pipeline",l).catch(s=>{if(s instanceof v8&&s.status===404)return{nodes:[],edges:[]};throw s})}function hkt(l,s,u,h,g){return ia("/api/pipeline/preview",{graph:l,node_id:s,row_limit:u,scenario:h??"live"},{timeout:12e4,...g})}function Ofn(l,s){return ia("/api/pipeline/save",l,s)}function Sfn(l,s){return ia("/api/pipeline/trace",l,{timeout:12e4,...s})}function jfn(l,s,u,h){return ia("/api/pipeline/sink",{graph:l,node_id:s,scenario:u??"live"},{timeout:3e5,...h})}function Tfn(l,s){return ia("/api/submodel/create",l,s)}function Efn(l,s){return Ol(`/api/submodel/${encodeURIComponent(l)}`,s)}function Cfn(l,s){return ia("/api/submodel/dissolve",l,s)}function Mfn(l,s){return Ol(`/api/schema?path=${encodeURIComponent(l)}`,s)}function Afn(l,s){return Ol(`/api/schema/databricks?table=${encodeURIComponent(l)}`,s)}function Nfn(l){return Ol("/api/modelling/mlflow/check",l)}function _fn(l,s){return Ol(`/api/modelling/train/status/${encodeURIComponent(l)}`,s)}function Dfn(l,s){return ia("/api/modelling/train",{...l,scenario:l.scenario??"live"},s)}function Lfn(l,s){return ia("/api/modelling/estimate",l,{timeout:3e4,...s})}function Pfn(l,s){return ia("/api/modelling/export",l,s)}function Ifn(l,s){return ia("/api/modelling/mlflow/log",l,{timeout:12e4,...s})}function Rfn(l,s){return ia("/api/optimiser/solve",l,{timeout:3e5,...s})}function $fn(l,s){return Ol(`/api/optimiser/solve/status/${encodeURIComponent(l)}`,s)}function Bfn(l,s){return ia("/api/optimiser/save",l,s)}function zfn(l,s){return ia("/api/optimiser/mlflow/log",l,s)}function Ffn(l,s){return ia("/api/optimiser/frontier",l,{timeout:12e4,...s})}function qfn(l){return Ol("/api/databricks/warehouses",l)}function Hfn(l){return Ol("/api/databricks/catalogs",l)}function Qfn(l,s){return Ol(`/api/databricks/schemas?catalog=${encodeURIComponent(l)}`,s)}function Gfn(l,s,u){return Ol(`/api/databricks/tables?catalog=${encodeURIComponent(l)}&schema=${encodeURIComponent(s)}`,u)}function Ufn(l,s){return Ol(`/api/databricks/cache?table=${encodeURIComponent(l)}`,s)}function Jfn(l,s){return Ol(`/api/databricks/fetch/progress?table=${encodeURIComponent(l)}`,s)}function Xfn(l,s){return ia("/api/databricks/fetch",l,{timeout:3e5,...s})}function Vfn(l,s){return QMe(`/api/databricks/cache?table=${encodeURIComponent(l)}`,s)}function Wfn(l,s){return ia("/api/json-cache/build",l,{timeout:18e5,...s})}function Kfn(l,s){return Ol(`/api/json-cache/progress?path=${encodeURIComponent(l)}`,s)}function Yfn(l,s){return Ol(`/api/json-cache/status?path=${encodeURIComponent(l)}`,s)}function Zfn(l,s){return QMe(`/api/json-cache?path=${encodeURIComponent(l)}`,s)}function ehn(l){return Ol("/api/mlflow/experiments",l)}function thn(l,s,u){const h=new URLSearchParams({experiment_id:l});return s&&h.set("artifact_filter",s),Ol(`/api/mlflow/runs?${h.toString()}`,u)}function nhn(l){return Ol("/api/mlflow/models",l)}function ihn(l,s){return Ol(`/api/mlflow/model-versions?model_name=${encodeURIComponent(l)}`,s)}function rhn(l){return Ol("/api/utility",l)}function shn(l,s){return Ol(`/api/utility/${encodeURIComponent(l)}`,s)}function ohn(l,s){return ia("/api/utility",l,s)}function chn(l,s,u){return Ol(`/api/utility/${encodeURIComponent(l)}`,{method:"PUT",headers:{"Content-Type":"application/json"},body:JSON.stringify({content:s}),...u})}function lhn(l,s){return QMe(`/api/utility/${encodeURIComponent(l)}`,s)}function uhn(l,s,u){const h=new URLSearchParams({dir:l});return s&&h.set("extensions",s),Ol(`/api/files?${h.toString()}`,u)}function ahn(l){return Ol("/api/git/status",l)}function fhn(l){return Ol("/api/git/branches",l)}function hhn(l,s){return ia("/api/git/branches",{description:l},s)}function dhn(l,s){return ia("/api/git/switch",{branch:l},s)}function ghn(l){return ia("/api/git/save",{},l)}function phn(l){return ia("/api/git/submit",{},l)}function bhn(l,s){const u=`?limit=${l}`;return Ol(`/api/git/history${u}`,s)}function mhn(l,s){return ia("/api/git/revert",{sha:l},s)}function whn(l){return ia("/api/git/pull",{},l)}function vhn(l,s){return ia("/api/git/archive",{branch:l},s)}function yhn(l,s){return Ol("/api/git/branches",{method:"DELETE",headers:{"Content-Type":"application/json"},body:JSON.stringify({branch:l}),...s})}const Kc=Bhe()((l,s)=>({rowLimit:100,setRowLimit:u=>l({rowLimit:u}),collapsedSections:{},toggleSection:u=>l(h=>({collapsedSections:{...h.collapsedSections,[u]:!h.collapsedSections[u]}})),isSectionOpen:(u,h=!1)=>{const g=s().collapsedSections[u];return g===void 0?h:g},mlflow:{status:"pending",backend:"",host:""},_mlflowFetching:!1,_mlflowLastAttempt:0,fetchMlflow:()=>{const u=s(),h=u.mlflow.status==="error"&&Date.now()-u._mlflowLastAttempt>=1e4;if(u._mlflowFetching||u.mlflow.status!=="pending"&&!h)return;l({_mlflowFetching:!0,_mlflowLastAttempt:Date.now()});const g=new Promise((w,p)=>setTimeout(()=>p(new Error("MLflow check timed out after 5s")),5e3));Promise.race([Nfn(),g]).then(w=>{w.mlflow_installed?l({mlflow:{status:"connected",backend:w.backend||"local",host:w.databricks_host||""}}):l({mlflow:{status:"error",backend:"",host:""}})}).catch(w=>{console.warn("MLflow check failed:",w),l({mlflow:{status:"error",backend:"",host:""}})}).finally(()=>{l({_mlflowFetching:!1})})},scenarios:["live"],activeScenario:"live",setScenarios:u=>l({scenarios:u}),setActiveScenario:u=>l({activeScenario:u}),addScenario:u=>l(h=>{const g=u.trim().toLowerCase().replace(/\s+/g,"_");return!g||h.scenarios.includes(g)?h:{scenarios:[...h.scenarios,g]}}),removeScenario:u=>l(h=>u==="live"?h:{scenarios:h.scenarios.filter(w=>w!==u),activeScenario:h.activeScenario===u?"live":h.activeScenario}),fileListCache:{},setFileListCache:(u,h)=>l(g=>({fileListCache:{...g.fileListCache,[u]:{items:h,fetchedAt:Date.now()}}})),getFileListCache:u=>{const h=s().fileListCache[u];return!h||Date.now()-h.fetchedAt>3e4?null:h.items}}));function xhn(){const l=Kc(s=>s.mlflow);return{mlflowStatus:l.status==="pending"?"loading":l.status,mlflowBackend:l.backend}}const khn={ok:"#22c55e",error:"#ef4444",running:"#6366f1"};function Ohn({data:l,selected:s}){var Y,Z;const u=l,h=u.nodeType||Ln.TRANSFORM,g=bfn[h]||ukt,w=Vfe[h]||Vfe[Ln.TRANSFORM],p=akt[h]||"NODE",k=h===Ln.API_INPUT,j=h===Ln.LIVE_SWITCH,A=Kc(ee=>ee.activeScenario),_=j&&A==="live",D=!!((Y=u.config)!=null&&Y.instanceOf),I=dfn.has(h),B=gfn.has(h),F=!!u._traceActive,U=!!u._traceDimmed,K=u._traceValue;return E.jsxs("div",{className:"relative rounded-xl min-w-[180px] max-w-[260px] cursor-pointer",style:{background:"var(--bg-elevated)",border:F?`1.5px solid ${w}`:s?`1.5px solid ${w}`:D?`1.5px dashed ${w}60`:"1px solid var(--border-bright)",boxShadow:F?`0 0 12px ${w}40, var(--node-shadow)`:"var(--node-shadow)",opacity:U?.3:1,transition:"border-color 0.15s ease, opacity 0.2s ease, box-shadow 0.2s ease"},children:[E.jsx("div",{className:"absolute left-0 top-3 bottom-3 w-[3px] rounded-full",style:{backgroundColor:w,opacity:s?1:.6,transition:"opacity 0.2s ease"}}),!I&&E.jsx(Gw,{type:"target",position:br.Left}),E.jsxs("div",{className:"pl-4 pr-3 py-2.5",children:[E.jsxs("div",{className:"flex items-center gap-2 mb-1",children:[E.jsx(g,{size:12,style:{color:w},className:"shrink-0 opacity-80"}),E.jsx("span",{className:"text-[10px] font-bold uppercase tracking-[0.1em] shrink-0",style:{color:w,opacity:.8},children:p}),D&&E.jsxs("span",{className:"ml-auto inline-flex items-center gap-0.5 px-1.5 py-0.5 rounded-full text-[9px] font-bold uppercase tracking-[0.08em] shrink-0",style:{background:`${w}15`,color:w,border:`1px solid ${w}25`},title:`Instance of ${(Z=u.config)==null?void 0:Z.instanceOf}`,children:[E.jsx(zMe,{size:8}),"Instance"]}),k&&E.jsxs("span",{className:"ml-auto inline-flex items-center gap-0.5 px-1.5 py-0.5 rounded-full text-[9px] font-bold uppercase tracking-[0.08em] shrink-0",style:{background:"rgba(34,197,94,.12)",color:"#22c55e",border:"1px solid rgba(34,197,94,.2)"},children:[E.jsx(FMe,{size:8}),"API"]}),_&&E.jsx("span",{className:"ml-auto inline-flex items-center px-1.5 py-0.5 rounded-full text-[9px] font-bold uppercase tracking-[0.08em] shrink-0",style:{background:"rgba(34,197,94,.12)",color:"#22c55e",border:"1px solid rgba(34,197,94,.2)"},children:"LIVE"}),u._status&&E.jsx("span",{className:`${k?"":"ml-auto "} w-[7px] h-[7px] rounded-full shrink-0 ${u._status==="running"?"animate-pulse-dot":""}`,style:{backgroundColor:khn[u._status]}})]}),E.jsx("div",{className:"font-semibold text-[13px] leading-tight truncate",style:{color:"var(--text-primary)"},children:u.label}),F&&K!==void 0&&E.jsx("div",{className:"mt-1 px-1.5 py-0.5 rounded text-[11px] font-mono truncate",style:{background:`${w}18`,color:w,border:`1px solid ${w}30`,maxWidth:"100%"},children:mfn(K)})]}),!B&&E.jsx(Gw,{type:"source",position:br.Right})]})}const l0=pe.memo(Ohn),Uk=Vfe.submodel||"#f97316";function Shn({data:l,selected:s}){const u=l,h=u.config||{},g=h.inputPorts||[],w=h.outputPorts||[],p=(h.childNodeIds||[]).length,k=!!u._traceActive,j=!!u._traceDimmed;return E.jsxs("div",{className:"relative rounded-xl min-w-[200px] max-w-[280px] cursor-pointer",style:{background:"var(--bg-elevated)",border:k?`1.5px solid ${Uk}`:s?`1.5px solid ${Uk}`:"1.5px dashed var(--border-bright)",boxShadow:k?`0 0 12px ${Uk}40, var(--node-shadow)`:"var(--node-shadow)",opacity:j?.3:1,transition:"border-color 0.15s ease, opacity 0.2s ease, box-shadow 0.2s ease"},children:[E.jsx("div",{className:"absolute left-0 top-3 bottom-3 w-[3px] rounded-full",style:{backgroundColor:Uk,opacity:s?1:.6,transition:"opacity 0.2s ease"}}),g.map(A=>E.jsx(Gw,{id:`in__${A}`,type:"target",position:br.Left,style:{top:"50%",opacity:0,width:0,height:0,pointerEvents:"none"}},`in__${A}`)),E.jsx(Gw,{type:"target",position:br.Left}),E.jsxs("div",{className:"pl-4 pr-3 py-2.5",children:[E.jsxs("div",{className:"flex items-center gap-2 mb-1",children:[E.jsx(jV,{size:12,style:{color:Uk},className:"shrink-0 opacity-80"}),E.jsx("span",{className:"text-[10px] font-bold uppercase tracking-[0.1em] shrink-0",style:{color:Uk,opacity:.8},children:"SUBMODEL"}),E.jsxs("span",{className:"ml-auto text-[9px] font-mono px-1.5 py-0.5 rounded-full",style:{background:`${Uk}18`,color:Uk,border:`1px solid ${Uk}30`},children:[p," nodes"]})]}),E.jsx("div",{className:"font-semibold text-[13px] leading-tight truncate",style:{color:"var(--text-primary)"},children:u.label}),h.file&&E.jsx("div",{className:"text-[10px] truncate mt-0.5",style:{color:"var(--text-muted)"},children:h.file}),w.length>0&&E.jsx("div",{className:"flex flex-col gap-0.5 items-end mt-1.5",children:w.map(A=>E.jsxs("span",{className:"text-[9px] font-mono",style:{color:"var(--text-muted)"},children:[A," →"]},A))})]}),w.length>0?w.map((A,_)=>E.jsx(Gw,{id:`out__${A}`,type:"source",position:br.Right,style:{top:`${(_+1)/(w.length+1)*100}%`}},`out__${A}`)):E.jsx(Gw,{type:"source",position:br.Right})]})}const jhn=pe.memo(Shn),TEe="#94a3b8";function Thn({data:l}){const s=l,u=s.portDirection==="input",h=u?K5t:Pun,g=!!s._traceActive,w=!!s._traceDimmed;return E.jsxs("div",{className:"relative rounded-full px-4 py-2 flex items-center gap-2 min-w-[120px]",style:{background:"var(--bg-elevated)",border:g?"1.5px solid var(--accent)":`1.5px dashed ${TEe}40`,boxShadow:g?"0 0 10px rgba(96,165,250,.35)":"none",opacity:w?.3:.85,transition:"border-color 0.15s ease, opacity 0.2s ease, box-shadow 0.2s ease"},children:[!u&&E.jsx(Gw,{type:"target",position:br.Left}),E.jsx(h,{size:12,style:{color:TEe},className:"shrink-0"}),E.jsx("span",{className:"text-[11px] font-mono font-medium truncate",style:{color:TEe},children:s.portName||s.label}),u&&E.jsx(Gw,{type:"source",position:br.Right})]})}const Ehn=pe.memo(Thn);function Chn(l,s){const u=zI[s];l.dataTransfer.setData("application/reactflow-type",s),l.dataTransfer.setData("application/reactflow-config",JSON.stringify(u.defaultConfig)),l.dataTransfer.effectAllowed="move"}function Mhn({onCollapse:l,nodes:s}){const u=new Set;if(s)for(const h of s){const g=h.data.nodeType;g&&ext.has(g)&&u.add(g)}return E.jsxs("div",{className:"w-[180px] h-full overflow-y-auto shrink-0 flex flex-col",style:{background:"var(--chrome)",borderRight:"1px solid var(--chrome-border)"},children:[E.jsxs("div",{className:"px-4 py-3 flex items-center justify-between",children:[E.jsx("h2",{className:"text-[11px] font-bold uppercase tracking-[0.1em]",style:{color:"var(--text-muted)"},children:"Nodes"}),l&&E.jsx("button",{onClick:l,className:"p-0.5 rounded transition-colors",style:{color:"var(--text-muted)"},onMouseEnter:h=>{h.currentTarget.style.background="var(--chrome-hover)",h.currentTarget.style.color="var(--text-secondary)"},onMouseLeave:h=>{h.currentTarget.style.background="transparent",h.currentTarget.style.color="var(--text-muted)"},title:"Collapse palette",children:E.jsx(Can,{size:14})})]}),E.jsx("div",{className:"px-2 space-y-0.5 flex-1",children:pfn.map(h=>{const g=zI[h],w=g.icon,p=ext.has(h)&&u.has(h);return E.jsxs("div",{draggable:!p,onDragStart:k=>{p||Chn(k,h)},className:`flex items-center gap-2.5 px-2.5 py-2 rounded-lg transition-colors ${p?"opacity-35 cursor-not-allowed":"cursor-grab active:cursor-grabbing"}`,style:{"--hover-bg":"var(--chrome-hover)"},onMouseEnter:k=>{p||(k.currentTarget.style.background="var(--chrome-hover)")},onMouseLeave:k=>k.currentTarget.style.background="transparent",title:p?`Only one ${g.name} allowed per pipeline`:g.description,children:[E.jsx("div",{className:"w-6 h-6 rounded-md flex items-center justify-center shrink-0",style:{background:`${g.color}18`},children:E.jsx(w,{size:13,style:{color:g.color}})}),E.jsx("span",{className:"text-[13px] font-medium",style:{color:"var(--text-primary)"},children:g.name})]},h)})})]})}function ECe(l){let s=l.trim().replace(/[\s-]/g,"_");return s=s.replace(/[^a-zA-Z0-9_]/g,""),s&&/^[0-9]/.test(s)&&(s=`node_${s}`),s||"unnamed_node"}function Ahn(l){let s=5381;for(let u=0;u<l.length;u++)s=(s<<5)+s+l.charCodeAt(u)|0;return(s>>>0).toString(36)}function dkt(l){const{_nodeId:s,_columns:u,_schemaWarnings:h,...g}=l;return Ahn(JSON.stringify(g))}const ll=Bhe()((l,s)=>({previews:{},columnCache:{},solveResults:{},solveJobs:{},trainResults:{},trainJobs:{},graphVersion:0,setColumns:(u,h,g)=>l(w=>({columnCache:{...w.columnCache,[u]:{columns:h,graphVersion:g}}})),getColumns:u=>{const h=s().columnCache[u];return h?{columns:h.columns,fresh:h.graphVersion===s().graphVersion}:null},setPreview:(u,h,g)=>l(w=>({previews:{...w.previews,[u]:{data:h,graphVersion:g}}})),getPreview:u=>s().previews[u]??null,bumpGraphVersion:()=>l(u=>({graphVersion:u.graphVersion+1})),startSolveJob:(u,h,g,w,p)=>l(k=>({solveJobs:{...k.solveJobs,[u]:{jobId:h,nodeId:u,nodeLabel:g,progress:null,error:null,constraints:w,configHash:p}}})),updateSolveProgress:(u,h)=>l(g=>{const w=g.solveJobs[u];return w?{solveJobs:{...g.solveJobs,[u]:{...w,progress:h}}}:g}),completeSolveJob:(u,h)=>l(g=>{const w=g.solveJobs[u];if(!w)return g;const{[u]:p,...k}=g.solveJobs;return{solveJobs:k,solveResults:{...g.solveResults,[u]:{result:h,jobId:w.jobId,configHash:w.configHash,constraints:w.constraints,nodeLabel:w.nodeLabel}}}}),failSolveJob:(u,h)=>l(g=>{const w=g.solveJobs[u];return w?{solveJobs:{...g.solveJobs,[u]:{...w,progress:null,error:h}}}:g}),startTrainJob:(u,h,g,w)=>l(p=>({trainJobs:{...p.trainJobs,[u]:{jobId:h,nodeId:u,nodeLabel:g,progress:null,error:null,configHash:w}}})),updateTrainProgress:(u,h)=>l(g=>{const w=g.trainJobs[u];return w?{trainJobs:{...g.trainJobs,[u]:{...w,progress:h}}}:g}),completeTrainJob:(u,h)=>l(g=>{const w=g.trainJobs[u],{[u]:p,...k}=g.trainJobs;return{trainJobs:k,trainResults:{...g.trainResults,[u]:{result:h,jobId:(w==null?void 0:w.jobId)??"",configHash:(w==null?void 0:w.configHash)??""}}}}),failTrainJob:(u,h)=>l(g=>{const w=g.trainJobs[u];return w?{trainJobs:{...g.trainJobs,[u]:{...w,progress:null,error:h}}}:g}),getOptimiserPreview:u=>{const h=s().solveResults[u];return h?{result:h.result,jobId:h.jobId,constraints:h.constraints,nodeLabel:h.nodeLabel}:null},clearNode:u=>l(h=>{const{[u]:g,...w}=h.previews,{[u]:p,...k}=h.columnCache,{[u]:j,...A}=h.solveResults,{[u]:_,...D}=h.solveJobs,{[u]:I,...B}=h.trainResults,{[u]:F,...U}=h.trainJobs;return{previews:w,columnCache:k,solveResults:A,solveJobs:D,trainResults:B,trainJobs:U}})}));function ni(l,s,u){return l[s]??u}function ZX(l,s,u,h){return{nodes:l.map(g=>({id:g.id,type:g.type||g.data.nodeType,data:g.data,position:{x:0,y:0}})),edges:s,submodels:u,preamble:h}}function gkt(l,s,u,h){return s.current?{nodes:s.current.nodes,edges:s.current.edges,submodels:s.current.submodels,preamble:h.current}:{nodes:l.current.nodes,edges:l.current.edges,submodels:u.current,preamble:h.current}}function Nhn({config:l,onUpdate:s,columns:u,target:h,weight:g,task:w}){return E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Target & Weight"}),E.jsxs("div",{className:"mt-1.5 space-y-2",children:[E.jsxs("div",{children:[E.jsx("label",{className:"text-xs",style:{color:"var(--text-secondary)"},children:"Target column"}),E.jsxs("select",{value:h,onChange:p=>s("target",p.target.value),className:"w-full mt-0.5 px-2.5 py-1.5 rounded-lg text-xs font-mono",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"},children:[E.jsx("option",{value:"",children:"Select target..."}),u.map(p=>E.jsxs("option",{value:p.name,children:[p.name," (",p.dtype,")"]},p.name))]})]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-xs",style:{color:"var(--text-secondary)"},children:"Weight column (optional)"}),E.jsxs("select",{value:g,onChange:p=>s("weight",p.target.value),className:"w-full mt-0.5 px-2.5 py-1.5 rounded-lg text-xs font-mono",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"},children:[E.jsx("option",{value:"",children:"None"}),u.map(p=>E.jsx("option",{value:p.name,children:p.name},p.name))]})]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-xs",style:{color:"var(--text-secondary)"},children:"Offset column (optional, e.g. log-exposure)"}),E.jsxs("select",{value:ni(l,"offset",""),onChange:p=>s("offset",p.target.value||null),className:"w-full mt-0.5 px-2.5 py-1.5 rounded-lg text-xs font-mono",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"},children:[E.jsx("option",{value:"",children:"None"}),u.map(p=>E.jsx("option",{value:p.name,children:p.name},p.name))]})]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-xs",style:{color:"var(--text-secondary)"},children:"Task"}),E.jsx("div",{className:"flex gap-2 mt-0.5",children:["regression","classification"].map(p=>E.jsx("button",{onClick:()=>{s("task",p),s("metrics",p==="regression"?["gini","rmse"]:["auc","logloss"])},className:"px-3 py-1 rounded-md text-xs font-medium transition-colors",style:{background:w===p?"var(--accent-soft)":"var(--input-bg)",color:w===p?"var(--accent)":"var(--text-secondary)",border:`1px solid ${w===p?"var(--accent)":"var(--border)"}`},children:p},p))})]})]})]})}const _hn=["RMSE","MAE","Poisson","Tweedie"],Dhn=["Logloss","CrossEntropy"];function Lhn({config:l,onUpdate:s,columns:u,target:h,weight:g,exclude:w,algorithm:p,task:k,params:j,featureCount:A,advancedOpen:_,toggleSection:D,onParamUpdate:I}){return E.jsxs(E.Fragment,{children:[E.jsxs("div",{children:[E.jsxs("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:["Features ",u.length>0&&E.jsxs("span",{className:"font-normal",children:["(",A," of ",u.length,")"]})]}),E.jsxs("div",{className:"mt-1.5",children:[E.jsx("label",{className:"text-xs",style:{color:"var(--text-secondary)"},children:"Exclude columns"}),E.jsx("div",{className:"mt-1 flex flex-wrap gap-1",children:u.filter(B=>B.name!==h&&B.name!==g).map(B=>{const F=w.includes(B.name);return E.jsx("button",{onClick:()=>{const U=F?w.filter(K=>K!==B.name):[...w,B.name];s("exclude",U)},className:"px-2 py-0.5 rounded text-[11px] font-mono transition-colors",style:{background:F?"rgba(239,68,68,.15)":"var(--chrome-hover)",color:F?"#ef4444":"var(--text-secondary)",textDecoration:F?"line-through":"none"},children:B.name},B.name)})})]})]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Algorithm"}),E.jsxs("div",{className:"mt-1.5 space-y-2",children:[E.jsx("select",{value:p,onChange:B=>s("algorithm",B.target.value),className:"w-full px-2.5 py-1.5 rounded-lg text-xs font-mono",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"},children:E.jsx("option",{value:"catboost",children:"CatBoost"})}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:"Loss function"}),E.jsxs("select",{value:ni(l,"loss_function",""),onChange:B=>s("loss_function",B.target.value||null),className:"w-full mt-0.5 px-2.5 py-1.5 rounded-lg text-xs font-mono",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"},children:[E.jsx("option",{value:"",children:"Default"}),(k==="classification"?Dhn:_hn).map(B=>E.jsx("option",{value:B,children:B},B))]})]}),ni(l,"loss_function","")==="Tweedie"&&E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:"Variance power (1.0=Poisson, 2.0=Gamma)"}),E.jsx("input",{type:"range",min:1,max:2,step:.05,value:ni(l,"variance_power",1.5),onChange:B=>s("variance_power",parseFloat(B.target.value)),className:"w-full mt-0.5"}),E.jsx("div",{className:"text-[11px] font-mono text-right",style:{color:"var(--text-muted)"},children:ni(l,"variance_power",1.5).toFixed(2)})]}),E.jsx("div",{className:"grid grid-cols-2 gap-2",children:[{key:"iterations",label:"Iterations",default:1e3,step:1},{key:"learning_rate",label:"Learning Rate",default:.05,step:.01},{key:"depth",label:"Depth",default:6,step:1},{key:"l2_leaf_reg",label:"L2 Reg",default:3,step:.1}].map(B=>E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:B.label}),E.jsx("input",{type:"number",step:B.step,value:j[B.key]??B.default,onChange:F=>I(B.key,parseFloat(F.target.value)||B.default),className:"w-full mt-0.5 px-2 py-1 rounded text-xs font-mono",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"}})]},B.key))}),E.jsx("div",{className:"grid grid-cols-2 gap-2",children:[{key:"random_strength",label:"Random Strength",default:1,step:.1},{key:"bagging_temperature",label:"Bagging Temp",default:1,step:.1},{key:"min_data_in_leaf",label:"Min Data in Leaf",default:1,step:1},{key:"border_count",label:"Border Count",default:254,step:1}].map(B=>E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:B.label}),E.jsx("input",{type:"number",step:B.step,value:j[B.key]??B.default,onChange:F=>I(B.key,parseFloat(F.target.value)||B.default),className:"w-full mt-0.5 px-2 py-1 rounded text-xs font-mono",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"}})]},B.key))}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:"Grow policy"}),E.jsx("select",{value:ni(j,"grow_policy","SymmetricTree"),onChange:B=>I("grow_policy",B.target.value),className:"w-full mt-0.5 px-2.5 py-1.5 rounded-lg text-xs font-mono",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"},children:["SymmetricTree","Lossguide","Depthwise"].map(B=>E.jsx("option",{value:B,children:B},B))})]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:"Early stopping rounds (0 = disabled)"}),E.jsx("input",{type:"number",min:0,step:1,value:j.early_stopping_rounds??50,onChange:B=>I("early_stopping_rounds",parseInt(B.target.value)||0),className:"w-full mt-0.5 px-2 py-1 rounded text-xs font-mono",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"}})]}),E.jsxs("label",{className:"flex items-center gap-2 cursor-pointer select-none",children:[E.jsx("input",{type:"checkbox",checked:j.task_type==="GPU",onChange:B=>I("task_type",B.target.checked?"GPU":"CPU"),className:"accent-purple-500"}),E.jsx("span",{className:"text-[11px]",style:{color:"var(--text-primary)"},children:"GPU training"}),E.jsx("span",{className:"text-[10px]",style:{color:"var(--text-muted)"},children:"(CUDA)"})]}),E.jsxs("button",{onClick:()=>D("modelling.advanced"),className:"flex items-center gap-1 text-[11px]",style:{color:"var(--text-muted)"},children:[_?E.jsx(Vw,{size:12}):E.jsx(NI,{size:12}),"Advanced params (JSON)"]}),_&&E.jsx("textarea",{value:JSON.stringify(j,null,2),onChange:B=>{try{s("params",JSON.parse(B.target.value))}catch{}},rows:6,className:"w-full px-2.5 py-2 rounded-lg text-xs font-mono",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"}})]})]})]})}const Phn=["gini","rmse","mae","mse","r2","poisson_deviance","tweedie_deviance"],Ihn=["auc","logloss"];function Rhn({config:l,onUpdate:s,columns:u,target:h,weight:g,exclude:w,task:p,split:k,metrics:j,mlflowOpen:A,monotonicOpen:_,toggleSection:D,onSplitUpdate:I}){const B=p==="classification"?Ihn:Phn;return E.jsxs(E.Fragment,{children:[E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Split Strategy"}),E.jsxs("div",{className:"mt-1.5 space-y-2",children:[E.jsx("div",{className:"flex gap-2",children:["random","temporal","group"].map(F=>E.jsx("button",{onClick:()=>I("strategy",F),className:"px-3 py-1 rounded-md text-xs font-medium transition-colors",style:{background:k.strategy===F?"var(--accent-soft)":"var(--input-bg)",color:k.strategy===F?"var(--accent)":"var(--text-secondary)",border:`1px solid ${k.strategy===F?"var(--accent)":"var(--border)"}`},children:F},F))}),k.strategy==="random"&&E.jsxs("div",{className:"grid grid-cols-2 gap-2",children:[E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:"Test size"}),E.jsx("input",{type:"number",step:.05,min:.05,max:.5,value:k.test_size??.2,onChange:F=>I("test_size",parseFloat(F.target.value)||.2),className:"w-full mt-0.5 px-2 py-1 rounded text-xs font-mono",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"}})]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:"Seed"}),E.jsx("input",{type:"number",value:k.seed??42,onChange:F=>I("seed",parseInt(F.target.value)||42),className:"w-full mt-0.5 px-2 py-1 rounded text-xs font-mono",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"}})]})]}),k.strategy==="temporal"&&E.jsxs("div",{className:"space-y-2",children:[E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:"Date column"}),E.jsxs("select",{value:ni(k,"date_column",""),onChange:F=>I("date_column",F.target.value),className:"w-full mt-0.5 px-2.5 py-1.5 rounded-lg text-xs font-mono",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"},children:[E.jsx("option",{value:"",children:"Select..."}),u.map(F=>E.jsx("option",{value:F.name,children:F.name},F.name))]})]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:"Cutoff date"}),E.jsx("input",{type:"date",value:ni(k,"cutoff_date",""),onChange:F=>I("cutoff_date",F.target.value),className:"w-full mt-0.5 px-2.5 py-1.5 rounded-lg text-xs font-mono",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"}})]})]}),k.strategy==="group"&&E.jsxs("div",{className:"space-y-2",children:[E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:"Group column"}),E.jsxs("select",{value:ni(k,"group_column",""),onChange:F=>I("group_column",F.target.value),className:"w-full mt-0.5 px-2.5 py-1.5 rounded-lg text-xs font-mono",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"},children:[E.jsx("option",{value:"",children:"Select..."}),u.map(F=>E.jsx("option",{value:F.name,children:F.name},F.name))]})]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:"Test size"}),E.jsx("input",{type:"number",step:.05,min:.05,max:.5,value:k.test_size??.2,onChange:F=>I("test_size",parseFloat(F.target.value)||.2),className:"w-full mt-0.5 px-2 py-1 rounded text-xs font-mono",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"}})]})]}),E.jsxs("div",{className:"flex items-center gap-2 mt-2",children:[E.jsx("label",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:"Cross-validate"}),E.jsx("button",{onClick:()=>s("cv_folds",l.cv_folds?null:5),className:"px-2 py-0.5 rounded text-[11px] font-mono",style:{background:l.cv_folds?"rgba(168,85,247,.15)":"var(--chrome-hover)",color:l.cv_folds?"#a855f7":"var(--text-muted)",border:`1px solid ${l.cv_folds?"rgba(168,85,247,.3)":"transparent"}`},children:l.cv_folds?"On":"Off"}),!!l.cv_folds&&E.jsxs("div",{className:"flex items-center gap-1",children:[E.jsx("label",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:"Folds:"}),E.jsx("input",{type:"number",min:2,max:20,step:1,value:ni(l,"cv_folds",5),onChange:F=>s("cv_folds",parseInt(F.target.value)||5),className:"w-14 px-2 py-0.5 rounded text-xs font-mono",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"}})]})]}),(()=>{const F=typeof l.row_limit=="number"?l.row_limit:null;return E.jsxs("div",{className:"flex items-center gap-2 mt-2",children:[E.jsx("label",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:"Row limit"}),E.jsx("input",{type:"number",min:0,step:1e5,value:F??"",onChange:U=>{const K=U.target.value;s("row_limit",K===""?null:Math.max(0,parseInt(K)||0))},placeholder:"All rows",className:"w-32 px-2 py-0.5 rounded text-xs font-mono",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"}}),F!=null&&F>0&&E.jsxs("span",{className:"text-[10px] font-mono",style:{color:"var(--text-muted)"},children:[F.toLocaleString()," rows"]})]})})()]})]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Metrics"}),E.jsx("div",{className:"mt-1.5 flex flex-wrap gap-1.5",children:B.map(F=>{const U=j.includes(F);return E.jsx("button",{onClick:()=>{const K=U?j.filter(Y=>Y!==F):[...j,F];s("metrics",K)},className:"px-2.5 py-1 rounded-md text-xs font-mono transition-colors",style:{background:U?"rgba(168,85,247,.15)":"var(--chrome-hover)",color:U?"#a855f7":"var(--text-muted)",border:`1px solid ${U?"rgba(168,85,247,.3)":"transparent"}`},children:F},F)})})]}),E.jsxs("div",{children:[E.jsxs("button",{onClick:()=>D("modelling.mlflow"),className:"flex items-center gap-1 text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:[A?E.jsx(Vw,{size:12}):E.jsx(NI,{size:12}),"MLflow Logging"]}),A&&E.jsxs("div",{className:"mt-1.5 space-y-2",children:[E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:"Experiment path"}),E.jsx("input",{type:"text",placeholder:"/Shared/haute/experiment",value:ni(l,"mlflow_experiment",""),onChange:F=>s("mlflow_experiment",F.target.value),className:"w-full mt-0.5 px-2.5 py-1.5 rounded-lg text-xs font-mono",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"}})]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:"Model name (registered model)"}),E.jsx("input",{type:"text",placeholder:"Optional",value:ni(l,"model_name",""),onChange:F=>s("model_name",F.target.value),className:"w-full mt-0.5 px-2.5 py-1.5 rounded-lg text-xs font-mono",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"}})]})]})]}),u.length>0&&E.jsxs("div",{children:[E.jsxs("button",{onClick:()=>D("modelling.monotonic"),className:"flex items-center gap-1 text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:[_?E.jsx(Vw,{size:12}):E.jsx(NI,{size:12}),"Monotonic Constraints"]}),_&&E.jsxs("div",{className:"mt-1.5 space-y-1",children:[E.jsx("div",{className:"text-[10px]",style:{color:"var(--text-muted)"},children:"Set per-feature constraints (numeric features only)"}),u.filter(F=>F.name!==h&&F.name!==g&&!w.includes(F.name)&&!["Utf8","Categorical","String"].includes(F.dtype)).map(F=>{const U=ni(l,"monotone_constraints",{}),K=U[F.name]??0;return E.jsxs("div",{className:"flex items-center gap-2",children:[E.jsx("span",{className:"text-[11px] font-mono flex-1 truncate",style:{color:"var(--text-secondary)"},children:F.name}),[-1,0,1].map(Y=>E.jsx("button",{onClick:()=>{const Z={...U};Y===0?delete Z[F.name]:Z[F.name]=Y,s("monotone_constraints",Object.keys(Z).length>0?Z:null)},className:"px-1.5 py-0.5 rounded text-[10px] font-mono",style:{background:K===Y?Y===1?"rgba(34,197,94,.15)":Y===-1?"rgba(239,68,68,.15)":"var(--accent-soft)":"var(--chrome-hover)",color:K===Y?Y===1?"#22c55e":Y===-1?"#ef4444":"var(--accent)":"var(--text-muted)",border:`1px solid ${K===Y?Y===1?"rgba(34,197,94,.3)":Y===-1?"rgba(239,68,68,.3)":"var(--accent)":"transparent"}`},children:Y===1?"+1":Y===-1?"-1":"0"},Y))]},F.name)})]})]})]})}function $hn({lossHistory:l,bestIteration:s}){if(!l||l.length<2)return null;const u=Object.keys(l[0]).filter(ee=>ee!=="iteration"),h=u.find(ee=>ee.startsWith("train_")),g=u.find(ee=>ee.startsWith("eval_"));if(!h)return null;const w=280,p=80,k=4,j=4,A=w-k*2,_=p-j*2,D=[];for(const ee of l)h&&ee[h]!=null&&D.push(ee[h]),g&&ee[g]!=null&&D.push(ee[g]);const I=Math.min(...D),F=Math.max(...D)-I||1,U=ee=>k+ee/(l.length-1)*A,K=ee=>j+_-(ee-I)/F*_,Y=ee=>l.map((fe,be)=>fe[ee]!=null?`${be===0?"M":"L"}${U(be).toFixed(1)},${K(fe[ee]).toFixed(1)}`:null).filter(Boolean).join(" "),Z=s!=null?U(Math.min(s,l.length-1)):null;return E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Loss Curve"}),E.jsxs("svg",{width:w,height:p,className:"mt-1",style:{background:"var(--input-bg)",borderRadius:6,border:"1px solid var(--border)"},children:[E.jsx("path",{d:Y(h),fill:"none",stroke:"#a855f7",strokeWidth:1.5}),g&&E.jsx("path",{d:Y(g),fill:"none",stroke:"#22c55e",strokeWidth:1.5}),Z!=null&&E.jsx("line",{x1:Z,y1:j,x2:Z,y2:j+_,stroke:"#f59e0b",strokeWidth:1,strokeDasharray:"3,2"})]}),E.jsxs("div",{className:"flex gap-3 mt-1 text-[10px]",style:{color:"var(--text-muted)"},children:[E.jsxs("span",{children:[E.jsx("span",{style:{color:"#a855f7"},children:"--"})," Train"]}),g&&E.jsxs("span",{children:[E.jsx("span",{style:{color:"#22c55e"},children:"--"})," Eval"]}),Z!=null&&E.jsxs("span",{children:[E.jsx("span",{style:{color:"#f59e0b"},children:"|"})," Best iter"]})]})]})}function Bhn({trainResult:l}){var p,k,j;const[s,u]=pe.useState("prediction");if(l.feature_importance.length===0)return null;const h=[{key:"prediction",label:"Prediction"},...(p=l.feature_importance_loss)!=null&&p.length?[{key:"loss",label:"Loss"}]:[],...(k=l.shap_summary)!=null&&k.length?[{key:"shap",label:"SHAP"}]:[]],g=s==="shap"?(l.shap_summary||[]).slice(0,10).map(A=>({feature:A.feature,importance:A.mean_abs_shap})):s==="loss"?(l.feature_importance_loss||[]).slice(0,10):l.feature_importance.slice(0,10),w=((j=g[0])==null?void 0:j.importance)||1;return E.jsxs("div",{children:[E.jsxs("div",{className:"flex items-center gap-2 mb-1",children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Top Features"}),h.length>1&&E.jsx("div",{className:"flex gap-1",children:h.map(A=>E.jsx("button",{onClick:()=>u(A.key),className:"px-1.5 py-0.5 rounded text-[10px]",style:{background:s===A.key?"var(--accent-soft)":"var(--chrome-hover)",color:s===A.key?"var(--accent)":"var(--text-muted)"},children:A.label},A.key))})]}),E.jsx("div",{className:"space-y-0.5",children:g.map((A,_)=>E.jsxs("div",{className:"flex items-center gap-2 text-xs font-mono",children:[E.jsx("span",{className:"truncate flex-1",style:{color:"var(--text-secondary)"},children:A.feature}),E.jsx("div",{className:"w-20 h-1.5 rounded-full overflow-hidden",style:{background:"var(--chrome-hover)"},children:E.jsx("div",{className:"h-full rounded-full",style:{width:`${Math.abs(A.importance)/Math.abs(w)*100}%`,background:"#a855f7"}})}),E.jsx("span",{className:"w-12 text-right",style:{color:"var(--text-muted)"},children:A.importance.toFixed(1)})]},_))})]})}function zhn({trainJobId:l,mlflowBackend:s,config:u,onMlflowResult:h}){const[g,w]=pe.useState(!1),[p,k]=pe.useState(null),j=pe.useCallback(async()=>{w(!0),k(null),h==null||h(null);try{const A=await Ifn({job_id:l,experiment_name:ni(u,"mlflow_experiment","")||null,model_name:ni(u,"model_name","")||null});k(A),h==null||h(A)}catch(A){const _={status:"error",error:String(A)};k(_),h==null||h(_)}finally{w(!1)}},[l,u,h]);return E.jsxs("div",{className:"space-y-1.5",children:[E.jsxs("button",{onClick:j,disabled:g,className:"w-full flex items-center justify-center gap-2 px-3 py-2 rounded-lg text-xs font-medium transition-colors",style:{background:g?"var(--chrome-hover)":"rgba(59,130,246,.15)",color:g?"var(--text-muted)":"#3b82f6",border:"1px solid rgba(59,130,246,.3)"},children:[g?E.jsx(Ey,{size:14,className:"animate-spin"}):E.jsx(BMe,{size:14}),g?"Logging...":`Log to MLflow (${s.backend})`]}),p&&p.status==="ok"&&E.jsxs("div",{className:"px-3 py-2 rounded-lg text-xs space-y-0.5",style:{background:"rgba(59,130,246,.08)",border:"1px solid rgba(59,130,246,.2)"},children:[E.jsxs("div",{style:{color:"#3b82f6"},children:["Logged to ",p.experiment_name]}),p.run_url&&E.jsx("a",{href:p.run_url,target:"_blank",rel:"noreferrer",className:"underline",style:{color:"#60a5fa"},children:"Open in Databricks"}),!p.run_url&&p.tracking_uri&&E.jsxs("div",{style:{color:"var(--text-muted)"},children:["Run ID: ",p.run_id]})]}),p&&p.status==="error"&&E.jsx("div",{className:"px-3 py-2 rounded-lg text-xs",style:{background:"rgba(239,68,68,.08)",border:"1px solid rgba(239,68,68,.2)",color:"#fca5a5"},children:p.error})]})}function Fhn({trainProgress:l}){return E.jsxs("div",{className:"px-3 py-2.5 rounded-lg text-xs space-y-2",style:{background:"rgba(168,85,247,.06)",border:"1px solid rgba(168,85,247,.2)"},children:[E.jsxs("div",{className:"space-y-1",children:[E.jsxs("div",{className:"flex justify-between text-[11px]",children:[E.jsx("span",{style:{color:"#a855f7"},children:l.message||"Training..."}),E.jsx("span",{style:{color:"var(--text-muted)"},children:fkt(l.elapsed_seconds)})]}),E.jsx("div",{className:"w-full h-1.5 rounded-full overflow-hidden",style:{background:"rgba(168,85,247,.15)"},children:E.jsx("div",{className:"h-full rounded-full transition-all duration-300",style:{width:`${Math.max(l.progress*100,2)}%`,background:"#a855f7"}})})]}),l.total_iterations>0&&E.jsxs("div",{className:"flex gap-4 text-[11px] font-mono",style:{color:"var(--text-secondary)"},children:[E.jsxs("span",{children:["Round ",E.jsx("span",{style:{color:"var(--text-primary)"},children:l.iteration}),"/",l.total_iterations]}),Object.entries(l.train_loss).map(([s,u])=>E.jsxs("span",{children:[s,": ",E.jsx("span",{style:{color:"var(--text-primary)"},children:u.toFixed(4)})]},s))]})]})}function qhn({config:l,target:s,params:u,training:h,trainProgress:g,trainResult:w,trainJobId:p,isStale:k,exporting:j,exportedScript:A,mlflowBackend:_,ramEstimate:D,ramEstimateLoading:I,onTrain:B,onExport:F,onMlflowResult:U}){return E.jsxs(E.Fragment,{children:[k&&E.jsxs("div",{className:"flex items-center gap-2 px-3 py-2 rounded-lg text-xs",style:{background:"rgba(245,158,11,.08)",border:"1px solid rgba(245,158,11,.2)"},children:[E.jsx(qMe,{size:12,style:{color:"#f59e0b"},className:"shrink-0"}),E.jsx("span",{style:{color:"#fbbf24"},children:"Config changed since last training"}),E.jsx("button",{onClick:B,disabled:h||!s,className:"ml-auto px-2 py-0.5 rounded text-[11px] font-medium",style:{background:"rgba(168,85,247,.15)",color:"#a855f7"},children:"Re-train"})]}),I&&E.jsxs("div",{className:"flex items-center gap-2 px-3 py-2 rounded-lg text-xs",style:{background:"rgba(168,85,247,.06)",border:"1px solid rgba(168,85,247,.15)"},children:[E.jsx(Ey,{size:12,className:"animate-spin",style:{color:"#a855f7"}}),E.jsx("span",{style:{color:"var(--text-muted)"},children:"Estimating dataset size..."})]}),D&&!I&&D.total_rows!=null&&E.jsxs("div",{className:"px-3 py-2.5 rounded-lg text-xs space-y-1.5",style:{background:D.was_downsampled?"rgba(245,158,11,.06)":"rgba(34,197,94,.06)",border:`1px solid ${D.was_downsampled?"rgba(245,158,11,.2)":"rgba(34,197,94,.15)"}`},children:[E.jsxs("div",{className:"flex items-center gap-2",children:[D.was_downsampled&&E.jsx(Oy,{size:12,className:"shrink-0",style:{color:"#f59e0b"}}),E.jsx("span",{className:"font-medium",style:{color:D.was_downsampled?"#fbbf24":"#22c55e"},children:D.was_downsampled?"Will downsample":"Dataset fits in memory"})]}),E.jsxs("div",{className:"grid grid-cols-2 gap-x-4 gap-y-0.5 text-[11px] font-mono",style:{color:"var(--text-secondary)"},children:[E.jsx("span",{children:"Source rows"}),E.jsx("span",{style:{color:"var(--text-primary)"},children:D.total_rows.toLocaleString()}),E.jsx("span",{children:"Est. training RAM"}),E.jsx("span",{style:{color:"var(--text-primary)"},children:D.training_mb<1024?`${D.training_mb.toFixed(0)} MB`:`${(D.training_mb/1024).toFixed(1)} GB`}),E.jsx("span",{children:"Available RAM"}),E.jsx("span",{style:{color:"var(--text-primary)"},children:D.available_mb<1024?`${D.available_mb.toFixed(0)} MB`:`${(D.available_mb/1024).toFixed(1)} GB`}),D.was_downsampled&&D.safe_row_limit!=null&&E.jsxs(E.Fragment,{children:[E.jsx("span",{children:"Training rows"}),E.jsx("span",{style:{color:"#f59e0b"},children:D.safe_row_limit.toLocaleString()})]}),D.gpu_vram_estimated_mb!=null&&E.jsxs(E.Fragment,{children:[E.jsx("span",{children:"Est. GPU VRAM"}),E.jsx("span",{style:{color:D.gpu_warning?"#f59e0b":"var(--text-primary)"},children:D.gpu_vram_estimated_mb<1024?`${D.gpu_vram_estimated_mb.toFixed(0)} MB`:`${(D.gpu_vram_estimated_mb/1024).toFixed(1)} GB`}),D.gpu_vram_available_mb!=null&&E.jsxs(E.Fragment,{children:[E.jsx("span",{children:"GPU VRAM"}),E.jsx("span",{style:{color:"var(--text-primary)"},children:D.gpu_vram_available_mb<1024?`${D.gpu_vram_available_mb.toFixed(0)} MB`:`${(D.gpu_vram_available_mb/1024).toFixed(1)} GB`})]})]})]}),D.gpu_warning&&E.jsxs("div",{className:"flex items-center gap-2 mt-1",style:{color:"#f59e0b"},children:[E.jsx(Oy,{size:12,className:"shrink-0"}),E.jsx("span",{children:D.gpu_warning})]})]}),E.jsxs("div",{className:"space-y-2 pt-2",style:{borderTop:"1px solid var(--border)"},children:[E.jsxs("button",{onClick:B,disabled:h||!s,className:"w-full flex items-center justify-center gap-2 px-3 py-2 rounded-lg text-xs font-medium transition-colors",style:{background:h?"var(--chrome-hover)":"#a855f7",color:h?"var(--text-muted)":"#fff",opacity:s?1:.5},children:[h?E.jsx(Ey,{size:14,className:"animate-spin"}):E.jsx(_an,{size:14}),h?"Training...":"Train Model"]}),E.jsxs("button",{onClick:F,disabled:j||!s,className:"w-full flex items-center justify-center gap-2 px-3 py-2 rounded-lg text-xs font-medium transition-colors",style:{background:"var(--chrome-hover)",color:"var(--text-secondary)",opacity:s?1:.5},children:[j?E.jsx(Ey,{size:14,className:"animate-spin"}):E.jsx(nan,{size:14}),"Export Training Script"]})]}),g&&E.jsx(Fhn,{trainProgress:g}),w&&E.jsx("div",{className:"space-y-2",children:w.status==="error"?E.jsx("div",{className:"px-3 py-2.5 rounded-lg text-xs space-y-1.5",style:{background:"rgba(239,68,68,.08)",border:"1px solid rgba(239,68,68,.2)"},children:E.jsxs("div",{className:"flex items-start gap-2",children:[E.jsx(Oy,{size:14,className:"shrink-0 mt-0.5",style:{color:"#ef4444"}}),E.jsxs("div",{className:"space-y-1 min-w-0",children:[E.jsx("div",{className:"font-semibold",style:{color:"#ef4444"},children:"Training failed"}),E.jsx("div",{style:{color:"#fca5a5",lineHeight:"1.5"},children:w.error})]})]})}):E.jsxs(E.Fragment,{children:[E.jsxs("div",{className:"px-3 py-2 rounded-lg text-xs space-y-0.5",style:{background:"rgba(34,197,94,.1)",color:"#22c55e"},children:[E.jsxs("div",{children:["Model saved to ",w.model_path," (",w.train_rows.toLocaleString()," train / ",w.test_rows.toLocaleString()," test)"]}),w.best_iteration!=null&&E.jsxs("div",{style:{color:"#f59e0b"},children:["Stopped early at iteration ",w.best_iteration," / ",u.iterations??1e3]})]}),w.warning&&E.jsxs("div",{className:"flex items-start gap-2 px-3 py-2 rounded-lg text-xs",style:{background:"rgba(245,158,11,.06)",border:"1px solid rgba(245,158,11,.2)"},children:[E.jsx(Oy,{size:12,className:"shrink-0 mt-0.5",style:{color:"#f59e0b"}}),E.jsx("span",{style:{color:"#fbbf24"},children:w.warning})]}),(_==null?void 0:_.installed)&&p&&E.jsx(zhn,{trainJobId:p,mlflowBackend:_,config:l,onMlflowResult:U}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Metrics"}),E.jsx("div",{className:"mt-1 space-y-0.5",children:Object.entries(w.metrics).map(([K,Y])=>E.jsxs("div",{className:"flex justify-between text-xs font-mono",children:[E.jsx("span",{style:{color:"var(--text-secondary)"},children:K}),E.jsx("span",{style:{color:"var(--text-primary)"},children:Y.toFixed(4)})]},K))})]}),w.cv_results&&E.jsxs("div",{children:[E.jsxs("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:["Cross-Validation (",w.cv_results.n_folds,"-fold)"]}),E.jsx("div",{className:"mt-1 space-y-0.5",children:Object.entries(w.cv_results.mean_metrics).map(([K,Y])=>{var Z;return E.jsxs("div",{className:"flex justify-between text-xs font-mono",children:[E.jsx("span",{style:{color:"var(--text-secondary)"},children:K}),E.jsxs("span",{style:{color:"var(--text-primary)"},children:[Y.toFixed(4),((Z=w.cv_results)==null?void 0:Z.std_metrics[K])!=null&&E.jsxs("span",{style:{color:"var(--text-muted)"},children:[" +/- ",w.cv_results.std_metrics[K].toFixed(4)]})]})]},K)})})]}),w.loss_history&&w.loss_history.length>1&&E.jsx($hn,{lossHistory:w.loss_history,bestIteration:w.best_iteration}),w.double_lift&&w.double_lift.length>0&&E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Double Lift (Actual vs Predicted by Decile)"}),E.jsxs("div",{className:"mt-1 text-[11px] font-mono",style:{color:"var(--text-secondary)"},children:[E.jsxs("div",{className:"grid grid-cols-4 gap-1 pb-0.5 mb-0.5",style:{borderBottom:"1px solid var(--border)"},children:[E.jsx("span",{style:{color:"var(--text-muted)"},children:"Decile"}),E.jsx("span",{style:{color:"var(--text-muted)"},children:"Actual"}),E.jsx("span",{style:{color:"var(--text-muted)"},children:"Predicted"}),E.jsx("span",{style:{color:"var(--text-muted)"},children:"Count"})]}),w.double_lift.map(K=>E.jsxs("div",{className:"grid grid-cols-4 gap-1",children:[E.jsx("span",{children:K.decile}),E.jsx("span",{style:{color:"var(--text-primary)"},children:K.actual.toFixed(4)}),E.jsx("span",{style:{color:"#a855f7"},children:K.predicted.toFixed(4)}),E.jsx("span",{children:K.count})]},K.decile))]})]}),w.feature_importance.length>0&&E.jsx(Bhn,{trainResult:w})]})}),A&&E.jsxs("div",{children:[E.jsxs("div",{className:"flex items-center justify-between mb-1",children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Generated Script"}),E.jsx("button",{onClick:()=>{navigator.clipboard.writeText(A)},className:"text-[11px] px-2 py-0.5 rounded",style:{color:"var(--accent)",background:"var(--accent-soft)"},children:"Copy"})]}),E.jsx("pre",{className:"px-3 py-2 rounded-lg text-[11px] font-mono overflow-x-auto max-h-60 overflow-y-auto",style:{background:"var(--input-bg)",color:"var(--text-primary)",border:"1px solid var(--border)"},children:A})]})]})}function Hhn({config:l,onUpdate:s,upstreamColumns:u,allNodes:h,edges:g,submodels:w,preamble:p}){const k=l._nodeId,j=ll(Gn=>Gn.trainJobs[k]),A=ll(Gn=>Gn.trainResults[k]),_=ll(Gn=>Gn.startTrainJob),D=!!j,I=(j==null?void 0:j.progress)??null,B=(A==null?void 0:A.result)??null,F=(A==null?void 0:A.jobId)??(j==null?void 0:j.jobId)??null,U=pe.useMemo(()=>dkt(l),[l]),K=!!A&&A.configHash!==U,[Y,Z]=pe.useState(!1),[ee,ce]=pe.useState(null),[,fe]=pe.useState(null),[be,me]=pe.useState(null),[Re,Te]=pe.useState(!1),Ke=pe.useRef(null),ze=pe.useRef({allNodes:h,edges:g,submodels:w,preamble:p});ze.current={allNodes:h,edges:g,submodels:w,preamble:p},pe.useEffect(()=>{var Bl;if(!k)return;(Bl=Ke.current)==null||Bl.abort();const Gn=new AbortController;Ke.current=Gn,Te(!0),me(null);const{allNodes:Ir,edges:is,submodels:bs,preamble:bo}=ze.current;return Lfn({graph:ZX(Ir,is,bs,bo),node_id:k},{signal:Gn.signal}).then(Zl=>{Gn.signal.aborted||me(Zl)}).catch(Zl=>{Gn.signal.aborted||console.warn("RAM estimate failed:",Zl)}).finally(()=>{Gn.signal.aborted||Te(!1)}),()=>Gn.abort()},[k]);const je=Kc(Gn=>Gn.mlflow),te=je.status==="connected"?{installed:!0,backend:je.backend,host:je.host}:null,ge=Kc(Gn=>Gn.isSectionOpen("modelling.advanced")),He=Kc(Gn=>Gn.isSectionOpen("modelling.mlflow")),ae=Kc(Gn=>Gn.isSectionOpen("modelling.monotonic")),Le=Kc(Gn=>Gn.toggleSection),Oe=ni(l,"target",""),Qe=ni(l,"weight",""),kt=ni(l,"exclude",[]),Ae=ni(l,"algorithm","catboost"),Ye=ni(l,"task","regression"),mt=ni(l,"params",{}),Ue=ni(l,"split",{strategy:"random",test_size:.2,seed:42}),Pt=ni(l,"metrics",Ye==="regression"?["gini","rmse"]:["auc","logloss"]),rn=u||[],Cn=rn.filter(Gn=>Gn.name!==Oe&&Gn.name!==Qe&&!kt.includes(Gn.name)).length,Pn=pe.useCallback((Gn,Ir)=>{s("params",{...mt,[Gn]:Ir})},[mt,s]),mi=pe.useCallback((Gn,Ir)=>{s("split",{...Ue,[Gn]:Ir})},[Ue,s]),er=pe.useCallback(()=>ZX(h,g,w,p),[h,g,w,p]),Mr=pe.useCallback(async()=>{var Ir;fe(null);const Gn=((Ir=h.find(is=>is.id===k))==null?void 0:Ir.data.label)||"Model Training";try{const is=await Dfn({graph:er(),node_id:k,scenario:Kc.getState().activeScenario});is.status==="started"&&is.job_id?_(k,is.job_id,Gn,U):(is.status,ll.getState().completeTrainJob(k,is))}catch(is){ll.getState().completeTrainJob(k,{status:"error",metrics:{},feature_importance:[],model_path:"",train_rows:0,test_rows:0,error:String(is)})}},[k,h,er,U,_]),hr=pe.useCallback(async()=>{Z(!0);try{const Gn=await Pfn({graph:er(),node_id:l._nodeId,data_path:""});ce(Gn.script||null)}catch(Gn){console.warn("Export failed:",Gn)}finally{Z(!1)}},[l._nodeId,er]);return E.jsxs("div",{className:"px-4 py-3 space-y-4",children:[E.jsx(Nhn,{config:l,onUpdate:s,columns:rn,target:Oe,weight:Qe,task:Ye}),E.jsx(Lhn,{config:l,onUpdate:s,columns:rn,target:Oe,weight:Qe,exclude:kt,algorithm:Ae,task:Ye,params:mt,featureCount:Cn,advancedOpen:ge,toggleSection:Le,onParamUpdate:Pn}),E.jsx(Rhn,{config:l,onUpdate:s,columns:rn,target:Oe,weight:Qe,exclude:kt,task:Ye,split:Ue,metrics:Pt,mlflowOpen:He,monotonicOpen:ae,toggleSection:Le,onSplitUpdate:mi}),E.jsx(qhn,{config:l,target:Oe,params:mt,training:D,trainProgress:I,trainResult:B,trainJobId:F,isStale:K,exporting:Y,exportedScript:ee,mlflowBackend:te,ramEstimate:be,ramEstimateLoading:Re,onTrain:Mr,onExport:hr,onMlflowResult:fe})]})}function Qhn(l,s,u,h,g){const w=ll(_=>_.setColumns),p=ll(_=>{var D;return l?((D=_.columnCache[l])==null?void 0:D.columns)??null:null}),k=ll(_=>{if(!l)return!1;const D=_.columnCache[l];return D?D.graphVersion===_.graphVersion:!1}),[j,A]=pe.useState(p??[]);return pe.useEffect(()=>{if(!l){A([]);return}if(p&&(A(p),k))return;const _=ZX(s,u,h,g);hkt(_,l,1).then(D=>{D.columns&&(A(D.columns),w(l,D.columns,ll.getState().graphVersion))}).catch(D=>{console.warn("Column fetch failed",D),p||A([])})},[l,s,u,h,g,w,p,k]),j}function Ghn(l,s,u,h){const g=pe.useCallback(()=>{const j=new Set(Object.keys(l)),A=u.find(I=>!j.has(I.name)&&I.name!==s),_=A?A.name:`constraint_${Object.keys(l).length+1}`,D={...l,[_]:{min:.9}};h("constraints",D)},[l,u,s,h]),w=pe.useCallback(j=>{const A={...l};delete A[j],h("constraints",A)},[l,h]),p=pe.useCallback((j,A)=>{if(j===A)return;const _={};for(const[D,I]of Object.entries(l))_[D===j?A:D]=I;h("constraints",_)},[l,h]),k=pe.useCallback((j,A,_)=>{h("constraints",{...l,[j]:{[A]:_}})},[l,h]);return{handleAddConstraint:g,handleRemoveConstraint:w,handleConstraintColumnChange:p,handleConstraintValueChange:k}}function zo(l,s){const u=l.replace("#",""),h=u.length===3?u[0]+u[0]+u[1]+u[1]+u[2]+u[2]:u,g=parseInt(h.slice(0,2),16),w=parseInt(h.slice(2,4),16),p=parseInt(h.slice(4,6),16);return`rgba(${g},${w},${p},${s})`}function pkt(l,s){for(const u of l)if(u.outputColumn){s[u.outputColumn]||(s[u.outputColumn]=new Set);for(const h of u.rules||[]){const g=h.assignment;g&&s[u.outputColumn].add(g)}}}function bkt(l){const s={};for(const[u,h]of Object.entries(l))h.size>0&&(s[u]=[...h]);return s}function mkt(l){if(l.data.nodeType!==Ln.BANDING)return null;const u=(l.data.config||{}).factors;return Array.isArray(u)?u:null}function nxt(l,s){const u=l.find(w=>w.id===s);if(!u)return{};const h=mkt(u);if(!h)return{};const g={};return pkt(h,g),bkt(g)}function Uhn(l){const s={};for(const u of l){const h=mkt(u);h&&pkt(h,s)}return bkt(s)}function wkt(l,s,u){const h=u.filter(w=>w.target===l).map(w=>w.source),g=new Map(s.map(w=>[w.id,w]));return h.map(w=>g.get(w)).filter(w=>!!w).map(w=>({id:w.id,label:w.data.label||w.id,nodeType:w.data.nodeType}))}function Jhn(l,s,u){return wkt(l,s,u).filter(h=>h.nodeType===Ln.BANDING).map(({id:h,label:g})=>({id:h,label:g}))}const Xhn=[{value:"min",label:"Min (relative)"},{value:"max",label:"Max (relative)"},{value:"min_abs",label:"Min (absolute)"},{value:"max_abs",label:"Max (absolute)"}];function Vhn({config:l,onUpdate:s,allNodes:u,edges:h,submodels:g,accentColor:w}){const p=l._nodeId,k=ll(Un=>Un.solveJobs[p]),j=ll(Un=>Un.solveResults[p]),A=ll(Un=>Un.startSolveJob),_=!!k,D=(k==null?void 0:k.progress)??null,I=(k==null?void 0:k.error)??null,B=(j==null?void 0:j.result)??null,F=(j==null?void 0:j.jobId)??(k==null?void 0:k.jobId)??null,U=pe.useMemo(()=>dkt(l),[l]),K=!!j&&j.configHash!==U,[Y,Z]=pe.useState(!1),[ee,ce]=pe.useState(null),[fe,be]=pe.useState(!1),[me,Re]=pe.useState(null),Te=Kc(Un=>Un.mlflow),Ke=Te.status==="connected"?{installed:!0,backend:Te.backend,host:Te.host}:null,ze=Kc(Un=>Un.isSectionOpen("optimiser.advanced")),je=Kc(Un=>Un.toggleSection),te=ni(l,"mode","online"),ge=ni(l,"factor_columns",[]),He=ni(l,"objective",""),ae=ni(l,"constraints",{}),Le=ni(l,"quote_id","quote_id"),Oe=ni(l,"scenario_index","scenario_index"),Qe=ni(l,"scenario_value","scenario_value"),kt=ni(l,"max_iter",50),Ae=ni(l,"tolerance",1e-6),Ye=ni(l,"chunk_size",5e5),mt=ni(l,"record_history",!0),Ue=ni(l,"max_cd_iterations",10),Pt=ni(l,"cd_tolerance",1e-4),rn=pe.useMemo(()=>p?wkt(p,u,h):[],[p,u,h]),Cn=ni(l,"data_input",""),Pn=Qhn(Cn,u,h,g),mi=pe.useCallback(()=>ZX(u,h,g),[u,h,g]),{handleAddConstraint:er,handleRemoveConstraint:Mr,handleConstraintColumnChange:hr,handleConstraintValueChange:Gn}=Ghn(ae,He,Pn,s),Ir=pe.useCallback(Un=>{ge.some(io=>io.length===1&&io[0]===Un)?s("factor_columns",ge.filter(io=>!(io.length===1&&io[0]===Un))):s("factor_columns",[...ge,[Un]])},[ge,s]),is=pe.useCallback(async()=>{var Rc;ce(null),Re(null);const Un=((Rc=u.find(io=>io.id===p))==null?void 0:Rc.data.label)||"Optimiser";try{const io=await Rfn({graph:mi(),node_id:p});io.status==="started"&&io.job_id?A(p,io.job_id,Un,ae,U):io.status==="error"&&ll.getState().failSolveJob(p,io.error||"Unknown error")}catch(io){ll.getState().failSolveJob(p,String(io))}},[p,u,mi,ae,U,A]),bs=pe.useCallback(async()=>{if(F){Z(!0),ce(null);try{const Un=await Bfn({job_id:F,output_path:"output/optimiser_result.json"});ce(Un.message||`Saved to ${Un.path}`)}catch(Un){ce(`Error: ${Un}`)}finally{Z(!1)}}},[F]),bo=pe.useCallback(async()=>{if(F){be(!0),Re(null);try{const Un=await zfn({job_id:F});Re(Un)}catch(Un){Re({status:"error",error:String(Un)})}finally{be(!1)}}},[F]),Bl=pe.useMemo(()=>p?Jhn(p,u,h):[],[p,u,h]),Zl=ni(l,"banding_source",""),rs=Zl||(Bl.length>0?Bl[0].id:"");pe.useEffect(()=>{te==="ratebook"&&!Zl&&rs&&s("banding_source",rs)},[te,Zl,rs,s]);const Ls=pe.useMemo(()=>rs?nxt(u,rs):{},[u,rs]),f1=pe.useMemo(()=>Object.keys(Ls).sort(),[Ls]),mo=pe.useCallback(Un=>{s("banding_source",Un);const Rc=nxt(u,Un),io=Object.keys(Rc).map(zf=>[zf]);s("factor_columns",io)},[u,s]),eu=!!He&&Object.keys(ae).length>0&&(te!=="ratebook"||ge.length>0);return E.jsxs("div",{className:"px-4 py-3 space-y-4",children:[E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Mode"}),E.jsx("div",{className:"mt-1.5 flex gap-1",children:["online","ratebook"].map(Un=>E.jsx("button",{onClick:()=>s("mode",Un),className:"flex-1 px-3 py-1.5 rounded-lg text-xs font-medium transition-colors",style:{background:te===Un?zo(w,.15):"var(--chrome-hover)",color:te===Un?w:"var(--text-muted)",border:`1px solid ${te===Un?zo(w,.3):"transparent"}`},children:Un==="online"?"Online":"Ratebook"},Un))})]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Objectives & Constraints"}),E.jsx("div",{className:"mt-1.5",children:rn.length>0?E.jsxs("select",{value:Cn,onChange:Un=>s("data_input",Un.target.value),className:"w-full mt-0.5 px-2.5 py-1.5 rounded-lg text-xs",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"},children:[E.jsx("option",{value:"",children:"Select input..."}),rn.map(Un=>E.jsx("option",{value:Un.id,children:Un.label},Un.id))]}):E.jsx("div",{className:"mt-0.5 text-[11px] py-2 text-center",style:{color:"var(--text-muted)"},children:"No inputs connected."})})]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Objective"}),E.jsxs("div",{className:"mt-1.5",children:[E.jsx("label",{className:"text-xs",style:{color:"var(--text-secondary)"},children:"Column to maximise"}),E.jsxs("select",{value:He,onChange:Un=>s("objective",Un.target.value),className:"w-full mt-0.5 px-2.5 py-1.5 rounded-lg text-xs font-mono",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"},children:[E.jsx("option",{value:"",children:"Select objective..."}),Pn.map(Un=>E.jsxs("option",{value:Un.name,children:[Un.name," (",Un.dtype,")"]},Un.name))]})]})]}),te==="ratebook"&&E.jsxs("div",{className:"space-y-3",children:[E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Rating Factor Source"}),Bl.length>0?E.jsx("select",{value:rs,onChange:Un=>mo(Un.target.value),className:"w-full mt-1 px-2.5 py-1.5 rounded-lg text-xs",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"},children:Bl.map(Un=>E.jsx("option",{value:Un.id,children:Un.label},Un.id))}):E.jsx("div",{className:"mt-1 text-[11px] py-2 text-center",style:{color:"var(--text-muted)"},children:"No Banding nodes found. Add a Banding node to define rating factors."})]}),f1.length>0&&E.jsxs("div",{children:[E.jsxs("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:[E.jsx(okt,{size:10,className:"inline mr-1"}),"Rating Factors (",ge.length," selected)"]}),E.jsx("div",{className:"mt-1.5 space-y-1",children:f1.map(Un=>{const Rc=Ls[Un]||[],io=ge.some(zf=>zf.length===1&&zf[0]===Un);return E.jsxs("button",{onClick:()=>Ir(Un),className:"w-full flex items-center justify-between px-2.5 py-1.5 rounded-lg text-xs transition-colors",style:{background:io?zo(w,.1):"var(--bg-surface)",border:`1px solid ${io?zo(w,.3):"var(--border)"}`},children:[E.jsx("span",{className:"font-mono",style:{color:io?w:"var(--text-primary)"},children:Un}),E.jsxs("span",{className:"text-[10px]",style:{color:io?zo(w,.7):"var(--text-muted)"},children:[Rc.length," levels"]})]},Un)})})]})]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Column Mappings"}),E.jsx("div",{className:"mt-1.5 space-y-2",children:[{key:"quote_id",label:"Quote ID",value:Le,default:"quote_id"},{key:"scenario_index",label:"Scenario Index",value:Oe,default:"scenario_index"},{key:"scenario_value",label:"Scenario Value",value:Qe,default:"scenario_value"}].map(Un=>E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:Un.label}),E.jsxs("select",{value:Un.value,onChange:Rc=>s(Un.key,Rc.target.value),className:"w-full mt-0.5 px-2.5 py-1.5 rounded-lg text-xs font-mono",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"},children:[E.jsxs("option",{value:"",children:["Select ",Un.label.toLowerCase(),"..."]}),Pn.map(Rc=>E.jsx("option",{value:Rc.name,children:Rc.name},Rc.name))]})]},Un.key))})]}),E.jsxs("div",{children:[E.jsxs("div",{className:"flex items-center justify-between",children:[E.jsxs("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:["Constraints (",Object.keys(ae).length,")"]}),E.jsxs("button",{onClick:er,className:"flex items-center gap-1 px-2 py-0.5 rounded text-[11px] transition-colors",style:{color:"var(--accent)",background:"var(--accent-soft)"},children:[E.jsx(w8,{size:10})," Add"]})]}),E.jsxs("div",{className:"mt-1.5 space-y-2",children:[Object.entries(ae).map(([Un,Rc])=>{const io=Object.keys(Rc)[0]||"min",zf=Rc[io]??.9;return E.jsxs("div",{className:"flex items-center gap-1.5 p-2 rounded-lg",style:{background:"var(--bg-surface)",border:"1px solid var(--border)"},children:[E.jsxs("select",{value:Un,onChange:tu=>hr(Un,tu.target.value),className:"flex-1 min-w-0 px-1.5 py-1 rounded text-[11px] font-mono",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"},children:[E.jsx("option",{value:Un,children:Un}),Pn.filter(tu=>tu.name!==Un&&tu.name!==He&&!ae[tu.name]).map(tu=>E.jsx("option",{value:tu.name,children:tu.name},tu.name))]}),E.jsx("select",{value:io,onChange:tu=>Gn(Un,tu.target.value,zf),className:"w-[90px] px-1 py-1 rounded text-[10px]",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-secondary)"},children:Xhn.map(tu=>E.jsx("option",{value:tu.value,children:tu.label},tu.value))}),E.jsx("input",{type:"number",step:.01,value:zf,onChange:tu=>Gn(Un,io,parseFloat(tu.target.value)||0),className:"w-16 px-1.5 py-1 rounded text-[11px] font-mono text-right",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"}}),E.jsx("button",{onClick:()=>Mr(Un),className:"p-0.5 rounded transition-colors shrink-0",style:{color:"var(--text-muted)"},children:E.jsx(jp,{size:12})})]},Un)}),Object.keys(ae).length===0&&E.jsx("div",{className:"text-[11px] py-2 text-center",style:{color:"var(--text-muted)"},children:'No constraints added. Click "Add" to set volume or loss ratio bounds.'})]})]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Solver"}),E.jsxs("div",{className:"mt-1.5 grid grid-cols-2 gap-2",children:[E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:"Max iterations"}),E.jsx("input",{type:"number",min:1,step:1,value:kt,onChange:Un=>s("max_iter",parseInt(Un.target.value)||50),className:"w-full mt-0.5 px-2 py-1 rounded text-xs font-mono",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"}})]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:"Tolerance"}),E.jsx("input",{type:"number",step:1e-6,value:Ae,onChange:Un=>s("tolerance",parseFloat(Un.target.value)||1e-6),className:"w-full mt-0.5 px-2 py-1 rounded text-xs font-mono",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"}})]})]})]}),E.jsxs("div",{children:[E.jsxs("button",{onClick:()=>je("optimiser.advanced"),className:"flex items-center gap-1 text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:[ze?E.jsx(Vw,{size:12}):E.jsx(NI,{size:12}),"Advanced"]}),ze&&E.jsxs("div",{className:"mt-1.5 space-y-2",children:[E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:"Chunk size"}),E.jsx("input",{type:"number",min:1e3,step:1e4,value:Ye,onChange:Un=>s("chunk_size",parseInt(Un.target.value)||5e5),className:"w-full mt-0.5 px-2 py-1 rounded text-xs font-mono",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"}})]}),E.jsxs("div",{className:"flex items-center gap-2",children:[E.jsx("label",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:"Record history"}),E.jsx("button",{onClick:()=>s("record_history",!mt),className:"px-2 py-0.5 rounded text-[11px] font-mono",style:{background:mt?zo(w,.15):"var(--chrome-hover)",color:mt?w:"var(--text-muted)",border:`1px solid ${mt?zo(w,.3):"transparent"}`},children:mt?"On":"Off"})]}),te==="ratebook"&&E.jsxs("div",{className:"grid grid-cols-2 gap-2",children:[E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:"CD iterations"}),E.jsx("input",{type:"number",min:1,step:1,value:Ue,onChange:Un=>s("max_cd_iterations",parseInt(Un.target.value)||10),className:"w-full mt-0.5 px-2 py-1 rounded text-xs font-mono",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"}})]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:"CD tolerance"}),E.jsx("input",{type:"number",step:1e-4,value:Pt,onChange:Un=>s("cd_tolerance",parseFloat(Un.target.value)||1e-4),className:"w-full mt-0.5 px-2 py-1 rounded text-xs font-mono",style:{background:"var(--input-bg)",border:"1px solid var(--border)",color:"var(--text-primary)"}})]})]})]})]}),K&&E.jsxs("div",{className:"flex items-center gap-2 px-3 py-2 rounded-lg text-xs",style:{background:"rgba(245,158,11,.08)",border:"1px solid rgba(245,158,11,.2)"},children:[E.jsx(qMe,{size:12,style:{color:"#f59e0b"},className:"shrink-0"}),E.jsx("span",{style:{color:"#fbbf24"},children:"Config changed since last solve"}),E.jsx("button",{onClick:is,disabled:_||!eu,className:"ml-auto px-2 py-0.5 rounded text-[11px] font-medium",style:{background:zo(w,.15),color:w},children:"Re-run"})]}),E.jsx("div",{className:"space-y-2 pt-2",style:{borderTop:"1px solid var(--border)"},children:E.jsxs("button",{onClick:is,disabled:_||!eu,className:"w-full flex items-center justify-center gap-2 px-3 py-2 rounded-lg text-xs font-medium transition-colors",style:{background:_?"var(--chrome-hover)":w,color:_?"var(--text-muted)":"#fff",opacity:eu?1:.5},children:[_?E.jsx(Ey,{size:14,className:"animate-spin"}):E.jsx(PX,{size:14}),_?"Optimising...":"Optimise"]})}),D&&E.jsx("div",{className:"px-3 py-2.5 rounded-lg text-xs space-y-2",style:{background:zo(w,.06),border:`1px solid ${zo(w,.2)}`},children:E.jsxs("div",{className:"space-y-1",children:[E.jsxs("div",{className:"flex justify-between text-[11px]",children:[E.jsx("span",{style:{color:w},children:D.message||"Solving..."}),E.jsx("span",{style:{color:"var(--text-muted)"},children:fkt(D.elapsed_seconds)})]}),E.jsx("div",{className:"w-full h-1.5 rounded-full overflow-hidden",style:{background:zo(w,.15)},children:E.jsx("div",{className:"h-full rounded-full transition-all duration-300",style:{width:`${Math.max(D.progress*100,2)}%`,background:w}})})]})}),I&&E.jsx("div",{className:"px-3 py-2.5 rounded-lg text-xs space-y-1.5",style:{background:"rgba(239,68,68,.08)",border:"1px solid rgba(239,68,68,.2)"},children:E.jsxs("div",{className:"flex items-start gap-2",children:[E.jsx(Oy,{size:14,className:"shrink-0 mt-0.5",style:{color:"#ef4444"}}),E.jsxs("div",{className:"space-y-1 min-w-0",children:[E.jsx("div",{className:"font-semibold",style:{color:"#ef4444"},children:"Optimisation failed"}),E.jsx("div",{style:{color:"#fca5a5",lineHeight:"1.5"},children:I})]})]})}),B&&E.jsxs("div",{className:"space-y-2",children:[!B.converged&&E.jsxs("div",{className:"flex items-start gap-2 px-3 py-2 rounded-lg text-xs",style:{background:"rgba(245,158,11,.1)",border:"1px solid rgba(245,158,11,.25)"},children:[E.jsx(Oy,{size:14,className:"shrink-0 mt-0.5",style:{color:"#f59e0b"}}),E.jsxs("div",{children:[E.jsx("div",{className:"font-semibold",style:{color:"#f59e0b"},children:"Solver did not converge"}),E.jsx("div",{style:{color:"#fbbf24",lineHeight:"1.5"},children:B.warning||"Try increasing max iterations or relaxing the tolerance."})]})]}),E.jsx("div",{className:"px-3 py-2 rounded-lg text-xs space-y-1",style:{background:B.converged?"rgba(34,197,94,.1)":"rgba(245,158,11,.06)",border:`1px solid ${B.converged?"rgba(34,197,94,.2)":"rgba(245,158,11,.15)"}`},children:E.jsxs("div",{style:{color:B.converged?"#22c55e":"#f59e0b"},children:[B.converged?"Converged":"Did not converge",B.mode==="ratebook"?` in ${B.cd_iterations??"?"} CD iterations`:` in ${B.iterations??"?"} iterations`,B.n_quotes!=null&&B.n_steps!=null&&E.jsxs(E.Fragment,{children:[" (",B.n_quotes.toLocaleString()," quotes, ",B.n_steps," steps)"]})]})}),E.jsxs("div",{className:"space-y-2 pt-1",children:[E.jsxs("button",{onClick:bs,disabled:Y,className:"w-full flex items-center justify-center gap-2 px-3 py-2 rounded-lg text-xs font-medium transition-colors",style:{background:Y?"var(--chrome-hover)":zo(w,.15),color:Y?"var(--text-muted)":w,border:`1px solid ${zo(w,.3)}`},children:[Y?E.jsx(Ey,{size:14,className:"animate-spin"}):E.jsx(Han,{size:14}),Y?"Saving...":"Save Result"]}),ee&&E.jsx("div",{className:"text-[11px] px-3 py-1.5 rounded-lg",style:{background:"var(--bg-surface)",color:"var(--text-secondary)",border:"1px solid var(--border)"},children:ee}),(Ke==null?void 0:Ke.installed)&&F&&E.jsxs(E.Fragment,{children:[E.jsxs("button",{onClick:bo,disabled:fe,className:"w-full flex items-center justify-center gap-2 px-3 py-2 rounded-lg text-xs font-medium transition-colors",style:{background:fe?"var(--chrome-hover)":"rgba(59,130,246,.15)",color:fe?"var(--text-muted)":"#3b82f6",border:"1px solid rgba(59,130,246,.3)"},children:[fe?E.jsx(Ey,{size:14,className:"animate-spin"}):E.jsx(BMe,{size:14}),fe?"Logging...":`Log to MLflow (${Ke.backend})`]}),me&&me.status==="ok"&&E.jsxs("div",{className:"px-3 py-2 rounded-lg text-xs space-y-1",style:{background:"rgba(59,130,246,.08)",border:"1px solid rgba(59,130,246,.2)",color:"#3b82f6"},children:[E.jsx("div",{children:"Logged successfully"}),me.experiment_name&&E.jsx("div",{className:"font-mono text-[11px]",style:{color:"#93c5fd"},children:me.experiment_name}),me.run_url?E.jsx("a",{href:me.run_url,target:"_blank",rel:"noreferrer",className:"underline",style:{color:"#60a5fa"},children:"Open in Databricks"}):me.run_id?E.jsxs("div",{className:"font-mono text-[11px]",style:{color:"#93c5fd"},children:["Run: ",me.run_id.slice(0,8)]}):null]}),me&&me.status==="error"&&E.jsx("div",{className:"px-3 py-2 rounded-lg text-xs",style:{background:"rgba(239,68,68,.08)",border:"1px solid rgba(239,68,68,.2)",color:"#fca5a5"},children:me.error})]})]})]})]})}const Whn={Int64:"text-blue-400",Int32:"text-blue-400",Float64:"text-emerald-400",Float32:"text-emerald-400",String:"text-amber-400",Utf8:"text-amber-400",Boolean:"text-purple-400",Date:"text-rose-400",Datetime:"text-rose-400"};function GMe(l){for(const[s,u]of Object.entries(Whn))if(l.includes(s))return u;return"text-slate-400"}let CCe=[],vkt=[];(()=>{let l="lc,34,7n,7,7b,19,,,,2,,2,,,20,b,1c,l,g,,2t,7,2,6,2,2,,4,z,,u,r,2j,b,1m,9,9,,o,4,,9,,3,,5,17,3,3b,f,,w,1j,,,,4,8,4,,3,7,a,2,t,,1m,,,,2,4,8,,9,,a,2,q,,2,2,1l,,4,2,4,2,2,3,3,,u,2,3,,b,2,1l,,4,5,,2,4,,k,2,m,6,,,1m,,,2,,4,8,,7,3,a,2,u,,1n,,,,c,,9,,14,,3,,1l,3,5,3,,4,7,2,b,2,t,,1m,,2,,2,,3,,5,2,7,2,b,2,s,2,1l,2,,,2,4,8,,9,,a,2,t,,20,,4,,2,3,,,8,,29,,2,7,c,8,2q,,2,9,b,6,22,2,r,,,,,,1j,e,,5,,2,5,b,,10,9,,2u,4,,6,,2,2,2,p,2,4,3,g,4,d,,2,2,6,,f,,jj,3,qa,3,t,3,t,2,u,2,1s,2,,7,8,,2,b,9,,19,3,3b,2,y,,3a,3,4,2,9,,6,3,63,2,2,,1m,,,7,,,,,2,8,6,a,2,,1c,h,1r,4,1c,7,,,5,,14,9,c,2,w,4,2,2,,3,1k,,,2,3,,,3,1m,8,2,2,48,3,,d,,7,4,,6,,3,2,5i,1m,,5,ek,,5f,x,2da,3,3x,,2o,w,fe,6,2x,2,n9w,4,,a,w,2,28,2,7k,,3,,4,,p,2,5,,47,2,q,i,d,,12,8,p,b,1a,3,1c,,2,4,2,2,13,,1v,6,2,2,2,2,c,,8,,1b,,1f,,,3,2,2,5,2,,,16,2,8,,6m,,2,,4,,fn4,,kh,g,g,g,a6,2,gt,,6a,,45,5,1ae,3,,2,5,4,14,3,4,,4l,2,fx,4,ar,2,49,b,4w,,1i,f,1k,3,1d,4,2,2,1x,3,10,5,,8,1q,,c,2,1g,9,a,4,2,,2n,3,2,,,2,6,,4g,,3,8,l,2,1l,2,,,,,m,,e,7,3,5,5f,8,2,3,,,n,,29,,2,6,,,2,,,2,,2,6j,,2,4,6,2,,2,r,2,2d,8,2,,,2,2y,,,,2,6,,,2t,3,2,4,,5,77,9,,2,6t,,a,2,,,4,,40,4,2,2,4,,w,a,14,6,2,4,8,,9,6,2,3,1a,d,,2,ba,7,,6,,,2a,m,2,7,,2,,2,3e,6,3,,,2,,7,,,20,2,3,,,,9n,2,f0b,5,1n,7,t4,,1r,4,29,,f5k,2,43q,,,3,4,5,8,8,2,7,u,4,44,3,1iz,1j,4,1e,8,,e,,m,5,,f,11s,7,,h,2,7,,2,,5,79,7,c5,4,15s,7,31,7,240,5,gx7k,2o,3k,6o".split(",").map(s=>s?parseInt(s,36):1);for(let s=0,u=0;s<l.length;s++)(s%2?vkt:CCe).push(u=u+l[s])})();function Khn(l){if(l<768)return!1;for(let s=0,u=CCe.length;;){let h=s+u>>1;if(l<CCe[h])u=h;else if(l>=vkt[h])s=h+1;else return!0;if(s==u)return!1}}function ixt(l){return l>=127462&&l<=127487}const rxt=8205;function Yhn(l,s,u=!0,h=!0){return(u?ykt:Zhn)(l,s,h)}function ykt(l,s,u){if(s==l.length)return s;s&&xkt(l.charCodeAt(s))&&kkt(l.charCodeAt(s-1))&&s--;let h=EEe(l,s);for(s+=sxt(h);s<l.length;){let g=EEe(l,s);if(h==rxt||g==rxt||u&&Khn(g))s+=sxt(g),h=g;else if(ixt(g)){let w=0,p=s-2;for(;p>=0&&ixt(EEe(l,p));)w++,p-=2;if(w%2==0)break;s+=2}else break}return s}function Zhn(l,s,u){for(;s>0;){let h=ykt(l,s-2,u);if(h<s)return h;s--}return 0}function EEe(l,s){let u=l.charCodeAt(s);if(!kkt(u)||s+1==l.length)return u;let h=l.charCodeAt(s+1);return xkt(h)?(u-55296<<10)+(h-56320)+65536:u}function xkt(l){return l>=56320&&l<57344}function kkt(l){return l>=55296&&l<56320}function sxt(l){return l<65536?1:2}class uc{lineAt(s){if(s<0||s>this.length)throw new RangeError(`Invalid position ${s} in document of length ${this.length}`);return this.lineInner(s,!1,1,0)}line(s){if(s<1||s>this.lines)throw new RangeError(`Invalid line number ${s} in ${this.lines}-line document`);return this.lineInner(s,!0,1,0)}replace(s,u,h){[s,u]=_I(this,s,u);let g=[];return this.decompose(0,s,g,2),h.length&&h.decompose(0,h.length,g,3),this.decompose(u,this.length,g,1),F3.from(g,this.length-(u-s)+h.length)}append(s){return this.replace(this.length,this.length,s)}slice(s,u=this.length){[s,u]=_I(this,s,u);let h=[];return this.decompose(s,u,h,0),F3.from(h,u-s)}eq(s){if(s==this)return!0;if(s.length!=this.length||s.lines!=this.lines)return!1;let u=this.scanIdentical(s,1),h=this.length-this.scanIdentical(s,-1),g=new IX(this),w=new IX(s);for(let p=u,k=u;;){if(g.next(p),w.next(p),p=0,g.lineBreak!=w.lineBreak||g.done!=w.done||g.value!=w.value)return!1;if(k+=g.value.length,g.done||k>=h)return!0}}iter(s=1){return new IX(this,s)}iterRange(s,u=this.length){return new Okt(this,s,u)}iterLines(s,u){let h;if(s==null)h=this.iter();else{u==null&&(u=this.lines+1);let g=this.line(s).from;h=this.iterRange(g,Math.max(g,u==this.lines+1?this.length:u<=1?0:this.line(u-1).to))}return new Skt(h)}toString(){return this.sliceString(0)}toJSON(){let s=[];return this.flatten(s),s}constructor(){}static of(s){if(s.length==0)throw new RangeError("A document must have at least one line");return s.length==1&&!s[0]?uc.empty:s.length<=32?new $f(s):F3.from($f.split(s,[]))}}class $f extends uc{constructor(s,u=edn(s)){super(),this.text=s,this.length=u}get lines(){return this.text.length}get children(){return null}lineInner(s,u,h,g){for(let w=0;;w++){let p=this.text[w],k=g+p.length;if((u?h:k)>=s)return new tdn(g,k,h,p);g=k+1,h++}}decompose(s,u,h,g){let w=s<=0&&u>=this.length?this:new $f(oxt(this.text,s,u),Math.min(u,this.length)-Math.max(0,s));if(g&1){let p=h.pop(),k=jfe(w.text,p.text.slice(),0,w.length);if(k.length<=32)h.push(new $f(k,p.length+w.length));else{let j=k.length>>1;h.push(new $f(k.slice(0,j)),new $f(k.slice(j)))}}else h.push(w)}replace(s,u,h){if(!(h instanceof $f))return super.replace(s,u,h);[s,u]=_I(this,s,u);let g=jfe(this.text,jfe(h.text,oxt(this.text,0,s)),u),w=this.length+h.length-(u-s);return g.length<=32?new $f(g,w):F3.from($f.split(g,[]),w)}sliceString(s,u=this.length,h=`
`){[s,u]=_I(this,s,u);let g="";for(let w=0,p=0;w<=u&&p<this.text.length;p++){let k=this.text[p],j=w+k.length;w>s&&p&&(g+=h),s<j&&u>w&&(g+=k.slice(Math.max(0,s-w),u-w)),w=j+1}return g}flatten(s){for(let u of this.text)s.push(u)}scanIdentical(){return 0}static split(s,u){let h=[],g=-1;for(let w of s)h.push(w),g+=w.length+1,h.length==32&&(u.push(new $f(h,g)),h=[],g=-1);return g>-1&&u.push(new $f(h,g)),u}}class F3 extends uc{constructor(s,u){super(),this.children=s,this.length=u,this.lines=0;for(let h of s)this.lines+=h.lines}lineInner(s,u,h,g){for(let w=0;;w++){let p=this.children[w],k=g+p.length,j=h+p.lines-1;if((u?j:k)>=s)return p.lineInner(s,u,h,g);g=k+1,h=j+1}}decompose(s,u,h,g){for(let w=0,p=0;p<=u&&w<this.children.length;w++){let k=this.children[w],j=p+k.length;if(s<=j&&u>=p){let A=g&((p<=s?1:0)|(j>=u?2:0));p>=s&&j<=u&&!A?h.push(k):k.decompose(s-p,u-p,h,A)}p=j+1}}replace(s,u,h){if([s,u]=_I(this,s,u),h.lines<this.lines)for(let g=0,w=0;g<this.children.length;g++){let p=this.children[g],k=w+p.length;if(s>=w&&u<=k){let j=p.replace(s-w,u-w,h),A=this.lines-p.lines+j.lines;if(j.lines<A>>4&&j.lines>A>>6){let _=this.children.slice();return _[g]=j,new F3(_,this.length-(u-s)+h.length)}return super.replace(w,k,j)}w=k+1}return super.replace(s,u,h)}sliceString(s,u=this.length,h=`
`){[s,u]=_I(this,s,u);let g="";for(let w=0,p=0;w<this.children.length&&p<=u;w++){let k=this.children[w],j=p+k.length;p>s&&w&&(g+=h),s<j&&u>p&&(g+=k.sliceString(s-p,u-p,h)),p=j+1}return g}flatten(s){for(let u of this.children)u.flatten(s)}scanIdentical(s,u){if(!(s instanceof F3))return 0;let h=0,[g,w,p,k]=u>0?[0,0,this.children.length,s.children.length]:[this.children.length-1,s.children.length-1,-1,-1];for(;;g+=u,w+=u){if(g==p||w==k)return h;let j=this.children[g],A=s.children[w];if(j!=A)return h+j.scanIdentical(A,u);h+=j.length+1}}static from(s,u=s.reduce((h,g)=>h+g.length+1,-1)){let h=0;for(let B of s)h+=B.lines;if(h<32){let B=[];for(let F of s)F.flatten(B);return new $f(B,u)}let g=Math.max(32,h>>5),w=g<<1,p=g>>1,k=[],j=0,A=-1,_=[];function D(B){let F;if(B.lines>w&&B instanceof F3)for(let U of B.children)D(U);else B.lines>p&&(j>p||!j)?(I(),k.push(B)):B instanceof $f&&j&&(F=_[_.length-1])instanceof $f&&B.lines+F.lines<=32?(j+=B.lines,A+=B.length+1,_[_.length-1]=new $f(F.text.concat(B.text),F.length+1+B.length)):(j+B.lines>g&&I(),j+=B.lines,A+=B.length+1,_.push(B))}function I(){j!=0&&(k.push(_.length==1?_[0]:F3.from(_,A)),A=-1,j=_.length=0)}for(let B of s)D(B);return I(),k.length==1?k[0]:new F3(k,u)}}uc.empty=new $f([""],0);function edn(l){let s=-1;for(let u of l)s+=u.length+1;return s}function jfe(l,s,u=0,h=1e9){for(let g=0,w=0,p=!0;w<l.length&&g<=h;w++){let k=l[w],j=g+k.length;j>=u&&(j>h&&(k=k.slice(0,h-g)),g<u&&(k=k.slice(u-g)),p?(s[s.length-1]+=k,p=!1):s.push(k)),g=j+1}return s}function oxt(l,s,u){return jfe(l,[""],s,u)}class IX{constructor(s,u=1){this.dir=u,this.done=!1,this.lineBreak=!1,this.value="",this.nodes=[s],this.offsets=[u>0?1:(s instanceof $f?s.text.length:s.children.length)<<1]}nextInner(s,u){for(this.done=this.lineBreak=!1;;){let h=this.nodes.length-1,g=this.nodes[h],w=this.offsets[h],p=w>>1,k=g instanceof $f?g.text.length:g.children.length;if(p==(u>0?k:0)){if(h==0)return this.done=!0,this.value="",this;u>0&&this.offsets[h-1]++,this.nodes.pop(),this.offsets.pop()}else if((w&1)==(u>0?0:1)){if(this.offsets[h]+=u,s==0)return this.lineBreak=!0,this.value=`
`,this;s--}else if(g instanceof $f){let j=g.text[p+(u<0?-1:0)];if(this.offsets[h]+=u,j.length>Math.max(0,s))return this.value=s==0?j:u>0?j.slice(s):j.slice(0,j.length-s),this;s-=j.length}else{let j=g.children[p+(u<0?-1:0)];s>j.length?(s-=j.length,this.offsets[h]+=u):(u<0&&this.offsets[h]--,this.nodes.push(j),this.offsets.push(u>0?1:(j instanceof $f?j.text.length:j.children.length)<<1))}}}next(s=0){return s<0&&(this.nextInner(-s,-this.dir),s=this.value.length),this.nextInner(s,this.dir)}}class Okt{constructor(s,u,h){this.value="",this.done=!1,this.cursor=new IX(s,u>h?-1:1),this.pos=u>h?s.length:0,this.from=Math.min(u,h),this.to=Math.max(u,h)}nextInner(s,u){if(u<0?this.pos<=this.from:this.pos>=this.to)return this.value="",this.done=!0,this;s+=Math.max(0,u<0?this.pos-this.to:this.from-this.pos);let h=u<0?this.pos-this.from:this.to-this.pos;s>h&&(s=h),h-=s;let{value:g}=this.cursor.next(s);return this.pos+=(g.length+s)*u,this.value=g.length<=h?g:u<0?g.slice(g.length-h):g.slice(0,h),this.done=!this.value,this}next(s=0){return s<0?s=Math.max(s,this.from-this.pos):s>0&&(s=Math.min(s,this.to-this.pos)),this.nextInner(s,this.cursor.dir)}get lineBreak(){return this.cursor.lineBreak&&this.value!=""}}class Skt{constructor(s){this.inner=s,this.afterBreak=!0,this.value="",this.done=!1}next(s=0){let{done:u,lineBreak:h,value:g}=this.inner.next(s);return u&&this.afterBreak?(this.value="",this.afterBreak=!1):u?(this.done=!0,this.value=""):h?this.afterBreak?this.value="":(this.afterBreak=!0,this.next()):(this.value=g,this.afterBreak=!1),this}get lineBreak(){return!1}}typeof Symbol<"u"&&(uc.prototype[Symbol.iterator]=function(){return this.iter()},IX.prototype[Symbol.iterator]=Okt.prototype[Symbol.iterator]=Skt.prototype[Symbol.iterator]=function(){return this});class tdn{constructor(s,u,h,g){this.from=s,this.to=u,this.number=h,this.text=g}get length(){return this.to-this.from}}function _I(l,s,u){return s=Math.max(0,Math.min(l.length,s)),[s,Math.max(s,Math.min(l.length,u))]}function Sd(l,s,u=!0,h=!0){return Yhn(l,s,u,h)}function ndn(l){return l>=56320&&l<57344}function idn(l){return l>=55296&&l<56320}function em(l,s){let u=l.charCodeAt(s);if(!idn(u)||s+1==l.length)return u;let h=l.charCodeAt(s+1);return ndn(h)?(u-55296<<10)+(h-56320)+65536:u}function UMe(l){return l<=65535?String.fromCharCode(l):(l-=65536,String.fromCharCode((l>>10)+55296,(l&1023)+56320))}function q3(l){return l<65536?1:2}const MCe=/\r\n?|\n/;var u1=(function(l){return l[l.Simple=0]="Simple",l[l.TrackDel=1]="TrackDel",l[l.TrackBefore=2]="TrackBefore",l[l.TrackAfter=3]="TrackAfter",l})(u1||(u1={}));class V3{constructor(s){this.sections=s}get length(){let s=0;for(let u=0;u<this.sections.length;u+=2)s+=this.sections[u];return s}get newLength(){let s=0;for(let u=0;u<this.sections.length;u+=2){let h=this.sections[u+1];s+=h<0?this.sections[u]:h}return s}get empty(){return this.sections.length==0||this.sections.length==2&&this.sections[1]<0}iterGaps(s){for(let u=0,h=0,g=0;u<this.sections.length;){let w=this.sections[u++],p=this.sections[u++];p<0?(s(h,g,w),g+=w):g+=p,h+=w}}iterChangedRanges(s,u=!1){ACe(this,s,u)}get invertedDesc(){let s=[];for(let u=0;u<this.sections.length;){let h=this.sections[u++],g=this.sections[u++];g<0?s.push(h,g):s.push(g,h)}return new V3(s)}composeDesc(s){return this.empty?s:s.empty?this:jkt(this,s)}mapDesc(s,u=!1){return s.empty?this:NCe(this,s,u)}mapPos(s,u=-1,h=u1.Simple){let g=0,w=0;for(let p=0;p<this.sections.length;){let k=this.sections[p++],j=this.sections[p++],A=g+k;if(j<0){if(A>s)return w+(s-g);w+=k}else{if(h!=u1.Simple&&A>=s&&(h==u1.TrackDel&&g<s&&A>s||h==u1.TrackBefore&&g<s||h==u1.TrackAfter&&A>s))return null;if(A>s||A==s&&u<0&&!k)return s==g||u<0?w:w+j;w+=j}g=A}if(s>g)throw new RangeError(`Position ${s} is out of range for changeset of length ${g}`);return w}touchesRange(s,u=s){for(let h=0,g=0;h<this.sections.length&&g<=u;){let w=this.sections[h++],p=this.sections[h++],k=g+w;if(p>=0&&g<=u&&k>=s)return g<s&&k>u?"cover":!0;g=k}return!1}toString(){let s="";for(let u=0;u<this.sections.length;){let h=this.sections[u++],g=this.sections[u++];s+=(s?" ":"")+h+(g>=0?":"+g:"")}return s}toJSON(){return this.sections}static fromJSON(s){if(!Array.isArray(s)||s.length%2||s.some(u=>typeof u!="number"))throw new RangeError("Invalid JSON representation of ChangeDesc");return new V3(s)}static create(s){return new V3(s)}}class Jh extends V3{constructor(s,u){super(s),this.inserted=u}apply(s){if(this.length!=s.length)throw new RangeError("Applying change set to a document with the wrong length");return ACe(this,(u,h,g,w,p)=>s=s.replace(g,g+(h-u),p),!1),s}mapDesc(s,u=!1){return NCe(this,s,u,!0)}invert(s){let u=this.sections.slice(),h=[];for(let g=0,w=0;g<u.length;g+=2){let p=u[g],k=u[g+1];if(k>=0){u[g]=k,u[g+1]=p;let j=g>>1;for(;h.length<j;)h.push(uc.empty);h.push(p?s.slice(w,w+p):uc.empty)}w+=p}return new Jh(u,h)}compose(s){return this.empty?s:s.empty?this:jkt(this,s,!0)}map(s,u=!1){return s.empty?this:NCe(this,s,u,!0)}iterChanges(s,u=!1){ACe(this,s,u)}get desc(){return V3.create(this.sections)}filter(s){let u=[],h=[],g=[],w=new eV(this);e:for(let p=0,k=0;;){let j=p==s.length?1e9:s[p++];for(;k<j||k==j&&w.len==0;){if(w.done)break e;let _=Math.min(w.len,j-k);og(g,_,-1);let D=w.ins==-1?-1:w.off==0?w.ins:0;og(u,_,D),D>0&&b8(h,u,w.text),w.forward(_),k+=_}let A=s[p++];for(;k<A;){if(w.done)break e;let _=Math.min(w.len,A-k);og(u,_,-1),og(g,_,w.ins==-1?-1:w.off==0?w.ins:0),w.forward(_),k+=_}}return{changes:new Jh(u,h),filtered:V3.create(g)}}toJSON(){let s=[];for(let u=0;u<this.sections.length;u+=2){let h=this.sections[u],g=this.sections[u+1];g<0?s.push(h):g==0?s.push([h]):s.push([h].concat(this.inserted[u>>1].toJSON()))}return s}static of(s,u,h){let g=[],w=[],p=0,k=null;function j(_=!1){if(!_&&!g.length)return;p<u&&og(g,u-p,-1);let D=new Jh(g,w);k=k?k.compose(D.map(k)):D,g=[],w=[],p=0}function A(_){if(Array.isArray(_))for(let D of _)A(D);else if(_ instanceof Jh){if(_.length!=u)throw new RangeError(`Mismatched change set length (got ${_.length}, expected ${u})`);j(),k=k?k.compose(_.map(k)):_}else{let{from:D,to:I=D,insert:B}=_;if(D>I||D<0||I>u)throw new RangeError(`Invalid change range ${D} to ${I} (in doc of length ${u})`);let F=B?typeof B=="string"?uc.of(B.split(h||MCe)):B:uc.empty,U=F.length;if(D==I&&U==0)return;D<p&&j(),D>p&&og(g,D-p,-1),og(g,I-D,U),b8(w,g,F),p=I}}return A(s),j(!k),k}static empty(s){return new Jh(s?[s,-1]:[],[])}static fromJSON(s){if(!Array.isArray(s))throw new RangeError("Invalid JSON representation of ChangeSet");let u=[],h=[];for(let g=0;g<s.length;g++){let w=s[g];if(typeof w=="number")u.push(w,-1);else{if(!Array.isArray(w)||typeof w[0]!="number"||w.some((p,k)=>k&&typeof p!="string"))throw new RangeError("Invalid JSON representation of ChangeSet");if(w.length==1)u.push(w[0],0);else{for(;h.length<g;)h.push(uc.empty);h[g]=uc.of(w.slice(1)),u.push(w[0],h[g].length)}}}return new Jh(u,h)}static createSet(s,u){return new Jh(s,u)}}function og(l,s,u,h=!1){if(s==0&&u<=0)return;let g=l.length-2;g>=0&&u<=0&&u==l[g+1]?l[g]+=s:g>=0&&s==0&&l[g]==0?l[g+1]+=u:h?(l[g]+=s,l[g+1]+=u):l.push(s,u)}function b8(l,s,u){if(u.length==0)return;let h=s.length-2>>1;if(h<l.length)l[l.length-1]=l[l.length-1].append(u);else{for(;l.length<h;)l.push(uc.empty);l.push(u)}}function ACe(l,s,u){let h=l.inserted;for(let g=0,w=0,p=0;p<l.sections.length;){let k=l.sections[p++],j=l.sections[p++];if(j<0)g+=k,w+=k;else{let A=g,_=w,D=uc.empty;for(;A+=k,_+=j,j&&h&&(D=D.append(h[p-2>>1])),!(u||p==l.sections.length||l.sections[p+1]<0);)k=l.sections[p++],j=l.sections[p++];s(g,A,w,_,D),g=A,w=_}}}function NCe(l,s,u,h=!1){let g=[],w=h?[]:null,p=new eV(l),k=new eV(s);for(let j=-1;;){if(p.done&&k.len||k.done&&p.len)throw new Error("Mismatched change set lengths");if(p.ins==-1&&k.ins==-1){let A=Math.min(p.len,k.len);og(g,A,-1),p.forward(A),k.forward(A)}else if(k.ins>=0&&(p.ins<0||j==p.i||p.off==0&&(k.len<p.len||k.len==p.len&&!u))){let A=k.len;for(og(g,k.ins,-1);A;){let _=Math.min(p.len,A);p.ins>=0&&j<p.i&&p.len<=_&&(og(g,0,p.ins),w&&b8(w,g,p.text),j=p.i),p.forward(_),A-=_}k.next()}else if(p.ins>=0){let A=0,_=p.len;for(;_;)if(k.ins==-1){let D=Math.min(_,k.len);A+=D,_-=D,k.forward(D)}else if(k.ins==0&&k.len<_)_-=k.len,k.next();else break;og(g,A,j<p.i?p.ins:0),w&&j<p.i&&b8(w,g,p.text),j=p.i,p.forward(p.len-_)}else{if(p.done&&k.done)return w?Jh.createSet(g,w):V3.create(g);throw new Error("Mismatched change set lengths")}}}function jkt(l,s,u=!1){let h=[],g=u?[]:null,w=new eV(l),p=new eV(s);for(let k=!1;;){if(w.done&&p.done)return g?Jh.createSet(h,g):V3.create(h);if(w.ins==0)og(h,w.len,0,k),w.next();else if(p.len==0&&!p.done)og(h,0,p.ins,k),g&&b8(g,h,p.text),p.next();else{if(w.done||p.done)throw new Error("Mismatched change set lengths");{let j=Math.min(w.len2,p.len),A=h.length;if(w.ins==-1){let _=p.ins==-1?-1:p.off?0:p.ins;og(h,j,_,k),g&&_&&b8(g,h,p.text)}else p.ins==-1?(og(h,w.off?0:w.len,j,k),g&&b8(g,h,w.textBit(j))):(og(h,w.off?0:w.len,p.off?0:p.ins,k),g&&!p.off&&b8(g,h,p.text));k=(w.ins>j||p.ins>=0&&p.len>j)&&(k||h.length>A),w.forward2(j),p.forward(j)}}}}class eV{constructor(s){this.set=s,this.i=0,this.next()}next(){let{sections:s}=this.set;this.i<s.length?(this.len=s[this.i++],this.ins=s[this.i++]):(this.len=0,this.ins=-2),this.off=0}get done(){return this.ins==-2}get len2(){return this.ins<0?this.len:this.ins}get text(){let{inserted:s}=this.set,u=this.i-2>>1;return u>=s.length?uc.empty:s[u]}textBit(s){let{inserted:u}=this.set,h=this.i-2>>1;return h>=u.length&&!s?uc.empty:u[h].slice(this.off,s==null?void 0:this.off+s)}forward(s){s==this.len?this.next():(this.len-=s,this.off+=s)}forward2(s){this.ins==-1?this.forward(s):s==this.ins?this.next():(this.ins-=s,this.off+=s)}}class uM{constructor(s,u,h){this.from=s,this.to=u,this.flags=h}get anchor(){return this.flags&32?this.to:this.from}get head(){return this.flags&32?this.from:this.to}get empty(){return this.from==this.to}get assoc(){return this.flags&8?-1:this.flags&16?1:0}get bidiLevel(){let s=this.flags&7;return s==7?null:s}get goalColumn(){let s=this.flags>>6;return s==16777215?void 0:s}map(s,u=-1){let h,g;return this.empty?h=g=s.mapPos(this.from,u):(h=s.mapPos(this.from,1),g=s.mapPos(this.to,-1)),h==this.from&&g==this.to?this:new uM(h,g,this.flags)}extend(s,u=s){if(s<=this.anchor&&u>=this.anchor)return kn.range(s,u);let h=Math.abs(s-this.anchor)>Math.abs(u-this.anchor)?s:u;return kn.range(this.anchor,h)}eq(s,u=!1){return this.anchor==s.anchor&&this.head==s.head&&this.goalColumn==s.goalColumn&&(!u||!this.empty||this.assoc==s.assoc)}toJSON(){return{anchor:this.anchor,head:this.head}}static fromJSON(s){if(!s||typeof s.anchor!="number"||typeof s.head!="number")throw new RangeError("Invalid JSON representation for SelectionRange");return kn.range(s.anchor,s.head)}static create(s,u,h){return new uM(s,u,h)}}class kn{constructor(s,u){this.ranges=s,this.mainIndex=u}map(s,u=-1){return s.empty?this:kn.create(this.ranges.map(h=>h.map(s,u)),this.mainIndex)}eq(s,u=!1){if(this.ranges.length!=s.ranges.length||this.mainIndex!=s.mainIndex)return!1;for(let h=0;h<this.ranges.length;h++)if(!this.ranges[h].eq(s.ranges[h],u))return!1;return!0}get main(){return this.ranges[this.mainIndex]}asSingle(){return this.ranges.length==1?this:new kn([this.main],0)}addRange(s,u=!0){return kn.create([s].concat(this.ranges),u?0:this.mainIndex+1)}replaceRange(s,u=this.mainIndex){let h=this.ranges.slice();return h[u]=s,kn.create(h,this.mainIndex)}toJSON(){return{ranges:this.ranges.map(s=>s.toJSON()),main:this.mainIndex}}static fromJSON(s){if(!s||!Array.isArray(s.ranges)||typeof s.main!="number"||s.main>=s.ranges.length)throw new RangeError("Invalid JSON representation for EditorSelection");return new kn(s.ranges.map(u=>uM.fromJSON(u)),s.main)}static single(s,u=s){return new kn([kn.range(s,u)],0)}static create(s,u=0){if(s.length==0)throw new RangeError("A selection needs at least one range");for(let h=0,g=0;g<s.length;g++){let w=s[g];if(w.empty?w.from<=h:w.from<h)return kn.normalized(s.slice(),u);h=w.to}return new kn(s,u)}static cursor(s,u=0,h,g){return uM.create(s,s,(u==0?0:u<0?8:16)|(h==null?7:Math.min(6,h))|(g??16777215)<<6)}static range(s,u,h,g){let w=(h??16777215)<<6|(g==null?7:Math.min(6,g));return u<s?uM.create(u,s,48|w):uM.create(s,u,(u>s?8:0)|w)}static normalized(s,u=0){let h=s[u];s.sort((g,w)=>g.from-w.from),u=s.indexOf(h);for(let g=1;g<s.length;g++){let w=s[g],p=s[g-1];if(w.empty?w.from<=p.to:w.from<p.to){let k=p.from,j=Math.max(w.to,p.to);g<=u&&u--,s.splice(--g,2,w.anchor>w.head?kn.range(j,k):kn.range(k,j))}}return new kn(s,u)}}function Tkt(l,s){for(let u of l.ranges)if(u.to>s)throw new RangeError("Selection points outside of document")}let JMe=0;class Qi{constructor(s,u,h,g,w){this.combine=s,this.compareInput=u,this.compare=h,this.isStatic=g,this.id=JMe++,this.default=s([]),this.extensions=typeof w=="function"?w(this):w}get reader(){return this}static define(s={}){return new Qi(s.combine||(u=>u),s.compareInput||((u,h)=>u===h),s.compare||(s.combine?(u,h)=>u===h:XMe),!!s.static,s.enables)}of(s){return new Tfe([],this,0,s)}compute(s,u){if(this.isStatic)throw new Error("Can't compute a static facet");return new Tfe(s,this,1,u)}computeN(s,u){if(this.isStatic)throw new Error("Can't compute a static facet");return new Tfe(s,this,2,u)}from(s,u){return u||(u=h=>h),this.compute([s],h=>u(h.field(s)))}}function XMe(l,s){return l==s||l.length==s.length&&l.every((u,h)=>u===s[h])}class Tfe{constructor(s,u,h,g){this.dependencies=s,this.facet=u,this.type=h,this.value=g,this.id=JMe++}dynamicSlot(s){var u;let h=this.value,g=this.facet.compareInput,w=this.id,p=s[w]>>1,k=this.type==2,j=!1,A=!1,_=[];for(let D of this.dependencies)D=="doc"?j=!0:D=="selection"?A=!0:(((u=s[D.id])!==null&&u!==void 0?u:1)&1)==0&&_.push(s[D.id]);return{create(D){return D.values[p]=h(D),1},update(D,I){if(j&&I.docChanged||A&&(I.docChanged||I.selection)||_Ce(D,_)){let B=h(D);if(k?!cxt(B,D.values[p],g):!g(B,D.values[p]))return D.values[p]=B,1}return 0},reconfigure:(D,I)=>{let B,F=I.config.address[w];if(F!=null){let U=Kfe(I,F);if(this.dependencies.every(K=>K instanceof Qi?I.facet(K)===D.facet(K):K instanceof Td?I.field(K,!1)==D.field(K,!1):!0)||(k?cxt(B=h(D),U,g):g(B=h(D),U)))return D.values[p]=U,0}else B=h(D);return D.values[p]=B,1}}}}function cxt(l,s,u){if(l.length!=s.length)return!1;for(let h=0;h<l.length;h++)if(!u(l[h],s[h]))return!1;return!0}function _Ce(l,s){let u=!1;for(let h of s)RX(l,h)&1&&(u=!0);return u}function rdn(l,s,u){let h=u.map(j=>l[j.id]),g=u.map(j=>j.type),w=h.filter(j=>!(j&1)),p=l[s.id]>>1;function k(j){let A=[];for(let _=0;_<h.length;_++){let D=Kfe(j,h[_]);if(g[_]==2)for(let I of D)A.push(I);else A.push(D)}return s.combine(A)}return{create(j){for(let A of h)RX(j,A);return j.values[p]=k(j),1},update(j,A){if(!_Ce(j,w))return 0;let _=k(j);return s.compare(_,j.values[p])?0:(j.values[p]=_,1)},reconfigure(j,A){let _=_Ce(j,h),D=A.config.facets[s.id],I=A.facet(s);if(D&&!_&&XMe(u,D))return j.values[p]=I,0;let B=k(j);return s.compare(B,I)?(j.values[p]=I,0):(j.values[p]=B,1)}}}const Gae=Qi.define({static:!0});class Td{constructor(s,u,h,g,w){this.id=s,this.createF=u,this.updateF=h,this.compareF=g,this.spec=w,this.provides=void 0}static define(s){let u=new Td(JMe++,s.create,s.update,s.compare||((h,g)=>h===g),s);return s.provide&&(u.provides=s.provide(u)),u}create(s){let u=s.facet(Gae).find(h=>h.field==this);return((u==null?void 0:u.create)||this.createF)(s)}slot(s){let u=s[this.id]>>1;return{create:h=>(h.values[u]=this.create(h),1),update:(h,g)=>{let w=h.values[u],p=this.updateF(w,g);return this.compareF(w,p)?0:(h.values[u]=p,1)},reconfigure:(h,g)=>{let w=h.facet(Gae),p=g.facet(Gae),k;return(k=w.find(j=>j.field==this))&&k!=p.find(j=>j.field==this)?(h.values[u]=k.create(h),1):g.config.address[this.id]!=null?(h.values[u]=g.field(this),0):(h.values[u]=this.create(h),1)}}}init(s){return[this,Gae.of({field:this,create:s})]}get extension(){return this}}const oM={lowest:4,low:3,default:2,high:1,highest:0};function xX(l){return s=>new Ekt(s,l)}const E8={highest:xX(oM.highest),high:xX(oM.high),default:xX(oM.default),low:xX(oM.low),lowest:xX(oM.lowest)};class Ekt{constructor(s,u){this.inner=s,this.prec=u}}class TV{of(s){return new DCe(this,s)}reconfigure(s){return TV.reconfigure.of({compartment:this,extension:s})}get(s){return s.config.compartments.get(this)}}class DCe{constructor(s,u){this.compartment=s,this.inner=u}}class Wfe{constructor(s,u,h,g,w,p){for(this.base=s,this.compartments=u,this.dynamicSlots=h,this.address=g,this.staticValues=w,this.facets=p,this.statusTemplate=[];this.statusTemplate.length<h.length;)this.statusTemplate.push(0)}staticFacet(s){let u=this.address[s.id];return u==null?s.default:this.staticValues[u>>1]}static resolve(s,u,h){let g=[],w=Object.create(null),p=new Map;for(let I of sdn(s,u,p))I instanceof Td?g.push(I):(w[I.facet.id]||(w[I.facet.id]=[])).push(I);let k=Object.create(null),j=[],A=[];for(let I of g)k[I.id]=A.length<<1,A.push(B=>I.slot(B));let _=h==null?void 0:h.config.facets;for(let I in w){let B=w[I],F=B[0].facet,U=_&&_[I]||[];if(B.every(K=>K.type==0))if(k[F.id]=j.length<<1|1,XMe(U,B))j.push(h.facet(F));else{let K=F.combine(B.map(Y=>Y.value));j.push(h&&F.compare(K,h.facet(F))?h.facet(F):K)}else{for(let K of B)K.type==0?(k[K.id]=j.length<<1|1,j.push(K.value)):(k[K.id]=A.length<<1,A.push(Y=>K.dynamicSlot(Y)));k[F.id]=A.length<<1,A.push(K=>rdn(K,F,B))}}let D=A.map(I=>I(k));return new Wfe(s,p,D,k,j,w)}}function sdn(l,s,u){let h=[[],[],[],[],[]],g=new Map;function w(p,k){let j=g.get(p);if(j!=null){if(j<=k)return;let A=h[j].indexOf(p);A>-1&&h[j].splice(A,1),p instanceof DCe&&u.delete(p.compartment)}if(g.set(p,k),Array.isArray(p))for(let A of p)w(A,k);else if(p instanceof DCe){if(u.has(p.compartment))throw new RangeError("Duplicate use of compartment in extensions");let A=s.get(p.compartment)||p.inner;u.set(p.compartment,A),w(A,k)}else if(p instanceof Ekt)w(p.inner,p.prec);else if(p instanceof Td)h[k].push(p),p.provides&&w(p.provides,k);else if(p instanceof Tfe)h[k].push(p),p.facet.extensions&&w(p.facet.extensions,oM.default);else{let A=p.extension;if(!A)throw new Error(`Unrecognized extension value in extension set (${p}). This sometimes happens because multiple instances of @codemirror/state are loaded, breaking instanceof checks.`);w(A,k)}}return w(l,oM.default),h.reduce((p,k)=>p.concat(k))}function RX(l,s){if(s&1)return 2;let u=s>>1,h=l.status[u];if(h==4)throw new Error("Cyclic dependency between fields and/or facets");if(h&2)return h;l.status[u]=4;let g=l.computeSlot(l,l.config.dynamicSlots[u]);return l.status[u]=2|g}function Kfe(l,s){return s&1?l.config.staticValues[s>>1]:l.values[s>>1]}const Ckt=Qi.define(),LCe=Qi.define({combine:l=>l.some(s=>s),static:!0}),Mkt=Qi.define({combine:l=>l.length?l[0]:void 0,static:!0}),Akt=Qi.define(),Nkt=Qi.define(),_kt=Qi.define(),Dkt=Qi.define({combine:l=>l.length?l[0]:!1});class cO{constructor(s,u){this.type=s,this.value=u}static define(){return new odn}}class odn{of(s){return new cO(this,s)}}class cdn{constructor(s){this.map=s}of(s){return new Ds(this,s)}}class Ds{constructor(s,u){this.type=s,this.value=u}map(s){let u=this.type.map(this.value,s);return u===void 0?void 0:u==this.value?this:new Ds(this.type,u)}is(s){return this.type==s}static define(s={}){return new cdn(s.map||(u=>u))}static mapEffects(s,u){if(!s.length)return s;let h=[];for(let g of s){let w=g.map(u);w&&h.push(w)}return h}}Ds.reconfigure=Ds.define();Ds.appendConfig=Ds.define();class hh{constructor(s,u,h,g,w,p){this.startState=s,this.changes=u,this.selection=h,this.effects=g,this.annotations=w,this.scrollIntoView=p,this._doc=null,this._state=null,h&&Tkt(h,u.newLength),w.some(k=>k.type==hh.time)||(this.annotations=w.concat(hh.time.of(Date.now())))}static create(s,u,h,g,w,p){return new hh(s,u,h,g,w,p)}get newDoc(){return this._doc||(this._doc=this.changes.apply(this.startState.doc))}get newSelection(){return this.selection||this.startState.selection.map(this.changes)}get state(){return this._state||this.startState.applyTransaction(this),this._state}annotation(s){for(let u of this.annotations)if(u.type==s)return u.value}get docChanged(){return!this.changes.empty}get reconfigured(){return this.startState.config!=this.state.config}isUserEvent(s){let u=this.annotation(hh.userEvent);return!!(u&&(u==s||u.length>s.length&&u.slice(0,s.length)==s&&u[s.length]=="."))}}hh.time=cO.define();hh.userEvent=cO.define();hh.addToHistory=cO.define();hh.remote=cO.define();function ldn(l,s){let u=[];for(let h=0,g=0;;){let w,p;if(h<l.length&&(g==s.length||s[g]>=l[h]))w=l[h++],p=l[h++];else if(g<s.length)w=s[g++],p=s[g++];else return u;!u.length||u[u.length-1]<w?u.push(w,p):u[u.length-1]<p&&(u[u.length-1]=p)}}function Lkt(l,s,u){var h;let g,w,p;return u?(g=s.changes,w=Jh.empty(s.changes.length),p=l.changes.compose(s.changes)):(g=s.changes.map(l.changes),w=l.changes.mapDesc(s.changes,!0),p=l.changes.compose(g)),{changes:p,selection:s.selection?s.selection.map(w):(h=l.selection)===null||h===void 0?void 0:h.map(g),effects:Ds.mapEffects(l.effects,g).concat(Ds.mapEffects(s.effects,w)),annotations:l.annotations.length?l.annotations.concat(s.annotations):s.annotations,scrollIntoView:l.scrollIntoView||s.scrollIntoView}}function PCe(l,s,u){let h=s.selection,g=bI(s.annotations);return s.userEvent&&(g=g.concat(hh.userEvent.of(s.userEvent))),{changes:s.changes instanceof Jh?s.changes:Jh.of(s.changes||[],u,l.facet(Mkt)),selection:h&&(h instanceof kn?h:kn.single(h.anchor,h.head)),effects:bI(s.effects),annotations:g,scrollIntoView:!!s.scrollIntoView}}function Pkt(l,s,u){let h=PCe(l,s.length?s[0]:{},l.doc.length);s.length&&s[0].filter===!1&&(u=!1);for(let w=1;w<s.length;w++){s[w].filter===!1&&(u=!1);let p=!!s[w].sequential;h=Lkt(h,PCe(l,s[w],p?h.changes.newLength:l.doc.length),p)}let g=hh.create(l,h.changes,h.selection,h.effects,h.annotations,h.scrollIntoView);return adn(u?udn(g):g)}function udn(l){let s=l.startState,u=!0;for(let g of s.facet(Akt)){let w=g(l);if(w===!1){u=!1;break}Array.isArray(w)&&(u=u===!0?w:ldn(u,w))}if(u!==!0){let g,w;if(u===!1)w=l.changes.invertedDesc,g=Jh.empty(s.doc.length);else{let p=l.changes.filter(u);g=p.changes,w=p.filtered.mapDesc(p.changes).invertedDesc}l=hh.create(s,g,l.selection&&l.selection.map(w),Ds.mapEffects(l.effects,w),l.annotations,l.scrollIntoView)}let h=s.facet(Nkt);for(let g=h.length-1;g>=0;g--){let w=h[g](l);w instanceof hh?l=w:Array.isArray(w)&&w.length==1&&w[0]instanceof hh?l=w[0]:l=Pkt(s,bI(w),!1)}return l}function adn(l){let s=l.startState,u=s.facet(_kt),h=l;for(let g=u.length-1;g>=0;g--){let w=u[g](l);w&&Object.keys(w).length&&(h=Lkt(h,PCe(s,w,l.changes.newLength),!0))}return h==l?l:hh.create(s,l.changes,l.selection,h.effects,h.annotations,h.scrollIntoView)}const fdn=[];function bI(l){return l==null?fdn:Array.isArray(l)?l:[l]}var ea=(function(l){return l[l.Word=0]="Word",l[l.Space=1]="Space",l[l.Other=2]="Other",l})(ea||(ea={}));const hdn=/[\u00df\u0587\u0590-\u05f4\u0600-\u06ff\u3040-\u309f\u30a0-\u30ff\u3400-\u4db5\u4e00-\u9fcc\uac00-\ud7af]/;let ICe;try{ICe=new RegExp("[\\p{Alphabetic}\\p{Number}_]","u")}catch{}function ddn(l){if(ICe)return ICe.test(l);for(let s=0;s<l.length;s++){let u=l[s];if(/\w/.test(u)||u>""&&(u.toUpperCase()!=u.toLowerCase()||hdn.test(u)))return!0}return!1}function gdn(l){return s=>{if(!/\S/.test(s))return ea.Space;if(ddn(s))return ea.Word;for(let u=0;u<l.length;u++)if(s.indexOf(l[u])>-1)return ea.Word;return ea.Other}}class Ic{constructor(s,u,h,g,w,p){this.config=s,this.doc=u,this.selection=h,this.values=g,this.status=s.statusTemplate.slice(),this.computeSlot=w,p&&(p._state=this);for(let k=0;k<this.config.dynamicSlots.length;k++)RX(this,k<<1);this.computeSlot=null}field(s,u=!0){let h=this.config.address[s.id];if(h==null){if(u)throw new RangeError("Field is not present in this state");return}return RX(this,h),Kfe(this,h)}update(...s){return Pkt(this,s,!0)}applyTransaction(s){let u=this.config,{base:h,compartments:g}=u;for(let k of s.effects)k.is(TV.reconfigure)?(u&&(g=new Map,u.compartments.forEach((j,A)=>g.set(A,j)),u=null),g.set(k.value.compartment,k.value.extension)):k.is(Ds.reconfigure)?(u=null,h=k.value):k.is(Ds.appendConfig)&&(u=null,h=bI(h).concat(k.value));let w;u?w=s.startState.values.slice():(u=Wfe.resolve(h,g,this),w=new Ic(u,this.doc,this.selection,u.dynamicSlots.map(()=>null),(j,A)=>A.reconfigure(j,this),null).values);let p=s.startState.facet(LCe)?s.newSelection:s.newSelection.asSingle();new Ic(u,s.newDoc,p,w,(k,j)=>j.update(k,s),s)}replaceSelection(s){return typeof s=="string"&&(s=this.toText(s)),this.changeByRange(u=>({changes:{from:u.from,to:u.to,insert:s},range:kn.cursor(u.from+s.length)}))}changeByRange(s){let u=this.selection,h=s(u.ranges[0]),g=this.changes(h.changes),w=[h.range],p=bI(h.effects);for(let k=1;k<u.ranges.length;k++){let j=s(u.ranges[k]),A=this.changes(j.changes),_=A.map(g);for(let I=0;I<k;I++)w[I]=w[I].map(_);let D=g.mapDesc(A,!0);w.push(j.range.map(D)),g=g.compose(_),p=Ds.mapEffects(p,_).concat(Ds.mapEffects(bI(j.effects),D))}return{changes:g,selection:kn.create(w,u.mainIndex),effects:p}}changes(s=[]){return s instanceof Jh?s:Jh.of(s,this.doc.length,this.facet(Ic.lineSeparator))}toText(s){return uc.of(s.split(this.facet(Ic.lineSeparator)||MCe))}sliceDoc(s=0,u=this.doc.length){return this.doc.sliceString(s,u,this.lineBreak)}facet(s){let u=this.config.address[s.id];return u==null?s.default:(RX(this,u),Kfe(this,u))}toJSON(s){let u={doc:this.sliceDoc(),selection:this.selection.toJSON()};if(s)for(let h in s){let g=s[h];g instanceof Td&&this.config.address[g.id]!=null&&(u[h]=g.spec.toJSON(this.field(s[h]),this))}return u}static fromJSON(s,u={},h){if(!s||typeof s.doc!="string")throw new RangeError("Invalid JSON representation for EditorState");let g=[];if(h){for(let w in h)if(Object.prototype.hasOwnProperty.call(s,w)){let p=h[w],k=s[w];g.push(p.init(j=>p.spec.fromJSON(k,j)))}}return Ic.create({doc:s.doc,selection:kn.fromJSON(s.selection),extensions:u.extensions?g.concat([u.extensions]):g})}static create(s={}){let u=Wfe.resolve(s.extensions||[],new Map),h=s.doc instanceof uc?s.doc:uc.of((s.doc||"").split(u.staticFacet(Ic.lineSeparator)||MCe)),g=s.selection?s.selection instanceof kn?s.selection:kn.single(s.selection.anchor,s.selection.head):kn.single(0);return Tkt(g,h.length),u.staticFacet(LCe)||(g=g.asSingle()),new Ic(u,h,g,u.dynamicSlots.map(()=>null),(w,p)=>p.create(w),null)}get tabSize(){return this.facet(Ic.tabSize)}get lineBreak(){return this.facet(Ic.lineSeparator)||`
`}get readOnly(){return this.facet(Dkt)}phrase(s,...u){for(let h of this.facet(Ic.phrases))if(Object.prototype.hasOwnProperty.call(h,s)){s=h[s];break}return u.length&&(s=s.replace(/\$(\$|\d*)/g,(h,g)=>{if(g=="$")return"$";let w=+(g||1);return!w||w>u.length?h:u[w-1]})),s}languageDataAt(s,u,h=-1){let g=[];for(let w of this.facet(Ckt))for(let p of w(this,u,h))Object.prototype.hasOwnProperty.call(p,s)&&g.push(p[s]);return g}charCategorizer(s){let u=this.languageDataAt("wordChars",s);return gdn(u.length?u[0]:"")}wordAt(s){let{text:u,from:h,length:g}=this.doc.lineAt(s),w=this.charCategorizer(s),p=s-h,k=s-h;for(;p>0;){let j=Sd(u,p,!1);if(w(u.slice(j,p))!=ea.Word)break;p=j}for(;k<g;){let j=Sd(u,k);if(w(u.slice(k,j))!=ea.Word)break;k=j}return p==k?null:kn.range(p+h,k+h)}}Ic.allowMultipleSelections=LCe;Ic.tabSize=Qi.define({combine:l=>l.length?l[0]:4});Ic.lineSeparator=Mkt;Ic.readOnly=Dkt;Ic.phrases=Qi.define({compare(l,s){let u=Object.keys(l),h=Object.keys(s);return u.length==h.length&&u.every(g=>l[g]==s[g])}});Ic.languageData=Ckt;Ic.changeFilter=Akt;Ic.transactionFilter=Nkt;Ic.transactionExtender=_kt;TV.reconfigure=Ds.define();function Z3(l,s,u={}){let h={};for(let g of l)for(let w of Object.keys(g)){let p=g[w],k=h[w];if(k===void 0)h[w]=p;else if(!(k===p||p===void 0))if(Object.hasOwnProperty.call(u,w))h[w]=u[w](k,p);else throw new Error("Config merge conflict for field "+w)}for(let g in s)h[g]===void 0&&(h[g]=s[g]);return h}class y8{eq(s){return this==s}range(s,u=s){return RCe.create(s,u,this)}}y8.prototype.startSide=y8.prototype.endSide=0;y8.prototype.point=!1;y8.prototype.mapMode=u1.TrackDel;function VMe(l,s){return l==s||l.constructor==s.constructor&&l.eq(s)}let RCe=class Ikt{constructor(s,u,h){this.from=s,this.to=u,this.value=h}static create(s,u,h){return new Ikt(s,u,h)}};function $Ce(l,s){return l.from-s.from||l.value.startSide-s.value.startSide}class WMe{constructor(s,u,h,g){this.from=s,this.to=u,this.value=h,this.maxPoint=g}get length(){return this.to[this.to.length-1]}findIndex(s,u,h,g=0){let w=h?this.to:this.from;for(let p=g,k=w.length;;){if(p==k)return p;let j=p+k>>1,A=w[j]-s||(h?this.value[j].endSide:this.value[j].startSide)-u;if(j==p)return A>=0?p:k;A>=0?k=j:p=j+1}}between(s,u,h,g){for(let w=this.findIndex(u,-1e9,!0),p=this.findIndex(h,1e9,!1,w);w<p;w++)if(g(this.from[w]+s,this.to[w]+s,this.value[w])===!1)return!1}map(s,u){let h=[],g=[],w=[],p=-1,k=-1;for(let j=0;j<this.value.length;j++){let A=this.value[j],_=this.from[j]+s,D=this.to[j]+s,I,B;if(_==D){let F=u.mapPos(_,A.startSide,A.mapMode);if(F==null||(I=B=F,A.startSide!=A.endSide&&(B=u.mapPos(_,A.endSide),B<I)))continue}else if(I=u.mapPos(_,A.startSide),B=u.mapPos(D,A.endSide),I>B||I==B&&A.startSide>0&&A.endSide<=0)continue;(B-I||A.endSide-A.startSide)<0||(p<0&&(p=I),A.point&&(k=Math.max(k,B-I)),h.push(A),g.push(I-p),w.push(B-p))}return{mapped:h.length?new WMe(g,w,h,k):null,pos:p}}}class xo{constructor(s,u,h,g){this.chunkPos=s,this.chunk=u,this.nextLayer=h,this.maxPoint=g}static create(s,u,h,g){return new xo(s,u,h,g)}get length(){let s=this.chunk.length-1;return s<0?0:Math.max(this.chunkEnd(s),this.nextLayer.length)}get size(){if(this.isEmpty)return 0;let s=this.nextLayer.size;for(let u of this.chunk)s+=u.value.length;return s}chunkEnd(s){return this.chunkPos[s]+this.chunk[s].length}update(s){let{add:u=[],sort:h=!1,filterFrom:g=0,filterTo:w=this.length}=s,p=s.filter;if(u.length==0&&!p)return this;if(h&&(u=u.slice().sort($Ce)),this.isEmpty)return u.length?xo.of(u):this;let k=new Rkt(this,null,-1).goto(0),j=0,A=[],_=new x8;for(;k.value||j<u.length;)if(j<u.length&&(k.from-u[j].from||k.startSide-u[j].value.startSide)>=0){let D=u[j++];_.addInner(D.from,D.to,D.value)||A.push(D)}else k.rangeIndex==1&&k.chunkIndex<this.chunk.length&&(j==u.length||this.chunkEnd(k.chunkIndex)<u[j].from)&&(!p||g>this.chunkEnd(k.chunkIndex)||w<this.chunkPos[k.chunkIndex])&&_.addChunk(this.chunkPos[k.chunkIndex],this.chunk[k.chunkIndex])?k.nextChunk():((!p||g>k.to||w<k.from||p(k.from,k.to,k.value))&&(_.addInner(k.from,k.to,k.value)||A.push(RCe.create(k.from,k.to,k.value))),k.next());return _.finishInner(this.nextLayer.isEmpty&&!A.length?xo.empty:this.nextLayer.update({add:A,filter:p,filterFrom:g,filterTo:w}))}map(s){if(s.empty||this.isEmpty)return this;let u=[],h=[],g=-1;for(let p=0;p<this.chunk.length;p++){let k=this.chunkPos[p],j=this.chunk[p],A=s.touchesRange(k,k+j.length);if(A===!1)g=Math.max(g,j.maxPoint),u.push(j),h.push(s.mapPos(k));else if(A===!0){let{mapped:_,pos:D}=j.map(k,s);_&&(g=Math.max(g,_.maxPoint),u.push(_),h.push(D))}}let w=this.nextLayer.map(s);return u.length==0?w:new xo(h,u,w||xo.empty,g)}between(s,u,h){if(!this.isEmpty){for(let g=0;g<this.chunk.length;g++){let w=this.chunkPos[g],p=this.chunk[g];if(u>=w&&s<=w+p.length&&p.between(w,s-w,u-w,h)===!1)return}this.nextLayer.between(s,u,h)}}iter(s=0){return tV.from([this]).goto(s)}get isEmpty(){return this.nextLayer==this}static iter(s,u=0){return tV.from(s).goto(u)}static compare(s,u,h,g,w=-1){let p=s.filter(D=>D.maxPoint>0||!D.isEmpty&&D.maxPoint>=w),k=u.filter(D=>D.maxPoint>0||!D.isEmpty&&D.maxPoint>=w),j=lxt(p,k,h),A=new kX(p,j,w),_=new kX(k,j,w);h.iterGaps((D,I,B)=>uxt(A,D,_,I,B,g)),h.empty&&h.length==0&&uxt(A,0,_,0,0,g)}static eq(s,u,h=0,g){g==null&&(g=999999999);let w=s.filter(_=>!_.isEmpty&&u.indexOf(_)<0),p=u.filter(_=>!_.isEmpty&&s.indexOf(_)<0);if(w.length!=p.length)return!1;if(!w.length)return!0;let k=lxt(w,p),j=new kX(w,k,0).goto(h),A=new kX(p,k,0).goto(h);for(;;){if(j.to!=A.to||!BCe(j.active,A.active)||j.point&&(!A.point||!VMe(j.point,A.point)))return!1;if(j.to>g)return!0;j.next(),A.next()}}static spans(s,u,h,g,w=-1){let p=new kX(s,null,w).goto(u),k=u,j=p.openStart;for(;;){let A=Math.min(p.to,h);if(p.point){let _=p.activeForPoint(p.to),D=p.pointFrom<u?_.length+1:p.point.startSide<0?_.length:Math.min(_.length,j);g.point(k,A,p.point,_,D,p.pointRank),j=Math.min(p.openEnd(A),_.length)}else A>k&&(g.span(k,A,p.active,j),j=p.openEnd(A));if(p.to>h)return j+(p.point&&p.to>h?1:0);k=p.to,p.next()}}static of(s,u=!1){let h=new x8;for(let g of s instanceof RCe?[s]:u?pdn(s):s)h.add(g.from,g.to,g.value);return h.finish()}static join(s){if(!s.length)return xo.empty;let u=s[s.length-1];for(let h=s.length-2;h>=0;h--)for(let g=s[h];g!=xo.empty;g=g.nextLayer)u=new xo(g.chunkPos,g.chunk,u,Math.max(g.maxPoint,u.maxPoint));return u}}xo.empty=new xo([],[],null,-1);function pdn(l){if(l.length>1)for(let s=l[0],u=1;u<l.length;u++){let h=l[u];if($Ce(s,h)>0)return l.slice().sort($Ce);s=h}return l}xo.empty.nextLayer=xo.empty;class x8{finishChunk(s){this.chunks.push(new WMe(this.from,this.to,this.value,this.maxPoint)),this.chunkPos.push(this.chunkStart),this.chunkStart=-1,this.setMaxPoint=Math.max(this.setMaxPoint,this.maxPoint),this.maxPoint=-1,s&&(this.from=[],this.to=[],this.value=[])}constructor(){this.chunks=[],this.chunkPos=[],this.chunkStart=-1,this.last=null,this.lastFrom=-1e9,this.lastTo=-1e9,this.from=[],this.to=[],this.value=[],this.maxPoint=-1,this.setMaxPoint=-1,this.nextLayer=null}add(s,u,h){this.addInner(s,u,h)||(this.nextLayer||(this.nextLayer=new x8)).add(s,u,h)}addInner(s,u,h){let g=s-this.lastTo||h.startSide-this.last.endSide;if(g<=0&&(s-this.lastFrom||h.startSide-this.last.startSide)<0)throw new Error("Ranges must be added sorted by `from` position and `startSide`");return g<0?!1:(this.from.length==250&&this.finishChunk(!0),this.chunkStart<0&&(this.chunkStart=s),this.from.push(s-this.chunkStart),this.to.push(u-this.chunkStart),this.last=h,this.lastFrom=s,this.lastTo=u,this.value.push(h),h.point&&(this.maxPoint=Math.max(this.maxPoint,u-s)),!0)}addChunk(s,u){if((s-this.lastTo||u.value[0].startSide-this.last.endSide)<0)return!1;this.from.length&&this.finishChunk(!0),this.setMaxPoint=Math.max(this.setMaxPoint,u.maxPoint),this.chunks.push(u),this.chunkPos.push(s);let h=u.value.length-1;return this.last=u.value[h],this.lastFrom=u.from[h]+s,this.lastTo=u.to[h]+s,!0}finish(){return this.finishInner(xo.empty)}finishInner(s){if(this.from.length&&this.finishChunk(!1),this.chunks.length==0)return s;let u=xo.create(this.chunkPos,this.chunks,this.nextLayer?this.nextLayer.finishInner(s):s,this.setMaxPoint);return this.from=null,u}}function lxt(l,s,u){let h=new Map;for(let w of l)for(let p=0;p<w.chunk.length;p++)w.chunk[p].maxPoint<=0&&h.set(w.chunk[p],w.chunkPos[p]);let g=new Set;for(let w of s)for(let p=0;p<w.chunk.length;p++){let k=h.get(w.chunk[p]);k!=null&&(u?u.mapPos(k):k)==w.chunkPos[p]&&!(u!=null&&u.touchesRange(k,k+w.chunk[p].length))&&g.add(w.chunk[p])}return g}class Rkt{constructor(s,u,h,g=0){this.layer=s,this.skip=u,this.minPoint=h,this.rank=g}get startSide(){return this.value?this.value.startSide:0}get endSide(){return this.value?this.value.endSide:0}goto(s,u=-1e9){return this.chunkIndex=this.rangeIndex=0,this.gotoInner(s,u,!1),this}gotoInner(s,u,h){for(;this.chunkIndex<this.layer.chunk.length;){let g=this.layer.chunk[this.chunkIndex];if(!(this.skip&&this.skip.has(g)||this.layer.chunkEnd(this.chunkIndex)<s||g.maxPoint<this.minPoint))break;this.chunkIndex++,h=!1}if(this.chunkIndex<this.layer.chunk.length){let g=this.layer.chunk[this.chunkIndex].findIndex(s-this.layer.chunkPos[this.chunkIndex],u,!0);(!h||this.rangeIndex<g)&&this.setRangeIndex(g)}this.next()}forward(s,u){(this.to-s||this.endSide-u)<0&&this.gotoInner(s,u,!0)}next(){for(;;)if(this.chunkIndex==this.layer.chunk.length){this.from=this.to=1e9,this.value=null;break}else{let s=this.layer.chunkPos[this.chunkIndex],u=this.layer.chunk[this.chunkIndex],h=s+u.from[this.rangeIndex];if(this.from=h,this.to=s+u.to[this.rangeIndex],this.value=u.value[this.rangeIndex],this.setRangeIndex(this.rangeIndex+1),this.minPoint<0||this.value.point&&this.to-this.from>=this.minPoint)break}}setRangeIndex(s){if(s==this.layer.chunk[this.chunkIndex].value.length){if(this.chunkIndex++,this.skip)for(;this.chunkIndex<this.layer.chunk.length&&this.skip.has(this.layer.chunk[this.chunkIndex]);)this.chunkIndex++;this.rangeIndex=0}else this.rangeIndex=s}nextChunk(){this.chunkIndex++,this.rangeIndex=0,this.next()}compare(s){return this.from-s.from||this.startSide-s.startSide||this.rank-s.rank||this.to-s.to||this.endSide-s.endSide}}class tV{constructor(s){this.heap=s}static from(s,u=null,h=-1){let g=[];for(let w=0;w<s.length;w++)for(let p=s[w];!p.isEmpty;p=p.nextLayer)p.maxPoint>=h&&g.push(new Rkt(p,u,h,w));return g.length==1?g[0]:new tV(g)}get startSide(){return this.value?this.value.startSide:0}goto(s,u=-1e9){for(let h of this.heap)h.goto(s,u);for(let h=this.heap.length>>1;h>=0;h--)CEe(this.heap,h);return this.next(),this}forward(s,u){for(let h of this.heap)h.forward(s,u);for(let h=this.heap.length>>1;h>=0;h--)CEe(this.heap,h);(this.to-s||this.value.endSide-u)<0&&this.next()}next(){if(this.heap.length==0)this.from=this.to=1e9,this.value=null,this.rank=-1;else{let s=this.heap[0];this.from=s.from,this.to=s.to,this.value=s.value,this.rank=s.rank,s.value&&s.next(),CEe(this.heap,0)}}}function CEe(l,s){for(let u=l[s];;){let h=(s<<1)+1;if(h>=l.length)break;let g=l[h];if(h+1<l.length&&g.compare(l[h+1])>=0&&(g=l[h+1],h++),u.compare(g)<0)break;l[h]=u,l[s]=g,s=h}}class kX{constructor(s,u,h){this.minPoint=h,this.active=[],this.activeTo=[],this.activeRank=[],this.minActive=-1,this.point=null,this.pointFrom=0,this.pointRank=0,this.to=-1e9,this.endSide=0,this.openStart=-1,this.cursor=tV.from(s,u,h)}goto(s,u=-1e9){return this.cursor.goto(s,u),this.active.length=this.activeTo.length=this.activeRank.length=0,this.minActive=-1,this.to=s,this.endSide=u,this.openStart=-1,this.next(),this}forward(s,u){for(;this.minActive>-1&&(this.activeTo[this.minActive]-s||this.active[this.minActive].endSide-u)<0;)this.removeActive(this.minActive);this.cursor.forward(s,u)}removeActive(s){Uae(this.active,s),Uae(this.activeTo,s),Uae(this.activeRank,s),this.minActive=axt(this.active,this.activeTo)}addActive(s){let u=0,{value:h,to:g,rank:w}=this.cursor;for(;u<this.activeRank.length&&(w-this.activeRank[u]||g-this.activeTo[u])>0;)u++;Jae(this.active,u,h),Jae(this.activeTo,u,g),Jae(this.activeRank,u,w),s&&Jae(s,u,this.cursor.from),this.minActive=axt(this.active,this.activeTo)}next(){let s=this.to,u=this.point;this.point=null;let h=this.openStart<0?[]:null;for(;;){let g=this.minActive;if(g>-1&&(this.activeTo[g]-this.cursor.from||this.active[g].endSide-this.cursor.startSide)<0){if(this.activeTo[g]>s){this.to=this.activeTo[g],this.endSide=this.active[g].endSide;break}this.removeActive(g),h&&Uae(h,g)}else if(this.cursor.value)if(this.cursor.from>s){this.to=this.cursor.from,this.endSide=this.cursor.startSide;break}else{let w=this.cursor.value;if(!w.point)this.addActive(h),this.cursor.next();else if(u&&this.cursor.to==this.to&&this.cursor.from<this.cursor.to)this.cursor.next();else{this.point=w,this.pointFrom=this.cursor.from,this.pointRank=this.cursor.rank,this.to=this.cursor.to,this.endSide=w.endSide,this.cursor.next(),this.forward(this.to,this.endSide);break}}else{this.to=this.endSide=1e9;break}}if(h){this.openStart=0;for(let g=h.length-1;g>=0&&h[g]<s;g--)this.openStart++}}activeForPoint(s){if(!this.active.length)return this.active;let u=[];for(let h=this.active.length-1;h>=0&&!(this.activeRank[h]<this.pointRank);h--)(this.activeTo[h]>s||this.activeTo[h]==s&&this.active[h].endSide>=this.point.endSide)&&u.push(this.active[h]);return u.reverse()}openEnd(s){let u=0;for(let h=this.activeTo.length-1;h>=0&&this.activeTo[h]>s;h--)u++;return u}}function uxt(l,s,u,h,g,w){l.goto(s),u.goto(h);let p=h+g,k=h,j=h-s,A=!!w.boundChange;for(let _=!1;;){let D=l.to+j-u.to,I=D||l.endSide-u.endSide,B=I<0?l.to+j:u.to,F=Math.min(B,p);if(l.point||u.point?(l.point&&u.point&&VMe(l.point,u.point)&&BCe(l.activeForPoint(l.to),u.activeForPoint(u.to))||w.comparePoint(k,F,l.point,u.point),_=!1):(_&&w.boundChange(k),F>k&&!BCe(l.active,u.active)&&w.compareRange(k,F,l.active,u.active),A&&F<p&&(D||l.openEnd(B)!=u.openEnd(B))&&(_=!0)),B>p)break;k=B,I<=0&&l.next(),I>=0&&u.next()}}function BCe(l,s){if(l.length!=s.length)return!1;for(let u=0;u<l.length;u++)if(l[u]!=s[u]&&!VMe(l[u],s[u]))return!1;return!0}function Uae(l,s){for(let u=s,h=l.length-1;u<h;u++)l[u]=l[u+1];l.pop()}function Jae(l,s,u){for(let h=l.length-1;h>=s;h--)l[h+1]=l[h];l[s]=u}function axt(l,s){let u=-1,h=1e9;for(let g=0;g<s.length;g++)(s[g]-h||l[g].endSide-l[u].endSide)<0&&(u=g,h=s[g]);return u}function EV(l,s,u=l.length){let h=0;for(let g=0;g<u&&g<l.length;)l.charCodeAt(g)==9?(h+=s-h%s,g++):(h++,g=Sd(l,g));return h}function zCe(l,s,u,h){for(let g=0,w=0;;){if(w>=s)return g;if(g==l.length)break;w+=l.charCodeAt(g)==9?u-w%u:1,g=Sd(l,g)}return h===!0?-1:l.length}const FCe="ͼ",fxt=typeof Symbol>"u"?"__"+FCe:Symbol.for(FCe),qCe=typeof Symbol>"u"?"__styleSet"+Math.floor(Math.random()*1e8):Symbol("styleSet"),hxt=typeof globalThis<"u"?globalThis:typeof window<"u"?window:{};class k8{constructor(s,u){this.rules=[];let{finish:h}=u||{};function g(p){return/^@/.test(p)?[p]:p.split(/,\s*/)}function w(p,k,j,A){let _=[],D=/^@(\w+)\b/.exec(p[0]),I=D&&D[1]=="keyframes";if(D&&k==null)return j.push(p[0]+";");for(let B in k){let F=k[B];if(/&/.test(B))w(B.split(/,\s*/).map(U=>p.map(K=>U.replace(/&/,K))).reduce((U,K)=>U.concat(K)),F,j);else if(F&&typeof F=="object"){if(!D)throw new RangeError("The value of a property ("+B+") should be a primitive value.");w(g(B),F,_,I)}else F!=null&&_.push(B.replace(/_.*/,"").replace(/[A-Z]/g,U=>"-"+U.toLowerCase())+": "+F+";")}(_.length||I)&&j.push((h&&!D&&!A?p.map(h):p).join(", ")+" {"+_.join(" ")+"}")}for(let p in s)w(g(p),s[p],this.rules)}getRules(){return this.rules.join(`
`)}static newName(){let s=hxt[fxt]||1;return hxt[fxt]=s+1,FCe+s.toString(36)}static mount(s,u,h){let g=s[qCe],w=h&&h.nonce;g?w&&g.setNonce(w):g=new bdn(s,w),g.mount(Array.isArray(u)?u:[u],s)}}let dxt=new Map;class bdn{constructor(s,u){let h=s.ownerDocument||s,g=h.defaultView;if(!s.head&&s.adoptedStyleSheets&&g.CSSStyleSheet){let w=dxt.get(h);if(w)return s[qCe]=w;this.sheet=new g.CSSStyleSheet,dxt.set(h,this)}else this.styleTag=h.createElement("style"),u&&this.styleTag.setAttribute("nonce",u);this.modules=[],s[qCe]=this}mount(s,u){let h=this.sheet,g=0,w=0;for(let p=0;p<s.length;p++){let k=s[p],j=this.modules.indexOf(k);if(j<w&&j>-1&&(this.modules.splice(j,1),w--,j=-1),j==-1){if(this.modules.splice(w++,0,k),h)for(let A=0;A<k.rules.length;A++)h.insertRule(k.rules[A],g++)}else{for(;w<j;)g+=this.modules[w++].rules.length;g+=k.rules.length,w++}}if(h)u.adoptedStyleSheets.indexOf(this.sheet)<0&&(u.adoptedStyleSheets=[this.sheet,...u.adoptedStyleSheets]);else{let p="";for(let j=0;j<this.modules.length;j++)p+=this.modules[j].getRules()+`
`;this.styleTag.textContent=p;let k=u.head||u;this.styleTag.parentNode!=k&&k.insertBefore(this.styleTag,k.firstChild)}}setNonce(s){this.styleTag&&this.styleTag.getAttribute("nonce")!=s&&this.styleTag.setAttribute("nonce",s)}}var O8={8:"Backspace",9:"Tab",10:"Enter",12:"NumLock",13:"Enter",16:"Shift",17:"Control",18:"Alt",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",44:"PrintScreen",45:"Insert",46:"Delete",59:";",61:"=",91:"Meta",92:"Meta",106:"*",107:"+",108:",",109:"-",110:".",111:"/",144:"NumLock",145:"ScrollLock",160:"Shift",161:"Shift",162:"Control",163:"Control",164:"Alt",165:"Alt",173:"-",186:";",187:"=",188:",",189:"-",190:".",191:"/",192:"`",219:"[",220:"\\",221:"]",222:"'"},nV={48:")",49:"!",50:"@",51:"#",52:"$",53:"%",54:"^",55:"&",56:"*",57:"(",59:":",61:"+",173:"_",186:":",187:"+",188:"<",189:"_",190:">",191:"?",192:"~",219:"{",220:"|",221:"}",222:'"'},mdn=typeof navigator<"u"&&/Mac/.test(navigator.platform),wdn=typeof navigator<"u"&&/MSIE \d|Trident\/(?:[7-9]|\d{2,})\..*rv:(\d+)/.exec(navigator.userAgent);for(var l1=0;l1<10;l1++)O8[48+l1]=O8[96+l1]=String(l1);for(var l1=1;l1<=24;l1++)O8[l1+111]="F"+l1;for(var l1=65;l1<=90;l1++)O8[l1]=String.fromCharCode(l1+32),nV[l1]=String.fromCharCode(l1);for(var MEe in O8)nV.hasOwnProperty(MEe)||(nV[MEe]=O8[MEe]);function vdn(l){var s=mdn&&l.metaKey&&l.shiftKey&&!l.ctrlKey&&!l.altKey||wdn&&l.shiftKey&&l.key&&l.key.length==1||l.key=="Unidentified",u=!s&&l.key||(l.shiftKey?nV:O8)[l.keyCode]||l.key||"Unidentified";return u=="Esc"&&(u="Escape"),u=="Del"&&(u="Delete"),u=="Left"&&(u="ArrowLeft"),u=="Up"&&(u="ArrowUp"),u=="Right"&&(u="ArrowRight"),u=="Down"&&(u="ArrowDown"),u}function $l(){var l=arguments[0];typeof l=="string"&&(l=document.createElement(l));var s=1,u=arguments[1];if(u&&typeof u=="object"&&u.nodeType==null&&!Array.isArray(u)){for(var h in u)if(Object.prototype.hasOwnProperty.call(u,h)){var g=u[h];typeof g=="string"?l.setAttribute(h,g):g!=null&&(l[h]=g)}s++}for(;s<arguments.length;s++)$kt(l,arguments[s]);return l}function $kt(l,s){if(typeof s=="string")l.appendChild(document.createTextNode(s));else if(s!=null)if(s.nodeType!=null)l.appendChild(s);else if(Array.isArray(s))for(var u=0;u<s.length;u++)$kt(l,s[u]);else throw new RangeError("Unsupported child node: "+s)}let u0=typeof navigator<"u"?navigator:{userAgent:"",vendor:"",platform:""},HCe=typeof document<"u"?document:{documentElement:{style:{}}};const QCe=/Edge\/(\d+)/.exec(u0.userAgent),Bkt=/MSIE \d/.test(u0.userAgent),GCe=/Trident\/(?:[7-9]|\d{2,})\..*rv:(\d+)/.exec(u0.userAgent),zhe=!!(Bkt||GCe||QCe),gxt=!zhe&&/gecko\/(\d+)/i.test(u0.userAgent),AEe=!zhe&&/Chrome\/(\d+)/.exec(u0.userAgent),ydn="webkitFontSmoothing"in HCe.documentElement.style,UCe=!zhe&&/Apple Computer/.test(u0.vendor),pxt=UCe&&(/Mobile\/\w+/.test(u0.userAgent)||u0.maxTouchPoints>2);var Ji={mac:pxt||/Mac/.test(u0.platform),windows:/Win/.test(u0.platform),linux:/Linux|X11/.test(u0.platform),ie:zhe,ie_version:Bkt?HCe.documentMode||6:GCe?+GCe[1]:QCe?+QCe[1]:0,gecko:gxt,gecko_version:gxt?+(/Firefox\/(\d+)/.exec(u0.userAgent)||[0,0])[1]:0,chrome:!!AEe,chrome_version:AEe?+AEe[1]:0,ios:pxt,android:/Android\b/.test(u0.userAgent),webkit_version:ydn?+(/\bAppleWebKit\/(\d+)/.exec(u0.userAgent)||[0,0])[1]:0,safari:UCe,safari_version:UCe?+(/\bVersion\/(\d+(\.\d+)?)/.exec(u0.userAgent)||[0,0])[1]:0,tabSize:HCe.documentElement.style.tabSize!=null?"tab-size":"-moz-tab-size"};function KMe(l,s){for(let u in l)u=="class"&&s.class?s.class+=" "+l.class:u=="style"&&s.style?s.style+=";"+l.style:s[u]=l[u];return s}const Yfe=Object.create(null);function YMe(l,s,u){if(l==s)return!0;l||(l=Yfe),s||(s=Yfe);let h=Object.keys(l),g=Object.keys(s);if(h.length-0!=g.length-0)return!1;for(let w of h)if(w!=u&&(g.indexOf(w)==-1||l[w]!==s[w]))return!1;return!0}function xdn(l,s){for(let u=l.attributes.length-1;u>=0;u--){let h=l.attributes[u].name;s[h]==null&&l.removeAttribute(h)}for(let u in s){let h=s[u];u=="style"?l.style.cssText=h:l.getAttribute(u)!=h&&l.setAttribute(u,h)}}function bxt(l,s,u){let h=!1;if(s)for(let g in s)u&&g in u||(h=!0,g=="style"?l.style.cssText="":l.removeAttribute(g));if(u)for(let g in u)s&&s[g]==u[g]||(h=!0,g=="style"?l.style.cssText=u[g]:l.setAttribute(g,u[g]));return h}function kdn(l){let s=Object.create(null);for(let u=0;u<l.attributes.length;u++){let h=l.attributes[u];s[h.name]=h.value}return s}class lO{eq(s){return!1}updateDOM(s,u){return!1}compare(s){return this==s||this.constructor==s.constructor&&this.eq(s)}get estimatedHeight(){return-1}get lineBreaks(){return 0}ignoreEvent(s){return!0}coordsAt(s,u,h){return null}get isHidden(){return!1}get editable(){return!1}destroy(s){}}var a1=(function(l){return l[l.Text=0]="Text",l[l.WidgetBefore=1]="WidgetBefore",l[l.WidgetAfter=2]="WidgetAfter",l[l.WidgetRange=3]="WidgetRange",l})(a1||(a1={}));class Fr extends y8{constructor(s,u,h,g){super(),this.startSide=s,this.endSide=u,this.widget=h,this.spec=g}get heightRelevant(){return!1}static mark(s){return new CV(s)}static widget(s){let u=Math.max(-1e4,Math.min(1e4,s.side||0)),h=!!s.block;return u+=h&&!s.inlineOrder?u>0?3e8:-4e8:u>0?1e8:-1e8,new xM(s,u,u,h,s.widget||null,!1)}static replace(s){let u=!!s.block,h,g;if(s.isBlockGap)h=-5e8,g=4e8;else{let{start:w,end:p}=zkt(s,u);h=(w?u?-3e8:-1:5e8)-1,g=(p?u?2e8:1:-6e8)+1}return new xM(s,h,g,u,s.widget||null,!0)}static line(s){return new MV(s)}static set(s,u=!1){return xo.of(s,u)}hasHeight(){return this.widget?this.widget.estimatedHeight>-1:!1}}Fr.none=xo.empty;class CV extends Fr{constructor(s){let{start:u,end:h}=zkt(s);super(u?-1:5e8,h?1:-6e8,null,s),this.tagName=s.tagName||"span",this.attrs=s.class&&s.attributes?KMe(s.attributes,{class:s.class}):s.class?{class:s.class}:s.attributes||Yfe}eq(s){return this==s||s instanceof CV&&this.tagName==s.tagName&&YMe(this.attrs,s.attrs)}range(s,u=s){if(s>=u)throw new RangeError("Mark decorations may not be empty");return super.range(s,u)}}CV.prototype.point=!1;class MV extends Fr{constructor(s){super(-2e8,-2e8,null,s)}eq(s){return s instanceof MV&&this.spec.class==s.spec.class&&YMe(this.spec.attributes,s.spec.attributes)}range(s,u=s){if(u!=s)throw new RangeError("Line decoration ranges must be zero-length");return super.range(s,u)}}MV.prototype.mapMode=u1.TrackBefore;MV.prototype.point=!0;class xM extends Fr{constructor(s,u,h,g,w,p){super(u,h,w,s),this.block=g,this.isReplace=p,this.mapMode=g?u<=0?u1.TrackBefore:u1.TrackAfter:u1.TrackDel}get type(){return this.startSide!=this.endSide?a1.WidgetRange:this.startSide<=0?a1.WidgetBefore:a1.WidgetAfter}get heightRelevant(){return this.block||!!this.widget&&(this.widget.estimatedHeight>=5||this.widget.lineBreaks>0)}eq(s){return s instanceof xM&&Odn(this.widget,s.widget)&&this.block==s.block&&this.startSide==s.startSide&&this.endSide==s.endSide}range(s,u=s){if(this.isReplace&&(s>u||s==u&&this.startSide>0&&this.endSide<=0))throw new RangeError("Invalid range for replacement decoration");if(!this.isReplace&&u!=s)throw new RangeError("Widget decorations can only have zero-length ranges");return super.range(s,u)}}xM.prototype.point=!0;function zkt(l,s=!1){let{inclusiveStart:u,inclusiveEnd:h}=l;return u==null&&(u=l.inclusive),h==null&&(h=l.inclusive),{start:u??s,end:h??s}}function Odn(l,s){return l==s||!!(l&&s&&l.compare(s))}function mI(l,s,u,h=0){let g=u.length-1;g>=0&&u[g]+h>=l?u[g]=Math.max(u[g],s):u.push(l,s)}class iV extends y8{constructor(s,u){super(),this.tagName=s,this.attributes=u}eq(s){return s==this||s instanceof iV&&this.tagName==s.tagName&&YMe(this.attributes,s.attributes)}static create(s){return new iV(s.tagName,s.attributes||Yfe)}static set(s,u=!1){return xo.of(s,u)}}iV.prototype.startSide=iV.prototype.endSide=-1;function rV(l){let s;return l.nodeType==11?s=l.getSelection?l:l.ownerDocument:s=l,s.getSelection()}function JCe(l,s){return s?l==s||l.contains(s.nodeType!=1?s.parentNode:s):!1}function $X(l,s){if(!s.anchorNode)return!1;try{return JCe(l,s.anchorNode)}catch{return!1}}function BX(l){return l.nodeType==3?oV(l,0,l.nodeValue.length).getClientRects():l.nodeType==1?l.getClientRects():[]}function zX(l,s,u,h){return u?mxt(l,s,u,h,-1)||mxt(l,s,u,h,1):!1}function S8(l){for(var s=0;;s++)if(l=l.previousSibling,!l)return s}function Zfe(l){return l.nodeType==1&&/^(DIV|P|LI|UL|OL|BLOCKQUOTE|DD|DT|H\d|SECTION|PRE)$/.test(l.nodeName)}function mxt(l,s,u,h,g){for(;;){if(l==u&&s==h)return!0;if(s==(g<0?0:rO(l))){if(l.nodeName=="DIV")return!1;let w=l.parentNode;if(!w||w.nodeType!=1)return!1;s=S8(l)+(g<0?0:1),l=w}else if(l.nodeType==1){if(l=l.childNodes[s+(g<0?-1:0)],l.nodeType==1&&l.contentEditable=="false")return!1;s=g<0?rO(l):0}else return!1}}function rO(l){return l.nodeType==3?l.nodeValue.length:l.childNodes.length}function sV(l,s){let u=s?l.left:l.right;return{left:u,right:u,top:l.top,bottom:l.bottom}}function Sdn(l){let s=l.visualViewport;return s?{left:0,right:s.width,top:0,bottom:s.height}:{left:0,right:l.innerWidth,top:0,bottom:l.innerHeight}}function Fkt(l,s){let u=s.width/l.offsetWidth,h=s.height/l.offsetHeight;return(u>.995&&u<1.005||!isFinite(u)||Math.abs(s.width-l.offsetWidth)<1)&&(u=1),(h>.995&&h<1.005||!isFinite(h)||Math.abs(s.height-l.offsetHeight)<1)&&(h=1),{scaleX:u,scaleY:h}}function jdn(l,s,u,h,g,w,p,k){let j=l.ownerDocument,A=j.defaultView||window;for(let _=l,D=!1;_&&!D;)if(_.nodeType==1){let I,B=_==j.body,F=1,U=1;if(B)I=Sdn(A);else{if(/^(fixed|sticky)$/.test(getComputedStyle(_).position)&&(D=!0),_.scrollHeight<=_.clientHeight&&_.scrollWidth<=_.clientWidth){_=_.assignedSlot||_.parentNode;continue}let Z=_.getBoundingClientRect();({scaleX:F,scaleY:U}=Fkt(_,Z)),I={left:Z.left,right:Z.left+_.clientWidth*F,top:Z.top,bottom:Z.top+_.clientHeight*U}}let K=0,Y=0;if(g=="nearest")s.top<I.top?(Y=s.top-(I.top+p),u>0&&s.bottom>I.bottom+Y&&(Y=s.bottom-I.bottom+p)):s.bottom>I.bottom&&(Y=s.bottom-I.bottom+p,u<0&&s.top-Y<I.top&&(Y=s.top-(I.top+p)));else{let Z=s.bottom-s.top,ee=I.bottom-I.top;Y=(g=="center"&&Z<=ee?s.top+Z/2-ee/2:g=="start"||g=="center"&&u<0?s.top-p:s.bottom-ee+p)-I.top}if(h=="nearest"?s.left<I.left?(K=s.left-(I.left+w),u>0&&s.right>I.right+K&&(K=s.right-I.right+w)):s.right>I.right&&(K=s.right-I.right+w,u<0&&s.left<I.left+K&&(K=s.left-(I.left+w))):K=(h=="center"?s.left+(s.right-s.left)/2-(I.right-I.left)/2:h=="start"==k?s.left-w:s.right-(I.right-I.left)+w)-I.left,K||Y)if(B)A.scrollBy(K,Y);else{let Z=0,ee=0;if(Y){let ce=_.scrollTop;_.scrollTop+=Y/U,ee=(_.scrollTop-ce)*U}if(K){let ce=_.scrollLeft;_.scrollLeft+=K/F,Z=(_.scrollLeft-ce)*F}s={left:s.left-Z,top:s.top-ee,right:s.right-Z,bottom:s.bottom-ee},Z&&Math.abs(Z-K)<1&&(h="nearest"),ee&&Math.abs(ee-Y)<1&&(g="nearest")}if(B)break;(s.top<I.top||s.bottom>I.bottom||s.left<I.left||s.right>I.right)&&(s={left:Math.max(s.left,I.left),right:Math.min(s.right,I.right),top:Math.max(s.top,I.top),bottom:Math.min(s.bottom,I.bottom)}),_=_.assignedSlot||_.parentNode}else if(_.nodeType==11)_=_.host;else break}function qkt(l,s=!0){let u=l.ownerDocument,h=null,g=null;for(let w=l.parentNode;w&&!(w==u.body||(!s||h)&&g);)if(w.nodeType==1)!g&&w.scrollHeight>w.clientHeight&&(g=w),s&&!h&&w.scrollWidth>w.clientWidth&&(h=w),w=w.assignedSlot||w.parentNode;else if(w.nodeType==11)w=w.host;else break;return{x:h,y:g}}class Tdn{constructor(){this.anchorNode=null,this.anchorOffset=0,this.focusNode=null,this.focusOffset=0}eq(s){return this.anchorNode==s.anchorNode&&this.anchorOffset==s.anchorOffset&&this.focusNode==s.focusNode&&this.focusOffset==s.focusOffset}setRange(s){let{anchorNode:u,focusNode:h}=s;this.set(u,Math.min(s.anchorOffset,u?rO(u):0),h,Math.min(s.focusOffset,h?rO(h):0))}set(s,u,h,g){this.anchorNode=s,this.anchorOffset=u,this.focusNode=h,this.focusOffset=g}}let sM=null;Ji.safari&&Ji.safari_version>=26&&(sM=!1);function Hkt(l){if(l.setActive)return l.setActive();if(sM)return l.focus(sM);let s=[];for(let u=l;u&&(s.push(u,u.scrollTop,u.scrollLeft),u!=u.ownerDocument);u=u.parentNode);if(l.focus(sM==null?{get preventScroll(){return sM={preventScroll:!0},!0}}:void 0),!sM){sM=!1;for(let u=0;u<s.length;){let h=s[u++],g=s[u++],w=s[u++];h.scrollTop!=g&&(h.scrollTop=g),h.scrollLeft!=w&&(h.scrollLeft=w)}}}let wxt;function oV(l,s,u=s){let h=wxt||(wxt=document.createRange());return h.setEnd(l,u),h.setStart(l,s),h}function wI(l,s,u,h){let g={key:s,code:s,keyCode:u,which:u,cancelable:!0};h&&({altKey:g.altKey,ctrlKey:g.ctrlKey,shiftKey:g.shiftKey,metaKey:g.metaKey}=h);let w=new KeyboardEvent("keydown",g);w.synthetic=!0,l.dispatchEvent(w);let p=new KeyboardEvent("keyup",g);return p.synthetic=!0,l.dispatchEvent(p),w.defaultPrevented||p.defaultPrevented}function Edn(l){for(;l;){if(l&&(l.nodeType==9||l.nodeType==11&&l.host))return l;l=l.assignedSlot||l.parentNode}return null}function Cdn(l,s){let u=s.focusNode,h=s.focusOffset;if(!u||s.anchorNode!=u||s.anchorOffset!=h)return!1;for(h=Math.min(h,rO(u));;)if(h){if(u.nodeType!=1)return!1;let g=u.childNodes[h-1];g.contentEditable=="false"?h--:(u=g,h=rO(u))}else{if(u==l)return!0;h=S8(u),u=u.parentNode}}function Qkt(l){return l instanceof Window?l.pageYOffset>Math.max(0,l.document.documentElement.scrollHeight-l.innerHeight-4):l.scrollTop>Math.max(1,l.scrollHeight-l.clientHeight-4)}function Gkt(l,s){for(let u=l,h=s;;){if(u.nodeType==3&&h>0)return{node:u,offset:h};if(u.nodeType==1&&h>0){if(u.contentEditable=="false")return null;u=u.childNodes[h-1],h=rO(u)}else if(u.parentNode&&!Zfe(u))h=S8(u),u=u.parentNode;else return null}}function Ukt(l,s){for(let u=l,h=s;;){if(u.nodeType==3&&h<u.nodeValue.length)return{node:u,offset:h};if(u.nodeType==1&&h<u.childNodes.length){if(u.contentEditable=="false")return null;u=u.childNodes[h],h=0}else if(u.parentNode&&!Zfe(u))h=S8(u)+1,u=u.parentNode;else return null}}class Sy{constructor(s,u,h=!0){this.node=s,this.offset=u,this.precise=h}static before(s,u){return new Sy(s.parentNode,S8(s),u)}static after(s,u){return new Sy(s.parentNode,S8(s)+1,u)}}var Yl=(function(l){return l[l.LTR=0]="LTR",l[l.RTL=1]="RTL",l})(Yl||(Yl={}));const kM=Yl.LTR,ZMe=Yl.RTL;function Jkt(l){let s=[];for(let u=0;u<l.length;u++)s.push(1<<+l[u]);return s}const Mdn=Jkt("88888888888888888888888888888888888666888888787833333333337888888000000000000000000000000008888880000000000000000000000000088888888888888888888888888888888888887866668888088888663380888308888800000000000000000000000800000000000000000000000000000008"),Adn=Jkt("4444448826627288999999999992222222222222222222222222222222222222222222222229999999999999999999994444444444644222822222222222222222222222222222222222222222222222222222222222222222222222222222222222222222222222222222999999949999999229989999223333333333"),XCe=Object.create(null),I3=[];for(let l of["()","[]","{}"]){let s=l.charCodeAt(0),u=l.charCodeAt(1);XCe[s]=u,XCe[u]=-s}function Xkt(l){return l<=247?Mdn[l]:1424<=l&&l<=1524?2:1536<=l&&l<=1785?Adn[l-1536]:1774<=l&&l<=2220?4:8192<=l&&l<=8204?256:64336<=l&&l<=65023?4:1}const Ndn=/[\u0590-\u05f4\u0600-\u06ff\u0700-\u08ac\ufb50-\ufdff]/;class Q3{get dir(){return this.level%2?ZMe:kM}constructor(s,u,h){this.from=s,this.to=u,this.level=h}side(s,u){return this.dir==u==s?this.to:this.from}forward(s,u){return s==(this.dir==u)}static find(s,u,h,g){let w=-1;for(let p=0;p<s.length;p++){let k=s[p];if(k.from<=u&&k.to>=u){if(k.level==h)return p;(w<0||(g!=0?g<0?k.from<u:k.to>u:s[w].level>k.level))&&(w=p)}}if(w<0)throw new RangeError("Index out of range");return w}}function Vkt(l,s){if(l.length!=s.length)return!1;for(let u=0;u<l.length;u++){let h=l[u],g=s[u];if(h.from!=g.from||h.to!=g.to||h.direction!=g.direction||!Vkt(h.inner,g.inner))return!1}return!0}const Kl=[];function _dn(l,s,u,h,g){for(let w=0;w<=h.length;w++){let p=w?h[w-1].to:s,k=w<h.length?h[w].from:u,j=w?256:g;for(let A=p,_=j,D=j;A<k;A++){let I=Xkt(l.charCodeAt(A));I==512?I=_:I==8&&D==4&&(I=16),Kl[A]=I==4?2:I,I&7&&(D=I),_=I}for(let A=p,_=j,D=j;A<k;A++){let I=Kl[A];if(I==128)A<k-1&&_==Kl[A+1]&&_&24?I=Kl[A]=_:Kl[A]=256;else if(I==64){let B=A+1;for(;B<k&&Kl[B]==64;)B++;let F=A&&_==8||B<u&&Kl[B]==8?D==1?1:8:256;for(let U=A;U<B;U++)Kl[U]=F;A=B-1}else I==8&&D==1&&(Kl[A]=1);_=I,I&7&&(D=I)}}}function Ddn(l,s,u,h,g){let w=g==1?2:1;for(let p=0,k=0,j=0;p<=h.length;p++){let A=p?h[p-1].to:s,_=p<h.length?h[p].from:u;for(let D=A,I,B,F;D<_;D++)if(B=XCe[I=l.charCodeAt(D)])if(B<0){for(let U=k-3;U>=0;U-=3)if(I3[U+1]==-B){let K=I3[U+2],Y=K&2?g:K&4?K&1?w:g:0;Y&&(Kl[D]=Kl[I3[U]]=Y),k=U;break}}else{if(I3.length==189)break;I3[k++]=D,I3[k++]=I,I3[k++]=j}else if((F=Kl[D])==2||F==1){let U=F==g;j=U?0:1;for(let K=k-3;K>=0;K-=3){let Y=I3[K+2];if(Y&2)break;if(U)I3[K+2]|=2;else{if(Y&4)break;I3[K+2]|=4}}}}}function Ldn(l,s,u,h){for(let g=0,w=h;g<=u.length;g++){let p=g?u[g-1].to:l,k=g<u.length?u[g].from:s;for(let j=p;j<k;){let A=Kl[j];if(A==256){let _=j+1;for(;;)if(_==k){if(g==u.length)break;_=u[g++].to,k=g<u.length?u[g].from:s}else if(Kl[_]==256)_++;else break;let D=w==1,I=(_<s?Kl[_]:h)==1,B=D==I?D?1:2:h;for(let F=_,U=g,K=U?u[U-1].to:l;F>j;)F==K&&(F=u[--U].from,K=U?u[U-1].to:l),Kl[--F]=B;j=_}else w=A,j++}}}function VCe(l,s,u,h,g,w,p){let k=h%2?2:1;if(h%2==g%2)for(let j=s,A=0;j<u;){let _=!0,D=!1;if(A==w.length||j<w[A].from){let U=Kl[j];U!=k&&(_=!1,D=U==16)}let I=!_&&k==1?[]:null,B=_?h:h+1,F=j;e:for(;;)if(A<w.length&&F==w[A].from){if(D)break e;let U=w[A];if(!_)for(let K=U.to,Y=A+1;;){if(K==u)break e;if(Y<w.length&&w[Y].from==K)K=w[Y++].to;else{if(Kl[K]==k)break e;break}}if(A++,I)I.push(U);else{U.from>j&&p.push(new Q3(j,U.from,B));let K=U.direction==kM!=!(B%2);WCe(l,K?h+1:h,g,U.inner,U.from,U.to,p),j=U.to}F=U.to}else{if(F==u||(_?Kl[F]!=k:Kl[F]==k))break;F++}I?VCe(l,j,F,h+1,g,I,p):j<F&&p.push(new Q3(j,F,B)),j=F}else for(let j=u,A=w.length;j>s;){let _=!0,D=!1;if(!A||j>w[A-1].to){let U=Kl[j-1];U!=k&&(_=!1,D=U==16)}let I=!_&&k==1?[]:null,B=_?h:h+1,F=j;e:for(;;)if(A&&F==w[A-1].to){if(D)break e;let U=w[--A];if(!_)for(let K=U.from,Y=A;;){if(K==s)break e;if(Y&&w[Y-1].to==K)K=w[--Y].from;else{if(Kl[K-1]==k)break e;break}}if(I)I.push(U);else{U.to<j&&p.push(new Q3(U.to,j,B));let K=U.direction==kM!=!(B%2);WCe(l,K?h+1:h,g,U.inner,U.from,U.to,p),j=U.from}F=U.from}else{if(F==s||(_?Kl[F-1]!=k:Kl[F-1]==k))break;F--}I?VCe(l,F,j,h+1,g,I,p):F<j&&p.push(new Q3(F,j,B)),j=F}}function WCe(l,s,u,h,g,w,p){let k=s%2?2:1;_dn(l,g,w,h,k),Ddn(l,g,w,h,k),Ldn(g,w,h,k),VCe(l,g,w,s,u,h,p)}function Pdn(l,s,u){if(!l)return[new Q3(0,0,s==ZMe?1:0)];if(s==kM&&!u.length&&!Ndn.test(l))return Wkt(l.length);if(u.length)for(;l.length>Kl.length;)Kl[Kl.length]=256;let h=[],g=s==kM?0:1;return WCe(l,g,g,u,0,l.length,h),h}function Wkt(l){return[new Q3(0,l,0)]}let Kkt="";function Idn(l,s,u,h,g){var w;let p=h.head-l.from,k=Q3.find(s,p,(w=h.bidiLevel)!==null&&w!==void 0?w:-1,h.assoc),j=s[k],A=j.side(g,u);if(p==A){let I=k+=g?1:-1;if(I<0||I>=s.length)return null;j=s[k=I],p=j.side(!g,u),A=j.side(g,u)}let _=Sd(l.text,p,j.forward(g,u));(_<j.from||_>j.to)&&(_=A),Kkt=l.text.slice(Math.min(p,_),Math.max(p,_));let D=k==(g?s.length-1:0)?null:s[k+(g?1:-1)];return D&&_==A&&D.level+(g?0:1)<j.level?kn.cursor(D.side(!g,u)+l.from,D.forward(g,u)?1:-1,D.level):kn.cursor(_+l.from,j.forward(g,u)?-1:1,j.level)}function Rdn(l,s,u){for(let h=s;h<u;h++){let g=Xkt(l.charCodeAt(h));if(g==1)return kM;if(g==2||g==4)return ZMe}return kM}const Ykt=Qi.define(),Zkt=Qi.define(),eOt=Qi.define(),tOt=Qi.define(),KCe=Qi.define(),nOt=Qi.define(),iOt=Qi.define(),eAe=Qi.define(),tAe=Qi.define(),rOt=Qi.define({combine:l=>l.some(s=>s)}),sOt=Qi.define({combine:l=>l.some(s=>s)}),oOt=Qi.define();class vI{constructor(s,u="nearest",h="nearest",g=5,w=5,p=!1){this.range=s,this.y=u,this.x=h,this.yMargin=g,this.xMargin=w,this.isSnapshot=p}map(s){return s.empty?this:new vI(this.range.map(s),this.y,this.x,this.yMargin,this.xMargin,this.isSnapshot)}clip(s){return this.range.to<=s.doc.length?this:new vI(kn.cursor(s.doc.length),this.y,this.x,this.yMargin,this.xMargin,this.isSnapshot)}}const Xae=Ds.define({map:(l,s)=>l.map(s)}),cOt=Ds.define();function kp(l,s,u){let h=l.facet(tOt);h.length?h[0](s):window.onerror&&window.onerror(String(s),u,void 0,void 0,s)||(u?console.error(u+":",s):console.error(s))}const Zk=Qi.define({combine:l=>l.length?l[0]:!0});let $dn=0;const aI=Qi.define({combine(l){return l.filter((s,u)=>{for(let h=0;h<u;h++)if(l[h].plugin==s.plugin)return!1;return!0})}});class Xh{constructor(s,u,h,g,w){this.id=s,this.create=u,this.domEventHandlers=h,this.domEventObservers=g,this.baseExtensions=w(this),this.extension=this.baseExtensions.concat(aI.of({plugin:this,arg:void 0}))}of(s){return this.baseExtensions.concat(aI.of({plugin:this,arg:s}))}static define(s,u){const{eventHandlers:h,eventObservers:g,provide:w,decorations:p}=u||{};return new Xh($dn++,s,h,g,k=>{let j=[];return p&&j.push(Fhe.of(A=>{let _=A.plugin(k);return _?p(_):Fr.none})),w&&j.push(w(k)),j})}static fromClass(s,u){return Xh.define((h,g)=>new s(h,g),u)}}class NEe{constructor(s){this.spec=s,this.mustUpdate=null,this.value=null}get plugin(){return this.spec&&this.spec.plugin}update(s){if(this.value){if(this.mustUpdate){let u=this.mustUpdate;if(this.mustUpdate=null,this.value.update)try{this.value.update(u)}catch(h){if(kp(u.state,h,"CodeMirror plugin crashed"),this.value.destroy)try{this.value.destroy()}catch{}this.deactivate()}}}else if(this.spec)try{this.value=this.spec.plugin.create(s,this.spec.arg)}catch(u){kp(s.state,u,"CodeMirror plugin crashed"),this.deactivate()}return this}destroy(s){var u;if(!((u=this.value)===null||u===void 0)&&u.destroy)try{this.value.destroy()}catch(h){kp(s.state,h,"CodeMirror plugin crashed")}}deactivate(){this.spec=this.value=null}}const lOt=Qi.define(),nAe=Qi.define(),Fhe=Qi.define(),uOt=Qi.define(),iAe=Qi.define(),AV=Qi.define(),aOt=Qi.define();function vxt(l,s){let u=l.state.facet(aOt);if(!u.length)return u;let h=u.map(w=>w instanceof Function?w(l):w),g=[];return xo.spans(h,s.from,s.to,{point(){},span(w,p,k,j){let A=w-s.from,_=p-s.from,D=g;for(let I=k.length-1;I>=0;I--,j--){let B=k[I].spec.bidiIsolate,F;if(B==null&&(B=Rdn(s.text,A,_)),j>0&&D.length&&(F=D[D.length-1]).to==A&&F.direction==B)F.to=_,D=F.inner;else{let U={from:A,to:_,direction:B,inner:[]};D.push(U),D=U.inner}}}}),g}const fOt=Qi.define();function rAe(l){let s=0,u=0,h=0,g=0;for(let w of l.state.facet(fOt)){let p=w(l);p&&(p.left!=null&&(s=Math.max(s,p.left)),p.right!=null&&(u=Math.max(u,p.right)),p.top!=null&&(h=Math.max(h,p.top)),p.bottom!=null&&(g=Math.max(g,p.bottom)))}return{left:s,right:u,top:h,bottom:g}}const NX=Qi.define();class Uw{constructor(s,u,h,g){this.fromA=s,this.toA=u,this.fromB=h,this.toB=g}join(s){return new Uw(Math.min(this.fromA,s.fromA),Math.max(this.toA,s.toA),Math.min(this.fromB,s.fromB),Math.max(this.toB,s.toB))}addToSet(s){let u=s.length,h=this;for(;u>0;u--){let g=s[u-1];if(!(g.fromA>h.toA)){if(g.toA<h.fromA)break;h=h.join(g),s.splice(u-1,1)}}return s.splice(u,0,h),s}static extendWithRanges(s,u){if(u.length==0)return s;let h=[];for(let g=0,w=0,p=0;;){let k=g<s.length?s[g].fromB:1e9,j=w<u.length?u[w]:1e9,A=Math.min(k,j);if(A==1e9)break;let _=A+p,D=A,I=_;for(;;)if(w<u.length&&u[w]<=D){let B=u[w+1];w+=2,D=Math.max(D,B);for(let F=g;F<s.length&&s[F].fromB<=D;F++)p=s[F].toA-s[F].toB;I=Math.max(I,B+p)}else if(g<s.length&&s[g].fromB<=D){let B=s[g++];D=Math.max(D,B.toB),I=Math.max(I,B.toA),p=B.toA-B.toB}else break;h.push(new Uw(_,I,A,D))}return h}}class ehe{constructor(s,u,h){this.view=s,this.state=u,this.transactions=h,this.flags=0,this.startState=s.state,this.changes=Jh.empty(this.startState.doc.length);for(let w of h)this.changes=this.changes.compose(w.changes);let g=[];this.changes.iterChangedRanges((w,p,k,j)=>g.push(new Uw(w,p,k,j))),this.changedRanges=g}static create(s,u,h){return new ehe(s,u,h)}get viewportChanged(){return(this.flags&4)>0}get viewportMoved(){return(this.flags&8)>0}get heightChanged(){return(this.flags&2)>0}get geometryChanged(){return this.docChanged||(this.flags&18)>0}get focusChanged(){return(this.flags&1)>0}get docChanged(){return!this.changes.empty}get selectionSet(){return this.transactions.some(s=>s.selection)}get empty(){return this.flags==0&&this.transactions.length==0}}const Bdn=[];class of{constructor(s,u,h=0){this.dom=s,this.length=u,this.flags=h,this.parent=null,s.cmTile=this}get breakAfter(){return this.flags&1}get children(){return Bdn}isWidget(){return!1}get isHidden(){return!1}isComposite(){return!1}isLine(){return!1}isText(){return!1}isBlock(){return!1}get domAttrs(){return null}sync(s){if(this.flags|=2,this.flags&4){this.flags&=-5;let u=this.domAttrs;u&&xdn(this.dom,u)}}toString(){return this.constructor.name+(this.children.length?`(${this.children})`:"")+(this.breakAfter?"#":"")}destroy(){this.parent=null}setDOM(s){this.dom=s,s.cmTile=this}get posAtStart(){return this.parent?this.parent.posBefore(this):0}get posAtEnd(){return this.posAtStart+this.length}posBefore(s,u=this.posAtStart){let h=u;for(let g of this.children){if(g==s)return h;h+=g.length+g.breakAfter}throw new RangeError("Invalid child in posBefore")}posAfter(s){return this.posBefore(s)+s.length}covers(s){return!0}coordsIn(s,u){return null}domPosFor(s,u){let h=S8(this.dom),g=this.length?s>0:u>0;return new Sy(this.parent.dom,h+(g?1:0),s==0||s==this.length)}markDirty(s){this.flags&=-3,s&&(this.flags|=4),this.parent&&this.parent.flags&2&&this.parent.markDirty(!1)}get overrideDOMText(){return null}get root(){for(let s=this;s;s=s.parent)if(s instanceof Hhe)return s;return null}static get(s){return s.cmTile}}class qhe extends of{constructor(s){super(s,0),this._children=[]}isComposite(){return!0}get children(){return this._children}get lastChild(){return this.children.length?this.children[this.children.length-1]:null}append(s){this.children.push(s),s.parent=this}sync(s){if(this.flags&2)return;super.sync(s);let u=this.dom,h=null,g,w=(s==null?void 0:s.node)==u?s:null,p=0;for(let k of this.children){if(k.sync(s),p+=k.length+k.breakAfter,g=h?h.nextSibling:u.firstChild,w&&g!=k.dom&&(w.written=!0),k.dom.parentNode==u)for(;g&&g!=k.dom;)g=yxt(g);else u.insertBefore(k.dom,g);h=k.dom}for(g=h?h.nextSibling:u.firstChild,w&&g&&(w.written=!0);g;)g=yxt(g);this.length=p}}function yxt(l){let s=l.nextSibling;return l.parentNode.removeChild(l),s}class Hhe extends qhe{constructor(s,u){super(u),this.view=s}owns(s){for(;s;s=s.parent)if(s==this)return!0;return!1}isBlock(){return!0}nearest(s){for(;;){if(!s)return null;let u=of.get(s);if(u&&this.owns(u))return u;s=s.parentNode}}blockTiles(s){for(let u=[],h=this,g=0,w=0;;)if(g==h.children.length){if(!u.length)return;h=h.parent,h.breakAfter&&w++,g=u.pop()}else{let p=h.children[g++];if(p instanceof nO)u.push(g),h=p,g=0;else{let k=w+p.length,j=s(p,w);if(j!==void 0)return j;w=k+p.breakAfter}}}resolveBlock(s,u){let h,g=-1,w,p=-1;if(this.blockTiles((k,j)=>{let A=j+k.length;if(s>=j&&s<=A){if(k.isWidget()&&u>=-1&&u<=1){if(k.flags&32)return!0;k.flags&16&&(h=void 0)}(j<s||s==A&&(u<-1?k.length:k.covers(1)))&&(!h||!k.isWidget()&&h.isWidget())&&(h=k,g=s-j),(A>s||s==j&&(u>1?k.length:k.covers(-1)))&&(!w||!k.isWidget()&&w.isWidget())&&(w=k,p=s-j)}}),!h&&!w)throw new Error("No tile at position "+s);return h&&u<0||!w?{tile:h,offset:g}:{tile:w,offset:p}}}class nO extends qhe{constructor(s,u){super(s),this.wrapper=u}isBlock(){return!0}covers(s){return this.children.length?s<0?this.children[0].covers(-1):this.lastChild.covers(1):!1}get domAttrs(){return this.wrapper.attributes}static of(s,u){let h=new nO(u||document.createElement(s.tagName),s);return u||(h.flags|=4),h}}class DI extends qhe{constructor(s,u){super(s),this.attrs=u}isLine(){return!0}static start(s,u,h){let g=new DI(u||document.createElement("div"),s);return(!u||!h)&&(g.flags|=4),g}get domAttrs(){return this.attrs}resolveInline(s,u,h){let g=null,w=-1,p=null,k=-1;function j(_,D){for(let I=0,B=0;I<_.children.length&&B<=D;I++){let F=_.children[I],U=B+F.length;U>=D&&(F.isComposite()?j(F,D-B):(!p||p.isHidden&&(u>0||h&&Fdn(p,F)))&&(U>D||F.flags&32)?(p=F,k=D-B):(B<D||F.flags&16&&!F.isHidden)&&(g=F,w=D-B)),B=U}}j(this,s);let A=(u<0?g:p)||g||p;return A?{tile:A,offset:A==g?w:k}:null}coordsIn(s,u){let h=this.resolveInline(s,u,!0);return h?h.tile.coordsIn(Math.max(0,h.offset),u):zdn(this)}domIn(s,u){let h=this.resolveInline(s,u);if(h){let{tile:g,offset:w}=h;if(this.dom.contains(g.dom))return g.isText()?new Sy(g.dom,Math.min(g.dom.nodeValue.length,w)):g.domPosFor(w,g.flags&16?1:g.flags&32?-1:u);let p=h.tile.parent,k=!1;for(let j of p.children){if(k)return new Sy(j.dom,0);j==h.tile&&(k=!0)}}return new Sy(this.dom,0)}}function zdn(l){let s=l.dom.lastChild;if(!s)return l.dom.getBoundingClientRect();let u=BX(s);return u[u.length-1]||null}function Fdn(l,s){let u=l.coordsIn(0,1),h=s.coordsIn(0,1);return u&&h&&h.top<u.bottom}class yp extends qhe{constructor(s,u){super(s),this.mark=u}get domAttrs(){return this.mark.attrs}static of(s,u){let h=new yp(u||document.createElement(s.tagName),s);return u||(h.flags|=4),h}}class aM extends of{constructor(s,u){super(s,u.length),this.text=u}sync(s){this.flags&2||(super.sync(s),this.dom.nodeValue!=this.text&&(s&&s.node==this.dom&&(s.written=!0),this.dom.nodeValue=this.text))}isText(){return!0}toString(){return JSON.stringify(this.text)}coordsIn(s,u){let h=this.dom.nodeValue.length;s>h&&(s=h);let g=s,w=s,p=0;s==0&&u<0||s==h&&u>=0?Ji.chrome||Ji.gecko||(s?(g--,p=1):w<h&&(w++,p=-1)):u<0?g--:w<h&&w++;let k=oV(this.dom,g,w).getClientRects();if(!k.length)return null;let j=k[(p?p<0:u>=0)?0:k.length-1];return Ji.safari&&!p&&j.width==0&&(j=Array.prototype.find.call(k,A=>A.width)||j),p?sV(j,p<0):j||null}static of(s,u){let h=new aM(u||document.createTextNode(s),s);return u||(h.flags|=2),h}}class OM extends of{constructor(s,u,h,g){super(s,u,g),this.widget=h}isWidget(){return!0}get isHidden(){return this.widget.isHidden}covers(s){return this.flags&48?!1:(this.flags&(s<0?64:128))>0}coordsIn(s,u){return this.coordsInWidget(s,u,!1)}coordsInWidget(s,u,h){let g=this.widget.coordsAt(this.dom,s,u);if(g)return g;if(h)return sV(this.dom.getBoundingClientRect(),this.length?s==0:u<=0);{let w=this.dom.getClientRects(),p=null;if(!w.length)return null;let k=this.flags&16?!0:this.flags&32?!1:s>0;for(let j=k?w.length-1:0;p=w[j],!(s>0?j==0:j==w.length-1||p.top<p.bottom);j+=k?-1:1);return sV(p,!k)}}get overrideDOMText(){if(!this.length)return uc.empty;let{root:s}=this;if(!s)return uc.empty;let u=this.posAtStart;return s.view.state.doc.slice(u,u+this.length)}destroy(){super.destroy(),this.widget.destroy(this.dom)}static of(s,u,h,g,w){return w||(w=s.toDOM(u),s.editable||(w.contentEditable="false")),new OM(w,h,s,g)}}class the extends of{constructor(s){let u=document.createElement("img");u.className="cm-widgetBuffer",u.setAttribute("aria-hidden","true"),super(u,0,s)}get isHidden(){return!0}get overrideDOMText(){return uc.empty}coordsIn(s){return this.dom.getBoundingClientRect()}}class qdn{constructor(s){this.index=0,this.beforeBreak=!1,this.parents=[],this.tile=s}advance(s,u,h){let{tile:g,index:w,beforeBreak:p,parents:k}=this;for(;s||u>0;)if(g.isComposite())if(p){if(!s)break;h&&h.break(),s--,p=!1}else if(w==g.children.length){if(!s&&!k.length)break;h&&h.leave(g),p=!!g.breakAfter,{tile:g,index:w}=k.pop(),w++}else{let j=g.children[w],A=j.breakAfter;(u>0?j.length<=s:j.length<s)&&(!h||h.skip(j,0,j.length)!==!1||!j.isComposite)?(p=!!A,w++,s-=j.length):(k.push({tile:g,index:w}),g=j,w=0,h&&j.isComposite()&&h.enter(j))}else if(w==g.length)p=!!g.breakAfter,{tile:g,index:w}=k.pop(),w++;else if(s){let j=Math.min(s,g.length-w);h&&h.skip(g,w,w+j),s-=j,w+=j}else break;return this.tile=g,this.index=w,this.beforeBreak=p,this}get root(){return this.parents.length?this.parents[0].tile:this.tile}}class Hdn{constructor(s,u,h,g){this.from=s,this.to=u,this.wrapper=h,this.rank=g}}class Qdn{constructor(s,u,h){this.cache=s,this.root=u,this.blockWrappers=h,this.curLine=null,this.lastBlock=null,this.afterWidget=null,this.pos=0,this.wrappers=[],this.wrapperPos=0}addText(s,u,h,g){var w;this.flushBuffer();let p=this.ensureMarks(u,h),k=p.lastChild;if(k&&k.isText()&&!(k.flags&8)&&k.length+s.length<512){this.cache.reused.set(k,2);let j=p.children[p.children.length-1]=new aM(k.dom,k.text+s);j.parent=p}else p.append(g||aM.of(s,(w=this.cache.find(aM))===null||w===void 0?void 0:w.dom));this.pos+=s.length,this.afterWidget=null}addComposition(s,u){let h=this.curLine;h.dom!=u.line.dom&&(h.setDOM(this.cache.reused.has(u.line)?_Ee(u.line.dom):u.line.dom),this.cache.reused.set(u.line,2));let g=h;for(let k=u.marks.length-1;k>=0;k--){let j=u.marks[k],A=g.lastChild;if(A instanceof yp&&A.mark.eq(j.mark))A.dom!=j.dom&&A.setDOM(_Ee(j.dom)),g=A;else{if(this.cache.reused.get(j)){let D=of.get(j.dom);D&&D.setDOM(_Ee(j.dom))}let _=yp.of(j.mark,j.dom);g.append(_),g=_}this.cache.reused.set(j,2)}let w=of.get(s.text);w&&this.cache.reused.set(w,2);let p=new aM(s.text,s.text.nodeValue);p.flags|=8,g.append(p)}addInlineWidget(s,u,h){let g=this.afterWidget&&s.flags&48&&(this.afterWidget.flags&48)==(s.flags&48);g||this.flushBuffer();let w=this.ensureMarks(u,h);!g&&!(s.flags&16)&&w.append(this.getBuffer(1)),w.append(s),this.pos+=s.length,this.afterWidget=s}addMark(s,u,h){this.flushBuffer(),this.ensureMarks(u,h).append(s),this.pos+=s.length,this.afterWidget=null}addBlockWidget(s){this.getBlockPos().append(s),this.pos+=s.length,this.lastBlock=s,this.endLine()}continueWidget(s){let u=this.afterWidget||this.lastBlock;u.length+=s,this.pos+=s}addLineStart(s,u){var h;s||(s=hOt);let g=DI.start(s,u||((h=this.cache.find(DI))===null||h===void 0?void 0:h.dom),!!u);this.getBlockPos().append(this.lastBlock=this.curLine=g)}addLine(s){this.getBlockPos().append(s),this.pos+=s.length,this.lastBlock=s,this.endLine()}addBreak(){this.lastBlock.flags|=1,this.endLine(),this.pos++}addLineStartIfNotCovered(s){this.blockPosCovered()||this.addLineStart(s)}ensureLine(s){this.curLine||this.addLineStart(s)}ensureMarks(s,u){var h;let g=this.curLine;for(let w=s.length-1;w>=0;w--){let p=s[w],k;if(u>0&&(k=g.lastChild)&&k instanceof yp&&k.mark.eq(p))g=k,u--;else{let j=yp.of(p,(h=this.cache.find(yp,A=>A.mark.eq(p)))===null||h===void 0?void 0:h.dom);g.append(j),g=j,u=0}}return g}endLine(){if(this.curLine){this.flushBuffer();let s=this.curLine.lastChild;(!s||!xxt(this.curLine,!1)||s.dom.nodeName!="BR"&&s.isWidget()&&!(Ji.ios&&xxt(this.curLine,!0)))&&this.curLine.append(this.cache.findWidget(DEe,0,32)||new OM(DEe.toDOM(),0,DEe,32)),this.curLine=this.afterWidget=null}}updateBlockWrappers(){this.wrapperPos>this.pos+1e4&&(this.blockWrappers.goto(this.pos),this.wrappers.length=0);for(let s=this.wrappers.length-1;s>=0;s--)this.wrappers[s].to<this.pos&&this.wrappers.splice(s,1);for(let s=this.blockWrappers;s.value&&s.from<=this.pos;s.next())if(s.to>=this.pos){let u=new Hdn(s.from,s.to,s.value,s.rank),h=this.wrappers.length;for(;h>0&&(this.wrappers[h-1].rank-u.rank||this.wrappers[h-1].to-u.to)<0;)h--;this.wrappers.splice(h,0,u)}this.wrapperPos=this.pos}getBlockPos(){var s;this.updateBlockWrappers();let u=this.root;for(let h of this.wrappers){let g=u.lastChild;if(h.from<this.pos&&g instanceof nO&&g.wrapper.eq(h.wrapper))u=g;else{let w=nO.of(h.wrapper,(s=this.cache.find(nO,p=>p.wrapper.eq(h.wrapper)))===null||s===void 0?void 0:s.dom);u.append(w),u=w}}return u}blockPosCovered(){let s=this.lastBlock;return s!=null&&!s.breakAfter&&(!s.isWidget()||(s.flags&160)>0)}getBuffer(s){let u=2|(s<0?16:32),h=this.cache.find(the,void 0,1);return h&&(h.flags=u),h||new the(u)}flushBuffer(){this.afterWidget&&!(this.afterWidget.flags&32)&&(this.afterWidget.parent.append(this.getBuffer(-1)),this.afterWidget=null)}}class Gdn{constructor(s){this.skipCount=0,this.text="",this.textOff=0,this.cursor=s.iter()}skip(s){this.textOff+s<=this.text.length?this.textOff+=s:(this.skipCount+=s-(this.text.length-this.textOff),this.text="",this.textOff=0)}next(s){if(this.textOff==this.text.length){let{value:g,lineBreak:w,done:p}=this.cursor.next(this.skipCount);if(this.skipCount=0,p)throw new Error("Ran out of text content when drawing inline views");this.text=g;let k=this.textOff=Math.min(s,g.length);return w?null:g.slice(0,k)}let u=Math.min(this.text.length,this.textOff+s),h=this.text.slice(this.textOff,u);return this.textOff=u,h}}const nhe=[OM,DI,aM,yp,the,nO,Hhe];for(let l=0;l<nhe.length;l++)nhe[l].bucket=l;class Udn{constructor(s){this.view=s,this.buckets=nhe.map(()=>[]),this.index=nhe.map(()=>0),this.reused=new Map}add(s){let u=s.constructor.bucket,h=this.buckets[u];h.length<6?h.push(s):h[this.index[u]=(this.index[u]+1)%6]=s}find(s,u,h=2){let g=s.bucket,w=this.buckets[g],p=this.index[g];for(let k=w.length-1;k>=0;k--){let j=(k+p)%w.length,A=w[j];if((!u||u(A))&&!this.reused.has(A))return w.splice(j,1),j<p&&this.index[g]--,this.reused.set(A,h),A}return null}findWidget(s,u,h){let g=this.buckets[0];if(g.length)for(let w=0,p=0;;w++){if(w==g.length){if(p)return null;p=1,w=0}let k=g[w];if(!this.reused.has(k)&&(p==0?k.widget.compare(s):k.widget.constructor==s.constructor&&s.updateDOM(k.dom,this.view)))return g.splice(w,1),w<this.index[0]&&this.index[0]--,k.widget==s&&k.length==u&&(k.flags&497)==h?(this.reused.set(k,1),k):(this.reused.set(k,2),new OM(k.dom,u,s,k.flags&-498|h))}}reuse(s){return this.reused.set(s,1),s}maybeReuse(s,u=2){if(!this.reused.has(s))return this.reused.set(s,u),s.dom}clear(){for(let s=0;s<this.buckets.length;s++)this.buckets[s].length=this.index[s]=0}}class Jdn{constructor(s,u,h,g,w){this.view=s,this.decorations=g,this.disallowBlockEffectsFor=w,this.openWidget=!1,this.openMarks=0,this.cache=new Udn(s),this.text=new Gdn(s.state.doc),this.builder=new Qdn(this.cache,new Hhe(s,s.contentDOM),xo.iter(h)),this.cache.reused.set(u,2),this.old=new qdn(u),this.reuseWalker={skip:(p,k,j)=>{if(this.cache.add(p),p.isComposite())return!1},enter:p=>this.cache.add(p),leave:()=>{},break:()=>{}}}run(s,u){let h=u&&this.getCompositionContext(u.text);for(let g=0,w=0,p=0;;){let k=p<s.length?s[p++]:null,j=k?k.fromA:this.old.root.length;if(j>g){let A=j-g;this.preserve(A,!p,!k),g=j,w+=A}if(!k)break;u&&k.fromA<=u.range.fromA&&k.toA>=u.range.toA?(this.forward(k.fromA,u.range.fromA,u.range.fromA<u.range.toA?1:-1),this.emit(w,u.range.fromB),this.cache.clear(),this.builder.addComposition(u,h),this.text.skip(u.range.toB-u.range.fromB),this.forward(u.range.fromA,k.toA),this.emit(u.range.toB,k.toB)):(this.forward(k.fromA,k.toA),this.emit(w,k.toB)),w=k.toB,g=k.toA}return this.builder.curLine&&this.builder.endLine(),this.builder.root}preserve(s,u,h){let g=Wdn(this.old),w=this.openMarks;this.old.advance(s,h?1:-1,{skip:(p,k,j)=>{if(p.isWidget())if(this.openWidget)this.builder.continueWidget(j-k);else{let A=j>0||k<p.length?OM.of(p.widget,this.view,j-k,p.flags&496,this.cache.maybeReuse(p)):this.cache.reuse(p);A.flags&256?(A.flags&=-2,this.builder.addBlockWidget(A)):(this.builder.ensureLine(null),this.builder.addInlineWidget(A,g,w),w=g.length)}else if(p.isText())this.builder.ensureLine(null),!k&&j==p.length&&!this.cache.reused.has(p)?this.builder.addText(p.text,g,w,this.cache.reuse(p)):(this.cache.add(p),this.builder.addText(p.text.slice(k,j),g,w)),w=g.length;else if(p.isLine())p.flags&=-2,this.cache.reused.set(p,1),this.builder.addLine(p);else if(p instanceof the)this.cache.add(p);else if(p instanceof yp)this.builder.ensureLine(null),this.builder.addMark(p,g,w),this.cache.reused.set(p,1),w=g.length;else return!1;this.openWidget=!1},enter:p=>{p.isLine()?this.builder.addLineStart(p.attrs,this.cache.maybeReuse(p)):(this.cache.add(p),p instanceof yp&&g.unshift(p.mark)),this.openWidget=!1},leave:p=>{p.isLine()?g.length&&(g.length=w=0):p instanceof yp&&(g.shift(),w=Math.min(w,g.length))},break:()=>{this.builder.addBreak(),this.openWidget=!1}}),this.text.skip(s)}emit(s,u){let h=null,g=this.builder,w=0,p=xo.spans(this.decorations,s,u,{point:(k,j,A,_,D,I)=>{if(A instanceof xM){if(this.disallowBlockEffectsFor[I]){if(A.block)throw new RangeError("Block decorations may not be specified via plugins");if(j>this.view.state.doc.lineAt(k).to)throw new RangeError("Decorations that replace line breaks may not be specified via plugins")}if(w=_.length,D>_.length)g.continueWidget(j-k);else{let B=A.widget||(A.block?LI.block:LI.inline),F=Xdn(A),U=this.cache.findWidget(B,j-k,F)||OM.of(B,this.view,j-k,F);A.block?(A.startSide>0&&g.addLineStartIfNotCovered(h),g.addBlockWidget(U)):(g.ensureLine(h),g.addInlineWidget(U,_,D))}h=null}else h=Vdn(h,A);j>k&&this.text.skip(j-k)},span:(k,j,A,_)=>{for(let D=k;D<j;){let I=this.text.next(Math.min(512,j-D));I==null?(g.addLineStartIfNotCovered(h),g.addBreak(),D++):(g.ensureLine(h),g.addText(I,A,D==k?_:A.length),D+=I.length),h=null}}});g.addLineStartIfNotCovered(h),this.openWidget=p>w,this.openMarks=p}forward(s,u,h=1){u-s<=10?this.old.advance(u-s,h,this.reuseWalker):(this.old.advance(5,-1,this.reuseWalker),this.old.advance(u-s-10,-1),this.old.advance(5,h,this.reuseWalker))}getCompositionContext(s){let u=[],h=null;for(let g=s.parentNode;;g=g.parentNode){let w=of.get(g);if(g==this.view.contentDOM)break;w instanceof yp?u.push(w):w!=null&&w.isLine()?h=w:w instanceof nO||(g.nodeName=="DIV"&&!h&&g!=this.view.contentDOM?h=new DI(g,hOt):h||u.push(yp.of(new CV({tagName:g.nodeName.toLowerCase(),attributes:kdn(g)}),g)))}return{line:h,marks:u}}}function xxt(l,s){let u=h=>{for(let g of h.children)if((s?g.isText():g.length)||u(g))return!0;return!1};return u(l)}function Xdn(l){let s=l.isReplace?(l.startSide<0?64:0)|(l.endSide>0?128:0):l.startSide>0?32:16;return l.block&&(s|=256),s}const hOt={class:"cm-line"};function Vdn(l,s){let u=s.spec.attributes,h=s.spec.class;return!u&&!h||(l||(l={class:"cm-line"}),u&&KMe(u,l),h&&(l.class+=" "+h)),l}function Wdn(l){let s=[];for(let u=l.parents.length;u>1;u--){let h=u==l.parents.length?l.tile:l.parents[u].tile;h instanceof yp&&s.push(h.mark)}return s}function _Ee(l){let s=of.get(l);return s&&s.setDOM(l.cloneNode()),l}class LI extends lO{constructor(s){super(),this.tag=s}eq(s){return s.tag==this.tag}toDOM(){return document.createElement(this.tag)}updateDOM(s){return s.nodeName.toLowerCase()==this.tag}get isHidden(){return!0}}LI.inline=new LI("span");LI.block=new LI("div");const DEe=new class extends lO{toDOM(){return document.createElement("br")}get isHidden(){return!0}get editable(){return!0}};class kxt{constructor(s){this.view=s,this.decorations=[],this.blockWrappers=[],this.dynamicDecorationMap=[!1],this.domChanged=null,this.hasComposition=null,this.editContextFormatting=Fr.none,this.lastCompositionAfterCursor=!1,this.minWidth=0,this.minWidthFrom=0,this.minWidthTo=0,this.impreciseAnchor=null,this.impreciseHead=null,this.forceSelection=!1,this.lastUpdate=Date.now(),this.updateDeco(),this.tile=new Hhe(s,s.contentDOM),this.updateInner([new Uw(0,0,0,s.state.doc.length)],null)}update(s){var u;let h=s.changedRanges;this.minWidth>0&&h.length&&(h.every(({fromA:_,toA:D})=>D<this.minWidthFrom||_>this.minWidthTo)?(this.minWidthFrom=s.changes.mapPos(this.minWidthFrom,1),this.minWidthTo=s.changes.mapPos(this.minWidthTo,1)):this.minWidth=this.minWidthFrom=this.minWidthTo=0),this.updateEditContextFormatting(s);let g=-1;this.view.inputState.composing>=0&&!this.view.observer.editContext&&(!((u=this.domChanged)===null||u===void 0)&&u.newSel?g=this.domChanged.newSel.head:!s1n(s.changes,this.hasComposition)&&!s.selectionSet&&(g=s.state.selection.main.head));let w=g>-1?Ydn(this.view,s.changes,g):null;if(this.domChanged=null,this.hasComposition){let{from:_,to:D}=this.hasComposition;h=new Uw(_,D,s.changes.mapPos(_,-1),s.changes.mapPos(D,1)).addToSet(h.slice())}this.hasComposition=w?{from:w.range.fromB,to:w.range.toB}:null,(Ji.ie||Ji.chrome)&&!w&&s&&s.state.doc.lines!=s.startState.doc.lines&&(this.forceSelection=!0);let p=this.decorations,k=this.blockWrappers;this.updateDeco();let j=t1n(p,this.decorations,s.changes);j.length&&(h=Uw.extendWithRanges(h,j));let A=i1n(k,this.blockWrappers,s.changes);return A.length&&(h=Uw.extendWithRanges(h,A)),w&&!h.some(_=>_.fromA<=w.range.fromA&&_.toA>=w.range.toA)&&(h=w.range.addToSet(h.slice())),this.tile.flags&2&&h.length==0?!1:(this.updateInner(h,w),s.transactions.length&&(this.lastUpdate=Date.now()),!0)}updateInner(s,u){this.view.viewState.mustMeasureContent=!0;let{observer:h}=this.view;h.ignore(()=>{if(u||s.length){let p=this.tile,k=new Jdn(this.view,p,this.blockWrappers,this.decorations,this.dynamicDecorationMap);u&&of.get(u.text)&&k.cache.reused.set(of.get(u.text),2),this.tile=k.run(s,u),YCe(p,k.cache.reused)}this.tile.dom.style.height=this.view.viewState.contentHeight/this.view.scaleY+"px",this.tile.dom.style.flexBasis=this.minWidth?this.minWidth+"px":"";let w=Ji.chrome||Ji.ios?{node:h.selectionRange.focusNode,written:!1}:void 0;this.tile.sync(w),w&&(w.written||h.selectionRange.focusNode!=w.node||!this.tile.dom.contains(w.node))&&(this.forceSelection=!0),this.tile.dom.style.height=""});let g=[];if(this.view.viewport.from||this.view.viewport.to<this.view.state.doc.length)for(let w of this.tile.children)w.isWidget()&&w.widget instanceof LEe&&g.push(w.dom);h.updateGaps(g)}updateEditContextFormatting(s){this.editContextFormatting=this.editContextFormatting.map(s.changes);for(let u of s.transactions)for(let h of u.effects)h.is(cOt)&&(this.editContextFormatting=h.value)}updateSelection(s=!1,u=!1){(s||!this.view.observer.selectionRange.focusNode)&&this.view.observer.readSelectionRange();let{dom:h}=this.tile,g=this.view.root.activeElement,w=g==h,p=!w&&!(this.view.state.facet(Zk)||h.tabIndex>-1)&&$X(h,this.view.observer.selectionRange)&&!(g&&h.contains(g));if(!(w||u||p))return;let k=this.forceSelection;this.forceSelection=!1;let j=this.view.state.selection.main,A,_;if(j.empty?_=A=this.inlineDOMNearPos(j.anchor,j.assoc||1):(_=this.inlineDOMNearPos(j.head,j.head==j.from?1:-1),A=this.inlineDOMNearPos(j.anchor,j.anchor==j.from?1:-1)),Ji.gecko&&j.empty&&!this.hasComposition&&Kdn(A)){let I=document.createTextNode("");this.view.observer.ignore(()=>A.node.insertBefore(I,A.node.childNodes[A.offset]||null)),A=_=new Sy(I,0),k=!0}let D=this.view.observer.selectionRange;(k||!D.focusNode||(!zX(A.node,A.offset,D.anchorNode,D.anchorOffset)||!zX(_.node,_.offset,D.focusNode,D.focusOffset))&&!this.suppressWidgetCursorChange(D,j))&&(this.view.observer.ignore(()=>{Ji.android&&Ji.chrome&&h.contains(D.focusNode)&&r1n(D.focusNode,h)&&(h.blur(),h.focus({preventScroll:!0}));let I=rV(this.view.root);if(I)if(j.empty){if(Ji.gecko){let B=Zdn(A.node,A.offset);if(B&&B!=3){let F=(B==1?Gkt:Ukt)(A.node,A.offset);F&&(A=new Sy(F.node,F.offset))}}I.collapse(A.node,A.offset),j.bidiLevel!=null&&I.caretBidiLevel!==void 0&&(I.caretBidiLevel=j.bidiLevel)}else if(I.extend){I.collapse(A.node,A.offset);try{I.extend(_.node,_.offset)}catch{}}else{let B=document.createRange();j.anchor>j.head&&([A,_]=[_,A]),B.setEnd(_.node,_.offset),B.setStart(A.node,A.offset),I.removeAllRanges(),I.addRange(B)}p&&this.view.root.activeElement==h&&(h.blur(),g&&g.focus())}),this.view.observer.setSelectionRange(A,_)),this.impreciseAnchor=A.precise?null:new Sy(D.anchorNode,D.anchorOffset),this.impreciseHead=_.precise?null:new Sy(D.focusNode,D.focusOffset)}suppressWidgetCursorChange(s,u){return this.hasComposition&&u.empty&&zX(s.focusNode,s.focusOffset,s.anchorNode,s.anchorOffset)&&this.posFromDOM(s.focusNode,s.focusOffset)==u.head}enforceCursorAssoc(){if(this.hasComposition)return;let{view:s}=this,u=s.state.selection.main,h=rV(s.root),{anchorNode:g,anchorOffset:w}=s.observer.selectionRange;if(!h||!u.empty||!u.assoc||!h.modify)return;let p=this.lineAt(u.head,u.assoc);if(!p)return;let k=p.posAtStart;if(u.head==k||u.head==k+p.length)return;let j=this.coordsAt(u.head,-1),A=this.coordsAt(u.head,1);if(!j||!A||j.bottom>A.top)return;let _=this.domAtPos(u.head+u.assoc,u.assoc);h.collapse(_.node,_.offset),h.modify("move",u.assoc<0?"forward":"backward","lineboundary"),s.observer.readSelectionRange();let D=s.observer.selectionRange;s.docView.posFromDOM(D.anchorNode,D.anchorOffset)!=u.from&&h.collapse(g,w)}posFromDOM(s,u){let h=this.tile.nearest(s);if(!h)return this.tile.dom.compareDocumentPosition(s)&2?0:this.view.state.doc.length;let g=h.posAtStart;if(h.isComposite()){let w;if(s==h.dom)w=h.dom.childNodes[u];else{let p=rO(s)==0?0:u==0?-1:1;for(;;){let k=s.parentNode;if(k==h.dom)break;p==0&&k.firstChild!=k.lastChild&&(s==k.firstChild?p=-1:p=1),s=k}p<0?w=s:w=s.nextSibling}if(w==h.dom.firstChild)return g;for(;w&&!of.get(w);)w=w.nextSibling;if(!w)return g+h.length;for(let p=0,k=g;;p++){let j=h.children[p];if(j.dom==w)return k;k+=j.length+j.breakAfter}}else return h.isText()?s==h.dom?g+u:g+(u?h.length:0):g}domAtPos(s,u){let{tile:h,offset:g}=this.tile.resolveBlock(s,u);return h.isWidget()?h.domPosFor(s,u):h.domIn(g,u)}inlineDOMNearPos(s,u){let h,g=-1,w=!1,p,k=-1,j=!1;return this.tile.blockTiles((A,_)=>{if(A.isWidget()){if(A.flags&32&&_>=s)return!0;A.flags&16&&(w=!0)}else{let D=_+A.length;if(_<=s&&(h=A,g=s-_,w=D<s),D>=s&&!p&&(p=A,k=s-_,j=_>s),_>s&&p)return!0}}),!h&&!p?this.domAtPos(s,u):(w&&p?h=null:j&&h&&(p=null),h&&u<0||!p?h.domIn(g,u):p.domIn(k,u))}coordsAt(s,u){let{tile:h,offset:g}=this.tile.resolveBlock(s,u);return h.isWidget()?h.widget instanceof LEe?null:h.coordsInWidget(g,u,!0):h.coordsIn(g,u)}lineAt(s,u){let{tile:h}=this.tile.resolveBlock(s,u);return h.isLine()?h:null}coordsForChar(s){let{tile:u,offset:h}=this.tile.resolveBlock(s,1);if(!u.isLine())return null;function g(w,p){if(w.isComposite())for(let k of w.children){if(k.length>=p){let j=g(k,p);if(j)return j}if(p-=k.length,p<0)break}else if(w.isText()&&p<w.length){let k=Sd(w.text,p);if(k==p)return null;let j=oV(w.dom,p,k).getClientRects();for(let A=0;A<j.length;A++){let _=j[A];if(A==j.length-1||_.top<_.bottom&&_.left<_.right)return _}}return null}return g(u,h)}measureVisibleLineHeights(s){let u=[],{from:h,to:g}=s,w=this.view.contentDOM.clientWidth,p=w>Math.max(this.view.scrollDOM.clientWidth,this.minWidth)+1,k=-1,j=this.view.textDirection==Yl.LTR,A=0,_=(D,I,B)=>{for(let F=0;F<D.children.length&&!(I>g);F++){let U=D.children[F],K=I+U.length,Y=U.dom.getBoundingClientRect(),{height:Z}=Y;if(B&&!F&&(A+=Y.top-B.top),U instanceof nO)K>h&&_(U,I,Y);else if(I>=h&&(A>0&&u.push(-A),u.push(Z+A),A=0,p)){let ee=U.dom.lastChild,ce=ee?BX(ee):[];if(ce.length){let fe=ce[ce.length-1],be=j?fe.right-Y.left:Y.right-fe.left;be>k&&(k=be,this.minWidth=w,this.minWidthFrom=I,this.minWidthTo=K)}}B&&F==D.children.length-1&&(A+=B.bottom-Y.bottom),I=K+U.breakAfter}};return _(this.tile,0,null),u}textDirectionAt(s){let{tile:u}=this.tile.resolveBlock(s,1);return getComputedStyle(u.dom).direction=="rtl"?Yl.RTL:Yl.LTR}measureTextSize(){let s=this.tile.blockTiles(p=>{if(p.isLine()&&p.children.length&&p.length<=20){let k=0,j;for(let A of p.children){if(!A.isText()||/[^ -~]/.test(A.text))return;let _=BX(A.dom);if(_.length!=1)return;k+=_[0].width,j=_[0].height}if(k)return{lineHeight:p.dom.getBoundingClientRect().height,charWidth:k/p.length,textHeight:j}}});if(s)return s;let u=document.createElement("div"),h,g,w;return u.className="cm-line",u.style.width="99999px",u.style.position="absolute",u.textContent="abc def ghi jkl mno pqr stu",this.view.observer.ignore(()=>{this.tile.dom.appendChild(u);let p=BX(u.firstChild)[0];h=u.getBoundingClientRect().height,g=p&&p.width?p.width/27:7,w=p&&p.height?p.height:h,u.remove()}),{lineHeight:h,charWidth:g,textHeight:w}}computeBlockGapDeco(){let s=[],u=this.view.viewState;for(let h=0,g=0;;g++){let w=g==u.viewports.length?null:u.viewports[g],p=w?w.from-1:this.view.state.doc.length;if(p>h){let k=(u.lineBlockAt(p).bottom-u.lineBlockAt(h).top)/this.view.scaleY;s.push(Fr.replace({widget:new LEe(k),block:!0,inclusive:!0,isBlockGap:!0}).range(h,p))}if(!w)break;h=w.to+1}return Fr.set(s)}updateDeco(){let s=1,u=this.view.state.facet(Fhe).map(w=>(this.dynamicDecorationMap[s++]=typeof w=="function")?w(this.view):w),h=!1,g=this.view.state.facet(iAe).map((w,p)=>{let k=typeof w=="function";return k&&(h=!0),k?w(this.view):w});for(g.length&&(this.dynamicDecorationMap[s++]=h,u.push(xo.join(g))),this.decorations=[this.editContextFormatting,...u,this.computeBlockGapDeco(),this.view.viewState.lineGapDeco];s<this.decorations.length;)this.dynamicDecorationMap[s++]=!1;this.blockWrappers=this.view.state.facet(uOt).map(w=>typeof w=="function"?w(this.view):w)}scrollIntoView(s){if(s.isSnapshot){let A=this.view.viewState.lineBlockAt(s.range.head);this.view.scrollDOM.scrollTop=A.top-s.yMargin,this.view.scrollDOM.scrollLeft=s.xMargin;return}for(let A of this.view.state.facet(oOt))try{if(A(this.view,s.range,s))return!0}catch(_){kp(this.view.state,_,"scroll handler")}let{range:u}=s,h=this.coordsAt(u.head,u.empty?u.assoc:u.head>u.anchor?-1:1),g;if(!h)return;!u.empty&&(g=this.coordsAt(u.anchor,u.anchor>u.head?-1:1))&&(h={left:Math.min(h.left,g.left),top:Math.min(h.top,g.top),right:Math.max(h.right,g.right),bottom:Math.max(h.bottom,g.bottom)});let w=rAe(this.view),p={left:h.left-w.left,top:h.top-w.top,right:h.right+w.right,bottom:h.bottom+w.bottom},{offsetWidth:k,offsetHeight:j}=this.view.scrollDOM;if(jdn(this.view.scrollDOM,p,u.head<u.anchor?-1:1,s.x,s.y,Math.max(Math.min(s.xMargin,k),-k),Math.max(Math.min(s.yMargin,j),-j),this.view.textDirection==Yl.LTR),window.visualViewport&&window.innerHeight-window.visualViewport.height>1&&(h.top>window.pageYOffset+window.visualViewport.offsetTop+window.visualViewport.height||h.bottom<window.pageYOffset+window.visualViewport.offsetTop)){let A=this.view.docView.lineAt(u.head,1);A&&A.dom.scrollIntoView({block:"nearest"})}}lineHasWidget(s){let u=h=>h.isWidget()||h.children.some(u);return u(this.tile.resolveBlock(s,1).tile)}destroy(){YCe(this.tile)}}function YCe(l,s){let u=s==null?void 0:s.get(l);if(u!=1){u==null&&l.destroy();for(let h of l.children)YCe(h,s)}}function Kdn(l){return l.node.nodeType==1&&l.node.firstChild&&(l.offset==0||l.node.childNodes[l.offset-1].contentEditable=="false")&&(l.offset==l.node.childNodes.length||l.node.childNodes[l.offset].contentEditable=="false")}function dOt(l,s){let u=l.observer.selectionRange;if(!u.focusNode)return null;let h=Gkt(u.focusNode,u.focusOffset),g=Ukt(u.focusNode,u.focusOffset),w=h||g;if(g&&h&&g.node!=h.node){let k=of.get(g.node);if(!k||k.isText()&&k.text!=g.node.nodeValue)w=g;else if(l.docView.lastCompositionAfterCursor){let j=of.get(h.node);!j||j.isText()&&j.text!=h.node.nodeValue||(w=g)}}if(l.docView.lastCompositionAfterCursor=w!=h,!w)return null;let p=s-w.offset;return{from:p,to:p+w.node.nodeValue.length,node:w.node}}function Ydn(l,s,u){let h=dOt(l,u);if(!h)return null;let{node:g,from:w,to:p}=h,k=g.nodeValue;if(/[\n\r]/.test(k)||l.state.doc.sliceString(h.from,h.to)!=k)return null;let j=s.invertedDesc;return{range:new Uw(j.mapPos(w),j.mapPos(p),w,p),text:g}}function Zdn(l,s){return l.nodeType!=1?0:(s&&l.childNodes[s-1].contentEditable=="false"?1:0)|(s<l.childNodes.length&&l.childNodes[s].contentEditable=="false"?2:0)}let e1n=class{constructor(){this.changes=[]}compareRange(s,u){mI(s,u,this.changes)}comparePoint(s,u){mI(s,u,this.changes)}boundChange(s){mI(s,s,this.changes)}};function t1n(l,s,u){let h=new e1n;return xo.compare(l,s,u,h),h.changes}class n1n{constructor(){this.changes=[]}compareRange(s,u){mI(s,u,this.changes)}comparePoint(){}boundChange(s){mI(s,s,this.changes)}}function i1n(l,s,u){let h=new n1n;return xo.compare(l,s,u,h),h.changes}function r1n(l,s){for(let u=l;u&&u!=s;u=u.assignedSlot||u.parentNode)if(u.nodeType==1&&u.contentEditable=="false")return!0;return!1}function s1n(l,s){let u=!1;return s&&l.iterChangedRanges((h,g)=>{h<s.to&&g>s.from&&(u=!0)}),u}class LEe extends lO{constructor(s){super(),this.height=s}toDOM(){let s=document.createElement("div");return s.className="cm-gap",this.updateDOM(s),s}eq(s){return s.height==this.height}updateDOM(s){return s.style.height=this.height+"px",!0}get editable(){return!0}get estimatedHeight(){return this.height}ignoreEvent(){return!1}}function o1n(l,s,u=1){let h=l.charCategorizer(s),g=l.doc.lineAt(s),w=s-g.from;if(g.length==0)return kn.cursor(s);w==0?u=1:w==g.length&&(u=-1);let p=w,k=w;u<0?p=Sd(g.text,w,!1):k=Sd(g.text,w);let j=h(g.text.slice(p,k));for(;p>0;){let A=Sd(g.text,p,!1);if(h(g.text.slice(A,p))!=j)break;p=A}for(;k<g.length;){let A=Sd(g.text,k);if(h(g.text.slice(k,A))!=j)break;k=A}return kn.range(p+g.from,k+g.from)}function c1n(l,s,u,h,g){let w=Math.round((h-s.left)*l.defaultCharacterWidth);if(l.lineWrapping&&u.height>l.defaultLineHeight*1.5){let k=l.viewState.heightOracle.textHeight,j=Math.floor((g-u.top-(l.defaultLineHeight-k)*.5)/k);w+=j*l.viewState.heightOracle.lineLength}let p=l.state.sliceDoc(u.from,u.to);return u.from+zCe(p,w,l.state.tabSize)}function ZCe(l,s,u){let h=l.lineBlockAt(s);if(Array.isArray(h.type)){let g;for(let w of h.type){if(w.from>s)break;if(!(w.to<s)){if(w.from<s&&w.to>s)return w;(!g||w.type==a1.Text&&(g.type!=w.type||(u<0?w.from<s:w.to>s)))&&(g=w)}}return g||h}return h}function l1n(l,s,u,h){let g=ZCe(l,s.head,s.assoc||-1),w=!h||g.type!=a1.Text||!(l.lineWrapping||g.widgetLineBreaks)?null:l.coordsAtPos(s.assoc<0&&s.head>g.from?s.head-1:s.head);if(w){let p=l.dom.getBoundingClientRect(),k=l.textDirectionAt(g.from),j=l.posAtCoords({x:u==(k==Yl.LTR)?p.right-1:p.left+1,y:(w.top+w.bottom)/2});if(j!=null)return kn.cursor(j,u?-1:1)}return kn.cursor(u?g.to:g.from,u?-1:1)}function Oxt(l,s,u,h){let g=l.state.doc.lineAt(s.head),w=l.bidiSpans(g),p=l.textDirectionAt(g.from);for(let k=s,j=null;;){let A=Idn(g,w,p,k,u),_=Kkt;if(!A){if(g.number==(u?l.state.doc.lines:1))return k;_=`
`,g=l.state.doc.line(g.number+(u?1:-1)),w=l.bidiSpans(g),A=l.visualLineSide(g,!u)}if(j){if(!j(_))return k}else{if(!h)return A;j=h(_)}k=A}}function u1n(l,s,u){let h=l.state.charCategorizer(s),g=h(u);return w=>{let p=h(w);return g==ea.Space&&(g=p),g==p}}function a1n(l,s,u,h){let g=s.head,w=u?1:-1;if(g==(u?l.state.doc.length:0))return kn.cursor(g,s.assoc);let p=s.goalColumn,k,j=l.contentDOM.getBoundingClientRect(),A=l.coordsAtPos(g,(s.empty?s.assoc:0)||(u?1:-1)),_=l.documentTop;if(A)p==null&&(p=A.left-j.left),k=w<0?A.top:A.bottom;else{let F=l.viewState.lineBlockAt(g);p==null&&(p=Math.min(j.right-j.left,l.defaultCharacterWidth*(g-F.from))),k=(w<0?F.top:F.bottom)+_}let D=j.left+p,I=h??l.viewState.heightOracle.textHeight>>1,B=eMe(l,{x:D,y:k+I*w},!1,w);return kn.cursor(B.pos,B.assoc,void 0,p)}function FX(l,s,u){for(;;){let h=0;for(let g of l)g.between(s-1,s+1,(w,p,k)=>{if(s>w&&s<p){let j=h||u||(s-w<p-s?-1:1);s=j<0?w:p,h=j}});if(!h)return s}}function gOt(l,s){let u=null;for(let h=0;h<s.ranges.length;h++){let g=s.ranges[h],w=null;if(g.empty){let p=FX(l,g.from,0);p!=g.from&&(w=kn.cursor(p,-1))}else{let p=FX(l,g.from,-1),k=FX(l,g.to,1);(p!=g.from||k!=g.to)&&(w=kn.range(g.from==g.anchor?p:k,g.from==g.head?p:k))}w&&(u||(u=s.ranges.slice()),u[h]=w)}return u?kn.create(u,s.mainIndex):s}function PEe(l,s,u){let h=FX(l.state.facet(AV).map(g=>g(l)),u.from,s.head>u.from?-1:1);return h==u.from?u:kn.cursor(h,h<u.from?1:-1)}class H3{constructor(s,u){this.pos=s,this.assoc=u}}function eMe(l,s,u,h){let g=l.contentDOM.getBoundingClientRect(),w=g.top+l.viewState.paddingTop,{x:p,y:k}=s,j=k-w,A;for(;;){if(j<0)return new H3(0,1);if(j>l.viewState.docHeight)return new H3(l.state.doc.length,-1);if(A=l.elementAtHeight(j),h==null)break;if(A.type==a1.Text){if(h<0?A.to<l.viewport.from:A.from>l.viewport.to)break;let I=l.docView.coordsAt(h<0?A.from:A.to,h>0?-1:1);if(I&&(h<0?I.top<=j+w:I.bottom>=j+w))break}let D=l.viewState.heightOracle.textHeight/2;j=h>0?A.bottom+D:A.top-D}if(l.viewport.from>=A.to||l.viewport.to<=A.from){if(u)return null;if(A.type==a1.Text){let D=c1n(l,g,A,p,k);return new H3(D,D==A.from?1:-1)}}if(A.type!=a1.Text)return j<(A.top+A.bottom)/2?new H3(A.from,1):new H3(A.to,-1);let _=l.docView.lineAt(A.from,2);return(!_||_.length!=A.length)&&(_=l.docView.lineAt(A.from,-2)),new f1n(l,p,k,l.textDirectionAt(A.from)).scanTile(_,A.from)}class f1n{constructor(s,u,h,g){this.view=s,this.x=u,this.y=h,this.baseDir=g,this.line=null,this.spans=null}bidiSpansAt(s){return(!this.line||this.line.from>s||this.line.to<s)&&(this.line=this.view.state.doc.lineAt(s),this.spans=this.view.bidiSpans(this.line)),this}baseDirAt(s,u){let{line:h,spans:g}=this.bidiSpansAt(s);return g[Q3.find(g,s-h.from,-1,u)].level==this.baseDir}dirAt(s,u){let{line:h,spans:g}=this.bidiSpansAt(s);return g[Q3.find(g,s-h.from,-1,u)].dir}bidiIn(s,u){let{spans:h,line:g}=this.bidiSpansAt(s);return h.length>1||h.length&&(h[0].level!=this.baseDir||h[0].to+g.from<u)}scan(s,u){let h=0,g=s.length-1,w=new Set,p=this.bidiIn(s[0],s[g]),k,j,A=-1,_=1e9,D;e:for(;h<g;){let B=g-h,F=h+g>>1;t:if(w.has(F)){let K=h+Math.floor(Math.random()*B);for(let Y=0;Y<B;Y++){if(!w.has(K)){F=K;break t}K++,K==g&&(K=h)}break e}w.add(F);let U=u(F);if(U)for(let K=0;K<U.length;K++){let Y=U[K],Z=0;if(Y.bottom<this.y)(!k||k.bottom<Y.bottom)&&(k=Y),Z=1;else if(Y.top>this.y)(!j||j.top>Y.top)&&(j=Y),Z=-1;else{let ee=Y.left>this.x?this.x-Y.left:Y.right<this.x?this.x-Y.right:0,ce=Math.abs(ee);ce<_&&(A=F,_=ce,D=Y),ee&&(Z=ee<0==(this.baseDir==Yl.LTR)?-1:1)}Z==-1&&(!p||this.baseDirAt(s[F],1))?g=F:Z==1&&(!p||this.baseDirAt(s[F+1],-1))&&(h=F+1)}}if(!D){let B=k&&(!j||this.y-k.bottom<j.top-this.y)?k:j;return this.y=(B.top+B.bottom)/2,this.scan(s,u)}let I=(p?this.dirAt(s[A],1):this.baseDir)==Yl.LTR;return{i:A,after:this.x>(D.left+D.right)/2==I}}scanText(s,u){let h=[];for(let w=0;w<s.length;w=Sd(s.text,w))h.push(u+w);h.push(u+s.length);let g=this.scan(h,w=>{let p=h[w]-u,k=h[w+1]-u;return oV(s.dom,p,k).getClientRects()});return g.after?new H3(h[g.i+1],-1):new H3(h[g.i],1)}scanTile(s,u){if(!s.length)return new H3(u,1);if(s.children.length==1){let k=s.children[0];if(k.isText())return this.scanText(k,u);if(k.isComposite())return this.scanTile(k,u)}let h=[u];for(let k=0,j=u;k<s.children.length;k++)h.push(j+=s.children[k].length);let g=this.scan(h,k=>{let j=s.children[k];return j.flags&48?null:(j.dom.nodeType==1?j.dom:oV(j.dom,0,j.length)).getClientRects()}),w=s.children[g.i],p=h[g.i];return w.isText()?this.scanText(w,p):w.isComposite()?this.scanTile(w,p):g.after?new H3(h[g.i+1],-1):new H3(p,1)}}const sI="";class h1n{constructor(s,u){this.points=s,this.view=u,this.text="",this.lineSeparator=u.state.facet(Ic.lineSeparator)}append(s){this.text+=s}lineBreak(){this.text+=sI}readRange(s,u){if(!s)return this;let h=s.parentNode;for(let g=s;;){this.findPointBefore(h,g);let w=this.text.length;this.readNode(g);let p=of.get(g),k=g.nextSibling;if(k==u){p!=null&&p.breakAfter&&!k&&h!=this.view.contentDOM&&this.lineBreak();break}let j=of.get(k);(p&&j?p.breakAfter:(p?p.breakAfter:Zfe(g))||Zfe(k)&&(g.nodeName!="BR"||p!=null&&p.isWidget())&&this.text.length>w)&&!g1n(k,u)&&this.lineBreak(),g=k}return this.findPointBefore(h,u),this}readTextNode(s){let u=s.nodeValue;for(let h of this.points)h.node==s&&(h.pos=this.text.length+Math.min(h.offset,u.length));for(let h=0,g=this.lineSeparator?null:/\r\n?|\n/g;;){let w=-1,p=1,k;if(this.lineSeparator?(w=u.indexOf(this.lineSeparator,h),p=this.lineSeparator.length):(k=g.exec(u))&&(w=k.index,p=k[0].length),this.append(u.slice(h,w<0?u.length:w)),w<0)break;if(this.lineBreak(),p>1)for(let j of this.points)j.node==s&&j.pos>this.text.length&&(j.pos-=p-1);h=w+p}}readNode(s){let u=of.get(s),h=u&&u.overrideDOMText;if(h!=null){this.findPointInside(s,h.length);for(let g=h.iter();!g.next().done;)g.lineBreak?this.lineBreak():this.append(g.value)}else s.nodeType==3?this.readTextNode(s):s.nodeName=="BR"?s.nextSibling&&this.lineBreak():s.nodeType==1&&this.readRange(s.firstChild,null)}findPointBefore(s,u){for(let h of this.points)h.node==s&&s.childNodes[h.offset]==u&&(h.pos=this.text.length)}findPointInside(s,u){for(let h of this.points)(s.nodeType==3?h.node==s:s.contains(h.node))&&(h.pos=this.text.length+(d1n(s,h.node,h.offset)?u:0))}}function d1n(l,s,u){for(;;){if(!s||u<rO(s))return!1;if(s==l)return!0;u=S8(s)+1,s=s.parentNode}}function g1n(l,s){let u;for(;!(l==s||!l);l=l.nextSibling){let h=of.get(l);if(!(h!=null&&h.isWidget()))return!1;h&&(u||(u=[])).push(h)}if(u)for(let h of u){let g=h.overrideDOMText;if(g!=null&&g.length)return!1}return!0}class Sxt{constructor(s,u){this.node=s,this.offset=u,this.pos=-1}}class p1n{constructor(s,u,h,g){this.typeOver=g,this.bounds=null,this.text="",this.domChanged=u>-1;let{impreciseHead:w,impreciseAnchor:p}=s.docView;if(s.state.readOnly&&u>-1)this.newSel=null;else if(u>-1&&(this.bounds=pOt(s.docView.tile,u,h,0))){let k=w||p?[]:m1n(s),j=new h1n(k,s);j.readRange(this.bounds.startDOM,this.bounds.endDOM),this.text=j.text,this.newSel=w1n(k,this.bounds.from)}else{let k=s.observer.selectionRange,j=w&&w.node==k.focusNode&&w.offset==k.focusOffset||!JCe(s.contentDOM,k.focusNode)?s.state.selection.main.head:s.docView.posFromDOM(k.focusNode,k.focusOffset),A=p&&p.node==k.anchorNode&&p.offset==k.anchorOffset||!JCe(s.contentDOM,k.anchorNode)?s.state.selection.main.anchor:s.docView.posFromDOM(k.anchorNode,k.anchorOffset),_=s.viewport;if((Ji.ios||Ji.chrome)&&s.state.selection.main.empty&&j!=A&&(_.from>0||_.to<s.state.doc.length)){let D=Math.min(j,A),I=Math.max(j,A),B=_.from-D,F=_.to-I;(B==0||B==1||D==0)&&(F==0||F==-1||I==s.state.doc.length)&&(j=0,A=s.state.doc.length)}s.inputState.composing>-1&&s.state.selection.ranges.length>1?this.newSel=s.state.selection.replaceRange(kn.range(A,j)):this.newSel=kn.single(A,j)}}}function pOt(l,s,u,h){if(l.isComposite()){let g=-1,w=-1,p=-1,k=-1;for(let j=0,A=h,_=h;j<l.children.length;j++){let D=l.children[j],I=A+D.length;if(A<s&&I>u)return pOt(D,s,u,A);if(I>=s&&g==-1&&(g=j,w=A),A>u&&D.dom.parentNode==l.dom){p=j,k=_;break}_=I,A=I+D.breakAfter}return{from:w,to:k<0?h+l.length:k,startDOM:(g?l.children[g-1].dom.nextSibling:null)||l.dom.firstChild,endDOM:p<l.children.length&&p>=0?l.children[p].dom:null}}else return l.isText()?{from:h,to:h+l.length,startDOM:l.dom,endDOM:l.dom.nextSibling}:null}function bOt(l,s){let u,{newSel:h}=s,{state:g}=l,w=g.selection.main,p=l.inputState.lastKeyTime>Date.now()-100?l.inputState.lastKeyCode:-1;if(s.bounds){let{from:k,to:j}=s.bounds,A=w.from,_=null;(p===8||Ji.android&&s.text.length<j-k)&&(A=w.to,_="end");let D=g.doc.sliceString(k,j,sI),I,B;!w.empty&&w.from>=k&&w.to<=j&&(s.typeOver||D!=s.text)&&D.slice(0,w.from-k)==s.text.slice(0,w.from-k)&&D.slice(w.to-k)==s.text.slice(I=s.text.length-(D.length-(w.to-k)))?u={from:w.from,to:w.to,insert:uc.of(s.text.slice(w.from-k,I).split(sI))}:(B=mOt(D,s.text,A-k,_))&&(Ji.chrome&&p==13&&B.toB==B.from+2&&s.text.slice(B.from,B.toB)==sI+sI&&B.toB--,u={from:k+B.from,to:k+B.toA,insert:uc.of(s.text.slice(B.from,B.toB).split(sI))})}else h&&(!l.hasFocus&&g.facet(Zk)||ihe(h,w))&&(h=null);if(!u&&!h)return!1;if((Ji.mac||Ji.android)&&u&&u.from==u.to&&u.from==w.head-1&&/^\. ?$/.test(u.insert.toString())&&l.contentDOM.getAttribute("autocorrect")=="off"?(h&&u.insert.length==2&&(h=kn.single(h.main.anchor-1,h.main.head-1)),u={from:u.from,to:u.to,insert:uc.of([u.insert.toString().replace("."," ")])}):g.doc.lineAt(w.from).to<w.to&&l.docView.lineHasWidget(w.to)&&l.inputState.insertingTextAt>Date.now()-50?u={from:w.from,to:w.to,insert:g.toText(l.inputState.insertingText)}:Ji.chrome&&u&&u.from==u.to&&u.from==w.head&&u.insert.toString()==`
 `&&l.lineWrapping&&(h&&(h=kn.single(h.main.anchor-1,h.main.head-1)),u={from:w.from,to:w.to,insert:uc.of([" "])}),u)return sAe(l,u,h,p);if(h&&!ihe(h,w)){let k=!1,j="select";return l.inputState.lastSelectionTime>Date.now()-50&&(l.inputState.lastSelectionOrigin=="select"&&(k=!0),j=l.inputState.lastSelectionOrigin,j=="select.pointer"&&(h=gOt(g.facet(AV).map(A=>A(l)),h))),l.dispatch({selection:h,scrollIntoView:k,userEvent:j}),!0}else return!1}function sAe(l,s,u,h=-1){if(Ji.ios&&l.inputState.flushIOSKey(s))return!0;let g=l.state.selection.main;if(Ji.android&&(s.to==g.to&&(s.from==g.from||s.from==g.from-1&&l.state.sliceDoc(s.from,g.from)==" ")&&s.insert.length==1&&s.insert.lines==2&&wI(l.contentDOM,"Enter",13)||(s.from==g.from-1&&s.to==g.to&&s.insert.length==0||h==8&&s.insert.length<s.to-s.from&&s.to>g.head)&&wI(l.contentDOM,"Backspace",8)||s.from==g.from&&s.to==g.to+1&&s.insert.length==0&&wI(l.contentDOM,"Delete",46)))return!0;let w=s.insert.toString();l.inputState.composing>=0&&l.inputState.composing++;let p,k=()=>p||(p=b1n(l,s,u));return l.state.facet(nOt).some(j=>j(l,s.from,s.to,w,k))||l.dispatch(k()),!0}function b1n(l,s,u){let h,g=l.state,w=g.selection.main,p=-1;if(s.from==s.to&&s.from<w.from||s.from>w.to){let j=s.from<w.from?-1:1,A=j<0?w.from:w.to,_=FX(g.facet(AV).map(D=>D(l)),A,j);s.from==_&&(p=_)}if(p>-1)h={changes:s,selection:kn.cursor(s.from+s.insert.length,-1)};else if(s.from>=w.from&&s.to<=w.to&&s.to-s.from>=(w.to-w.from)/3&&(!u||u.main.empty&&u.main.from==s.from+s.insert.length)&&l.inputState.composing<0){let j=w.from<s.from?g.sliceDoc(w.from,s.from):"",A=w.to>s.to?g.sliceDoc(s.to,w.to):"";h=g.replaceSelection(l.state.toText(j+s.insert.sliceString(0,void 0,l.state.lineBreak)+A))}else{let j=g.changes(s),A=u&&u.main.to<=j.newLength?u.main:void 0;if(g.selection.ranges.length>1&&(l.inputState.composing>=0||l.inputState.compositionPendingChange)&&s.to<=w.to+10&&s.to>=w.to-10){let _=l.state.sliceDoc(s.from,s.to),D,I=u&&dOt(l,u.main.head);if(I){let F=s.insert.length-(s.to-s.from);D={from:I.from,to:I.to-F}}else D=l.state.doc.lineAt(w.head);let B=w.to-s.to;h=g.changeByRange(F=>{if(F.from==w.from&&F.to==w.to)return{changes:j,range:A||F.map(j)};let U=F.to-B,K=U-_.length;if(l.state.sliceDoc(K,U)!=_||U>=D.from&&K<=D.to)return{range:F};let Y=g.changes({from:K,to:U,insert:s.insert}),Z=F.to-w.to;return{changes:Y,range:A?kn.range(Math.max(0,A.anchor+Z),Math.max(0,A.head+Z)):F.map(Y)}})}else h={changes:j,selection:A&&g.selection.replaceRange(A)}}let k="input.type";return(l.composing||l.inputState.compositionPendingChange&&l.inputState.compositionEndedAt>Date.now()-50)&&(l.inputState.compositionPendingChange=!1,k+=".compose",l.inputState.compositionFirstChange&&(k+=".start",l.inputState.compositionFirstChange=!1)),g.update(h,{userEvent:k,scrollIntoView:!0})}function mOt(l,s,u,h){let g=Math.min(l.length,s.length),w=0;for(;w<g&&l.charCodeAt(w)==s.charCodeAt(w);)w++;if(w==g&&l.length==s.length)return null;let p=l.length,k=s.length;for(;p>0&&k>0&&l.charCodeAt(p-1)==s.charCodeAt(k-1);)p--,k--;if(h=="end"){let j=Math.max(0,w-Math.min(p,k));u-=p+j-w}if(p<w&&l.length<s.length){let j=u<=w&&u>=p?w-u:0;w-=j,k=w+(k-p),p=w}else if(k<w){let j=u<=w&&u>=k?w-u:0;w-=j,p=w+(p-k),k=w}return{from:w,toA:p,toB:k}}function m1n(l){let s=[];if(l.root.activeElement!=l.contentDOM)return s;let{anchorNode:u,anchorOffset:h,focusNode:g,focusOffset:w}=l.observer.selectionRange;return u&&(s.push(new Sxt(u,h)),(g!=u||w!=h)&&s.push(new Sxt(g,w))),s}function w1n(l,s){if(l.length==0)return null;let u=l[0].pos,h=l.length==2?l[1].pos:u;return u>-1&&h>-1?kn.single(u+s,h+s):null}function ihe(l,s){return s.head==l.main.head&&s.anchor==l.main.anchor}class v1n{setSelectionOrigin(s){this.lastSelectionOrigin=s,this.lastSelectionTime=Date.now()}constructor(s){this.view=s,this.lastKeyCode=0,this.lastKeyTime=0,this.lastTouchTime=0,this.lastFocusTime=0,this.lastScrollTop=0,this.lastScrollLeft=0,this.lastWheelEvent=0,this.pendingIOSKey=void 0,this.tabFocusMode=-1,this.lastSelectionOrigin=null,this.lastSelectionTime=0,this.lastContextMenu=0,this.scrollHandlers=[],this.handlers=Object.create(null),this.composing=-1,this.compositionFirstChange=null,this.compositionEndedAt=0,this.compositionPendingKey=!1,this.compositionPendingChange=!1,this.insertingText="",this.insertingTextAt=0,this.mouseSelection=null,this.draggedContent=null,this.handleEvent=this.handleEvent.bind(this),this.notifiedFocused=s.hasFocus,Ji.safari&&s.contentDOM.addEventListener("input",()=>null),Ji.gecko&&L1n(s.contentDOM.ownerDocument)}handleEvent(s){!E1n(this.view,s)||this.ignoreDuringComposition(s)||s.type=="keydown"&&this.keydown(s)||(this.view.updateState!=0?Promise.resolve().then(()=>this.runHandlers(s.type,s)):this.runHandlers(s.type,s))}runHandlers(s,u){let h=this.handlers[s];if(h){for(let g of h.observers)g(this.view,u);for(let g of h.handlers){if(u.defaultPrevented)break;if(g(this.view,u)){u.preventDefault();break}}}}ensureHandlers(s){let u=y1n(s),h=this.handlers,g=this.view.contentDOM;for(let w in u)if(w!="scroll"){let p=!u[w].handlers.length,k=h[w];k&&p!=!k.handlers.length&&(g.removeEventListener(w,this.handleEvent),k=null),k||g.addEventListener(w,this.handleEvent,{passive:p})}for(let w in h)w!="scroll"&&!u[w]&&g.removeEventListener(w,this.handleEvent);this.handlers=u}keydown(s){if(this.lastKeyCode=s.keyCode,this.lastKeyTime=Date.now(),s.keyCode==9&&this.tabFocusMode>-1&&(!this.tabFocusMode||Date.now()<=this.tabFocusMode))return!0;if(this.tabFocusMode>0&&s.keyCode!=27&&vOt.indexOf(s.keyCode)<0&&(this.tabFocusMode=-1),Ji.android&&Ji.chrome&&!s.synthetic&&(s.keyCode==13||s.keyCode==8))return this.view.observer.delayAndroidKey(s.key,s.keyCode),!0;let u;return Ji.ios&&!s.synthetic&&!s.altKey&&!s.metaKey&&((u=wOt.find(h=>h.keyCode==s.keyCode))&&!s.ctrlKey||x1n.indexOf(s.key)>-1&&s.ctrlKey&&!s.shiftKey)?(this.pendingIOSKey=u||s,setTimeout(()=>this.flushIOSKey(),250),!0):(s.keyCode!=229&&this.view.observer.forceFlush(),!1)}flushIOSKey(s){let u=this.pendingIOSKey;return!u||u.key=="Enter"&&s&&s.from<s.to&&/^\S+$/.test(s.insert.toString())?!1:(this.pendingIOSKey=void 0,wI(this.view.contentDOM,u.key,u.keyCode,u instanceof KeyboardEvent?u:void 0))}ignoreDuringComposition(s){return!/^key/.test(s.type)||s.synthetic?!1:this.composing>0?!0:Ji.safari&&!Ji.ios&&this.compositionPendingKey&&Date.now()-this.compositionEndedAt<100?(this.compositionPendingKey=!1,!0):!1}startMouseSelection(s){this.mouseSelection&&this.mouseSelection.destroy(),this.mouseSelection=s}update(s){this.view.observer.update(s),this.mouseSelection&&this.mouseSelection.update(s),this.draggedContent&&s.docChanged&&(this.draggedContent=this.draggedContent.map(s.changes)),s.transactions.length&&(this.lastKeyCode=this.lastSelectionTime=0)}destroy(){this.mouseSelection&&this.mouseSelection.destroy()}}function jxt(l,s){return(u,h)=>{try{return s.call(l,h,u)}catch(g){kp(u.state,g)}}}function y1n(l){let s=Object.create(null);function u(h){return s[h]||(s[h]={observers:[],handlers:[]})}for(let h of l){let g=h.spec,w=g&&g.plugin.domEventHandlers,p=g&&g.plugin.domEventObservers;if(w)for(let k in w){let j=w[k];j&&u(k).handlers.push(jxt(h.value,j))}if(p)for(let k in p){let j=p[k];j&&u(k).observers.push(jxt(h.value,j))}}for(let h in Cy)u(h).handlers.push(Cy[h]);for(let h in Tp)u(h).observers.push(Tp[h]);return s}const wOt=[{key:"Backspace",keyCode:8,inputType:"deleteContentBackward"},{key:"Enter",keyCode:13,inputType:"insertParagraph"},{key:"Enter",keyCode:13,inputType:"insertLineBreak"},{key:"Delete",keyCode:46,inputType:"deleteContentForward"}],x1n="dthko",vOt=[16,17,18,20,91,92,224,225],Vae=6;function Wae(l){return Math.max(0,l)*.7+8}function k1n(l,s){return Math.max(Math.abs(l.clientX-s.clientX),Math.abs(l.clientY-s.clientY))}class O1n{constructor(s,u,h,g){this.view=s,this.startEvent=u,this.style=h,this.mustSelect=g,this.scrollSpeed={x:0,y:0},this.scrolling=-1,this.lastEvent=u,this.scrollParents=qkt(s.contentDOM),this.atoms=s.state.facet(AV).map(p=>p(s));let w=s.contentDOM.ownerDocument;w.addEventListener("mousemove",this.move=this.move.bind(this)),w.addEventListener("mouseup",this.up=this.up.bind(this)),this.extend=u.shiftKey,this.multiple=s.state.facet(Ic.allowMultipleSelections)&&S1n(s,u),this.dragging=T1n(s,u)&&kOt(u)==1?null:!1}start(s){this.dragging===!1&&this.select(s)}move(s){if(s.buttons==0)return this.destroy();if(this.dragging||this.dragging==null&&k1n(this.startEvent,s)<10)return;this.select(this.lastEvent=s);let u=0,h=0,g=0,w=0,p=this.view.win.innerWidth,k=this.view.win.innerHeight;this.scrollParents.x&&({left:g,right:p}=this.scrollParents.x.getBoundingClientRect()),this.scrollParents.y&&({top:w,bottom:k}=this.scrollParents.y.getBoundingClientRect());let j=rAe(this.view);s.clientX-j.left<=g+Vae?u=-Wae(g-s.clientX):s.clientX+j.right>=p-Vae&&(u=Wae(s.clientX-p)),s.clientY-j.top<=w+Vae?h=-Wae(w-s.clientY):s.clientY+j.bottom>=k-Vae&&(h=Wae(s.clientY-k)),this.setScrollSpeed(u,h)}up(s){this.dragging==null&&this.select(this.lastEvent),this.dragging||s.preventDefault(),this.destroy()}destroy(){this.setScrollSpeed(0,0);let s=this.view.contentDOM.ownerDocument;s.removeEventListener("mousemove",this.move),s.removeEventListener("mouseup",this.up),this.view.inputState.mouseSelection=this.view.inputState.draggedContent=null}setScrollSpeed(s,u){this.scrollSpeed={x:s,y:u},s||u?this.scrolling<0&&(this.scrolling=setInterval(()=>this.scroll(),50)):this.scrolling>-1&&(clearInterval(this.scrolling),this.scrolling=-1)}scroll(){let{x:s,y:u}=this.scrollSpeed;s&&this.scrollParents.x&&(this.scrollParents.x.scrollLeft+=s,s=0),u&&this.scrollParents.y&&(this.scrollParents.y.scrollTop+=u,u=0),(s||u)&&this.view.win.scrollBy(s,u),this.dragging===!1&&this.select(this.lastEvent)}select(s){let{view:u}=this,h=gOt(this.atoms,this.style.get(s,this.extend,this.multiple));(this.mustSelect||!h.eq(u.state.selection,this.dragging===!1))&&this.view.dispatch({selection:h,userEvent:"select.pointer"}),this.mustSelect=!1}update(s){s.transactions.some(u=>u.isUserEvent("input.type"))?this.destroy():this.style.update(s)&&setTimeout(()=>this.select(this.lastEvent),20)}}function S1n(l,s){let u=l.state.facet(Ykt);return u.length?u[0](s):Ji.mac?s.metaKey:s.ctrlKey}function j1n(l,s){let u=l.state.facet(Zkt);return u.length?u[0](s):Ji.mac?!s.altKey:!s.ctrlKey}function T1n(l,s){let{main:u}=l.state.selection;if(u.empty)return!1;let h=rV(l.root);if(!h||h.rangeCount==0)return!0;let g=h.getRangeAt(0).getClientRects();for(let w=0;w<g.length;w++){let p=g[w];if(p.left<=s.clientX&&p.right>=s.clientX&&p.top<=s.clientY&&p.bottom>=s.clientY)return!0}return!1}function E1n(l,s){if(!s.bubbles)return!0;if(s.defaultPrevented)return!1;for(let u=s.target,h;u!=l.contentDOM;u=u.parentNode)if(!u||u.nodeType==11||(h=of.get(u))&&h.isWidget()&&!h.isHidden&&h.widget.ignoreEvent(s))return!1;return!0}const Cy=Object.create(null),Tp=Object.create(null),yOt=Ji.ie&&Ji.ie_version<15||Ji.ios&&Ji.webkit_version<604;function C1n(l){let s=l.dom.parentNode;if(!s)return;let u=s.appendChild(document.createElement("textarea"));u.style.cssText="position: fixed; left: -10000px; top: 10px",u.focus(),setTimeout(()=>{l.focus(),u.remove(),xOt(l,u.value)},50)}function Qhe(l,s,u){for(let h of l.facet(s))u=h(u,l);return u}function xOt(l,s){s=Qhe(l.state,eAe,s);let{state:u}=l,h,g=1,w=u.toText(s),p=w.lines==u.selection.ranges.length;if(tMe!=null&&u.selection.ranges.every(j=>j.empty)&&tMe==w.toString()){let j=-1;h=u.changeByRange(A=>{let _=u.doc.lineAt(A.from);if(_.from==j)return{range:A};j=_.from;let D=u.toText((p?w.line(g++).text:s)+u.lineBreak);return{changes:{from:_.from,insert:D},range:kn.cursor(A.from+D.length)}})}else p?h=u.changeByRange(j=>{let A=w.line(g++);return{changes:{from:j.from,to:j.to,insert:A.text},range:kn.cursor(j.from+A.length)}}):h=u.replaceSelection(w);l.dispatch(h,{userEvent:"input.paste",scrollIntoView:!0})}Tp.scroll=l=>{l.inputState.lastScrollTop=l.scrollDOM.scrollTop,l.inputState.lastScrollLeft=l.scrollDOM.scrollLeft};Tp.wheel=Tp.mousewheel=l=>{l.inputState.lastWheelEvent=Date.now()};Cy.keydown=(l,s)=>(l.inputState.setSelectionOrigin("select"),s.keyCode==27&&l.inputState.tabFocusMode!=0&&(l.inputState.tabFocusMode=Date.now()+2e3),!1);Tp.touchstart=(l,s)=>{l.inputState.lastTouchTime=Date.now(),l.inputState.setSelectionOrigin("select.pointer")};Tp.touchmove=l=>{l.inputState.setSelectionOrigin("select.pointer")};Cy.mousedown=(l,s)=>{if(l.observer.flush(),l.inputState.lastTouchTime>Date.now()-2e3)return!1;let u=null;for(let h of l.state.facet(eOt))if(u=h(l,s),u)break;if(!u&&s.button==0&&(u=A1n(l,s)),u){let h=!l.hasFocus;l.inputState.startMouseSelection(new O1n(l,s,u,h)),h&&l.observer.ignore(()=>{Hkt(l.contentDOM);let w=l.root.activeElement;w&&!w.contains(l.contentDOM)&&w.blur()});let g=l.inputState.mouseSelection;if(g)return g.start(s),g.dragging===!1}else l.inputState.setSelectionOrigin("select.pointer");return!1};function Txt(l,s,u,h){if(h==1)return kn.cursor(s,u);if(h==2)return o1n(l.state,s,u);{let g=l.docView.lineAt(s,u),w=l.state.doc.lineAt(g?g.posAtEnd:s),p=g?g.posAtStart:w.from,k=g?g.posAtEnd:w.to;return k<l.state.doc.length&&k==w.to&&k++,kn.range(p,k)}}const M1n=Ji.ie&&Ji.ie_version<=11;let Ext=null,Cxt=0,Mxt=0;function kOt(l){if(!M1n)return l.detail;let s=Ext,u=Mxt;return Ext=l,Mxt=Date.now(),Cxt=!s||u>Date.now()-400&&Math.abs(s.clientX-l.clientX)<2&&Math.abs(s.clientY-l.clientY)<2?(Cxt+1)%3:1}function A1n(l,s){let u=l.posAndSideAtCoords({x:s.clientX,y:s.clientY},!1),h=kOt(s),g=l.state.selection;return{update(w){w.docChanged&&(u.pos=w.changes.mapPos(u.pos),g=g.map(w.changes))},get(w,p,k){let j=l.posAndSideAtCoords({x:w.clientX,y:w.clientY},!1),A,_=Txt(l,j.pos,j.assoc,h);if(u.pos!=j.pos&&!p){let D=Txt(l,u.pos,u.assoc,h),I=Math.min(D.from,_.from),B=Math.max(D.to,_.to);_=I<_.from?kn.range(I,B):kn.range(B,I)}return p?g.replaceRange(g.main.extend(_.from,_.to)):k&&h==1&&g.ranges.length>1&&(A=N1n(g,j.pos))?A:k?g.addRange(_):kn.create([_])}}}function N1n(l,s){for(let u=0;u<l.ranges.length;u++){let{from:h,to:g}=l.ranges[u];if(h<=s&&g>=s)return kn.create(l.ranges.slice(0,u).concat(l.ranges.slice(u+1)),l.mainIndex==u?0:l.mainIndex-(l.mainIndex>u?1:0))}return null}Cy.dragstart=(l,s)=>{let{selection:{main:u}}=l.state;if(s.target.draggable){let g=l.docView.tile.nearest(s.target);if(g&&g.isWidget()){let w=g.posAtStart,p=w+g.length;(w>=u.to||p<=u.from)&&(u=kn.range(w,p))}}let{inputState:h}=l;return h.mouseSelection&&(h.mouseSelection.dragging=!0),h.draggedContent=u,s.dataTransfer&&(s.dataTransfer.setData("Text",Qhe(l.state,tAe,l.state.sliceDoc(u.from,u.to))),s.dataTransfer.effectAllowed="copyMove"),!1};Cy.dragend=l=>(l.inputState.draggedContent=null,!1);function Axt(l,s,u,h){if(u=Qhe(l.state,eAe,u),!u)return;let g=l.posAtCoords({x:s.clientX,y:s.clientY},!1),{draggedContent:w}=l.inputState,p=h&&w&&j1n(l,s)?{from:w.from,to:w.to}:null,k={from:g,insert:u},j=l.state.changes(p?[p,k]:k);l.focus(),l.dispatch({changes:j,selection:{anchor:j.mapPos(g,-1),head:j.mapPos(g,1)},userEvent:p?"move.drop":"input.drop"}),l.inputState.draggedContent=null}Cy.drop=(l,s)=>{if(!s.dataTransfer)return!1;if(l.state.readOnly)return!0;let u=s.dataTransfer.files;if(u&&u.length){let h=Array(u.length),g=0,w=()=>{++g==u.length&&Axt(l,s,h.filter(p=>p!=null).join(l.state.lineBreak),!1)};for(let p=0;p<u.length;p++){let k=new FileReader;k.onerror=w,k.onload=()=>{/[\x00-\x08\x0e-\x1f]{2}/.test(k.result)||(h[p]=k.result),w()},k.readAsText(u[p])}return!0}else{let h=s.dataTransfer.getData("Text");if(h)return Axt(l,s,h,!0),!0}return!1};Cy.paste=(l,s)=>{if(l.state.readOnly)return!0;l.observer.flush();let u=yOt?null:s.clipboardData;return u?(xOt(l,u.getData("text/plain")||u.getData("text/uri-list")),!0):(C1n(l),!1)};function _1n(l,s){let u=l.dom.parentNode;if(!u)return;let h=u.appendChild(document.createElement("textarea"));h.style.cssText="position: fixed; left: -10000px; top: 10px",h.value=s,h.focus(),h.selectionEnd=s.length,h.selectionStart=0,setTimeout(()=>{h.remove(),l.focus()},50)}function D1n(l){let s=[],u=[],h=!1;for(let g of l.selection.ranges)g.empty||(s.push(l.sliceDoc(g.from,g.to)),u.push(g));if(!s.length){let g=-1;for(let{from:w}of l.selection.ranges){let p=l.doc.lineAt(w);p.number>g&&(s.push(p.text),u.push({from:p.from,to:Math.min(l.doc.length,p.to+1)})),g=p.number}h=!0}return{text:Qhe(l,tAe,s.join(l.lineBreak)),ranges:u,linewise:h}}let tMe=null;Cy.copy=Cy.cut=(l,s)=>{if(!$X(l.contentDOM,l.observer.selectionRange))return!1;let{text:u,ranges:h,linewise:g}=D1n(l.state);if(!u&&!g)return!1;tMe=g?u:null,s.type=="cut"&&!l.state.readOnly&&l.dispatch({changes:h,scrollIntoView:!0,userEvent:"delete.cut"});let w=yOt?null:s.clipboardData;return w?(w.clearData(),w.setData("text/plain",u),!0):(_1n(l,u),!1)};const OOt=cO.define();function SOt(l,s){let u=[];for(let h of l.facet(iOt)){let g=h(l,s);g&&u.push(g)}return u.length?l.update({effects:u,annotations:OOt.of(!0)}):null}function jOt(l){setTimeout(()=>{let s=l.hasFocus;if(s!=l.inputState.notifiedFocused){let u=SOt(l.state,s);u?l.dispatch(u):l.update([])}},10)}Tp.focus=l=>{l.inputState.lastFocusTime=Date.now(),!l.scrollDOM.scrollTop&&(l.inputState.lastScrollTop||l.inputState.lastScrollLeft)&&(l.scrollDOM.scrollTop=l.inputState.lastScrollTop,l.scrollDOM.scrollLeft=l.inputState.lastScrollLeft),jOt(l)};Tp.blur=l=>{l.observer.clearSelectionRange(),jOt(l)};Tp.compositionstart=Tp.compositionupdate=l=>{l.observer.editContext||(l.inputState.compositionFirstChange==null&&(l.inputState.compositionFirstChange=!0),l.inputState.composing<0&&(l.inputState.composing=0))};Tp.compositionend=l=>{l.observer.editContext||(l.inputState.composing=-1,l.inputState.compositionEndedAt=Date.now(),l.inputState.compositionPendingKey=!0,l.inputState.compositionPendingChange=l.observer.pendingRecords().length>0,l.inputState.compositionFirstChange=null,Ji.chrome&&Ji.android?l.observer.flushSoon():l.inputState.compositionPendingChange?Promise.resolve().then(()=>l.observer.flush()):setTimeout(()=>{l.inputState.composing<0&&l.docView.hasComposition&&l.update([])},50))};Tp.contextmenu=l=>{l.inputState.lastContextMenu=Date.now()};Cy.beforeinput=(l,s)=>{var u,h;if((s.inputType=="insertText"||s.inputType=="insertCompositionText")&&(l.inputState.insertingText=s.data,l.inputState.insertingTextAt=Date.now()),s.inputType=="insertReplacementText"&&l.observer.editContext){let w=(u=s.dataTransfer)===null||u===void 0?void 0:u.getData("text/plain"),p=s.getTargetRanges();if(w&&p.length){let k=p[0],j=l.posAtDOM(k.startContainer,k.startOffset),A=l.posAtDOM(k.endContainer,k.endOffset);return sAe(l,{from:j,to:A,insert:l.state.toText(w)},null),!0}}let g;if(Ji.chrome&&Ji.android&&(g=wOt.find(w=>w.inputType==s.inputType))&&(l.observer.delayAndroidKey(g.key,g.keyCode),g.key=="Backspace"||g.key=="Delete")){let w=((h=window.visualViewport)===null||h===void 0?void 0:h.height)||0;setTimeout(()=>{var p;(((p=window.visualViewport)===null||p===void 0?void 0:p.height)||0)>w+10&&l.hasFocus&&(l.contentDOM.blur(),l.focus())},100)}return Ji.ios&&s.inputType=="deleteContentForward"&&l.observer.flushSoon(),Ji.safari&&s.inputType=="insertText"&&l.inputState.composing>=0&&setTimeout(()=>Tp.compositionend(l,s),20),!1};const Nxt=new Set;function L1n(l){Nxt.has(l)||(Nxt.add(l),l.addEventListener("copy",()=>{}),l.addEventListener("cut",()=>{}))}const _xt=["pre-wrap","normal","pre-line","break-spaces"];let PI=!1;function Dxt(){PI=!1}class P1n{constructor(s){this.lineWrapping=s,this.doc=uc.empty,this.heightSamples={},this.lineHeight=14,this.charWidth=7,this.textHeight=14,this.lineLength=30}heightForGap(s,u){let h=this.doc.lineAt(u).number-this.doc.lineAt(s).number+1;return this.lineWrapping&&(h+=Math.max(0,Math.ceil((u-s-h*this.lineLength*.5)/this.lineLength))),this.lineHeight*h}heightForLine(s){return this.lineWrapping?(1+Math.max(0,Math.ceil((s-this.lineLength)/Math.max(1,this.lineLength-5))))*this.lineHeight:this.lineHeight}setDoc(s){return this.doc=s,this}mustRefreshForWrapping(s){return _xt.indexOf(s)>-1!=this.lineWrapping}mustRefreshForHeights(s){let u=!1;for(let h=0;h<s.length;h++){let g=s[h];g<0?h++:this.heightSamples[Math.floor(g*10)]||(u=!0,this.heightSamples[Math.floor(g*10)]=!0)}return u}refresh(s,u,h,g,w,p){let k=_xt.indexOf(s)>-1,j=Math.abs(u-this.lineHeight)>.3||this.lineWrapping!=k||Math.abs(h-this.charWidth)>.1;if(this.lineWrapping=k,this.lineHeight=u,this.charWidth=h,this.textHeight=g,this.lineLength=w,j){this.heightSamples={};for(let A=0;A<p.length;A++){let _=p[A];_<0?A++:this.heightSamples[Math.floor(_*10)]=!0}}return j}}class I1n{constructor(s,u){this.from=s,this.heights=u,this.index=0}get more(){return this.index<this.heights.length}}class yy{constructor(s,u,h,g,w){this.from=s,this.length=u,this.top=h,this.height=g,this._content=w}get type(){return typeof this._content=="number"?a1.Text:Array.isArray(this._content)?this._content:this._content.type}get to(){return this.from+this.length}get bottom(){return this.top+this.height}get widget(){return this._content instanceof xM?this._content.widget:null}get widgetLineBreaks(){return typeof this._content=="number"?this._content:0}join(s){let u=(Array.isArray(this._content)?this._content:[this]).concat(Array.isArray(s._content)?s._content:[s]);return new yy(this.from,this.length+s.length,this.top,this.height+s.height,u)}}var du=(function(l){return l[l.ByPos=0]="ByPos",l[l.ByHeight=1]="ByHeight",l[l.ByPosNoHeight=2]="ByPosNoHeight",l})(du||(du={}));const Efe=.001;class a0{constructor(s,u,h=2){this.length=s,this.height=u,this.flags=h}get outdated(){return(this.flags&2)>0}set outdated(s){this.flags=(s?2:0)|this.flags&-3}setHeight(s){this.height!=s&&(Math.abs(this.height-s)>Efe&&(PI=!0),this.height=s)}replace(s,u,h){return a0.of(h)}decomposeLeft(s,u){u.push(this)}decomposeRight(s,u){u.push(this)}applyChanges(s,u,h,g){let w=this,p=h.doc;for(let k=g.length-1;k>=0;k--){let{fromA:j,toA:A,fromB:_,toB:D}=g[k],I=w.lineAt(j,du.ByPosNoHeight,h.setDoc(u),0,0),B=I.to>=A?I:w.lineAt(A,du.ByPosNoHeight,h,0,0);for(D+=B.to-A,A=B.to;k>0&&I.from<=g[k-1].toA;)j=g[k-1].fromA,_=g[k-1].fromB,k--,j<I.from&&(I=w.lineAt(j,du.ByPosNoHeight,h,0,0));_+=I.from-j,j=I.from;let F=oAe.build(h.setDoc(p),s,_,D);w=rhe(w,w.replace(j,A,F))}return w.updateHeight(h,0)}static empty(){return new Yb(0,0,0)}static of(s){if(s.length==1)return s[0];let u=0,h=s.length,g=0,w=0;for(;;)if(u==h)if(g>w*2){let k=s[u-1];k.break?s.splice(--u,1,k.left,null,k.right):s.splice(--u,1,k.left,k.right),h+=1+k.break,g-=k.size}else if(w>g*2){let k=s[h];k.break?s.splice(h,1,k.left,null,k.right):s.splice(h,1,k.left,k.right),h+=2+k.break,w-=k.size}else break;else if(g<w){let k=s[u++];k&&(g+=k.size)}else{let k=s[--h];k&&(w+=k.size)}let p=0;return s[u-1]==null?(p=1,u--):s[u]==null&&(p=1,h++),new $1n(a0.of(s.slice(0,u)),p,a0.of(s.slice(h)))}}function rhe(l,s){return l==s?l:(l.constructor!=s.constructor&&(PI=!0),s)}a0.prototype.size=1;const R1n=Fr.replace({});class TOt extends a0{constructor(s,u,h){super(s,u),this.deco=h,this.spaceAbove=0}mainBlock(s,u){return new yy(u,this.length,s+this.spaceAbove,this.height-this.spaceAbove,this.deco||0)}blockAt(s,u,h,g){return this.spaceAbove&&s<h+this.spaceAbove?new yy(g,0,h,this.spaceAbove,R1n):this.mainBlock(h,g)}lineAt(s,u,h,g,w){let p=this.mainBlock(g,w);return this.spaceAbove?this.blockAt(0,h,g,w).join(p):p}forEachLine(s,u,h,g,w,p){s<=w+this.length&&u>=w&&p(this.lineAt(0,du.ByPos,h,g,w))}setMeasuredHeight(s){let u=s.heights[s.index++];u<0?(this.spaceAbove=-u,u=s.heights[s.index++]):this.spaceAbove=0,this.setHeight(u)}updateHeight(s,u=0,h=!1,g){return g&&g.from<=u&&g.more&&this.setMeasuredHeight(g),this.outdated=!1,this}toString(){return`block(${this.length})`}}class Yb extends TOt{constructor(s,u,h){super(s,u,null),this.collapsed=0,this.widgetHeight=0,this.breaks=0,this.spaceAbove=h}mainBlock(s,u){return new yy(u,this.length,s+this.spaceAbove,this.height-this.spaceAbove,this.breaks)}replace(s,u,h){let g=h[0];return h.length==1&&(g instanceof Yb||g instanceof c1&&g.flags&4)&&Math.abs(this.length-g.length)<10?(g instanceof c1?g=new Yb(g.length,this.height,this.spaceAbove):g.height=this.height,this.outdated||(g.outdated=!1),g):a0.of(h)}updateHeight(s,u=0,h=!1,g){return g&&g.from<=u&&g.more?this.setMeasuredHeight(g):(h||this.outdated)&&(this.spaceAbove=0,this.setHeight(Math.max(this.widgetHeight,s.heightForLine(this.length-this.collapsed))+this.breaks*s.lineHeight)),this.outdated=!1,this}toString(){return`line(${this.length}${this.collapsed?-this.collapsed:""}${this.widgetHeight?":"+this.widgetHeight:""})`}}class c1 extends a0{constructor(s){super(s,0)}heightMetrics(s,u){let h=s.doc.lineAt(u).number,g=s.doc.lineAt(u+this.length).number,w=g-h+1,p,k=0;if(s.lineWrapping){let j=Math.min(this.height,s.lineHeight*w);p=j/w,this.length>w+1&&(k=(this.height-j)/(this.length-w-1))}else p=this.height/w;return{firstLine:h,lastLine:g,perLine:p,perChar:k}}blockAt(s,u,h,g){let{firstLine:w,lastLine:p,perLine:k,perChar:j}=this.heightMetrics(u,g);if(u.lineWrapping){let A=g+(s<u.lineHeight?0:Math.round(Math.max(0,Math.min(1,(s-h)/this.height))*this.length)),_=u.doc.lineAt(A),D=k+_.length*j,I=Math.max(h,s-D/2);return new yy(_.from,_.length,I,D,0)}else{let A=Math.max(0,Math.min(p-w,Math.floor((s-h)/k))),{from:_,length:D}=u.doc.line(w+A);return new yy(_,D,h+k*A,k,0)}}lineAt(s,u,h,g,w){if(u==du.ByHeight)return this.blockAt(s,h,g,w);if(u==du.ByPosNoHeight){let{from:B,to:F}=h.doc.lineAt(s);return new yy(B,F-B,0,0,0)}let{firstLine:p,perLine:k,perChar:j}=this.heightMetrics(h,w),A=h.doc.lineAt(s),_=k+A.length*j,D=A.number-p,I=g+k*D+j*(A.from-w-D);return new yy(A.from,A.length,Math.max(g,Math.min(I,g+this.height-_)),_,0)}forEachLine(s,u,h,g,w,p){s=Math.max(s,w),u=Math.min(u,w+this.length);let{firstLine:k,perLine:j,perChar:A}=this.heightMetrics(h,w);for(let _=s,D=g;_<=u;){let I=h.doc.lineAt(_);if(_==s){let F=I.number-k;D+=j*F+A*(s-w-F)}let B=j+A*I.length;p(new yy(I.from,I.length,D,B,0)),D+=B,_=I.to+1}}replace(s,u,h){let g=this.length-u;if(g>0){let w=h[h.length-1];w instanceof c1?h[h.length-1]=new c1(w.length+g):h.push(null,new c1(g-1))}if(s>0){let w=h[0];w instanceof c1?h[0]=new c1(s+w.length):h.unshift(new c1(s-1),null)}return a0.of(h)}decomposeLeft(s,u){u.push(new c1(s-1),null)}decomposeRight(s,u){u.push(null,new c1(this.length-s-1))}updateHeight(s,u=0,h=!1,g){let w=u+this.length;if(g&&g.from<=u+this.length&&g.more){let p=[],k=Math.max(u,g.from),j=-1;for(g.from>u&&p.push(new c1(g.from-u-1).updateHeight(s,u));k<=w&&g.more;){let _=s.doc.lineAt(k).length;p.length&&p.push(null);let D=g.heights[g.index++],I=0;D<0&&(I=-D,D=g.heights[g.index++]),j==-1?j=D:Math.abs(D-j)>=Efe&&(j=-2);let B=new Yb(_,D,I);B.outdated=!1,p.push(B),k+=_+1}k<=w&&p.push(null,new c1(w-k).updateHeight(s,k));let A=a0.of(p);return(j<0||Math.abs(A.height-this.height)>=Efe||Math.abs(j-this.heightMetrics(s,u).perLine)>=Efe)&&(PI=!0),rhe(this,A)}else(h||this.outdated)&&(this.setHeight(s.heightForGap(u,u+this.length)),this.outdated=!1);return this}toString(){return`gap(${this.length})`}}class $1n extends a0{constructor(s,u,h){super(s.length+u+h.length,s.height+h.height,u|(s.outdated||h.outdated?2:0)),this.left=s,this.right=h,this.size=s.size+h.size}get break(){return this.flags&1}blockAt(s,u,h,g){let w=h+this.left.height;return s<w?this.left.blockAt(s,u,h,g):this.right.blockAt(s,u,w,g+this.left.length+this.break)}lineAt(s,u,h,g,w){let p=g+this.left.height,k=w+this.left.length+this.break,j=u==du.ByHeight?s<p:s<k,A=j?this.left.lineAt(s,u,h,g,w):this.right.lineAt(s,u,h,p,k);if(this.break||(j?A.to<k:A.from>k))return A;let _=u==du.ByPosNoHeight?du.ByPosNoHeight:du.ByPos;return j?A.join(this.right.lineAt(k,_,h,p,k)):this.left.lineAt(k,_,h,g,w).join(A)}forEachLine(s,u,h,g,w,p){let k=g+this.left.height,j=w+this.left.length+this.break;if(this.break)s<j&&this.left.forEachLine(s,u,h,g,w,p),u>=j&&this.right.forEachLine(s,u,h,k,j,p);else{let A=this.lineAt(j,du.ByPos,h,g,w);s<A.from&&this.left.forEachLine(s,A.from-1,h,g,w,p),A.to>=s&&A.from<=u&&p(A),u>A.to&&this.right.forEachLine(A.to+1,u,h,k,j,p)}}replace(s,u,h){let g=this.left.length+this.break;if(u<g)return this.balanced(this.left.replace(s,u,h),this.right);if(s>this.left.length)return this.balanced(this.left,this.right.replace(s-g,u-g,h));let w=[];s>0&&this.decomposeLeft(s,w);let p=w.length;for(let k of h)w.push(k);if(s>0&&Lxt(w,p-1),u<this.length){let k=w.length;this.decomposeRight(u,w),Lxt(w,k)}return a0.of(w)}decomposeLeft(s,u){let h=this.left.length;if(s<=h)return this.left.decomposeLeft(s,u);u.push(this.left),this.break&&(h++,s>=h&&u.push(null)),s>h&&this.right.decomposeLeft(s-h,u)}decomposeRight(s,u){let h=this.left.length,g=h+this.break;if(s>=g)return this.right.decomposeRight(s-g,u);s<h&&this.left.decomposeRight(s,u),this.break&&s<g&&u.push(null),u.push(this.right)}balanced(s,u){return s.size>2*u.size||u.size>2*s.size?a0.of(this.break?[s,null,u]:[s,u]):(this.left=rhe(this.left,s),this.right=rhe(this.right,u),this.setHeight(s.height+u.height),this.outdated=s.outdated||u.outdated,this.size=s.size+u.size,this.length=s.length+this.break+u.length,this)}updateHeight(s,u=0,h=!1,g){let{left:w,right:p}=this,k=u+w.length+this.break,j=null;return g&&g.from<=u+w.length&&g.more?j=w=w.updateHeight(s,u,h,g):w.updateHeight(s,u,h),g&&g.from<=k+p.length&&g.more?j=p=p.updateHeight(s,k,h,g):p.updateHeight(s,k,h),j?this.balanced(w,p):(this.height=this.left.height+this.right.height,this.outdated=!1,this)}toString(){return this.left+(this.break?" ":"-")+this.right}}function Lxt(l,s){let u,h;l[s]==null&&(u=l[s-1])instanceof c1&&(h=l[s+1])instanceof c1&&l.splice(s-1,3,new c1(u.length+1+h.length))}const B1n=5;class oAe{constructor(s,u){this.pos=s,this.oracle=u,this.nodes=[],this.lineStart=-1,this.lineEnd=-1,this.covering=null,this.writtenTo=s}get isCovered(){return this.covering&&this.nodes[this.nodes.length-1]==this.covering}span(s,u){if(this.lineStart>-1){let h=Math.min(u,this.lineEnd),g=this.nodes[this.nodes.length-1];g instanceof Yb?g.length+=h-this.pos:(h>this.pos||!this.isCovered)&&this.nodes.push(new Yb(h-this.pos,-1,0)),this.writtenTo=h,u>h&&(this.nodes.push(null),this.writtenTo++,this.lineStart=-1)}this.pos=u}point(s,u,h){if(s<u||h.heightRelevant){let g=h.widget?h.widget.estimatedHeight:0,w=h.widget?h.widget.lineBreaks:0;g<0&&(g=this.oracle.lineHeight);let p=u-s;h.block?this.addBlock(new TOt(p,g,h)):(p||w||g>=B1n)&&this.addLineDeco(g,w,p)}else u>s&&this.span(s,u);this.lineEnd>-1&&this.lineEnd<this.pos&&(this.lineEnd=this.oracle.doc.lineAt(this.pos).to)}enterLine(){if(this.lineStart>-1)return;let{from:s,to:u}=this.oracle.doc.lineAt(this.pos);this.lineStart=s,this.lineEnd=u,this.writtenTo<s&&((this.writtenTo<s-1||this.nodes[this.nodes.length-1]==null)&&this.nodes.push(this.blankContent(this.writtenTo,s-1)),this.nodes.push(null)),this.pos>s&&this.nodes.push(new Yb(this.pos-s,-1,0)),this.writtenTo=this.pos}blankContent(s,u){let h=new c1(u-s);return this.oracle.doc.lineAt(s).to==u&&(h.flags|=4),h}ensureLine(){this.enterLine();let s=this.nodes.length?this.nodes[this.nodes.length-1]:null;if(s instanceof Yb)return s;let u=new Yb(0,-1,0);return this.nodes.push(u),u}addBlock(s){this.enterLine();let u=s.deco;u&&u.startSide>0&&!this.isCovered&&this.ensureLine(),this.nodes.push(s),this.writtenTo=this.pos=this.pos+s.length,u&&u.endSide>0&&(this.covering=s)}addLineDeco(s,u,h){let g=this.ensureLine();g.length+=h,g.collapsed+=h,g.widgetHeight=Math.max(g.widgetHeight,s),g.breaks+=u,this.writtenTo=this.pos=this.pos+h}finish(s){let u=this.nodes.length==0?null:this.nodes[this.nodes.length-1];this.lineStart>-1&&!(u instanceof Yb)&&!this.isCovered?this.nodes.push(new Yb(0,-1,0)):(this.writtenTo<this.pos||u==null)&&this.nodes.push(this.blankContent(this.writtenTo,this.pos));let h=s;for(let g of this.nodes)g instanceof Yb&&g.updateHeight(this.oracle,h),h+=g?g.length:1;return this.nodes}static build(s,u,h,g){let w=new oAe(h,s);return xo.spans(u,h,g,w,0),w.finish(h)}}function z1n(l,s,u){let h=new F1n;return xo.compare(l,s,u,h,0),h.changes}class F1n{constructor(){this.changes=[]}compareRange(){}comparePoint(s,u,h,g){(s<u||h&&h.heightRelevant||g&&g.heightRelevant)&&mI(s,u,this.changes,5)}}function q1n(l,s){let u=l.getBoundingClientRect(),h=l.ownerDocument,g=h.defaultView||window,w=Math.max(0,u.left),p=Math.min(g.innerWidth,u.right),k=Math.max(0,u.top),j=Math.min(g.innerHeight,u.bottom);for(let A=l.parentNode;A&&A!=h.body;)if(A.nodeType==1){let _=A,D=window.getComputedStyle(_);if((_.scrollHeight>_.clientHeight||_.scrollWidth>_.clientWidth)&&D.overflow!="visible"){let I=_.getBoundingClientRect();w=Math.max(w,I.left),p=Math.min(p,I.right),k=Math.max(k,I.top),j=Math.min(A==l.parentNode?g.innerHeight:j,I.bottom)}A=D.position=="absolute"||D.position=="fixed"?_.offsetParent:_.parentNode}else if(A.nodeType==11)A=A.host;else break;return{left:w-u.left,right:Math.max(w,p)-u.left,top:k-(u.top+s),bottom:Math.max(k,j)-(u.top+s)}}function H1n(l){let s=l.getBoundingClientRect(),u=l.ownerDocument.defaultView||window;return s.left<u.innerWidth&&s.right>0&&s.top<u.innerHeight&&s.bottom>0}function Q1n(l,s){let u=l.getBoundingClientRect();return{left:0,right:u.right-u.left,top:s,bottom:u.bottom-(u.top+s)}}class IEe{constructor(s,u,h,g){this.from=s,this.to=u,this.size=h,this.displaySize=g}static same(s,u){if(s.length!=u.length)return!1;for(let h=0;h<s.length;h++){let g=s[h],w=u[h];if(g.from!=w.from||g.to!=w.to||g.size!=w.size)return!1}return!0}draw(s,u){return Fr.replace({widget:new G1n(this.displaySize*(u?s.scaleY:s.scaleX),u)}).range(this.from,this.to)}}class G1n extends lO{constructor(s,u){super(),this.size=s,this.vertical=u}eq(s){return s.size==this.size&&s.vertical==this.vertical}toDOM(){let s=document.createElement("div");return this.vertical?s.style.height=this.size+"px":(s.style.width=this.size+"px",s.style.height="2px",s.style.display="inline-block"),s}get estimatedHeight(){return this.vertical?this.size:-1}}class Pxt{constructor(s,u){this.view=s,this.state=u,this.pixelViewport={left:0,right:window.innerWidth,top:0,bottom:0},this.inView=!0,this.paddingTop=0,this.paddingBottom=0,this.contentDOMWidth=0,this.contentDOMHeight=0,this.editorHeight=0,this.editorWidth=0,this.scaleX=1,this.scaleY=1,this.scrollOffset=0,this.scrolledToBottom=!1,this.scrollAnchorPos=0,this.scrollAnchorHeight=-1,this.scaler=Ixt,this.scrollTarget=null,this.printing=!1,this.mustMeasureContent=!0,this.defaultTextDirection=Yl.LTR,this.visibleRanges=[],this.mustEnforceCursorAssoc=!1;let h=u.facet(nAe).some(g=>typeof g!="function"&&g.class=="cm-lineWrapping");this.heightOracle=new P1n(h),this.stateDeco=Rxt(u),this.heightMap=a0.empty().applyChanges(this.stateDeco,uc.empty,this.heightOracle.setDoc(u.doc),[new Uw(0,0,0,u.doc.length)]);for(let g=0;g<2&&(this.viewport=this.getViewport(0,null),!!this.updateForViewport());g++);this.updateViewportLines(),this.lineGaps=this.ensureLineGaps([]),this.lineGapDeco=Fr.set(this.lineGaps.map(g=>g.draw(this,!1))),this.scrollParent=s.scrollDOM,this.computeVisibleRanges()}updateForViewport(){let s=[this.viewport],{main:u}=this.state.selection;for(let h=0;h<=1;h++){let g=h?u.head:u.anchor;if(!s.some(({from:w,to:p})=>g>=w&&g<=p)){let{from:w,to:p}=this.lineBlockAt(g);s.push(new Kae(w,p))}}return this.viewports=s.sort((h,g)=>h.from-g.from),this.updateScaler()}updateScaler(){let s=this.scaler;return this.scaler=this.heightMap.height<=7e6?Ixt:new cAe(this.heightOracle,this.heightMap,this.viewports),s.eq(this.scaler)?0:2}updateViewportLines(){this.viewportLines=[],this.heightMap.forEachLine(this.viewport.from,this.viewport.to,this.heightOracle.setDoc(this.state.doc),0,0,s=>{this.viewportLines.push(_X(s,this.scaler))})}update(s,u=null){this.state=s.state;let h=this.stateDeco;this.stateDeco=Rxt(this.state);let g=s.changedRanges,w=Uw.extendWithRanges(g,z1n(h,this.stateDeco,s?s.changes:Jh.empty(this.state.doc.length))),p=this.heightMap.height,k=this.scrolledToBottom?null:this.scrollAnchorAt(this.scrollOffset);Dxt(),this.heightMap=this.heightMap.applyChanges(this.stateDeco,s.startState.doc,this.heightOracle.setDoc(this.state.doc),w),(this.heightMap.height!=p||PI)&&(s.flags|=2),k?(this.scrollAnchorPos=s.changes.mapPos(k.from,-1),this.scrollAnchorHeight=k.top):(this.scrollAnchorPos=-1,this.scrollAnchorHeight=p);let j=w.length?this.mapViewport(this.viewport,s.changes):this.viewport;(u&&(u.range.head<j.from||u.range.head>j.to)||!this.viewportIsAppropriate(j))&&(j=this.getViewport(0,u));let A=j.from!=this.viewport.from||j.to!=this.viewport.to;this.viewport=j,s.flags|=this.updateForViewport(),(A||!s.changes.empty||s.flags&2)&&this.updateViewportLines(),(this.lineGaps.length||this.viewport.to-this.viewport.from>4e3)&&this.updateLineGaps(this.ensureLineGaps(this.mapLineGaps(this.lineGaps,s.changes))),s.flags|=this.computeVisibleRanges(s.changes),u&&(this.scrollTarget=u),!this.mustEnforceCursorAssoc&&(s.selectionSet||s.focusChanged)&&s.view.lineWrapping&&s.state.selection.main.empty&&s.state.selection.main.assoc&&!s.state.facet(sOt)&&(this.mustEnforceCursorAssoc=!0)}measure(){let{view:s}=this,u=s.contentDOM,h=window.getComputedStyle(u),g=this.heightOracle,w=h.whiteSpace;this.defaultTextDirection=h.direction=="rtl"?Yl.RTL:Yl.LTR;let p=this.heightOracle.mustRefreshForWrapping(w)||this.mustMeasureContent==="refresh",k=u.getBoundingClientRect(),j=p||this.mustMeasureContent||this.contentDOMHeight!=k.height;this.contentDOMHeight=k.height,this.mustMeasureContent=!1;let A=0,_=0;if(k.width&&k.height){let{scaleX:fe,scaleY:be}=Fkt(u,k);(fe>.005&&Math.abs(this.scaleX-fe)>.005||be>.005&&Math.abs(this.scaleY-be)>.005)&&(this.scaleX=fe,this.scaleY=be,A|=16,p=j=!0)}let D=(parseInt(h.paddingTop)||0)*this.scaleY,I=(parseInt(h.paddingBottom)||0)*this.scaleY;(this.paddingTop!=D||this.paddingBottom!=I)&&(this.paddingTop=D,this.paddingBottom=I,A|=18),this.editorWidth!=s.scrollDOM.clientWidth&&(g.lineWrapping&&(j=!0),this.editorWidth=s.scrollDOM.clientWidth,A|=16);let B=qkt(this.view.contentDOM,!1).y;B!=this.scrollParent&&(this.scrollParent=B,this.scrollAnchorHeight=-1,this.scrollOffset=0);let F=this.getScrollOffset();this.scrollOffset!=F&&(this.scrollAnchorHeight=-1,this.scrollOffset=F),this.scrolledToBottom=Qkt(this.scrollParent||s.win);let U=(this.printing?Q1n:q1n)(u,this.paddingTop),K=U.top-this.pixelViewport.top,Y=U.bottom-this.pixelViewport.bottom;this.pixelViewport=U;let Z=this.pixelViewport.bottom>this.pixelViewport.top&&this.pixelViewport.right>this.pixelViewport.left;if(Z!=this.inView&&(this.inView=Z,Z&&(j=!0)),!this.inView&&!this.scrollTarget&&!H1n(s.dom))return 0;let ee=k.width;if((this.contentDOMWidth!=ee||this.editorHeight!=s.scrollDOM.clientHeight)&&(this.contentDOMWidth=k.width,this.editorHeight=s.scrollDOM.clientHeight,A|=16),j){let fe=s.docView.measureVisibleLineHeights(this.viewport);if(g.mustRefreshForHeights(fe)&&(p=!0),p||g.lineWrapping&&Math.abs(ee-this.contentDOMWidth)>g.charWidth){let{lineHeight:be,charWidth:me,textHeight:Re}=s.docView.measureTextSize();p=be>0&&g.refresh(w,be,me,Re,Math.max(5,ee/me),fe),p&&(s.docView.minWidth=0,A|=16)}K>0&&Y>0?_=Math.max(K,Y):K<0&&Y<0&&(_=Math.min(K,Y)),Dxt();for(let be of this.viewports){let me=be.from==this.viewport.from?fe:s.docView.measureVisibleLineHeights(be);this.heightMap=(p?a0.empty().applyChanges(this.stateDeco,uc.empty,this.heightOracle,[new Uw(0,0,0,s.state.doc.length)]):this.heightMap).updateHeight(g,0,p,new I1n(be.from,me))}PI&&(A|=2)}let ce=!this.viewportIsAppropriate(this.viewport,_)||this.scrollTarget&&(this.scrollTarget.range.head<this.viewport.from||this.scrollTarget.range.head>this.viewport.to);return ce&&(A&2&&(A|=this.updateScaler()),this.viewport=this.getViewport(_,this.scrollTarget),A|=this.updateForViewport()),(A&2||ce)&&this.updateViewportLines(),(this.lineGaps.length||this.viewport.to-this.viewport.from>4e3)&&this.updateLineGaps(this.ensureLineGaps(p?[]:this.lineGaps,s)),A|=this.computeVisibleRanges(),this.mustEnforceCursorAssoc&&(this.mustEnforceCursorAssoc=!1,s.docView.enforceCursorAssoc()),A}get visibleTop(){return this.scaler.fromDOM(this.pixelViewport.top)}get visibleBottom(){return this.scaler.fromDOM(this.pixelViewport.bottom)}getViewport(s,u){let h=.5-Math.max(-.5,Math.min(.5,s/1e3/2)),g=this.heightMap,w=this.heightOracle,{visibleTop:p,visibleBottom:k}=this,j=new Kae(g.lineAt(p-h*1e3,du.ByHeight,w,0,0).from,g.lineAt(k+(1-h)*1e3,du.ByHeight,w,0,0).to);if(u){let{head:A}=u.range;if(A<j.from||A>j.to){let _=Math.min(this.editorHeight,this.pixelViewport.bottom-this.pixelViewport.top),D=g.lineAt(A,du.ByPos,w,0,0),I;u.y=="center"?I=(D.top+D.bottom)/2-_/2:u.y=="start"||u.y=="nearest"&&A<j.from?I=D.top:I=D.bottom-_,j=new Kae(g.lineAt(I-1e3/2,du.ByHeight,w,0,0).from,g.lineAt(I+_+1e3/2,du.ByHeight,w,0,0).to)}}return j}mapViewport(s,u){let h=u.mapPos(s.from,-1),g=u.mapPos(s.to,1);return new Kae(this.heightMap.lineAt(h,du.ByPos,this.heightOracle,0,0).from,this.heightMap.lineAt(g,du.ByPos,this.heightOracle,0,0).to)}viewportIsAppropriate({from:s,to:u},h=0){if(!this.inView)return!0;let{top:g}=this.heightMap.lineAt(s,du.ByPos,this.heightOracle,0,0),{bottom:w}=this.heightMap.lineAt(u,du.ByPos,this.heightOracle,0,0),{visibleTop:p,visibleBottom:k}=this;return(s==0||g<=p-Math.max(10,Math.min(-h,250)))&&(u==this.state.doc.length||w>=k+Math.max(10,Math.min(h,250)))&&g>p-2*1e3&&w<k+2*1e3}mapLineGaps(s,u){if(!s.length||u.empty)return s;let h=[];for(let g of s)u.touchesRange(g.from,g.to)||h.push(new IEe(u.mapPos(g.from),u.mapPos(g.to),g.size,g.displaySize));return h}ensureLineGaps(s,u){let h=this.heightOracle.lineWrapping,g=h?1e4:2e3,w=g>>1,p=g<<1;if(this.defaultTextDirection!=Yl.LTR&&!h)return[];let k=[],j=(_,D,I,B)=>{if(D-_<w)return;let F=this.state.selection.main,U=[F.from];F.empty||U.push(F.to);for(let Y of U)if(Y>_&&Y<D){j(_,Y-10,I,B),j(Y+10,D,I,B);return}let K=J1n(s,Y=>Y.from>=I.from&&Y.to<=I.to&&Math.abs(Y.from-_)<w&&Math.abs(Y.to-D)<w&&!U.some(Z=>Y.from<Z&&Y.to>Z));if(!K){if(D<I.to&&u&&h&&u.visibleRanges.some(ee=>ee.from<=D&&ee.to>=D)){let ee=u.moveToLineBoundary(kn.cursor(D),!1,!0).head;ee>_&&(D=ee)}let Y=this.gapSize(I,_,D,B),Z=h||Y<2e6?Y:2e6;K=new IEe(_,D,Y,Z)}k.push(K)},A=_=>{if(_.length<p||_.type!=a1.Text)return;let D=U1n(_.from,_.to,this.stateDeco);if(D.total<p)return;let I=this.scrollTarget?this.scrollTarget.range.head:null,B,F;if(h){let U=g/this.heightOracle.lineLength*this.heightOracle.lineHeight,K,Y;if(I!=null){let Z=Zae(D,I),ee=((this.visibleBottom-this.visibleTop)/2+U)/_.height;K=Z-ee,Y=Z+ee}else K=(this.visibleTop-_.top-U)/_.height,Y=(this.visibleBottom-_.top+U)/_.height;B=Yae(D,K),F=Yae(D,Y)}else{let U=D.total*this.heightOracle.charWidth,K=g*this.heightOracle.charWidth,Y=0;if(U>2e6)for(let be of s)be.from>=_.from&&be.from<_.to&&be.size!=be.displaySize&&be.from*this.heightOracle.charWidth+Y<this.pixelViewport.left&&(Y=be.size-be.displaySize);let Z=this.pixelViewport.left+Y,ee=this.pixelViewport.right+Y,ce,fe;if(I!=null){let be=Zae(D,I),me=((ee-Z)/2+K)/U;ce=be-me,fe=be+me}else ce=(Z-K)/U,fe=(ee+K)/U;B=Yae(D,ce),F=Yae(D,fe)}B>_.from&&j(_.from,B,_,D),F<_.to&&j(F,_.to,_,D)};for(let _ of this.viewportLines)Array.isArray(_.type)?_.type.forEach(A):A(_);return k}gapSize(s,u,h,g){let w=Zae(g,h)-Zae(g,u);return this.heightOracle.lineWrapping?s.height*w:g.total*this.heightOracle.charWidth*w}updateLineGaps(s){IEe.same(s,this.lineGaps)||(this.lineGaps=s,this.lineGapDeco=Fr.set(s.map(u=>u.draw(this,this.heightOracle.lineWrapping))))}computeVisibleRanges(s){let u=this.stateDeco;this.lineGaps.length&&(u=u.concat(this.lineGapDeco));let h=[];xo.spans(u,this.viewport.from,this.viewport.to,{span(w,p){h.push({from:w,to:p})},point(){}},20);let g=0;if(h.length!=this.visibleRanges.length)g=12;else for(let w=0;w<h.length&&!(g&8);w++){let p=this.visibleRanges[w],k=h[w];(p.from!=k.from||p.to!=k.to)&&(g|=4,s&&s.mapPos(p.from,-1)==k.from&&s.mapPos(p.to,1)==k.to||(g|=8))}return this.visibleRanges=h,g}lineBlockAt(s){return s>=this.viewport.from&&s<=this.viewport.to&&this.viewportLines.find(u=>u.from<=s&&u.to>=s)||_X(this.heightMap.lineAt(s,du.ByPos,this.heightOracle,0,0),this.scaler)}lineBlockAtHeight(s){return s>=this.viewportLines[0].top&&s<=this.viewportLines[this.viewportLines.length-1].bottom&&this.viewportLines.find(u=>u.top<=s&&u.bottom>=s)||_X(this.heightMap.lineAt(this.scaler.fromDOM(s),du.ByHeight,this.heightOracle,0,0),this.scaler)}getScrollOffset(){return(this.scrollParent==this.view.scrollDOM?this.scrollParent.scrollTop:(this.scrollParent?this.scrollParent.getBoundingClientRect().top:0)-this.view.contentDOM.getBoundingClientRect().top)*this.scaleY}scrollAnchorAt(s){let u=this.lineBlockAtHeight(s+8);return u.from>=this.viewport.from||this.viewportLines[0].top-s>200?u:this.viewportLines[0]}elementAtHeight(s){return _X(this.heightMap.blockAt(this.scaler.fromDOM(s),this.heightOracle,0,0),this.scaler)}get docHeight(){return this.scaler.toDOM(this.heightMap.height)}get contentHeight(){return this.docHeight+this.paddingTop+this.paddingBottom}}class Kae{constructor(s,u){this.from=s,this.to=u}}function U1n(l,s,u){let h=[],g=l,w=0;return xo.spans(u,l,s,{span(){},point(p,k){p>g&&(h.push({from:g,to:p}),w+=p-g),g=k}},20),g<s&&(h.push({from:g,to:s}),w+=s-g),{total:w,ranges:h}}function Yae({total:l,ranges:s},u){if(u<=0)return s[0].from;if(u>=1)return s[s.length-1].to;let h=Math.floor(l*u);for(let g=0;;g++){let{from:w,to:p}=s[g],k=p-w;if(h<=k)return w+h;h-=k}}function Zae(l,s){let u=0;for(let{from:h,to:g}of l.ranges){if(s<=g){u+=s-h;break}u+=g-h}return u/l.total}function J1n(l,s){for(let u of l)if(s(u))return u}const Ixt={toDOM(l){return l},fromDOM(l){return l},scale:1,eq(l){return l==this}};function Rxt(l){let s=l.facet(Fhe).filter(h=>typeof h!="function"),u=l.facet(iAe).filter(h=>typeof h!="function");return u.length&&s.push(xo.join(u)),s}class cAe{constructor(s,u,h){let g=0,w=0,p=0;this.viewports=h.map(({from:k,to:j})=>{let A=u.lineAt(k,du.ByPos,s,0,0).top,_=u.lineAt(j,du.ByPos,s,0,0).bottom;return g+=_-A,{from:k,to:j,top:A,bottom:_,domTop:0,domBottom:0}}),this.scale=(7e6-g)/(u.height-g);for(let k of this.viewports)k.domTop=p+(k.top-w)*this.scale,p=k.domBottom=k.domTop+(k.bottom-k.top),w=k.bottom}toDOM(s){for(let u=0,h=0,g=0;;u++){let w=u<this.viewports.length?this.viewports[u]:null;if(!w||s<w.top)return g+(s-h)*this.scale;if(s<=w.bottom)return w.domTop+(s-w.top);h=w.bottom,g=w.domBottom}}fromDOM(s){for(let u=0,h=0,g=0;;u++){let w=u<this.viewports.length?this.viewports[u]:null;if(!w||s<w.domTop)return h+(s-g)/this.scale;if(s<=w.domBottom)return w.top+(s-w.domTop);h=w.bottom,g=w.domBottom}}eq(s){return s instanceof cAe?this.scale==s.scale&&this.viewports.length==s.viewports.length&&this.viewports.every((u,h)=>u.from==s.viewports[h].from&&u.to==s.viewports[h].to):!1}}function _X(l,s){if(s.scale==1)return l;let u=s.toDOM(l.top),h=s.toDOM(l.bottom);return new yy(l.from,l.length,u,h-u,Array.isArray(l._content)?l._content.map(g=>_X(g,s)):l._content)}const efe=Qi.define({combine:l=>l.join(" ")}),nMe=Qi.define({combine:l=>l.indexOf(!0)>-1}),iMe=k8.newName(),EOt=k8.newName(),COt=k8.newName(),MOt={"&light":"."+EOt,"&dark":"."+COt};function rMe(l,s,u){return new k8(s,{finish(h){return/&/.test(h)?h.replace(/&\w*/,g=>{if(g=="&")return l;if(!u||!u[g])throw new RangeError(`Unsupported selector: ${g}`);return u[g]}):l+" "+h}})}const X1n=rMe("."+iMe,{"&":{position:"relative !important",boxSizing:"border-box","&.cm-focused":{outline:"1px dotted #212121"},display:"flex !important",flexDirection:"column"},".cm-scroller":{display:"flex !important",alignItems:"flex-start !important",fontFamily:"monospace",lineHeight:1.4,height:"100%",overflowX:"auto",position:"relative",zIndex:0,overflowAnchor:"none"},".cm-content":{margin:0,flexGrow:2,flexShrink:0,display:"block",whiteSpace:"pre",wordWrap:"normal",boxSizing:"border-box",minHeight:"100%",padding:"4px 0",outline:"none","&[contenteditable=true]":{WebkitUserModify:"read-write-plaintext-only"}},".cm-lineWrapping":{whiteSpace_fallback:"pre-wrap",whiteSpace:"break-spaces",wordBreak:"break-word",overflowWrap:"anywhere",flexShrink:1},"&light .cm-content":{caretColor:"black"},"&dark .cm-content":{caretColor:"white"},".cm-line":{display:"block",padding:"0 2px 0 6px"},".cm-layer":{position:"absolute",left:0,top:0,contain:"size style","& > *":{position:"absolute"}},"&light .cm-selectionBackground":{background:"#d9d9d9"},"&dark .cm-selectionBackground":{background:"#222"},"&light.cm-focused > .cm-scroller > .cm-selectionLayer .cm-selectionBackground":{background:"#d7d4f0"},"&dark.cm-focused > .cm-scroller > .cm-selectionLayer .cm-selectionBackground":{background:"#233"},".cm-cursorLayer":{pointerEvents:"none"},"&.cm-focused > .cm-scroller > .cm-cursorLayer":{animation:"steps(1) cm-blink 1.2s infinite"},"@keyframes cm-blink":{"0%":{},"50%":{opacity:0},"100%":{}},"@keyframes cm-blink2":{"0%":{},"50%":{opacity:0},"100%":{}},".cm-cursor, .cm-dropCursor":{borderLeft:"1.2px solid black",marginLeft:"-0.6px",pointerEvents:"none"},".cm-cursor":{display:"none"},"&dark .cm-cursor":{borderLeftColor:"#ddd"},".cm-dropCursor":{position:"absolute"},"&.cm-focused > .cm-scroller > .cm-cursorLayer .cm-cursor":{display:"block"},".cm-iso":{unicodeBidi:"isolate"},".cm-announced":{position:"fixed",top:"-10000px"},"@media print":{".cm-announced":{display:"none"}},"&light .cm-activeLine":{backgroundColor:"#cceeff44"},"&dark .cm-activeLine":{backgroundColor:"#99eeff33"},"&light .cm-specialChar":{color:"red"},"&dark .cm-specialChar":{color:"#f78"},".cm-gutters":{flexShrink:0,display:"flex",height:"100%",boxSizing:"border-box",zIndex:200},".cm-gutters-before":{insetInlineStart:0},".cm-gutters-after":{insetInlineEnd:0},"&light .cm-gutters":{backgroundColor:"#f5f5f5",color:"#6c6c6c",border:"0px solid #ddd","&.cm-gutters-before":{borderRightWidth:"1px"},"&.cm-gutters-after":{borderLeftWidth:"1px"}},"&dark .cm-gutters":{backgroundColor:"#333338",color:"#ccc"},".cm-gutter":{display:"flex !important",flexDirection:"column",flexShrink:0,boxSizing:"border-box",minHeight:"100%",overflow:"hidden"},".cm-gutterElement":{boxSizing:"border-box"},".cm-lineNumbers .cm-gutterElement":{padding:"0 3px 0 5px",minWidth:"20px",textAlign:"right",whiteSpace:"nowrap"},"&light .cm-activeLineGutter":{backgroundColor:"#e2f2ff"},"&dark .cm-activeLineGutter":{backgroundColor:"#222227"},".cm-panels":{boxSizing:"border-box",position:"sticky",left:0,right:0,zIndex:300},"&light .cm-panels":{backgroundColor:"#f5f5f5",color:"black"},"&light .cm-panels-top":{borderBottom:"1px solid #ddd"},"&light .cm-panels-bottom":{borderTop:"1px solid #ddd"},"&dark .cm-panels":{backgroundColor:"#333338",color:"white"},".cm-dialog":{padding:"2px 19px 4px 6px",position:"relative","& label":{fontSize:"80%"}},".cm-dialog-close":{position:"absolute",top:"3px",right:"4px",backgroundColor:"inherit",border:"none",font:"inherit",fontSize:"14px",padding:"0"},".cm-tab":{display:"inline-block",overflow:"hidden",verticalAlign:"bottom"},".cm-widgetBuffer":{verticalAlign:"text-top",height:"1em",width:0,display:"inline"},".cm-placeholder":{color:"#888",display:"inline-block",verticalAlign:"top",userSelect:"none"},".cm-highlightSpace":{backgroundImage:"radial-gradient(circle at 50% 55%, #aaa 20%, transparent 5%)",backgroundPosition:"center"},".cm-highlightTab":{backgroundImage:`url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="200" height="20"><path stroke="%23888" stroke-width="1" fill="none" d="M1 10H196L190 5M190 15L196 10M197 4L197 16"/></svg>')`,backgroundSize:"auto 100%",backgroundPosition:"right 90%",backgroundRepeat:"no-repeat"},".cm-trailingSpace":{backgroundColor:"#ff332255"},".cm-button":{verticalAlign:"middle",color:"inherit",fontSize:"70%",padding:".2em 1em",borderRadius:"1px"},"&light .cm-button":{backgroundImage:"linear-gradient(#eff1f5, #d9d9df)",border:"1px solid #888","&:active":{backgroundImage:"linear-gradient(#b4b4b4, #d0d3d6)"}},"&dark .cm-button":{backgroundImage:"linear-gradient(#393939, #111)",border:"1px solid #888","&:active":{backgroundImage:"linear-gradient(#111, #333)"}},".cm-textfield":{verticalAlign:"middle",color:"inherit",fontSize:"70%",border:"1px solid silver",padding:".2em .5em"},"&light .cm-textfield":{backgroundColor:"white"},"&dark .cm-textfield":{border:"1px solid #555",backgroundColor:"inherit"}},MOt),V1n={childList:!0,characterData:!0,subtree:!0,attributes:!0,characterDataOldValue:!0},REe=Ji.ie&&Ji.ie_version<=11;class W1n{constructor(s){this.view=s,this.active=!1,this.editContext=null,this.selectionRange=new Tdn,this.selectionChanged=!1,this.delayedFlush=-1,this.resizeTimeout=-1,this.queue=[],this.delayedAndroidKey=null,this.flushingAndroidKey=-1,this.lastChange=0,this.scrollTargets=[],this.intersection=null,this.resizeScroll=null,this.intersecting=!1,this.gapIntersection=null,this.gaps=[],this.printQuery=null,this.parentCheck=-1,this.dom=s.contentDOM,this.observer=new MutationObserver(u=>{for(let h of u)this.queue.push(h);(Ji.ie&&Ji.ie_version<=11||Ji.ios&&s.composing)&&u.some(h=>h.type=="childList"&&h.removedNodes.length||h.type=="characterData"&&h.oldValue.length>h.target.nodeValue.length)?this.flushSoon():this.flush()}),window.EditContext&&Ji.android&&s.constructor.EDIT_CONTEXT!==!1&&!(Ji.chrome&&Ji.chrome_version<126)&&(this.editContext=new Y1n(s),s.state.facet(Zk)&&(s.contentDOM.editContext=this.editContext.editContext)),REe&&(this.onCharData=u=>{this.queue.push({target:u.target,type:"characterData",oldValue:u.prevValue}),this.flushSoon()}),this.onSelectionChange=this.onSelectionChange.bind(this),this.onResize=this.onResize.bind(this),this.onPrint=this.onPrint.bind(this),this.onScroll=this.onScroll.bind(this),window.matchMedia&&(this.printQuery=window.matchMedia("print")),typeof ResizeObserver=="function"&&(this.resizeScroll=new ResizeObserver(()=>{var u;((u=this.view.docView)===null||u===void 0?void 0:u.lastUpdate)<Date.now()-75&&this.onResize()}),this.resizeScroll.observe(s.scrollDOM)),this.addWindowListeners(this.win=s.win),this.start(),typeof IntersectionObserver=="function"&&(this.intersection=new IntersectionObserver(u=>{this.parentCheck<0&&(this.parentCheck=setTimeout(this.listenForScroll.bind(this),1e3)),u.length>0&&u[u.length-1].intersectionRatio>0!=this.intersecting&&(this.intersecting=!this.intersecting,this.intersecting!=this.view.inView&&this.onScrollChanged(document.createEvent("Event")))},{threshold:[0,.001]}),this.intersection.observe(this.dom),this.gapIntersection=new IntersectionObserver(u=>{u.length>0&&u[u.length-1].intersectionRatio>0&&this.onScrollChanged(document.createEvent("Event"))},{})),this.listenForScroll(),this.readSelectionRange()}onScrollChanged(s){this.view.inputState.runHandlers("scroll",s),this.intersecting&&this.view.measure()}onScroll(s){this.intersecting&&this.flush(!1),this.editContext&&this.view.requestMeasure(this.editContext.measureReq),this.onScrollChanged(s)}onResize(){this.resizeTimeout<0&&(this.resizeTimeout=setTimeout(()=>{this.resizeTimeout=-1,this.view.requestMeasure()},50))}onPrint(s){(s.type=="change"||!s.type)&&!s.matches||(this.view.viewState.printing=!0,this.view.measure(),setTimeout(()=>{this.view.viewState.printing=!1,this.view.requestMeasure()},500))}updateGaps(s){if(this.gapIntersection&&(s.length!=this.gaps.length||this.gaps.some((u,h)=>u!=s[h]))){this.gapIntersection.disconnect();for(let u of s)this.gapIntersection.observe(u);this.gaps=s}}onSelectionChange(s){let u=this.selectionChanged;if(!this.readSelectionRange()||this.delayedAndroidKey)return;let{view:h}=this,g=this.selectionRange;if(h.state.facet(Zk)?h.root.activeElement!=this.dom:!$X(this.dom,g))return;let w=g.anchorNode&&h.docView.tile.nearest(g.anchorNode);if(w&&w.isWidget()&&w.widget.ignoreEvent(s)){u||(this.selectionChanged=!1);return}(Ji.ie&&Ji.ie_version<=11||Ji.android&&Ji.chrome)&&!h.state.selection.main.empty&&g.focusNode&&zX(g.focusNode,g.focusOffset,g.anchorNode,g.anchorOffset)?this.flushSoon():this.flush(!1)}readSelectionRange(){let{view:s}=this,u=rV(s.root);if(!u)return!1;let h=Ji.safari&&s.root.nodeType==11&&s.root.activeElement==this.dom&&K1n(this.view,u)||u;if(!h||this.selectionRange.eq(h))return!1;let g=$X(this.dom,h);return g&&!this.selectionChanged&&s.inputState.lastFocusTime>Date.now()-200&&s.inputState.lastTouchTime<Date.now()-300&&Cdn(this.dom,h)?(this.view.inputState.lastFocusTime=0,s.docView.updateSelection(),!1):(this.selectionRange.setRange(h),g&&(this.selectionChanged=!0),!0)}setSelectionRange(s,u){this.selectionRange.set(s.node,s.offset,u.node,u.offset),this.selectionChanged=!1}clearSelectionRange(){this.selectionRange.set(null,0,null,0)}listenForScroll(){this.parentCheck=-1;let s=0,u=null;for(let h=this.dom;h;)if(h.nodeType==1)!u&&s<this.scrollTargets.length&&this.scrollTargets[s]==h?s++:u||(u=this.scrollTargets.slice(0,s)),u&&u.push(h),h=h.assignedSlot||h.parentNode;else if(h.nodeType==11)h=h.host;else break;if(s<this.scrollTargets.length&&!u&&(u=this.scrollTargets.slice(0,s)),u){for(let h of this.scrollTargets)h.removeEventListener("scroll",this.onScroll);for(let h of this.scrollTargets=u)h.addEventListener("scroll",this.onScroll)}}ignore(s){if(!this.active)return s();try{return this.stop(),s()}finally{this.start(),this.clear()}}start(){this.active||(this.observer.observe(this.dom,V1n),REe&&this.dom.addEventListener("DOMCharacterDataModified",this.onCharData),this.active=!0)}stop(){this.active&&(this.active=!1,this.observer.disconnect(),REe&&this.dom.removeEventListener("DOMCharacterDataModified",this.onCharData))}clear(){this.processRecords(),this.queue.length=0,this.selectionChanged=!1}delayAndroidKey(s,u){var h;if(!this.delayedAndroidKey){let g=()=>{let w=this.delayedAndroidKey;w&&(this.clearDelayedAndroidKey(),this.view.inputState.lastKeyCode=w.keyCode,this.view.inputState.lastKeyTime=Date.now(),!this.flush()&&w.force&&wI(this.dom,w.key,w.keyCode))};this.flushingAndroidKey=this.view.win.requestAnimationFrame(g)}(!this.delayedAndroidKey||s=="Enter")&&(this.delayedAndroidKey={key:s,keyCode:u,force:this.lastChange<Date.now()-50||!!(!((h=this.delayedAndroidKey)===null||h===void 0)&&h.force)})}clearDelayedAndroidKey(){this.win.cancelAnimationFrame(this.flushingAndroidKey),this.delayedAndroidKey=null,this.flushingAndroidKey=-1}flushSoon(){this.delayedFlush<0&&(this.delayedFlush=this.view.win.requestAnimationFrame(()=>{this.delayedFlush=-1,this.flush()}))}forceFlush(){this.delayedFlush>=0&&(this.view.win.cancelAnimationFrame(this.delayedFlush),this.delayedFlush=-1),this.flush()}pendingRecords(){for(let s of this.observer.takeRecords())this.queue.push(s);return this.queue}processRecords(){let s=this.pendingRecords();s.length&&(this.queue=[]);let u=-1,h=-1,g=!1;for(let w of s){let p=this.readMutation(w);p&&(p.typeOver&&(g=!0),u==-1?{from:u,to:h}=p:(u=Math.min(p.from,u),h=Math.max(p.to,h)))}return{from:u,to:h,typeOver:g}}readChange(){let{from:s,to:u,typeOver:h}=this.processRecords(),g=this.selectionChanged&&$X(this.dom,this.selectionRange);if(s<0&&!g)return null;s>-1&&(this.lastChange=Date.now()),this.view.inputState.lastFocusTime=0,this.selectionChanged=!1;let w=new p1n(this.view,s,u,h);return this.view.docView.domChanged={newSel:w.newSel?w.newSel.main:null},w}flush(s=!0){if(this.delayedFlush>=0||this.delayedAndroidKey)return!1;s&&this.readSelectionRange();let u=this.readChange();if(!u)return this.view.requestMeasure(),!1;let h=this.view.state,g=bOt(this.view,u);return this.view.state==h&&(u.domChanged||u.newSel&&!ihe(this.view.state.selection,u.newSel.main))&&this.view.update([]),g}readMutation(s){let u=this.view.docView.tile.nearest(s.target);if(!u||u.isWidget())return null;if(u.markDirty(s.type=="attributes"),s.type=="childList"){let h=$xt(u,s.previousSibling||s.target.previousSibling,-1),g=$xt(u,s.nextSibling||s.target.nextSibling,1);return{from:h?u.posAfter(h):u.posAtStart,to:g?u.posBefore(g):u.posAtEnd,typeOver:!1}}else return s.type=="characterData"?{from:u.posAtStart,to:u.posAtEnd,typeOver:s.target.nodeValue==s.oldValue}:null}setWindow(s){s!=this.win&&(this.removeWindowListeners(this.win),this.win=s,this.addWindowListeners(this.win))}addWindowListeners(s){s.addEventListener("resize",this.onResize),this.printQuery?this.printQuery.addEventListener?this.printQuery.addEventListener("change",this.onPrint):this.printQuery.addListener(this.onPrint):s.addEventListener("beforeprint",this.onPrint),s.addEventListener("scroll",this.onScroll),s.document.addEventListener("selectionchange",this.onSelectionChange)}removeWindowListeners(s){s.removeEventListener("scroll",this.onScroll),s.removeEventListener("resize",this.onResize),this.printQuery?this.printQuery.removeEventListener?this.printQuery.removeEventListener("change",this.onPrint):this.printQuery.removeListener(this.onPrint):s.removeEventListener("beforeprint",this.onPrint),s.document.removeEventListener("selectionchange",this.onSelectionChange)}update(s){this.editContext&&(this.editContext.update(s),s.startState.facet(Zk)!=s.state.facet(Zk)&&(s.view.contentDOM.editContext=s.state.facet(Zk)?this.editContext.editContext:null))}destroy(){var s,u,h;this.stop(),(s=this.intersection)===null||s===void 0||s.disconnect(),(u=this.gapIntersection)===null||u===void 0||u.disconnect(),(h=this.resizeScroll)===null||h===void 0||h.disconnect();for(let g of this.scrollTargets)g.removeEventListener("scroll",this.onScroll);this.removeWindowListeners(this.win),clearTimeout(this.parentCheck),clearTimeout(this.resizeTimeout),this.win.cancelAnimationFrame(this.delayedFlush),this.win.cancelAnimationFrame(this.flushingAndroidKey),this.editContext&&(this.view.contentDOM.editContext=null,this.editContext.destroy())}}function $xt(l,s,u){for(;s;){let h=of.get(s);if(h&&h.parent==l)return h;let g=s.parentNode;s=g!=l.dom?g:u>0?s.nextSibling:s.previousSibling}return null}function Bxt(l,s){let u=s.startContainer,h=s.startOffset,g=s.endContainer,w=s.endOffset,p=l.docView.domAtPos(l.state.selection.main.anchor,1);return zX(p.node,p.offset,g,w)&&([u,h,g,w]=[g,w,u,h]),{anchorNode:u,anchorOffset:h,focusNode:g,focusOffset:w}}function K1n(l,s){if(s.getComposedRanges){let g=s.getComposedRanges(l.root)[0];if(g)return Bxt(l,g)}let u=null;function h(g){g.preventDefault(),g.stopImmediatePropagation(),u=g.getTargetRanges()[0]}return l.contentDOM.addEventListener("beforeinput",h,!0),l.dom.ownerDocument.execCommand("indent"),l.contentDOM.removeEventListener("beforeinput",h,!0),u?Bxt(l,u):null}class Y1n{constructor(s){this.from=0,this.to=0,this.pendingContextChange=null,this.handlers=Object.create(null),this.composing=null,this.resetRange(s.state);let u=this.editContext=new window.EditContext({text:s.state.doc.sliceString(this.from,this.to),selectionStart:this.toContextPos(Math.max(this.from,Math.min(this.to,s.state.selection.main.anchor))),selectionEnd:this.toContextPos(s.state.selection.main.head)});this.handlers.textupdate=h=>{let g=s.state.selection.main,{anchor:w,head:p}=g,k=this.toEditorPos(h.updateRangeStart),j=this.toEditorPos(h.updateRangeEnd);s.inputState.composing>=0&&!this.composing&&(this.composing={contextBase:h.updateRangeStart,editorBase:k,drifted:!1});let A=j-k>h.text.length;k==this.from&&w<this.from?k=w:j==this.to&&w>this.to&&(j=w);let _=mOt(s.state.sliceDoc(k,j),h.text,(A?g.from:g.to)-k,A?"end":null);if(!_){let I=kn.single(this.toEditorPos(h.selectionStart),this.toEditorPos(h.selectionEnd));ihe(I,g)||s.dispatch({selection:I,userEvent:"select"});return}let D={from:_.from+k,to:_.toA+k,insert:uc.of(h.text.slice(_.from,_.toB).split(`
`))};if((Ji.mac||Ji.android)&&D.from==p-1&&/^\. ?$/.test(h.text)&&s.contentDOM.getAttribute("autocorrect")=="off"&&(D={from:k,to:j,insert:uc.of([h.text.replace("."," ")])}),this.pendingContextChange=D,!s.state.readOnly){let I=this.to-this.from+(D.to-D.from+D.insert.length);sAe(s,D,kn.single(this.toEditorPos(h.selectionStart,I),this.toEditorPos(h.selectionEnd,I)))}this.pendingContextChange&&(this.revertPending(s.state),this.setSelection(s.state)),D.from<D.to&&!D.insert.length&&s.inputState.composing>=0&&!/[\\p{Alphabetic}\\p{Number}_]/.test(u.text.slice(Math.max(0,h.updateRangeStart-1),Math.min(u.text.length,h.updateRangeStart+1)))&&this.handlers.compositionend(h)},this.handlers.characterboundsupdate=h=>{let g=[],w=null;for(let p=this.toEditorPos(h.rangeStart),k=this.toEditorPos(h.rangeEnd);p<k;p++){let j=s.coordsForChar(p);w=j&&new DOMRect(j.left,j.top,j.right-j.left,j.bottom-j.top)||w||new DOMRect,g.push(w)}u.updateCharacterBounds(h.rangeStart,g)},this.handlers.textformatupdate=h=>{let g=[];for(let w of h.getTextFormats()){let p=w.underlineStyle,k=w.underlineThickness;if(!/none/i.test(p)&&!/none/i.test(k)){let j=this.toEditorPos(w.rangeStart),A=this.toEditorPos(w.rangeEnd);if(j<A){let _=`text-decoration: underline ${/^[a-z]/.test(p)?p+" ":p=="Dashed"?"dashed ":p=="Squiggle"?"wavy ":""}${/thin/i.test(k)?1:2}px`;g.push(Fr.mark({attributes:{style:_}}).range(j,A))}}}s.dispatch({effects:cOt.of(Fr.set(g))})},this.handlers.compositionstart=()=>{s.inputState.composing<0&&(s.inputState.composing=0,s.inputState.compositionFirstChange=!0)},this.handlers.compositionend=()=>{if(s.inputState.composing=-1,s.inputState.compositionFirstChange=null,this.composing){let{drifted:h}=this.composing;this.composing=null,h&&this.reset(s.state)}};for(let h in this.handlers)u.addEventListener(h,this.handlers[h]);this.measureReq={read:h=>{this.editContext.updateControlBounds(h.contentDOM.getBoundingClientRect());let g=rV(h.root);g&&g.rangeCount&&this.editContext.updateSelectionBounds(g.getRangeAt(0).getBoundingClientRect())}}}applyEdits(s){let u=0,h=!1,g=this.pendingContextChange;return s.changes.iterChanges((w,p,k,j,A)=>{if(h)return;let _=A.length-(p-w);if(g&&p>=g.to)if(g.from==w&&g.to==p&&g.insert.eq(A)){g=this.pendingContextChange=null,u+=_,this.to+=_;return}else g=null,this.revertPending(s.state);if(w+=u,p+=u,p<=this.from)this.from+=_,this.to+=_;else if(w<this.to){if(w<this.from||p>this.to||this.to-this.from+A.length>3e4){h=!0;return}this.editContext.updateText(this.toContextPos(w),this.toContextPos(p),A.toString()),this.to+=_}u+=_}),g&&!h&&this.revertPending(s.state),!h}update(s){let u=this.pendingContextChange,h=s.startState.selection.main;this.composing&&(this.composing.drifted||!s.changes.touchesRange(h.from,h.to)&&s.transactions.some(g=>!g.isUserEvent("input.type")&&g.changes.touchesRange(this.from,this.to)))?(this.composing.drifted=!0,this.composing.editorBase=s.changes.mapPos(this.composing.editorBase)):!this.applyEdits(s)||!this.rangeIsValid(s.state)?(this.pendingContextChange=null,this.reset(s.state)):(s.docChanged||s.selectionSet||u)&&this.setSelection(s.state),(s.geometryChanged||s.docChanged||s.selectionSet)&&s.view.requestMeasure(this.measureReq)}resetRange(s){let{head:u}=s.selection.main;this.from=Math.max(0,u-1e4),this.to=Math.min(s.doc.length,u+1e4)}reset(s){this.resetRange(s),this.editContext.updateText(0,this.editContext.text.length,s.doc.sliceString(this.from,this.to)),this.setSelection(s)}revertPending(s){let u=this.pendingContextChange;this.pendingContextChange=null,this.editContext.updateText(this.toContextPos(u.from),this.toContextPos(u.from+u.insert.length),s.doc.sliceString(u.from,u.to))}setSelection(s){let{main:u}=s.selection,h=this.toContextPos(Math.max(this.from,Math.min(this.to,u.anchor))),g=this.toContextPos(u.head);(this.editContext.selectionStart!=h||this.editContext.selectionEnd!=g)&&this.editContext.updateSelection(h,g)}rangeIsValid(s){let{head:u}=s.selection.main;return!(this.from>0&&u-this.from<500||this.to<s.doc.length&&this.to-u<500||this.to-this.from>1e4*3)}toEditorPos(s,u=this.to-this.from){s=Math.min(s,u);let h=this.composing;return h&&h.drifted?h.editorBase+(s-h.contextBase):s+this.from}toContextPos(s){let u=this.composing;return u&&u.drifted?u.contextBase+(s-u.editorBase):s-this.from}destroy(){for(let s in this.handlers)this.editContext.removeEventListener(s,this.handlers[s])}}class Bi{get state(){return this.viewState.state}get viewport(){return this.viewState.viewport}get visibleRanges(){return this.viewState.visibleRanges}get inView(){return this.viewState.inView}get composing(){return!!this.inputState&&this.inputState.composing>0}get compositionStarted(){return!!this.inputState&&this.inputState.composing>=0}get root(){return this._root}get win(){return this.dom.ownerDocument.defaultView||window}constructor(s={}){var u;this.plugins=[],this.pluginMap=new Map,this.editorAttrs={},this.contentAttrs={},this.bidiCache=[],this.destroyed=!1,this.updateState=2,this.measureScheduled=-1,this.measureRequests=[],this.contentDOM=document.createElement("div"),this.scrollDOM=document.createElement("div"),this.scrollDOM.tabIndex=-1,this.scrollDOM.className="cm-scroller",this.scrollDOM.appendChild(this.contentDOM),this.announceDOM=document.createElement("div"),this.announceDOM.className="cm-announced",this.announceDOM.setAttribute("aria-live","polite"),this.dom=document.createElement("div"),this.dom.appendChild(this.announceDOM),this.dom.appendChild(this.scrollDOM),s.parent&&s.parent.appendChild(this.dom);let{dispatch:h}=s;this.dispatchTransactions=s.dispatchTransactions||h&&(g=>g.forEach(w=>h(w,this)))||(g=>this.update(g)),this.dispatch=this.dispatch.bind(this),this._root=s.root||Edn(s.parent)||document,this.viewState=new Pxt(this,s.state||Ic.create(s)),s.scrollTo&&s.scrollTo.is(Xae)&&(this.viewState.scrollTarget=s.scrollTo.value.clip(this.viewState.state)),this.plugins=this.state.facet(aI).map(g=>new NEe(g));for(let g of this.plugins)g.update(this);this.observer=new W1n(this),this.inputState=new v1n(this),this.inputState.ensureHandlers(this.plugins),this.docView=new kxt(this),this.mountStyles(),this.updateAttrs(),this.updateState=0,this.requestMeasure(),!((u=document.fonts)===null||u===void 0)&&u.ready&&document.fonts.ready.then(()=>{this.viewState.mustMeasureContent="refresh",this.requestMeasure()})}dispatch(...s){let u=s.length==1&&s[0]instanceof hh?s:s.length==1&&Array.isArray(s[0])?s[0]:[this.state.update(...s)];this.dispatchTransactions(u,this)}update(s){if(this.updateState!=0)throw new Error("Calls to EditorView.update are not allowed while an update is in progress");let u=!1,h=!1,g,w=this.state;for(let I of s){if(I.startState!=w)throw new RangeError("Trying to update state with a transaction that doesn't start from the previous state.");w=I.state}if(this.destroyed){this.viewState.state=w;return}let p=this.hasFocus,k=0,j=null;s.some(I=>I.annotation(OOt))?(this.inputState.notifiedFocused=p,k=1):p!=this.inputState.notifiedFocused&&(this.inputState.notifiedFocused=p,j=SOt(w,p),j||(k=1));let A=this.observer.delayedAndroidKey,_=null;if(A?(this.observer.clearDelayedAndroidKey(),_=this.observer.readChange(),(_&&!this.state.doc.eq(w.doc)||!this.state.selection.eq(w.selection))&&(_=null)):this.observer.clear(),w.facet(Ic.phrases)!=this.state.facet(Ic.phrases))return this.setState(w);g=ehe.create(this,w,s),g.flags|=k;let D=this.viewState.scrollTarget;try{this.updateState=2;for(let I of s){if(D&&(D=D.map(I.changes)),I.scrollIntoView){let{main:B}=I.state.selection;D=new vI(B.empty?B:kn.cursor(B.head,B.head>B.anchor?-1:1))}for(let B of I.effects)B.is(Xae)&&(D=B.value.clip(this.state))}this.viewState.update(g,D),this.bidiCache=she.update(this.bidiCache,g.changes),g.empty||(this.updatePlugins(g),this.inputState.update(g)),u=this.docView.update(g),this.state.facet(NX)!=this.styleModules&&this.mountStyles(),h=this.updateAttrs(),this.showAnnouncements(s),this.docView.updateSelection(u,s.some(I=>I.isUserEvent("select.pointer")))}finally{this.updateState=0}if(g.startState.facet(efe)!=g.state.facet(efe)&&(this.viewState.mustMeasureContent=!0),(u||h||D||this.viewState.mustEnforceCursorAssoc||this.viewState.mustMeasureContent)&&this.requestMeasure(),u&&this.docViewUpdate(),!g.empty)for(let I of this.state.facet(KCe))try{I(g)}catch(B){kp(this.state,B,"update listener")}(j||_)&&Promise.resolve().then(()=>{j&&this.state==j.startState&&this.dispatch(j),_&&!bOt(this,_)&&A.force&&wI(this.contentDOM,A.key,A.keyCode)})}setState(s){if(this.updateState!=0)throw new Error("Calls to EditorView.setState are not allowed while an update is in progress");if(this.destroyed){this.viewState.state=s;return}this.updateState=2;let u=this.hasFocus;try{for(let h of this.plugins)h.destroy(this);this.viewState=new Pxt(this,s),this.plugins=s.facet(aI).map(h=>new NEe(h)),this.pluginMap.clear();for(let h of this.plugins)h.update(this);this.docView.destroy(),this.docView=new kxt(this),this.inputState.ensureHandlers(this.plugins),this.mountStyles(),this.updateAttrs(),this.bidiCache=[]}finally{this.updateState=0}u&&this.focus(),this.requestMeasure()}updatePlugins(s){let u=s.startState.facet(aI),h=s.state.facet(aI);if(u!=h){let g=[];for(let w of h){let p=u.indexOf(w);if(p<0)g.push(new NEe(w));else{let k=this.plugins[p];k.mustUpdate=s,g.push(k)}}for(let w of this.plugins)w.mustUpdate!=s&&w.destroy(this);this.plugins=g,this.pluginMap.clear()}else for(let g of this.plugins)g.mustUpdate=s;for(let g=0;g<this.plugins.length;g++)this.plugins[g].update(this);u!=h&&this.inputState.ensureHandlers(this.plugins)}docViewUpdate(){for(let s of this.plugins){let u=s.value;if(u&&u.docViewUpdate)try{u.docViewUpdate(this)}catch(h){kp(this.state,h,"doc view update listener")}}}measure(s=!0){if(this.destroyed)return;if(this.measureScheduled>-1&&this.win.cancelAnimationFrame(this.measureScheduled),this.observer.delayedAndroidKey){this.measureScheduled=-1,this.requestMeasure();return}this.measureScheduled=0,s&&this.observer.forceFlush();let u=null,h=this.viewState.scrollParent,g=this.viewState.getScrollOffset(),{scrollAnchorPos:w,scrollAnchorHeight:p}=this.viewState;Math.abs(g-this.viewState.scrollOffset)>1&&(p=-1),this.viewState.scrollAnchorHeight=-1;try{for(let k=0;;k++){if(p<0)if(Qkt(h||this.win))w=-1,p=this.viewState.heightMap.height;else{let B=this.viewState.scrollAnchorAt(g);w=B.from,p=B.top}this.updateState=1;let j=this.viewState.measure();if(!j&&!this.measureRequests.length&&this.viewState.scrollTarget==null)break;if(k>5){console.warn(this.measureRequests.length?"Measure loop restarted more than 5 times":"Viewport failed to stabilize");break}let A=[];j&4||([this.measureRequests,A]=[A,this.measureRequests]);let _=A.map(B=>{try{return B.read(this)}catch(F){return kp(this.state,F),zxt}}),D=ehe.create(this,this.state,[]),I=!1;D.flags|=j,u?u.flags|=j:u=D,this.updateState=2,D.empty||(this.updatePlugins(D),this.inputState.update(D),this.updateAttrs(),I=this.docView.update(D),I&&this.docViewUpdate());for(let B=0;B<A.length;B++)if(_[B]!=zxt)try{let F=A[B];F.write&&F.write(_[B],this)}catch(F){kp(this.state,F)}if(I&&this.docView.updateSelection(!0),!D.viewportChanged&&this.measureRequests.length==0){if(this.viewState.editorHeight)if(this.viewState.scrollTarget){this.docView.scrollIntoView(this.viewState.scrollTarget),this.viewState.scrollTarget=null,p=-1;continue}else{let F=((w<0?this.viewState.heightMap.height:this.viewState.lineBlockAt(w).top)-p)/this.scaleY;if((F>1||F<-1)&&(h==this.scrollDOM||this.hasFocus||Math.max(this.inputState.lastWheelEvent,this.inputState.lastTouchTime)>Date.now()-100)){g=g+F,h?h.scrollTop+=F:this.win.scrollBy(0,F),p=-1;continue}}break}}}finally{this.updateState=0,this.measureScheduled=-1}if(u&&!u.empty)for(let k of this.state.facet(KCe))k(u)}get themeClasses(){return iMe+" "+(this.state.facet(nMe)?COt:EOt)+" "+this.state.facet(efe)}updateAttrs(){let s=Fxt(this,lOt,{class:"cm-editor"+(this.hasFocus?" cm-focused ":" ")+this.themeClasses}),u={spellcheck:"false",autocorrect:"off",autocapitalize:"off",writingsuggestions:"false",translate:"no",contenteditable:this.state.facet(Zk)?"true":"false",class:"cm-content",style:`${Ji.tabSize}: ${this.state.tabSize}`,role:"textbox","aria-multiline":"true"};this.state.readOnly&&(u["aria-readonly"]="true"),Fxt(this,nAe,u);let h=this.observer.ignore(()=>{let g=bxt(this.contentDOM,this.contentAttrs,u),w=bxt(this.dom,this.editorAttrs,s);return g||w});return this.editorAttrs=s,this.contentAttrs=u,h}showAnnouncements(s){let u=!0;for(let h of s)for(let g of h.effects)if(g.is(Bi.announce)){u&&(this.announceDOM.textContent=""),u=!1;let w=this.announceDOM.appendChild(document.createElement("div"));w.textContent=g.value}}mountStyles(){this.styleModules=this.state.facet(NX);let s=this.state.facet(Bi.cspNonce);k8.mount(this.root,this.styleModules.concat(X1n).reverse(),s?{nonce:s}:void 0)}readMeasured(){if(this.updateState==2)throw new Error("Reading the editor layout isn't allowed during an update");this.updateState==0&&this.measureScheduled>-1&&this.measure(!1)}requestMeasure(s){if(this.measureScheduled<0&&(this.measureScheduled=this.win.requestAnimationFrame(()=>this.measure())),s){if(this.measureRequests.indexOf(s)>-1)return;if(s.key!=null){for(let u=0;u<this.measureRequests.length;u++)if(this.measureRequests[u].key===s.key){this.measureRequests[u]=s;return}}this.measureRequests.push(s)}}plugin(s){let u=this.pluginMap.get(s);return(u===void 0||u&&u.plugin!=s)&&this.pluginMap.set(s,u=this.plugins.find(h=>h.plugin==s)||null),u&&u.update(this).value}get documentTop(){return this.contentDOM.getBoundingClientRect().top+this.viewState.paddingTop}get documentPadding(){return{top:this.viewState.paddingTop,bottom:this.viewState.paddingBottom}}get scaleX(){return this.viewState.scaleX}get scaleY(){return this.viewState.scaleY}elementAtHeight(s){return this.readMeasured(),this.viewState.elementAtHeight(s)}lineBlockAtHeight(s){return this.readMeasured(),this.viewState.lineBlockAtHeight(s)}get viewportLineBlocks(){return this.viewState.viewportLines}lineBlockAt(s){return this.viewState.lineBlockAt(s)}get contentHeight(){return this.viewState.contentHeight}moveByChar(s,u,h){return PEe(this,s,Oxt(this,s,u,h))}moveByGroup(s,u){return PEe(this,s,Oxt(this,s,u,h=>u1n(this,s.head,h)))}visualLineSide(s,u){let h=this.bidiSpans(s),g=this.textDirectionAt(s.from),w=h[u?h.length-1:0];return kn.cursor(w.side(u,g)+s.from,w.forward(!u,g)?1:-1)}moveToLineBoundary(s,u,h=!0){return l1n(this,s,u,h)}moveVertically(s,u,h){return PEe(this,s,a1n(this,s,u,h))}domAtPos(s,u=1){return this.docView.domAtPos(s,u)}posAtDOM(s,u=0){return this.docView.posFromDOM(s,u)}posAtCoords(s,u=!0){this.readMeasured();let h=eMe(this,s,u);return h&&h.pos}posAndSideAtCoords(s,u=!0){return this.readMeasured(),eMe(this,s,u)}coordsAtPos(s,u=1){this.readMeasured();let h=this.docView.coordsAt(s,u);if(!h||h.left==h.right)return h;let g=this.state.doc.lineAt(s),w=this.bidiSpans(g),p=w[Q3.find(w,s-g.from,-1,u)];return sV(h,p.dir==Yl.LTR==u>0)}coordsForChar(s){return this.readMeasured(),this.docView.coordsForChar(s)}get defaultCharacterWidth(){return this.viewState.heightOracle.charWidth}get defaultLineHeight(){return this.viewState.heightOracle.lineHeight}get textDirection(){return this.viewState.defaultTextDirection}textDirectionAt(s){return!this.state.facet(rOt)||s<this.viewport.from||s>this.viewport.to?this.textDirection:(this.readMeasured(),this.docView.textDirectionAt(s))}get lineWrapping(){return this.viewState.heightOracle.lineWrapping}bidiSpans(s){if(s.length>Z1n)return Wkt(s.length);let u=this.textDirectionAt(s.from),h;for(let w of this.bidiCache)if(w.from==s.from&&w.dir==u&&(w.fresh||Vkt(w.isolates,h=vxt(this,s))))return w.order;h||(h=vxt(this,s));let g=Pdn(s.text,u,h);return this.bidiCache.push(new she(s.from,s.to,u,h,!0,g)),g}get hasFocus(){var s;return(this.dom.ownerDocument.hasFocus()||Ji.safari&&((s=this.inputState)===null||s===void 0?void 0:s.lastContextMenu)>Date.now()-3e4)&&this.root.activeElement==this.contentDOM}focus(){this.observer.ignore(()=>{Hkt(this.contentDOM),this.docView.updateSelection()})}setRoot(s){this._root!=s&&(this._root=s,this.observer.setWindow((s.nodeType==9?s:s.ownerDocument).defaultView||window),this.mountStyles())}destroy(){this.root.activeElement==this.contentDOM&&this.contentDOM.blur();for(let s of this.plugins)s.destroy(this);this.plugins=[],this.inputState.destroy(),this.docView.destroy(),this.dom.remove(),this.observer.destroy(),this.measureScheduled>-1&&this.win.cancelAnimationFrame(this.measureScheduled),this.destroyed=!0}static scrollIntoView(s,u={}){return Xae.of(new vI(typeof s=="number"?kn.cursor(s):s,u.y,u.x,u.yMargin,u.xMargin))}scrollSnapshot(){let{scrollTop:s,scrollLeft:u}=this.scrollDOM,h=this.viewState.scrollAnchorAt(s);return Xae.of(new vI(kn.cursor(h.from),"start","start",h.top-s,u,!0))}setTabFocusMode(s){s==null?this.inputState.tabFocusMode=this.inputState.tabFocusMode<0?0:-1:typeof s=="boolean"?this.inputState.tabFocusMode=s?0:-1:this.inputState.tabFocusMode!=0&&(this.inputState.tabFocusMode=Date.now()+s)}static domEventHandlers(s){return Xh.define(()=>({}),{eventHandlers:s})}static domEventObservers(s){return Xh.define(()=>({}),{eventObservers:s})}static theme(s,u){let h=k8.newName(),g=[efe.of(h),NX.of(rMe(`.${h}`,s))];return u&&u.dark&&g.push(nMe.of(!0)),g}static baseTheme(s){return E8.lowest(NX.of(rMe("."+iMe,s,MOt)))}static findFromDOM(s){var u;let h=s.querySelector(".cm-content"),g=h&&of.get(h)||of.get(s);return((u=g==null?void 0:g.root)===null||u===void 0?void 0:u.view)||null}}Bi.styleModule=NX;Bi.inputHandler=nOt;Bi.clipboardInputFilter=eAe;Bi.clipboardOutputFilter=tAe;Bi.scrollHandler=oOt;Bi.focusChangeEffect=iOt;Bi.perLineTextDirection=rOt;Bi.exceptionSink=tOt;Bi.updateListener=KCe;Bi.editable=Zk;Bi.mouseSelectionStyle=eOt;Bi.dragMovesSelection=Zkt;Bi.clickAddsSelectionRange=Ykt;Bi.decorations=Fhe;Bi.blockWrappers=uOt;Bi.outerDecorations=iAe;Bi.atomicRanges=AV;Bi.bidiIsolatedRanges=aOt;Bi.scrollMargins=fOt;Bi.darkTheme=nMe;Bi.cspNonce=Qi.define({combine:l=>l.length?l[0]:""});Bi.contentAttributes=nAe;Bi.editorAttributes=lOt;Bi.lineWrapping=Bi.contentAttributes.of({class:"cm-lineWrapping"});Bi.announce=Ds.define();const Z1n=4096,zxt={};class she{constructor(s,u,h,g,w,p){this.from=s,this.to=u,this.dir=h,this.isolates=g,this.fresh=w,this.order=p}static update(s,u){if(u.empty&&!s.some(w=>w.fresh))return s;let h=[],g=s.length?s[s.length-1].dir:Yl.LTR;for(let w=Math.max(0,s.length-10);w<s.length;w++){let p=s[w];p.dir==g&&!u.touchesRange(p.from,p.to)&&h.push(new she(u.mapPos(p.from,1),u.mapPos(p.to,-1),p.dir,p.isolates,!1,p.order))}return h}}function Fxt(l,s,u){for(let h=l.state.facet(s),g=h.length-1;g>=0;g--){let w=h[g],p=typeof w=="function"?w(l):w;p&&KMe(p,u)}return u}const egn=Ji.mac?"mac":Ji.windows?"win":Ji.linux?"linux":"key";function tgn(l,s){const u=l.split(/-(?!$)/);let h=u[u.length-1];h=="Space"&&(h=" ");let g,w,p,k;for(let j=0;j<u.length-1;++j){const A=u[j];if(/^(cmd|meta|m)$/i.test(A))k=!0;else if(/^a(lt)?$/i.test(A))g=!0;else if(/^(c|ctrl|control)$/i.test(A))w=!0;else if(/^s(hift)?$/i.test(A))p=!0;else if(/^mod$/i.test(A))s=="mac"?k=!0:w=!0;else throw new Error("Unrecognized modifier name: "+A)}return g&&(h="Alt-"+h),w&&(h="Ctrl-"+h),k&&(h="Meta-"+h),p&&(h="Shift-"+h),h}function tfe(l,s,u){return s.altKey&&(l="Alt-"+l),s.ctrlKey&&(l="Ctrl-"+l),s.metaKey&&(l="Meta-"+l),u!==!1&&s.shiftKey&&(l="Shift-"+l),l}const ngn=E8.default(Bi.domEventHandlers({keydown(l,s){return NOt(AOt(s.state),l,s,"editor")}})),Ghe=Qi.define({enables:ngn}),qxt=new WeakMap;function AOt(l){let s=l.facet(Ghe),u=qxt.get(s);return u||qxt.set(s,u=sgn(s.reduce((h,g)=>h.concat(g),[]))),u}function ign(l,s,u){return NOt(AOt(l.state),s,l,u)}let p8=null;const rgn=4e3;function sgn(l,s=egn){let u=Object.create(null),h=Object.create(null),g=(p,k)=>{let j=h[p];if(j==null)h[p]=k;else if(j!=k)throw new Error("Key binding "+p+" is used both as a regular binding and as a multi-stroke prefix")},w=(p,k,j,A,_)=>{var D,I;let B=u[p]||(u[p]=Object.create(null)),F=k.split(/ (?!$)/).map(Y=>tgn(Y,s));for(let Y=1;Y<F.length;Y++){let Z=F.slice(0,Y).join(" ");g(Z,!0),B[Z]||(B[Z]={preventDefault:!0,stopPropagation:!1,run:[ee=>{let ce=p8={view:ee,prefix:Z,scope:p};return setTimeout(()=>{p8==ce&&(p8=null)},rgn),!0}]})}let U=F.join(" ");g(U,!1);let K=B[U]||(B[U]={preventDefault:!1,stopPropagation:!1,run:((I=(D=B._any)===null||D===void 0?void 0:D.run)===null||I===void 0?void 0:I.slice())||[]});j&&K.run.push(j),A&&(K.preventDefault=!0),_&&(K.stopPropagation=!0)};for(let p of l){let k=p.scope?p.scope.split(" "):["editor"];if(p.any)for(let A of k){let _=u[A]||(u[A]=Object.create(null));_._any||(_._any={preventDefault:!1,stopPropagation:!1,run:[]});let{any:D}=p;for(let I in _)_[I].run.push(B=>D(B,sMe))}let j=p[s]||p.key;if(j)for(let A of k)w(A,j,p.run,p.preventDefault,p.stopPropagation),p.shift&&w(A,"Shift-"+j,p.shift,p.preventDefault,p.stopPropagation)}return u}let sMe=null;function NOt(l,s,u,h){sMe=s;let g=vdn(s),w=em(g,0),p=q3(w)==g.length&&g!=" ",k="",j=!1,A=!1,_=!1;p8&&p8.view==u&&p8.scope==h&&(k=p8.prefix+" ",vOt.indexOf(s.keyCode)<0&&(A=!0,p8=null));let D=new Set,I=K=>{if(K){for(let Y of K.run)if(!D.has(Y)&&(D.add(Y),Y(u)))return K.stopPropagation&&(_=!0),!0;K.preventDefault&&(K.stopPropagation&&(_=!0),A=!0)}return!1},B=l[h],F,U;return B&&(I(B[k+tfe(g,s,!p)])?j=!0:p&&(s.altKey||s.metaKey||s.ctrlKey)&&!(Ji.windows&&s.ctrlKey&&s.altKey)&&!(Ji.mac&&s.altKey&&!(s.ctrlKey||s.metaKey))&&(F=O8[s.keyCode])&&F!=g?(I(B[k+tfe(F,s,!0)])||s.shiftKey&&(U=nV[s.keyCode])!=g&&U!=F&&I(B[k+tfe(U,s,!1)]))&&(j=!0):p&&s.shiftKey&&I(B[k+tfe(g,s,!0)])&&(j=!0),!j&&I(B._any)&&(j=!0)),A&&(j=!0),j&&_&&s.stopPropagation(),sMe=null,j}class NV{constructor(s,u,h,g,w){this.className=s,this.left=u,this.top=h,this.width=g,this.height=w}draw(){let s=document.createElement("div");return s.className=this.className,this.adjust(s),s}update(s,u){return u.className!=this.className?!1:(this.adjust(s),!0)}adjust(s){s.style.left=this.left+"px",s.style.top=this.top+"px",this.width!=null&&(s.style.width=this.width+"px"),s.style.height=this.height+"px"}eq(s){return this.left==s.left&&this.top==s.top&&this.width==s.width&&this.height==s.height&&this.className==s.className}static forRange(s,u,h){if(h.empty){let g=s.coordsAtPos(h.head,h.assoc||1);if(!g)return[];let w=_Ot(s);return[new NV(u,g.left-w.left,g.top-w.top,null,g.bottom-g.top)]}else return ogn(s,u,h)}}function _Ot(l){let s=l.scrollDOM.getBoundingClientRect();return{left:(l.textDirection==Yl.LTR?s.left:s.right-l.scrollDOM.clientWidth*l.scaleX)-l.scrollDOM.scrollLeft*l.scaleX,top:s.top-l.scrollDOM.scrollTop*l.scaleY}}function Hxt(l,s,u,h){let g=l.coordsAtPos(s,u*2);if(!g)return h;let w=l.dom.getBoundingClientRect(),p=(g.top+g.bottom)/2,k=l.posAtCoords({x:w.left+1,y:p}),j=l.posAtCoords({x:w.right-1,y:p});return k==null||j==null?h:{from:Math.max(h.from,Math.min(k,j)),to:Math.min(h.to,Math.max(k,j))}}function ogn(l,s,u){if(u.to<=l.viewport.from||u.from>=l.viewport.to)return[];let h=Math.max(u.from,l.viewport.from),g=Math.min(u.to,l.viewport.to),w=l.textDirection==Yl.LTR,p=l.contentDOM,k=p.getBoundingClientRect(),j=_Ot(l),A=p.querySelector(".cm-line"),_=A&&window.getComputedStyle(A),D=k.left+(_?parseInt(_.paddingLeft)+Math.min(0,parseInt(_.textIndent)):0),I=k.right-(_?parseInt(_.paddingRight):0),B=ZCe(l,h,1),F=ZCe(l,g,-1),U=B.type==a1.Text?B:null,K=F.type==a1.Text?F:null;if(U&&(l.lineWrapping||B.widgetLineBreaks)&&(U=Hxt(l,h,1,U)),K&&(l.lineWrapping||F.widgetLineBreaks)&&(K=Hxt(l,g,-1,K)),U&&K&&U.from==K.from&&U.to==K.to)return Z(ee(u.from,u.to,U));{let fe=U?ee(u.from,null,U):ce(B,!1),be=K?ee(null,u.to,K):ce(F,!0),me=[];return(U||B).to<(K||F).from-(U&&K?1:0)||B.widgetLineBreaks>1&&fe.bottom+l.defaultLineHeight/2<be.top?me.push(Y(D,fe.bottom,I,be.top)):fe.bottom<be.top&&l.elementAtHeight((fe.bottom+be.top)/2).type==a1.Text&&(fe.bottom=be.top=(fe.bottom+be.top)/2),Z(fe).concat(me).concat(Z(be))}function Y(fe,be,me,Re){return new NV(s,fe-j.left,be-j.top,Math.max(0,me-fe),Re-be)}function Z({top:fe,bottom:be,horizontal:me}){let Re=[];for(let Te=0;Te<me.length;Te+=2)Re.push(Y(me[Te],fe,me[Te+1],be));return Re}function ee(fe,be,me){let Re=1e9,Te=-1e9,Ke=[];function ze(ge,He,ae,Le,Oe){let Qe=l.coordsAtPos(ge,ge==me.to?-2:2),kt=l.coordsAtPos(ae,ae==me.from?2:-2);!Qe||!kt||(Re=Math.min(Qe.top,kt.top,Re),Te=Math.max(Qe.bottom,kt.bottom,Te),Oe==Yl.LTR?Ke.push(w&&He?D:Qe.left,w&&Le?I:kt.right):Ke.push(!w&&Le?D:kt.left,!w&&He?I:Qe.right))}let je=fe??me.from,te=be??me.to;for(let ge of l.visibleRanges)if(ge.to>je&&ge.from<te)for(let He=Math.max(ge.from,je),ae=Math.min(ge.to,te);;){let Le=l.state.doc.lineAt(He);for(let Oe of l.bidiSpans(Le)){let Qe=Oe.from+Le.from,kt=Oe.to+Le.from;if(Qe>=ae)break;kt>He&&ze(Math.max(Qe,He),fe==null&&Qe<=je,Math.min(kt,ae),be==null&&kt>=te,Oe.dir)}if(He=Le.to+1,He>=ae)break}return Ke.length==0&&ze(je,fe==null,te,be==null,l.textDirection),{top:Re,bottom:Te,horizontal:Ke}}function ce(fe,be){let me=k.top+(be?fe.top:fe.bottom);return{top:me,bottom:me,horizontal:[]}}}function cgn(l,s){return l.constructor==s.constructor&&l.eq(s)}class lgn{constructor(s,u){this.view=s,this.layer=u,this.drawn=[],this.scaleX=1,this.scaleY=1,this.measureReq={read:this.measure.bind(this),write:this.draw.bind(this)},this.dom=s.scrollDOM.appendChild(document.createElement("div")),this.dom.classList.add("cm-layer"),u.above&&this.dom.classList.add("cm-layer-above"),u.class&&this.dom.classList.add(u.class),this.scale(),this.dom.setAttribute("aria-hidden","true"),this.setOrder(s.state),s.requestMeasure(this.measureReq),u.mount&&u.mount(this.dom,s)}update(s){s.startState.facet(Cfe)!=s.state.facet(Cfe)&&this.setOrder(s.state),(this.layer.update(s,this.dom)||s.geometryChanged)&&(this.scale(),s.view.requestMeasure(this.measureReq))}docViewUpdate(s){this.layer.updateOnDocViewUpdate!==!1&&s.requestMeasure(this.measureReq)}setOrder(s){let u=0,h=s.facet(Cfe);for(;u<h.length&&h[u]!=this.layer;)u++;this.dom.style.zIndex=String((this.layer.above?150:-1)-u)}measure(){return this.layer.markers(this.view)}scale(){let{scaleX:s,scaleY:u}=this.view;(s!=this.scaleX||u!=this.scaleY)&&(this.scaleX=s,this.scaleY=u,this.dom.style.transform=`scale(${1/s}, ${1/u})`)}draw(s){if(s.length!=this.drawn.length||s.some((u,h)=>!cgn(u,this.drawn[h]))){let u=this.dom.firstChild,h=0;for(let g of s)g.update&&u&&g.constructor&&this.drawn[h].constructor&&g.update(u,this.drawn[h])?(u=u.nextSibling,h++):this.dom.insertBefore(g.draw(),u);for(;u;){let g=u.nextSibling;u.remove(),u=g}this.drawn=s,Ji.safari&&Ji.safari_version>=26&&(this.dom.style.display=this.dom.firstChild?"":"none")}}destroy(){this.layer.destroy&&this.layer.destroy(this.dom,this.view),this.dom.remove()}}const Cfe=Qi.define();function DOt(l){return[Xh.define(s=>new lgn(s,l)),Cfe.of(l)]}const cV=Qi.define({combine(l){return Z3(l,{cursorBlinkRate:1200,drawRangeCursor:!0},{cursorBlinkRate:(s,u)=>Math.min(s,u),drawRangeCursor:(s,u)=>s||u})}});function ugn(l={}){return[cV.of(l),agn,fgn,hgn,sOt.of(!0)]}function LOt(l){return l.startState.facet(cV)!=l.state.facet(cV)}const agn=DOt({above:!0,markers(l){let{state:s}=l,u=s.facet(cV),h=[];for(let g of s.selection.ranges){let w=g==s.selection.main;if(g.empty||u.drawRangeCursor){let p=w?"cm-cursor cm-cursor-primary":"cm-cursor cm-cursor-secondary",k=g.empty?g:kn.cursor(g.head,g.head>g.anchor?-1:1);for(let j of NV.forRange(l,p,k))h.push(j)}}return h},update(l,s){l.transactions.some(h=>h.selection)&&(s.style.animationName=s.style.animationName=="cm-blink"?"cm-blink2":"cm-blink");let u=LOt(l);return u&&Qxt(l.state,s),l.docChanged||l.selectionSet||u},mount(l,s){Qxt(s.state,l)},class:"cm-cursorLayer"});function Qxt(l,s){s.style.animationDuration=l.facet(cV).cursorBlinkRate+"ms"}const fgn=DOt({above:!1,markers(l){return l.state.selection.ranges.map(s=>s.empty?[]:NV.forRange(l,"cm-selectionBackground",s)).reduce((s,u)=>s.concat(u))},update(l,s){return l.docChanged||l.selectionSet||l.viewportChanged||LOt(l)},class:"cm-selectionLayer"}),hgn=E8.highest(Bi.theme({".cm-line":{"& ::selection, &::selection":{backgroundColor:"transparent !important"},caretColor:"transparent !important"},".cm-content":{caretColor:"transparent !important","& :focus":{caretColor:"initial !important","&::selection, & ::selection":{backgroundColor:"Highlight !important"}}}}));function dgn(){return pgn}const ggn=Fr.line({class:"cm-activeLine"}),pgn=Xh.fromClass(class{constructor(l){this.decorations=this.getDeco(l)}update(l){(l.docChanged||l.selectionSet)&&(this.decorations=this.getDeco(l.view))}getDeco(l){let s=-1,u=[];for(let h of l.state.selection.ranges){let g=l.lineBlockAt(h.head);g.from>s&&(u.push(ggn.range(g.from)),s=g.from)}return Fr.set(u)}},{decorations:l=>l.decorations});class bgn extends lO{constructor(s){super(),this.content=s}toDOM(s){let u=document.createElement("span");return u.className="cm-placeholder",u.style.pointerEvents="none",u.appendChild(typeof this.content=="string"?document.createTextNode(this.content):typeof this.content=="function"?this.content(s):this.content.cloneNode(!0)),u.setAttribute("aria-hidden","true"),u}coordsAt(s){let u=s.firstChild?BX(s.firstChild):[];if(!u.length)return null;let h=window.getComputedStyle(s.parentNode),g=sV(u[0],h.direction!="rtl"),w=parseInt(h.lineHeight);return g.bottom-g.top>w*1.5?{left:g.left,right:g.right,top:g.top,bottom:g.top+w}:g}ignoreEvent(){return!1}}function Gxt(l){let s=Xh.fromClass(class{constructor(u){this.view=u,this.placeholder=l?Fr.set([Fr.widget({widget:new bgn(l),side:1}).range(0)]):Fr.none}get decorations(){return this.view.state.doc.length?Fr.none:this.placeholder}},{decorations:u=>u.decorations});return typeof l=="string"?[s,Bi.contentAttributes.of({"aria-placeholder":l})]:s}const oMe=2e3;function mgn(l,s,u){let h=Math.min(s.line,u.line),g=Math.max(s.line,u.line),w=[];if(s.off>oMe||u.off>oMe||s.col<0||u.col<0){let p=Math.min(s.off,u.off),k=Math.max(s.off,u.off);for(let j=h;j<=g;j++){let A=l.doc.line(j);A.length<=k&&w.push(kn.range(A.from+p,A.to+k))}}else{let p=Math.min(s.col,u.col),k=Math.max(s.col,u.col);for(let j=h;j<=g;j++){let A=l.doc.line(j),_=zCe(A.text,p,l.tabSize,!0);if(_<0)w.push(kn.cursor(A.to));else{let D=zCe(A.text,k,l.tabSize);w.push(kn.range(A.from+_,A.from+D))}}}return w}function wgn(l,s){let u=l.coordsAtPos(l.viewport.from);return u?Math.round(Math.abs((u.left-s)/l.defaultCharacterWidth)):-1}function Uxt(l,s){let u=l.posAtCoords({x:s.clientX,y:s.clientY},!1),h=l.state.doc.lineAt(u),g=u-h.from,w=g>oMe?-1:g==h.length?wgn(l,s.clientX):EV(h.text,l.state.tabSize,u-h.from);return{line:h.number,col:w,off:g}}function vgn(l,s){let u=Uxt(l,s),h=l.state.selection;return u?{update(g){if(g.docChanged){let w=g.changes.mapPos(g.startState.doc.line(u.line).from),p=g.state.doc.lineAt(w);u={line:p.number,col:u.col,off:Math.min(u.off,p.length)},h=h.map(g.changes)}},get(g,w,p){let k=Uxt(l,g);if(!k)return h;let j=mgn(l.state,u,k);return j.length?p?kn.create(j.concat(h.ranges)):kn.create(j):h}}:null}function ygn(l){let s=(u=>u.altKey&&u.button==0);return Bi.mouseSelectionStyle.of((u,h)=>s(h)?vgn(u,h):null)}const nfe="-10000px";class POt{constructor(s,u,h,g){this.facet=u,this.createTooltipView=h,this.removeTooltipView=g,this.input=s.state.facet(u),this.tooltips=this.input.filter(p=>p);let w=null;this.tooltipViews=this.tooltips.map(p=>w=h(p,w))}update(s,u){var h;let g=s.state.facet(this.facet),w=g.filter(j=>j);if(g===this.input){for(let j of this.tooltipViews)j.update&&j.update(s);return!1}let p=[],k=u?[]:null;for(let j=0;j<w.length;j++){let A=w[j],_=-1;if(A){for(let D=0;D<this.tooltips.length;D++){let I=this.tooltips[D];I&&I.create==A.create&&(_=D)}if(_<0)p[j]=this.createTooltipView(A,j?p[j-1]:null),k&&(k[j]=!!A.above);else{let D=p[j]=this.tooltipViews[_];k&&(k[j]=u[_]),D.update&&D.update(s)}}}for(let j of this.tooltipViews)p.indexOf(j)<0&&(this.removeTooltipView(j),(h=j.destroy)===null||h===void 0||h.call(j));return u&&(k.forEach((j,A)=>u[A]=j),u.length=k.length),this.input=g,this.tooltips=w,this.tooltipViews=p,!0}}function xgn(l){let s=l.dom.ownerDocument.documentElement;return{top:0,left:0,bottom:s.clientHeight,right:s.clientWidth}}const $Ee=Qi.define({combine:l=>{var s,u,h;return{position:Ji.ios?"absolute":((s=l.find(g=>g.position))===null||s===void 0?void 0:s.position)||"fixed",parent:((u=l.find(g=>g.parent))===null||u===void 0?void 0:u.parent)||null,tooltipSpace:((h=l.find(g=>g.tooltipSpace))===null||h===void 0?void 0:h.tooltipSpace)||xgn}}}),Jxt=new WeakMap,lAe=Xh.fromClass(class{constructor(l){this.view=l,this.above=[],this.inView=!0,this.madeAbsolute=!1,this.lastTransaction=0,this.measureTimeout=-1;let s=l.state.facet($Ee);this.position=s.position,this.parent=s.parent,this.classes=l.themeClasses,this.createContainer(),this.measureReq={read:this.readMeasure.bind(this),write:this.writeMeasure.bind(this),key:this},this.resizeObserver=typeof ResizeObserver=="function"?new ResizeObserver(()=>this.measureSoon()):null,this.manager=new POt(l,Uhe,(u,h)=>this.createTooltip(u,h),u=>{this.resizeObserver&&this.resizeObserver.unobserve(u.dom),u.dom.remove()}),this.above=this.manager.tooltips.map(u=>!!u.above),this.intersectionObserver=typeof IntersectionObserver=="function"?new IntersectionObserver(u=>{Date.now()>this.lastTransaction-50&&u.length>0&&u[u.length-1].intersectionRatio<1&&this.measureSoon()},{threshold:[1]}):null,this.observeIntersection(),l.win.addEventListener("resize",this.measureSoon=this.measureSoon.bind(this)),this.maybeMeasure()}createContainer(){this.parent?(this.container=document.createElement("div"),this.container.style.position="relative",this.container.className=this.view.themeClasses,this.parent.appendChild(this.container)):this.container=this.view.dom}observeIntersection(){if(this.intersectionObserver){this.intersectionObserver.disconnect();for(let l of this.manager.tooltipViews)this.intersectionObserver.observe(l.dom)}}measureSoon(){this.measureTimeout<0&&(this.measureTimeout=setTimeout(()=>{this.measureTimeout=-1,this.maybeMeasure()},50))}update(l){l.transactions.length&&(this.lastTransaction=Date.now());let s=this.manager.update(l,this.above);s&&this.observeIntersection();let u=s||l.geometryChanged,h=l.state.facet($Ee);if(h.position!=this.position&&!this.madeAbsolute){this.position=h.position;for(let g of this.manager.tooltipViews)g.dom.style.position=this.position;u=!0}if(h.parent!=this.parent){this.parent&&this.container.remove(),this.parent=h.parent,this.createContainer();for(let g of this.manager.tooltipViews)this.container.appendChild(g.dom);u=!0}else this.parent&&this.view.themeClasses!=this.classes&&(this.classes=this.container.className=this.view.themeClasses);u&&this.maybeMeasure()}createTooltip(l,s){let u=l.create(this.view),h=s?s.dom:null;if(u.dom.classList.add("cm-tooltip"),l.arrow&&!u.dom.querySelector(".cm-tooltip > .cm-tooltip-arrow")){let g=document.createElement("div");g.className="cm-tooltip-arrow",u.dom.appendChild(g)}return u.dom.style.position=this.position,u.dom.style.top=nfe,u.dom.style.left="0px",this.container.insertBefore(u.dom,h),u.mount&&u.mount(this.view),this.resizeObserver&&this.resizeObserver.observe(u.dom),u}destroy(){var l,s,u;this.view.win.removeEventListener("resize",this.measureSoon);for(let h of this.manager.tooltipViews)h.dom.remove(),(l=h.destroy)===null||l===void 0||l.call(h);this.parent&&this.container.remove(),(s=this.resizeObserver)===null||s===void 0||s.disconnect(),(u=this.intersectionObserver)===null||u===void 0||u.disconnect(),clearTimeout(this.measureTimeout)}readMeasure(){let l=1,s=1,u=!1;if(this.position=="fixed"&&this.manager.tooltipViews.length){let{dom:w}=this.manager.tooltipViews[0];if(Ji.safari){let p=w.getBoundingClientRect();u=Math.abs(p.top+1e4)>1||Math.abs(p.left)>1}else u=!!w.offsetParent&&w.offsetParent!=this.container.ownerDocument.body}if(u||this.position=="absolute")if(this.parent){let w=this.parent.getBoundingClientRect();w.width&&w.height&&(l=w.width/this.parent.offsetWidth,s=w.height/this.parent.offsetHeight)}else({scaleX:l,scaleY:s}=this.view.viewState);let h=this.view.scrollDOM.getBoundingClientRect(),g=rAe(this.view);return{visible:{left:h.left+g.left,top:h.top+g.top,right:h.right-g.right,bottom:h.bottom-g.bottom},parent:this.parent?this.container.getBoundingClientRect():this.view.dom.getBoundingClientRect(),pos:this.manager.tooltips.map((w,p)=>{let k=this.manager.tooltipViews[p];return k.getCoords?k.getCoords(w.pos):this.view.coordsAtPos(w.pos)}),size:this.manager.tooltipViews.map(({dom:w})=>w.getBoundingClientRect()),space:this.view.state.facet($Ee).tooltipSpace(this.view),scaleX:l,scaleY:s,makeAbsolute:u}}writeMeasure(l){var s;if(l.makeAbsolute){this.madeAbsolute=!0,this.position="absolute";for(let k of this.manager.tooltipViews)k.dom.style.position="absolute"}let{visible:u,space:h,scaleX:g,scaleY:w}=l,p=[];for(let k=0;k<this.manager.tooltips.length;k++){let j=this.manager.tooltips[k],A=this.manager.tooltipViews[k],{dom:_}=A,D=l.pos[k],I=l.size[k];if(!D||j.clip!==!1&&(D.bottom<=Math.max(u.top,h.top)||D.top>=Math.min(u.bottom,h.bottom)||D.right<Math.max(u.left,h.left)-.1||D.left>Math.min(u.right,h.right)+.1)){_.style.top=nfe;continue}let B=j.arrow?A.dom.querySelector(".cm-tooltip-arrow"):null,F=B?7:0,U=I.right-I.left,K=(s=Jxt.get(A))!==null&&s!==void 0?s:I.bottom-I.top,Y=A.offset||Ogn,Z=this.view.textDirection==Yl.LTR,ee=I.width>h.right-h.left?Z?h.left:h.right-I.width:Z?Math.max(h.left,Math.min(D.left-(B?14:0)+Y.x,h.right-U)):Math.min(Math.max(h.left,D.left-U+(B?14:0)-Y.x),h.right-U),ce=this.above[k];!j.strictSide&&(ce?D.top-K-F-Y.y<h.top:D.bottom+K+F+Y.y>h.bottom)&&ce==h.bottom-D.bottom>D.top-h.top&&(ce=this.above[k]=!ce);let fe=(ce?D.top-h.top:h.bottom-D.bottom)-F;if(fe<K&&A.resize!==!1){if(fe<this.view.defaultLineHeight){_.style.top=nfe;continue}Jxt.set(A,K),_.style.height=(K=fe)/w+"px"}else _.style.height&&(_.style.height="");let be=ce?D.top-K-F-Y.y:D.bottom+F+Y.y,me=ee+U;if(A.overlap!==!0)for(let Re of p)Re.left<me&&Re.right>ee&&Re.top<be+K&&Re.bottom>be&&(be=ce?Re.top-K-2-F:Re.bottom+F+2);if(this.position=="absolute"?(_.style.top=(be-l.parent.top)/w+"px",Xxt(_,(ee-l.parent.left)/g)):(_.style.top=be/w+"px",Xxt(_,ee/g)),B){let Re=D.left+(Z?Y.x:-Y.x)-(ee+14-7);B.style.left=Re/g+"px"}A.overlap!==!0&&p.push({left:ee,top:be,right:me,bottom:be+K}),_.classList.toggle("cm-tooltip-above",ce),_.classList.toggle("cm-tooltip-below",!ce),A.positioned&&A.positioned(l.space)}}maybeMeasure(){if(this.manager.tooltips.length&&(this.view.inView&&this.view.requestMeasure(this.measureReq),this.inView!=this.view.inView&&(this.inView=this.view.inView,!this.inView)))for(let l of this.manager.tooltipViews)l.dom.style.top=nfe}},{eventObservers:{scroll(){this.maybeMeasure()}}});function Xxt(l,s){let u=parseInt(l.style.left,10);(isNaN(u)||Math.abs(s-u)>1)&&(l.style.left=s+"px")}const kgn=Bi.baseTheme({".cm-tooltip":{zIndex:500,boxSizing:"border-box"},"&light .cm-tooltip":{border:"1px solid #bbb",backgroundColor:"#f5f5f5"},"&light .cm-tooltip-section:not(:first-child)":{borderTop:"1px solid #bbb"},"&dark .cm-tooltip":{backgroundColor:"#333338",color:"white"},".cm-tooltip-arrow":{height:"7px",width:"14px",position:"absolute",zIndex:-1,overflow:"hidden","&:before, &:after":{content:"''",position:"absolute",width:0,height:0,borderLeft:"7px solid transparent",borderRight:"7px solid transparent"},".cm-tooltip-above &":{bottom:"-7px","&:before":{borderTop:"7px solid #bbb"},"&:after":{borderTop:"7px solid #f5f5f5",bottom:"1px"}},".cm-tooltip-below &":{top:"-7px","&:before":{borderBottom:"7px solid #bbb"},"&:after":{borderBottom:"7px solid #f5f5f5",top:"1px"}}},"&dark .cm-tooltip .cm-tooltip-arrow":{"&:before":{borderTopColor:"#333338",borderBottomColor:"#333338"},"&:after":{borderTopColor:"transparent",borderBottomColor:"transparent"}}}),Ogn={x:0,y:0},Uhe=Qi.define({enables:[lAe,kgn]}),ohe=Qi.define({combine:l=>l.reduce((s,u)=>s.concat(u),[])});class Jhe{static create(s){return new Jhe(s)}constructor(s){this.view=s,this.mounted=!1,this.dom=document.createElement("div"),this.dom.classList.add("cm-tooltip-hover"),this.manager=new POt(s,ohe,(u,h)=>this.createHostedView(u,h),u=>u.dom.remove())}createHostedView(s,u){let h=s.create(this.view);return h.dom.classList.add("cm-tooltip-section"),this.dom.insertBefore(h.dom,u?u.dom.nextSibling:this.dom.firstChild),this.mounted&&h.mount&&h.mount(this.view),h}mount(s){for(let u of this.manager.tooltipViews)u.mount&&u.mount(s);this.mounted=!0}positioned(s){for(let u of this.manager.tooltipViews)u.positioned&&u.positioned(s)}update(s){this.manager.update(s)}destroy(){var s;for(let u of this.manager.tooltipViews)(s=u.destroy)===null||s===void 0||s.call(u)}passProp(s){let u;for(let h of this.manager.tooltipViews){let g=h[s];if(g!==void 0){if(u===void 0)u=g;else if(u!==g)return}}return u}get offset(){return this.passProp("offset")}get getCoords(){return this.passProp("getCoords")}get overlap(){return this.passProp("overlap")}get resize(){return this.passProp("resize")}}const Sgn=Uhe.compute([ohe],l=>{let s=l.facet(ohe);return s.length===0?null:{pos:Math.min(...s.map(u=>u.pos)),end:Math.max(...s.map(u=>{var h;return(h=u.end)!==null&&h!==void 0?h:u.pos})),create:Jhe.create,above:s[0].above,arrow:s.some(u=>u.arrow)}});class jgn{constructor(s,u,h,g,w){this.view=s,this.source=u,this.field=h,this.setHover=g,this.hoverTime=w,this.hoverTimeout=-1,this.restartTimeout=-1,this.pending=null,this.lastMove={x:0,y:0,target:s.dom,time:0},this.checkHover=this.checkHover.bind(this),s.dom.addEventListener("mouseleave",this.mouseleave=this.mouseleave.bind(this)),s.dom.addEventListener("mousemove",this.mousemove=this.mousemove.bind(this))}update(){this.pending&&(this.pending=null,clearTimeout(this.restartTimeout),this.restartTimeout=setTimeout(()=>this.startHover(),20))}get active(){return this.view.state.field(this.field)}checkHover(){if(this.hoverTimeout=-1,this.active.length)return;let s=Date.now()-this.lastMove.time;s<this.hoverTime?this.hoverTimeout=setTimeout(this.checkHover,this.hoverTime-s):this.startHover()}startHover(){clearTimeout(this.restartTimeout);let{view:s,lastMove:u}=this,h=s.docView.tile.nearest(u.target);if(!h)return;let g,w=1;if(h.isWidget())g=h.posAtStart;else{if(g=s.posAtCoords(u),g==null)return;let k=s.coordsAtPos(g);if(!k||u.y<k.top||u.y>k.bottom||u.x<k.left-s.defaultCharacterWidth||u.x>k.right+s.defaultCharacterWidth)return;let j=s.bidiSpans(s.state.doc.lineAt(g)).find(_=>_.from<=g&&_.to>=g),A=j&&j.dir==Yl.RTL?-1:1;w=u.x<k.left?-A:A}let p=this.source(s,g,w);if(p!=null&&p.then){let k=this.pending={pos:g};p.then(j=>{this.pending==k&&(this.pending=null,j&&!(Array.isArray(j)&&!j.length)&&s.dispatch({effects:this.setHover.of(Array.isArray(j)?j:[j])}))},j=>kp(s.state,j,"hover tooltip"))}else p&&!(Array.isArray(p)&&!p.length)&&s.dispatch({effects:this.setHover.of(Array.isArray(p)?p:[p])})}get tooltip(){let s=this.view.plugin(lAe),u=s?s.manager.tooltips.findIndex(h=>h.create==Jhe.create):-1;return u>-1?s.manager.tooltipViews[u]:null}mousemove(s){var u,h;this.lastMove={x:s.clientX,y:s.clientY,target:s.target,time:Date.now()},this.hoverTimeout<0&&(this.hoverTimeout=setTimeout(this.checkHover,this.hoverTime));let{active:g,tooltip:w}=this;if(g.length&&w&&!Tgn(w.dom,s)||this.pending){let{pos:p}=g[0]||this.pending,k=(h=(u=g[0])===null||u===void 0?void 0:u.end)!==null&&h!==void 0?h:p;(p==k?this.view.posAtCoords(this.lastMove)!=p:!Egn(this.view,p,k,s.clientX,s.clientY))&&(this.view.dispatch({effects:this.setHover.of([])}),this.pending=null)}}mouseleave(s){clearTimeout(this.hoverTimeout),this.hoverTimeout=-1;let{active:u}=this;if(u.length){let{tooltip:h}=this;h&&h.dom.contains(s.relatedTarget)?this.watchTooltipLeave(h.dom):this.view.dispatch({effects:this.setHover.of([])})}}watchTooltipLeave(s){let u=h=>{s.removeEventListener("mouseleave",u),this.active.length&&!this.view.dom.contains(h.relatedTarget)&&this.view.dispatch({effects:this.setHover.of([])})};s.addEventListener("mouseleave",u)}destroy(){clearTimeout(this.hoverTimeout),clearTimeout(this.restartTimeout),this.view.dom.removeEventListener("mouseleave",this.mouseleave),this.view.dom.removeEventListener("mousemove",this.mousemove)}}const ife=4;function Tgn(l,s){let{left:u,right:h,top:g,bottom:w}=l.getBoundingClientRect(),p;if(p=l.querySelector(".cm-tooltip-arrow")){let k=p.getBoundingClientRect();g=Math.min(k.top,g),w=Math.max(k.bottom,w)}return s.clientX>=u-ife&&s.clientX<=h+ife&&s.clientY>=g-ife&&s.clientY<=w+ife}function Egn(l,s,u,h,g,w){let p=l.scrollDOM.getBoundingClientRect(),k=l.documentTop+l.documentPadding.top+l.contentHeight;if(p.left>h||p.right<h||p.top>g||Math.min(p.bottom,k)<g)return!1;let j=l.posAtCoords({x:h,y:g},!1);return j>=s&&j<=u}function Cgn(l,s={}){let u=Ds.define(),h=Td.define({create(){return[]},update(g,w){if(g.length&&(s.hideOnChange&&(w.docChanged||w.selection)?g=[]:s.hideOn&&(g=g.filter(p=>!s.hideOn(w,p))),w.docChanged)){let p=[];for(let k of g){let j=w.changes.mapPos(k.pos,-1,u1.TrackDel);if(j!=null){let A=Object.assign(Object.create(null),k);A.pos=j,A.end!=null&&(A.end=w.changes.mapPos(A.end)),p.push(A)}}g=p}for(let p of w.effects)p.is(u)&&(g=p.value),p.is(Mgn)&&(g=[]);return g},provide:g=>ohe.from(g)});return{active:h,extension:[h,Xh.define(g=>new jgn(g,l,h,u,s.hoverTime||300)),Sgn]}}function IOt(l,s){let u=l.plugin(lAe);if(!u)return null;let h=u.manager.tooltips.indexOf(s);return h<0?null:u.manager.tooltipViews[h]}const Mgn=Ds.define(),Vxt=Qi.define({combine(l){let s,u;for(let h of l)s=s||h.topContainer,u=u||h.bottomContainer;return{topContainer:s,bottomContainer:u}}});function ROt(l,s){let u=l.plugin($Ot),h=u?u.specs.indexOf(s):-1;return h>-1?u.panels[h]:null}const $Ot=Xh.fromClass(class{constructor(l){this.input=l.state.facet(lV),this.specs=this.input.filter(u=>u),this.panels=this.specs.map(u=>u(l));let s=l.state.facet(Vxt);this.top=new rfe(l,!0,s.topContainer),this.bottom=new rfe(l,!1,s.bottomContainer),this.top.sync(this.panels.filter(u=>u.top)),this.bottom.sync(this.panels.filter(u=>!u.top));for(let u of this.panels)u.dom.classList.add("cm-panel"),u.mount&&u.mount()}update(l){let s=l.state.facet(Vxt);this.top.container!=s.topContainer&&(this.top.sync([]),this.top=new rfe(l.view,!0,s.topContainer)),this.bottom.container!=s.bottomContainer&&(this.bottom.sync([]),this.bottom=new rfe(l.view,!1,s.bottomContainer)),this.top.syncClasses(),this.bottom.syncClasses();let u=l.state.facet(lV);if(u!=this.input){let h=u.filter(j=>j),g=[],w=[],p=[],k=[];for(let j of h){let A=this.specs.indexOf(j),_;A<0?(_=j(l.view),k.push(_)):(_=this.panels[A],_.update&&_.update(l)),g.push(_),(_.top?w:p).push(_)}this.specs=h,this.panels=g,this.top.sync(w),this.bottom.sync(p);for(let j of k)j.dom.classList.add("cm-panel"),j.mount&&j.mount()}else for(let h of this.panels)h.update&&h.update(l)}destroy(){this.top.sync([]),this.bottom.sync([])}},{provide:l=>Bi.scrollMargins.of(s=>{let u=s.plugin(l);return u&&{top:u.top.scrollMargin(),bottom:u.bottom.scrollMargin()}})});class rfe{constructor(s,u,h){this.view=s,this.top=u,this.container=h,this.dom=void 0,this.classes="",this.panels=[],this.syncClasses()}sync(s){for(let u of this.panels)u.destroy&&s.indexOf(u)<0&&u.destroy();this.panels=s,this.syncDOM()}syncDOM(){if(this.panels.length==0){this.dom&&(this.dom.remove(),this.dom=void 0);return}if(!this.dom){this.dom=document.createElement("div"),this.dom.className=this.top?"cm-panels cm-panels-top":"cm-panels cm-panels-bottom",this.dom.style[this.top?"top":"bottom"]="0";let u=this.container||this.view.dom;u.insertBefore(this.dom,this.top?u.firstChild:null)}let s=this.dom.firstChild;for(let u of this.panels)if(u.dom.parentNode==this.dom){for(;s!=u.dom;)s=Wxt(s);s=s.nextSibling}else this.dom.insertBefore(u.dom,s);for(;s;)s=Wxt(s)}scrollMargin(){return!this.dom||this.container?0:Math.max(0,this.top?this.dom.getBoundingClientRect().bottom-Math.max(0,this.view.scrollDOM.getBoundingClientRect().top):Math.min(innerHeight,this.view.scrollDOM.getBoundingClientRect().bottom)-this.dom.getBoundingClientRect().top)}syncClasses(){if(!(!this.container||this.classes==this.view.themeClasses)){for(let s of this.classes.split(" "))s&&this.container.classList.remove(s);for(let s of(this.classes=this.view.themeClasses).split(" "))s&&this.container.classList.add(s)}}}function Wxt(l){let s=l.nextSibling;return l.remove(),s}const lV=Qi.define({enables:$Ot});function Agn(l,s){let u,h=new Promise(p=>u=p),g=p=>Ngn(p,s,u);l.state.field(BEe,!1)?l.dispatch({effects:BOt.of(g)}):l.dispatch({effects:Ds.appendConfig.of(BEe.init(()=>[g]))});let w=zOt.of(g);return{close:w,result:h.then(p=>((l.win.queueMicrotask||(j=>l.win.setTimeout(j,10)))(()=>{l.state.field(BEe).indexOf(g)>-1&&l.dispatch({effects:w})}),p))}}const BEe=Td.define({create(){return[]},update(l,s){for(let u of s.effects)u.is(BOt)?l=[u.value].concat(l):u.is(zOt)&&(l=l.filter(h=>h!=u.value));return l},provide:l=>lV.computeN([l],s=>s.field(l))}),BOt=Ds.define(),zOt=Ds.define();function Ngn(l,s,u){let h=s.content?s.content(l,()=>p(null)):null;if(!h){if(h=$l("form"),s.input){let k=$l("input",s.input);/^(text|password|number|email|tel|url)$/.test(k.type)&&k.classList.add("cm-textfield"),k.name||(k.name="input"),h.appendChild($l("label",(s.label||"")+": ",k))}else h.appendChild(document.createTextNode(s.label||""));h.appendChild(document.createTextNode(" ")),h.appendChild($l("button",{class:"cm-button",type:"submit"},s.submitLabel||"OK"))}let g=h.nodeName=="FORM"?[h]:h.querySelectorAll("form");for(let k=0;k<g.length;k++){let j=g[k];j.addEventListener("keydown",A=>{A.keyCode==27?(A.preventDefault(),p(null)):A.keyCode==13&&(A.preventDefault(),p(j))}),j.addEventListener("submit",A=>{A.preventDefault(),p(j)})}let w=$l("div",h,$l("button",{onclick:()=>p(null),"aria-label":l.state.phrase("close"),class:"cm-dialog-close",type:"button"},["×"]));s.class&&(w.className=s.class),w.classList.add("cm-dialog");function p(k){w.contains(w.ownerDocument.activeElement)&&l.focus(),u(k)}return{dom:w,top:s.top,mount:()=>{if(s.focus){let k;typeof s.focus=="string"?k=h.querySelector(s.focus):k=h.querySelector("input")||h.querySelector("button"),k&&"select"in k?k.select():k&&"focus"in k&&k.focus()}}}}class K3 extends y8{compare(s){return this==s||this.constructor==s.constructor&&this.eq(s)}eq(s){return!1}destroy(s){}}K3.prototype.elementClass="";K3.prototype.toDOM=void 0;K3.prototype.mapMode=u1.TrackBefore;K3.prototype.startSide=K3.prototype.endSide=-1;K3.prototype.point=!0;const Mfe=Qi.define(),_gn=Qi.define(),Dgn={class:"",renderEmptyElements:!1,elementStyle:"",markers:()=>xo.empty,lineMarker:()=>null,widgetMarker:()=>null,lineMarkerChange:null,initialSpacer:null,updateSpacer:null,domEventHandlers:{},side:"before"},qX=Qi.define();function FOt(l){return[qOt(),qX.of({...Dgn,...l})]}const Kxt=Qi.define({combine:l=>l.some(s=>s)});function qOt(l){return[Lgn]}const Lgn=Xh.fromClass(class{constructor(l){this.view=l,this.domAfter=null,this.prevViewport=l.viewport,this.dom=document.createElement("div"),this.dom.className="cm-gutters cm-gutters-before",this.dom.setAttribute("aria-hidden","true"),this.dom.style.minHeight=this.view.contentHeight/this.view.scaleY+"px",this.gutters=l.state.facet(qX).map(s=>new Zxt(l,s)),this.fixed=!l.state.facet(Kxt);for(let s of this.gutters)s.config.side=="after"?this.getDOMAfter().appendChild(s.dom):this.dom.appendChild(s.dom);this.fixed&&(this.dom.style.position="sticky"),this.syncGutters(!1),l.scrollDOM.insertBefore(this.dom,l.contentDOM)}getDOMAfter(){return this.domAfter||(this.domAfter=document.createElement("div"),this.domAfter.className="cm-gutters cm-gutters-after",this.domAfter.setAttribute("aria-hidden","true"),this.domAfter.style.minHeight=this.view.contentHeight/this.view.scaleY+"px",this.domAfter.style.position=this.fixed?"sticky":"",this.view.scrollDOM.appendChild(this.domAfter)),this.domAfter}update(l){if(this.updateGutters(l)){let s=this.prevViewport,u=l.view.viewport,h=Math.min(s.to,u.to)-Math.max(s.from,u.from);this.syncGutters(h<(u.to-u.from)*.8)}if(l.geometryChanged){let s=this.view.contentHeight/this.view.scaleY+"px";this.dom.style.minHeight=s,this.domAfter&&(this.domAfter.style.minHeight=s)}this.view.state.facet(Kxt)!=!this.fixed&&(this.fixed=!this.fixed,this.dom.style.position=this.fixed?"sticky":"",this.domAfter&&(this.domAfter.style.position=this.fixed?"sticky":"")),this.prevViewport=l.view.viewport}syncGutters(l){let s=this.dom.nextSibling;l&&(this.dom.remove(),this.domAfter&&this.domAfter.remove());let u=xo.iter(this.view.state.facet(Mfe),this.view.viewport.from),h=[],g=this.gutters.map(w=>new Pgn(w,this.view.viewport,-this.view.documentPadding.top));for(let w of this.view.viewportLineBlocks)if(h.length&&(h=[]),Array.isArray(w.type)){let p=!0;for(let k of w.type)if(k.type==a1.Text&&p){cMe(u,h,k.from);for(let j of g)j.line(this.view,k,h);p=!1}else if(k.widget)for(let j of g)j.widget(this.view,k)}else if(w.type==a1.Text){cMe(u,h,w.from);for(let p of g)p.line(this.view,w,h)}else if(w.widget)for(let p of g)p.widget(this.view,w);for(let w of g)w.finish();l&&(this.view.scrollDOM.insertBefore(this.dom,s),this.domAfter&&this.view.scrollDOM.appendChild(this.domAfter))}updateGutters(l){let s=l.startState.facet(qX),u=l.state.facet(qX),h=l.docChanged||l.heightChanged||l.viewportChanged||!xo.eq(l.startState.facet(Mfe),l.state.facet(Mfe),l.view.viewport.from,l.view.viewport.to);if(s==u)for(let g of this.gutters)g.update(l)&&(h=!0);else{h=!0;let g=[];for(let w of u){let p=s.indexOf(w);p<0?g.push(new Zxt(this.view,w)):(this.gutters[p].update(l),g.push(this.gutters[p]))}for(let w of this.gutters)w.dom.remove(),g.indexOf(w)<0&&w.destroy();for(let w of g)w.config.side=="after"?this.getDOMAfter().appendChild(w.dom):this.dom.appendChild(w.dom);this.gutters=g}return h}destroy(){for(let l of this.gutters)l.destroy();this.dom.remove(),this.domAfter&&this.domAfter.remove()}},{provide:l=>Bi.scrollMargins.of(s=>{let u=s.plugin(l);if(!u||u.gutters.length==0||!u.fixed)return null;let h=u.dom.offsetWidth*s.scaleX,g=u.domAfter?u.domAfter.offsetWidth*s.scaleX:0;return s.textDirection==Yl.LTR?{left:h,right:g}:{right:h,left:g}})});function Yxt(l){return Array.isArray(l)?l:[l]}function cMe(l,s,u){for(;l.value&&l.from<=u;)l.from==u&&s.push(l.value),l.next()}class Pgn{constructor(s,u,h){this.gutter=s,this.height=h,this.i=0,this.cursor=xo.iter(s.markers,u.from)}addElement(s,u,h){let{gutter:g}=this,w=(u.top-this.height)/s.scaleY,p=u.height/s.scaleY;if(this.i==g.elements.length){let k=new HOt(s,p,w,h);g.elements.push(k),g.dom.appendChild(k.dom)}else g.elements[this.i].update(s,p,w,h);this.height=u.bottom,this.i++}line(s,u,h){let g=[];cMe(this.cursor,g,u.from),h.length&&(g=g.concat(h));let w=this.gutter.config.lineMarker(s,u,g);w&&g.unshift(w);let p=this.gutter;g.length==0&&!p.config.renderEmptyElements||this.addElement(s,u,g)}widget(s,u){let h=this.gutter.config.widgetMarker(s,u.widget,u),g=h?[h]:null;for(let w of s.state.facet(_gn)){let p=w(s,u.widget,u);p&&(g||(g=[])).push(p)}g&&this.addElement(s,u,g)}finish(){let s=this.gutter;for(;s.elements.length>this.i;){let u=s.elements.pop();s.dom.removeChild(u.dom),u.destroy()}}}class Zxt{constructor(s,u){this.view=s,this.config=u,this.elements=[],this.spacer=null,this.dom=document.createElement("div"),this.dom.className="cm-gutter"+(this.config.class?" "+this.config.class:"");for(let h in u.domEventHandlers)this.dom.addEventListener(h,g=>{let w=g.target,p;if(w!=this.dom&&this.dom.contains(w)){for(;w.parentNode!=this.dom;)w=w.parentNode;let j=w.getBoundingClientRect();p=(j.top+j.bottom)/2}else p=g.clientY;let k=s.lineBlockAtHeight(p-s.documentTop);u.domEventHandlers[h](s,k,g)&&g.preventDefault()});this.markers=Yxt(u.markers(s)),u.initialSpacer&&(this.spacer=new HOt(s,0,0,[u.initialSpacer(s)]),this.dom.appendChild(this.spacer.dom),this.spacer.dom.style.cssText+="visibility: hidden; pointer-events: none")}update(s){let u=this.markers;if(this.markers=Yxt(this.config.markers(s.view)),this.spacer&&this.config.updateSpacer){let g=this.config.updateSpacer(this.spacer.markers[0],s);g!=this.spacer.markers[0]&&this.spacer.update(s.view,0,0,[g])}let h=s.view.viewport;return!xo.eq(this.markers,u,h.from,h.to)||(this.config.lineMarkerChange?this.config.lineMarkerChange(s):!1)}destroy(){for(let s of this.elements)s.destroy()}}class HOt{constructor(s,u,h,g){this.height=-1,this.above=0,this.markers=[],this.dom=document.createElement("div"),this.dom.className="cm-gutterElement",this.update(s,u,h,g)}update(s,u,h,g){this.height!=u&&(this.height=u,this.dom.style.height=u+"px"),this.above!=h&&(this.dom.style.marginTop=(this.above=h)?h+"px":""),Ign(this.markers,g)||this.setMarkers(s,g)}setMarkers(s,u){let h="cm-gutterElement",g=this.dom.firstChild;for(let w=0,p=0;;){let k=p,j=w<u.length?u[w++]:null,A=!1;if(j){let _=j.elementClass;_&&(h+=" "+_);for(let D=p;D<this.markers.length;D++)if(this.markers[D].compare(j)){k=D,A=!0;break}}else k=this.markers.length;for(;p<k;){let _=this.markers[p++];if(_.toDOM){_.destroy(g);let D=g.nextSibling;g.remove(),g=D}}if(!j)break;j.toDOM&&(A?g=g.nextSibling:this.dom.insertBefore(j.toDOM(s),g)),A&&p++}this.dom.className=h,this.markers=u}destroy(){this.setMarkers(null,[])}}function Ign(l,s){if(l.length!=s.length)return!1;for(let u=0;u<l.length;u++)if(!l[u].compare(s[u]))return!1;return!0}const Rgn=Qi.define(),$gn=Qi.define(),fI=Qi.define({combine(l){return Z3(l,{formatNumber:String,domEventHandlers:{}},{domEventHandlers(s,u){let h=Object.assign({},s);for(let g in u){let w=h[g],p=u[g];h[g]=w?(k,j,A)=>w(k,j,A)||p(k,j,A):p}return h}})}});class zEe extends K3{constructor(s){super(),this.number=s}eq(s){return this.number==s.number}toDOM(){return document.createTextNode(this.number)}}function FEe(l,s){return l.state.facet(fI).formatNumber(s,l.state)}const Bgn=qX.compute([fI],l=>({class:"cm-lineNumbers",renderEmptyElements:!1,markers(s){return s.state.facet(Rgn)},lineMarker(s,u,h){return h.some(g=>g.toDOM)?null:new zEe(FEe(s,s.state.doc.lineAt(u.from).number))},widgetMarker:(s,u,h)=>{for(let g of s.state.facet($gn)){let w=g(s,u,h);if(w)return w}return null},lineMarkerChange:s=>s.startState.facet(fI)!=s.state.facet(fI),initialSpacer(s){return new zEe(FEe(s,e3t(s.state.doc.lines)))},updateSpacer(s,u){let h=FEe(u.view,e3t(u.view.state.doc.lines));return h==s.number?s:new zEe(h)},domEventHandlers:l.facet(fI).domEventHandlers,side:"before"}));function zgn(l={}){return[fI.of(l),qOt(),Bgn]}function e3t(l){let s=9;for(;s<l;)s=s*10+9;return s}const Fgn=new class extends K3{constructor(){super(...arguments),this.elementClass="cm-activeLineGutter"}},qgn=Mfe.compute(["selection"],l=>{let s=[],u=-1;for(let h of l.selection.ranges){let g=l.doc.lineAt(h.head).from;g>u&&(u=g,s.push(Fgn.range(g)))}return xo.of(s)});function Hgn(){return qgn}const QOt=1024;let Qgn=0;class qEe{constructor(s,u){this.from=s,this.to=u}}class Eo{constructor(s={}){this.id=Qgn++,this.perNode=!!s.perNode,this.deserialize=s.deserialize||(()=>{throw new Error("This node type doesn't define a deserialize function")}),this.combine=s.combine||null}add(s){if(this.perNode)throw new RangeError("Can't add per-node props to node types");return typeof s!="function"&&(s=Ep.match(s)),u=>{let h=s(u);return h===void 0?null:[this,h]}}}Eo.closedBy=new Eo({deserialize:l=>l.split(" ")});Eo.openedBy=new Eo({deserialize:l=>l.split(" ")});Eo.group=new Eo({deserialize:l=>l.split(" ")});Eo.isolate=new Eo({deserialize:l=>{if(l&&l!="rtl"&&l!="ltr"&&l!="auto")throw new RangeError("Invalid value for isolate: "+l);return l||"auto"}});Eo.contextHash=new Eo({perNode:!0});Eo.lookAhead=new Eo({perNode:!0});Eo.mounted=new Eo({perNode:!0});class HX{constructor(s,u,h,g=!1){this.tree=s,this.overlay=u,this.parser=h,this.bracketed=g}static get(s){return s&&s.props&&s.props[Eo.mounted.id]}}const Ggn=Object.create(null);class Ep{constructor(s,u,h,g=0){this.name=s,this.props=u,this.id=h,this.flags=g}static define(s){let u=s.props&&s.props.length?Object.create(null):Ggn,h=(s.top?1:0)|(s.skipped?2:0)|(s.error?4:0)|(s.name==null?8:0),g=new Ep(s.name||"",u,s.id,h);if(s.props){for(let w of s.props)if(Array.isArray(w)||(w=w(g)),w){if(w[0].perNode)throw new RangeError("Can't store a per-node prop on a node type");u[w[0].id]=w[1]}}return g}prop(s){return this.props[s.id]}get isTop(){return(this.flags&1)>0}get isSkipped(){return(this.flags&2)>0}get isError(){return(this.flags&4)>0}get isAnonymous(){return(this.flags&8)>0}is(s){if(typeof s=="string"){if(this.name==s)return!0;let u=this.prop(Eo.group);return u?u.indexOf(s)>-1:!1}return this.id==s}static match(s){let u=Object.create(null);for(let h in s)for(let g of h.split(" "))u[g]=s[h];return h=>{for(let g=h.prop(Eo.group),w=-1;w<(g?g.length:0);w++){let p=u[w<0?h.name:g[w]];if(p)return p}}}}Ep.none=new Ep("",Object.create(null),0,8);class uAe{constructor(s){this.types=s;for(let u=0;u<s.length;u++)if(s[u].id!=u)throw new RangeError("Node type ids should correspond to array positions when creating a node set")}extend(...s){let u=[];for(let h of this.types){let g=null;for(let w of s){let p=w(h);if(p){g||(g=Object.assign({},h.props));let k=p[1],j=p[0];j.combine&&j.id in g&&(k=j.combine(g[j.id],k)),g[j.id]=k}}u.push(g?new Ep(h.name,g,h.id,h.flags):h)}return new uAe(u)}}const sfe=new WeakMap,t3t=new WeakMap;var La;(function(l){l[l.ExcludeBuffers=1]="ExcludeBuffers",l[l.IncludeAnonymous=2]="IncludeAnonymous",l[l.IgnoreMounts=4]="IgnoreMounts",l[l.IgnoreOverlays=8]="IgnoreOverlays",l[l.EnterBracketed=16]="EnterBracketed"})(La||(La={}));class Bf{constructor(s,u,h,g,w){if(this.type=s,this.children=u,this.positions=h,this.length=g,this.props=null,w&&w.length){this.props=Object.create(null);for(let[p,k]of w)this.props[typeof p=="number"?p:p.id]=k}}toString(){let s=HX.get(this);if(s&&!s.overlay)return s.tree.toString();let u="";for(let h of this.children){let g=h.toString();g&&(u&&(u+=","),u+=g)}return this.type.name?(/\W/.test(this.type.name)&&!this.type.isError?JSON.stringify(this.type.name):this.type.name)+(u.length?"("+u+")":""):u}cursor(s=0){return new uMe(this.topNode,s)}cursorAt(s,u=0,h=0){let g=sfe.get(this)||this.topNode,w=new uMe(g);return w.moveTo(s,u),sfe.set(this,w._tree),w}get topNode(){return new Sp(this,0,0,null)}resolve(s,u=0){let h=uV(sfe.get(this)||this.topNode,s,u,!1);return sfe.set(this,h),h}resolveInner(s,u=0){let h=uV(t3t.get(this)||this.topNode,s,u,!0);return t3t.set(this,h),h}resolveStack(s,u=0){return Xgn(this,s,u)}iterate(s){let{enter:u,leave:h,from:g=0,to:w=this.length}=s,p=s.mode||0,k=(p&La.IncludeAnonymous)>0;for(let j=this.cursor(p|La.IncludeAnonymous);;){let A=!1;if(j.from<=w&&j.to>=g&&(!k&&j.type.isAnonymous||u(j)!==!1)){if(j.firstChild())continue;A=!0}for(;A&&h&&(k||!j.type.isAnonymous)&&h(j),!j.nextSibling();){if(!j.parent())return;A=!0}}}prop(s){return s.perNode?this.props?this.props[s.id]:void 0:this.type.prop(s)}get propValues(){let s=[];if(this.props)for(let u in this.props)s.push([+u,this.props[u]]);return s}balance(s={}){return this.children.length<=8?this:hAe(Ep.none,this.children,this.positions,0,this.children.length,0,this.length,(u,h,g)=>new Bf(this.type,u,h,g,this.propValues),s.makeTree||((u,h,g)=>new Bf(Ep.none,u,h,g)))}static build(s){return Vgn(s)}}Bf.empty=new Bf(Ep.none,[],[],0);class aAe{constructor(s,u){this.buffer=s,this.index=u}get id(){return this.buffer[this.index-4]}get start(){return this.buffer[this.index-3]}get end(){return this.buffer[this.index-2]}get size(){return this.buffer[this.index-1]}get pos(){return this.index}next(){this.index-=4}fork(){return new aAe(this.buffer,this.index)}}class j8{constructor(s,u,h){this.buffer=s,this.length=u,this.set=h}get type(){return Ep.none}toString(){let s=[];for(let u=0;u<this.buffer.length;)s.push(this.childString(u)),u=this.buffer[u+3];return s.join(",")}childString(s){let u=this.buffer[s],h=this.buffer[s+3],g=this.set.types[u],w=g.name;if(/\W/.test(w)&&!g.isError&&(w=JSON.stringify(w)),s+=4,h==s)return w;let p=[];for(;s<h;)p.push(this.childString(s)),s=this.buffer[s+3];return w+"("+p.join(",")+")"}findChild(s,u,h,g,w){let{buffer:p}=this,k=-1;for(let j=s;j!=u&&!(GOt(w,g,p[j+1],p[j+2])&&(k=j,h>0));j=p[j+3]);return k}slice(s,u,h){let g=this.buffer,w=new Uint16Array(u-s),p=0;for(let k=s,j=0;k<u;){w[j++]=g[k++],w[j++]=g[k++]-h;let A=w[j++]=g[k++]-h;w[j++]=g[k++]-s,p=Math.max(p,A)}return new j8(w,p,this.set)}}function GOt(l,s,u,h){switch(l){case-2:return u<s;case-1:return h>=s&&u<s;case 0:return u<s&&h>s;case 1:return u<=s&&h>s;case 2:return h>s;case 4:return!0}}function uV(l,s,u,h){for(var g;l.from==l.to||(u<1?l.from>=s:l.from>s)||(u>-1?l.to<=s:l.to<s);){let p=!h&&l instanceof Sp&&l.index<0?null:l.parent;if(!p)return l;l=p}let w=h?0:La.IgnoreOverlays;if(h)for(let p=l,k=p.parent;k;p=k,k=p.parent)p instanceof Sp&&p.index<0&&((g=k.enter(s,u,w))===null||g===void 0?void 0:g.from)!=p.from&&(l=k);for(;;){let p=l.enter(s,u,w);if(!p)return l;l=p}}class UOt{cursor(s=0){return new uMe(this,s)}getChild(s,u=null,h=null){let g=n3t(this,s,u,h);return g.length?g[0]:null}getChildren(s,u=null,h=null){return n3t(this,s,u,h)}resolve(s,u=0){return uV(this,s,u,!1)}resolveInner(s,u=0){return uV(this,s,u,!0)}matchContext(s){return lMe(this.parent,s)}enterUnfinishedNodesBefore(s){let u=this.childBefore(s),h=this;for(;u;){let g=u.lastChild;if(!g||g.to!=u.to)break;g.type.isError&&g.from==g.to?(h=u,u=g.prevSibling):u=g}return h}get node(){return this}get next(){return this.parent}}class Sp extends UOt{constructor(s,u,h,g){super(),this._tree=s,this.from=u,this.index=h,this._parent=g}get type(){return this._tree.type}get name(){return this._tree.type.name}get to(){return this.from+this._tree.length}nextChild(s,u,h,g,w=0){for(let p=this;;){for(let{children:k,positions:j}=p._tree,A=u>0?k.length:-1;s!=A;s+=u){let _=k[s],D=j[s]+p.from,I;if(!(!(w&La.EnterBracketed&&_ instanceof Bf&&(I=HX.get(_))&&!I.overlay&&I.bracketed&&h>=D&&h<=D+_.length)&&!GOt(g,h,D,D+_.length))){if(_ instanceof j8){if(w&La.ExcludeBuffers)continue;let B=_.findChild(0,_.buffer.length,u,h-D,g);if(B>-1)return new G3(new Ugn(p,_,s,D),null,B)}else if(w&La.IncludeAnonymous||!_.type.isAnonymous||fAe(_)){let B;if(!(w&La.IgnoreMounts)&&(B=HX.get(_))&&!B.overlay)return new Sp(B.tree,D,s,p);let F=new Sp(_,D,s,p);return w&La.IncludeAnonymous||!F.type.isAnonymous?F:F.nextChild(u<0?_.children.length-1:0,u,h,g,w)}}}if(w&La.IncludeAnonymous||!p.type.isAnonymous||(p.index>=0?s=p.index+u:s=u<0?-1:p._parent._tree.children.length,p=p._parent,!p))return null}}get firstChild(){return this.nextChild(0,1,0,4)}get lastChild(){return this.nextChild(this._tree.children.length-1,-1,0,4)}childAfter(s){return this.nextChild(0,1,s,2)}childBefore(s){return this.nextChild(this._tree.children.length-1,-1,s,-2)}prop(s){return this._tree.prop(s)}enter(s,u,h=0){let g;if(!(h&La.IgnoreOverlays)&&(g=HX.get(this._tree))&&g.overlay){let w=s-this.from,p=h&La.EnterBracketed&&g.bracketed;for(let{from:k,to:j}of g.overlay)if((u>0||p?k<=w:k<w)&&(u<0||p?j>=w:j>w))return new Sp(g.tree,g.overlay[0].from+this.from,-1,this)}return this.nextChild(0,1,s,u,h)}nextSignificantParent(){let s=this;for(;s.type.isAnonymous&&s._parent;)s=s._parent;return s}get parent(){return this._parent?this._parent.nextSignificantParent():null}get nextSibling(){return this._parent&&this.index>=0?this._parent.nextChild(this.index+1,1,0,4):null}get prevSibling(){return this._parent&&this.index>=0?this._parent.nextChild(this.index-1,-1,0,4):null}get tree(){return this._tree}toTree(){return this._tree}toString(){return this._tree.toString()}}function n3t(l,s,u,h){let g=l.cursor(),w=[];if(!g.firstChild())return w;if(u!=null){for(let p=!1;!p;)if(p=g.type.is(u),!g.nextSibling())return w}for(;;){if(h!=null&&g.type.is(h))return w;if(g.type.is(s)&&w.push(g.node),!g.nextSibling())return h==null?w:[]}}function lMe(l,s,u=s.length-1){for(let h=l;u>=0;h=h.parent){if(!h)return!1;if(!h.type.isAnonymous){if(s[u]&&s[u]!=h.name)return!1;u--}}return!0}class Ugn{constructor(s,u,h,g){this.parent=s,this.buffer=u,this.index=h,this.start=g}}class G3 extends UOt{get name(){return this.type.name}get from(){return this.context.start+this.context.buffer.buffer[this.index+1]}get to(){return this.context.start+this.context.buffer.buffer[this.index+2]}constructor(s,u,h){super(),this.context=s,this._parent=u,this.index=h,this.type=s.buffer.set.types[s.buffer.buffer[h]]}child(s,u,h){let{buffer:g}=this.context,w=g.findChild(this.index+4,g.buffer[this.index+3],s,u-this.context.start,h);return w<0?null:new G3(this.context,this,w)}get firstChild(){return this.child(1,0,4)}get lastChild(){return this.child(-1,0,4)}childAfter(s){return this.child(1,s,2)}childBefore(s){return this.child(-1,s,-2)}prop(s){return this.type.prop(s)}enter(s,u,h=0){if(h&La.ExcludeBuffers)return null;let{buffer:g}=this.context,w=g.findChild(this.index+4,g.buffer[this.index+3],u>0?1:-1,s-this.context.start,u);return w<0?null:new G3(this.context,this,w)}get parent(){return this._parent||this.context.parent.nextSignificantParent()}externalSibling(s){return this._parent?null:this.context.parent.nextChild(this.context.index+s,s,0,4)}get nextSibling(){let{buffer:s}=this.context,u=s.buffer[this.index+3];return u<(this._parent?s.buffer[this._parent.index+3]:s.buffer.length)?new G3(this.context,this._parent,u):this.externalSibling(1)}get prevSibling(){let{buffer:s}=this.context,u=this._parent?this._parent.index+4:0;return this.index==u?this.externalSibling(-1):new G3(this.context,this._parent,s.findChild(u,this.index,-1,0,4))}get tree(){return null}toTree(){let s=[],u=[],{buffer:h}=this.context,g=this.index+4,w=h.buffer[this.index+3];if(w>g){let p=h.buffer[this.index+1];s.push(h.slice(g,w,p)),u.push(0)}return new Bf(this.type,s,u,this.to-this.from)}toString(){return this.context.buffer.childString(this.index)}}function JOt(l){if(!l.length)return null;let s=0,u=l[0];for(let w=1;w<l.length;w++){let p=l[w];(p.from>u.from||p.to<u.to)&&(u=p,s=w)}let h=u instanceof Sp&&u.index<0?null:u.parent,g=l.slice();return h?g[s]=h:g.splice(s,1),new Jgn(g,u)}class Jgn{constructor(s,u){this.heads=s,this.node=u}get next(){return JOt(this.heads)}}function Xgn(l,s,u){let h=l.resolveInner(s,u),g=null;for(let w=h instanceof Sp?h:h.context.parent;w;w=w.parent)if(w.index<0){let p=w.parent;(g||(g=[h])).push(p.resolve(s,u)),w=p}else{let p=HX.get(w.tree);if(p&&p.overlay&&p.overlay[0].from<=s&&p.overlay[p.overlay.length-1].to>=s){let k=new Sp(p.tree,p.overlay[0].from+w.from,-1,w);(g||(g=[h])).push(uV(k,s,u,!1))}}return g?JOt(g):h}class uMe{get name(){return this.type.name}constructor(s,u=0){if(this.buffer=null,this.stack=[],this.index=0,this.bufferNode=null,this.mode=u&~La.EnterBracketed,s instanceof Sp)this.yieldNode(s);else{this._tree=s.context.parent,this.buffer=s.context;for(let h=s._parent;h;h=h._parent)this.stack.unshift(h.index);this.bufferNode=s,this.yieldBuf(s.index)}}yieldNode(s){return s?(this._tree=s,this.type=s.type,this.from=s.from,this.to=s.to,!0):!1}yieldBuf(s,u){this.index=s;let{start:h,buffer:g}=this.buffer;return this.type=u||g.set.types[g.buffer[s]],this.from=h+g.buffer[s+1],this.to=h+g.buffer[s+2],!0}yield(s){return s?s instanceof Sp?(this.buffer=null,this.yieldNode(s)):(this.buffer=s.context,this.yieldBuf(s.index,s.type)):!1}toString(){return this.buffer?this.buffer.buffer.childString(this.index):this._tree.toString()}enterChild(s,u,h){if(!this.buffer)return this.yield(this._tree.nextChild(s<0?this._tree._tree.children.length-1:0,s,u,h,this.mode));let{buffer:g}=this.buffer,w=g.findChild(this.index+4,g.buffer[this.index+3],s,u-this.buffer.start,h);return w<0?!1:(this.stack.push(this.index),this.yieldBuf(w))}firstChild(){return this.enterChild(1,0,4)}lastChild(){return this.enterChild(-1,0,4)}childAfter(s){return this.enterChild(1,s,2)}childBefore(s){return this.enterChild(-1,s,-2)}enter(s,u,h=this.mode){return this.buffer?h&La.ExcludeBuffers?!1:this.enterChild(1,s,u):this.yield(this._tree.enter(s,u,h))}parent(){if(!this.buffer)return this.yieldNode(this.mode&La.IncludeAnonymous?this._tree._parent:this._tree.parent);if(this.stack.length)return this.yieldBuf(this.stack.pop());let s=this.mode&La.IncludeAnonymous?this.buffer.parent:this.buffer.parent.nextSignificantParent();return this.buffer=null,this.yieldNode(s)}sibling(s){if(!this.buffer)return this._tree._parent?this.yield(this._tree.index<0?null:this._tree._parent.nextChild(this._tree.index+s,s,0,4,this.mode)):!1;let{buffer:u}=this.buffer,h=this.stack.length-1;if(s<0){let g=h<0?0:this.stack[h]+4;if(this.index!=g)return this.yieldBuf(u.findChild(g,this.index,-1,0,4))}else{let g=u.buffer[this.index+3];if(g<(h<0?u.buffer.length:u.buffer[this.stack[h]+3]))return this.yieldBuf(g)}return h<0?this.yield(this.buffer.parent.nextChild(this.buffer.index+s,s,0,4,this.mode)):!1}nextSibling(){return this.sibling(1)}prevSibling(){return this.sibling(-1)}atLastNode(s){let u,h,{buffer:g}=this;if(g){if(s>0){if(this.index<g.buffer.buffer.length)return!1}else for(let w=0;w<this.index;w++)if(g.buffer.buffer[w+3]<this.index)return!1;({index:u,parent:h}=g)}else({index:u,_parent:h}=this._tree);for(;h;{index:u,_parent:h}=h)if(u>-1)for(let w=u+s,p=s<0?-1:h._tree.children.length;w!=p;w+=s){let k=h._tree.children[w];if(this.mode&La.IncludeAnonymous||k instanceof j8||!k.type.isAnonymous||fAe(k))return!1}return!0}move(s,u){if(u&&this.enterChild(s,0,4))return!0;for(;;){if(this.sibling(s))return!0;if(this.atLastNode(s)||!this.parent())return!1}}next(s=!0){return this.move(1,s)}prev(s=!0){return this.move(-1,s)}moveTo(s,u=0){for(;(this.from==this.to||(u<1?this.from>=s:this.from>s)||(u>-1?this.to<=s:this.to<s))&&this.parent(););for(;this.enterChild(1,s,u););return this}get node(){if(!this.buffer)return this._tree;let s=this.bufferNode,u=null,h=0;if(s&&s.context==this.buffer)e:for(let g=this.index,w=this.stack.length;w>=0;){for(let p=s;p;p=p._parent)if(p.index==g){if(g==this.index)return p;u=p,h=w+1;break e}g=this.stack[--w]}for(let g=h;g<this.stack.length;g++)u=new G3(this.buffer,u,this.stack[g]);return this.bufferNode=new G3(this.buffer,u,this.index)}get tree(){return this.buffer?null:this._tree._tree}iterate(s,u){for(let h=0;;){let g=!1;if(this.type.isAnonymous||s(this)!==!1){if(this.firstChild()){h++;continue}this.type.isAnonymous||(g=!0)}for(;;){if(g&&u&&u(this),g=this.type.isAnonymous,!h)return;if(this.nextSibling())break;this.parent(),h--,g=!0}}}matchContext(s){if(!this.buffer)return lMe(this.node.parent,s);let{buffer:u}=this.buffer,{types:h}=u.set;for(let g=s.length-1,w=this.stack.length-1;g>=0;w--){if(w<0)return lMe(this._tree,s,g);let p=h[u.buffer[this.stack[w]]];if(!p.isAnonymous){if(s[g]&&s[g]!=p.name)return!1;g--}}return!0}}function fAe(l){return l.children.some(s=>s instanceof j8||!s.type.isAnonymous||fAe(s))}function Vgn(l){var s;let{buffer:u,nodeSet:h,maxBufferLength:g=QOt,reused:w=[],minRepeatType:p=h.types.length}=l,k=Array.isArray(u)?new aAe(u,u.length):u,j=h.types,A=0,_=0;function D(fe,be,me,Re,Te,Ke){let{id:ze,start:je,end:te,size:ge}=k,He=_,ae=A;if(ge<0)if(k.next(),ge==-1){let Ae=w[ze];me.push(Ae),Re.push(je-fe);return}else if(ge==-3){A=ze;return}else if(ge==-4){_=ze;return}else throw new RangeError(`Unrecognized record size: ${ge}`);let Le=j[ze],Oe,Qe,kt=je-fe;if(te-je<=g&&(Qe=K(k.pos-be,Te))){let Ae=new Uint16Array(Qe.size-Qe.skip),Ye=k.pos-Qe.size,mt=Ae.length;for(;k.pos>Ye;)mt=Y(Qe.start,Ae,mt);Oe=new j8(Ae,te-Qe.start,h),kt=Qe.start-fe}else{let Ae=k.pos-ge;k.next();let Ye=[],mt=[],Ue=ze>=p?ze:-1,Pt=0,rn=te;for(;k.pos>Ae;)Ue>=0&&k.id==Ue&&k.size>=0?(k.end<=rn-g&&(F(Ye,mt,je,Pt,k.end,rn,Ue,He,ae),Pt=Ye.length,rn=k.end),k.next()):Ke>2500?I(je,Ae,Ye,mt):D(je,Ae,Ye,mt,Ue,Ke+1);if(Ue>=0&&Pt>0&&Pt<Ye.length&&F(Ye,mt,je,Pt,je,rn,Ue,He,ae),Ye.reverse(),mt.reverse(),Ue>-1&&Pt>0){let Cn=B(Le,ae);Oe=hAe(Le,Ye,mt,0,Ye.length,0,te-je,Cn,Cn)}else Oe=U(Le,Ye,mt,te-je,He-te,ae)}me.push(Oe),Re.push(kt)}function I(fe,be,me,Re){let Te=[],Ke=0,ze=-1;for(;k.pos>be;){let{id:je,start:te,end:ge,size:He}=k;if(He>4)k.next();else{if(ze>-1&&te<ze)break;ze<0&&(ze=ge-g),Te.push(je,te,ge),Ke++,k.next()}}if(Ke){let je=new Uint16Array(Ke*4),te=Te[Te.length-2];for(let ge=Te.length-3,He=0;ge>=0;ge-=3)je[He++]=Te[ge],je[He++]=Te[ge+1]-te,je[He++]=Te[ge+2]-te,je[He++]=He;me.push(new j8(je,Te[2]-te,h)),Re.push(te-fe)}}function B(fe,be){return(me,Re,Te)=>{let Ke=0,ze=me.length-1,je,te;if(ze>=0&&(je=me[ze])instanceof Bf){if(!ze&&je.type==fe&&je.length==Te)return je;(te=je.prop(Eo.lookAhead))&&(Ke=Re[ze]+je.length+te)}return U(fe,me,Re,Te,Ke,be)}}function F(fe,be,me,Re,Te,Ke,ze,je,te){let ge=[],He=[];for(;fe.length>Re;)ge.push(fe.pop()),He.push(be.pop()+me-Te);fe.push(U(h.types[ze],ge,He,Ke-Te,je-Ke,te)),be.push(Te-me)}function U(fe,be,me,Re,Te,Ke,ze){if(Ke){let je=[Eo.contextHash,Ke];ze=ze?[je].concat(ze):[je]}if(Te>25){let je=[Eo.lookAhead,Te];ze=ze?[je].concat(ze):[je]}return new Bf(fe,be,me,Re,ze)}function K(fe,be){let me=k.fork(),Re=0,Te=0,Ke=0,ze=me.end-g,je={size:0,start:0,skip:0};e:for(let te=me.pos-fe;me.pos>te;){let ge=me.size;if(me.id==be&&ge>=0){je.size=Re,je.start=Te,je.skip=Ke,Ke+=4,Re+=4,me.next();continue}let He=me.pos-ge;if(ge<0||He<te||me.start<ze)break;let ae=me.id>=p?4:0,Le=me.start;for(me.next();me.pos>He;){if(me.size<0)if(me.size==-3||me.size==-4)ae+=4;else break e;else me.id>=p&&(ae+=4);me.next()}Te=Le,Re+=ge,Ke+=ae}return(be<0||Re==fe)&&(je.size=Re,je.start=Te,je.skip=Ke),je.size>4?je:void 0}function Y(fe,be,me){let{id:Re,start:Te,end:Ke,size:ze}=k;if(k.next(),ze>=0&&Re<p){let je=me;if(ze>4){let te=k.pos-(ze-4);for(;k.pos>te;)me=Y(fe,be,me)}be[--me]=je,be[--me]=Ke-fe,be[--me]=Te-fe,be[--me]=Re}else ze==-3?A=Re:ze==-4&&(_=Re);return me}let Z=[],ee=[];for(;k.pos>0;)D(l.start||0,l.bufferStart||0,Z,ee,-1,0);let ce=(s=l.length)!==null&&s!==void 0?s:Z.length?ee[0]+Z[0].length:0;return new Bf(j[l.topID],Z.reverse(),ee.reverse(),ce)}const i3t=new WeakMap;function Afe(l,s){if(!l.isAnonymous||s instanceof j8||s.type!=l)return 1;let u=i3t.get(s);if(u==null){u=1;for(let h of s.children){if(h.type!=l||!(h instanceof Bf)){u=1;break}u+=Afe(l,h)}i3t.set(s,u)}return u}function hAe(l,s,u,h,g,w,p,k,j){let A=0;for(let F=h;F<g;F++)A+=Afe(l,s[F]);let _=Math.ceil(A*1.5/8),D=[],I=[];function B(F,U,K,Y,Z){for(let ee=K;ee<Y;){let ce=ee,fe=U[ee],be=Afe(l,F[ee]);for(ee++;ee<Y;ee++){let me=Afe(l,F[ee]);if(be+me>=_)break;be+=me}if(ee==ce+1){if(be>_){let me=F[ce];B(me.children,me.positions,0,me.children.length,U[ce]+Z);continue}D.push(F[ce])}else{let me=U[ee-1]+F[ee-1].length-fe;D.push(hAe(l,F,U,ce,ee,fe,me,null,j))}I.push(fe+Z-w)}}return B(s,u,h,g,0),(k||j)(D,I,p)}class Wgn{constructor(){this.map=new WeakMap}setBuffer(s,u,h){let g=this.map.get(s);g||this.map.set(s,g=new Map),g.set(u,h)}getBuffer(s,u){let h=this.map.get(s);return h&&h.get(u)}set(s,u){s instanceof G3?this.setBuffer(s.context.buffer,s.index,u):s instanceof Sp&&this.map.set(s.tree,u)}get(s){return s instanceof G3?this.getBuffer(s.context.buffer,s.index):s instanceof Sp?this.map.get(s.tree):void 0}cursorSet(s,u){s.buffer?this.setBuffer(s.buffer.buffer,s.index,u):this.map.set(s.tree,u)}cursorGet(s){return s.buffer?this.getBuffer(s.buffer.buffer,s.index):this.map.get(s.tree)}}class gM{constructor(s,u,h,g,w=!1,p=!1){this.from=s,this.to=u,this.tree=h,this.offset=g,this.open=(w?1:0)|(p?2:0)}get openStart(){return(this.open&1)>0}get openEnd(){return(this.open&2)>0}static addTree(s,u=[],h=!1){let g=[new gM(0,s.length,s,0,!1,h)];for(let w of u)w.to>s.length&&g.push(w);return g}static applyChanges(s,u,h=128){if(!u.length)return s;let g=[],w=1,p=s.length?s[0]:null;for(let k=0,j=0,A=0;;k++){let _=k<u.length?u[k]:null,D=_?_.fromA:1e9;if(D-j>=h)for(;p&&p.from<D;){let I=p;if(j>=I.from||D<=I.to||A){let B=Math.max(I.from,j)-A,F=Math.min(I.to,D)-A;I=B>=F?null:new gM(B,F,I.tree,I.offset+A,k>0,!!_)}if(I&&g.push(I),p.to>D)break;p=w<s.length?s[w++]:null}if(!_)break;j=_.toA,A=_.toA-_.toB}return g}}class XOt{startParse(s,u,h){return typeof s=="string"&&(s=new Kgn(s)),h=h?h.length?h.map(g=>new qEe(g.from,g.to)):[new qEe(0,0)]:[new qEe(0,s.length)],this.createParse(s,u||[],h)}parse(s,u,h){let g=this.startParse(s,u,h);for(;;){let w=g.advance();if(w)return w}}}class Kgn{constructor(s){this.string=s}get length(){return this.string.length}chunk(s){return this.string.slice(s)}get lineChunks(){return!1}read(s,u){return this.string.slice(s,u)}}new Eo({perNode:!0});var r3t={};class che{constructor(s,u,h,g,w,p,k,j,A,_=0,D){this.p=s,this.stack=u,this.state=h,this.reducePos=g,this.pos=w,this.score=p,this.buffer=k,this.bufferBase=j,this.curContext=A,this.lookAhead=_,this.parent=D}toString(){return`[${this.stack.filter((s,u)=>u%3==0).concat(this.state)}]@${this.pos}${this.score?"!"+this.score:""}`}static start(s,u,h=0){let g=s.parser.context;return new che(s,[],u,h,h,0,[],0,g?new s3t(g,g.start):null,0,null)}get context(){return this.curContext?this.curContext.context:null}pushState(s,u){this.stack.push(this.state,u,this.bufferBase+this.buffer.length),this.state=s}reduce(s){var u;let h=s>>19,g=s&65535,{parser:w}=this.p,p=this.reducePos<this.pos-25&&this.setLookAhead(this.pos),k=w.dynamicPrecedence(g);if(k&&(this.score+=k),h==0){this.pushState(w.getGoto(this.state,g,!0),this.reducePos),g<w.minRepeatTerm&&this.storeNode(g,this.reducePos,this.reducePos,p?8:4,!0),this.reduceContext(g,this.reducePos);return}let j=this.stack.length-(h-1)*3-(s&262144?6:0),A=j?this.stack[j-2]:this.p.ranges[0].from,_=this.reducePos-A;_>=2e3&&!(!((u=this.p.parser.nodeSet.types[g])===null||u===void 0)&&u.isAnonymous)&&(A==this.p.lastBigReductionStart?(this.p.bigReductionCount++,this.p.lastBigReductionSize=_):this.p.lastBigReductionSize<_&&(this.p.bigReductionCount=1,this.p.lastBigReductionStart=A,this.p.lastBigReductionSize=_));let D=j?this.stack[j-1]:0,I=this.bufferBase+this.buffer.length-D;if(g<w.minRepeatTerm||s&131072){let B=w.stateFlag(this.state,1)?this.pos:this.reducePos;this.storeNode(g,A,B,I+4,!0)}if(s&262144)this.state=this.stack[j];else{let B=this.stack[j-3];this.state=w.getGoto(B,g,!0)}for(;this.stack.length>j;)this.stack.pop();this.reduceContext(g,A)}storeNode(s,u,h,g=4,w=!1){if(s==0&&(!this.stack.length||this.stack[this.stack.length-1]<this.buffer.length+this.bufferBase)){let p=this,k=this.buffer.length;if(k==0&&p.parent&&(k=p.bufferBase-p.parent.bufferBase,p=p.parent),k>0&&p.buffer[k-4]==0&&p.buffer[k-1]>-1){if(u==h)return;if(p.buffer[k-2]>=u){p.buffer[k-2]=h;return}}}if(!w||this.pos==h)this.buffer.push(s,u,h,g);else{let p=this.buffer.length;if(p>0&&(this.buffer[p-4]!=0||this.buffer[p-1]<0)){let k=!1;for(let j=p;j>0&&this.buffer[j-2]>h;j-=4)if(this.buffer[j-1]>=0){k=!0;break}if(k)for(;p>0&&this.buffer[p-2]>h;)this.buffer[p]=this.buffer[p-4],this.buffer[p+1]=this.buffer[p-3],this.buffer[p+2]=this.buffer[p-2],this.buffer[p+3]=this.buffer[p-1],p-=4,g>4&&(g-=4)}this.buffer[p]=s,this.buffer[p+1]=u,this.buffer[p+2]=h,this.buffer[p+3]=g}}shift(s,u,h,g){if(s&131072)this.pushState(s&65535,this.pos);else if((s&262144)==0){let w=s,{parser:p}=this.p;this.pos=g;let k=p.stateFlag(w,1);!k&&(g>h||u<=p.maxNode)&&(this.reducePos=g),this.pushState(w,k?h:Math.min(h,this.reducePos)),this.shiftContext(u,h),u<=p.maxNode&&this.buffer.push(u,h,g,4)}else this.pos=g,this.shiftContext(u,h),u<=this.p.parser.maxNode&&this.buffer.push(u,h,g,4)}apply(s,u,h,g){s&65536?this.reduce(s):this.shift(s,u,h,g)}useNode(s,u){let h=this.p.reused.length-1;(h<0||this.p.reused[h]!=s)&&(this.p.reused.push(s),h++);let g=this.pos;this.reducePos=this.pos=g+s.length,this.pushState(u,g),this.buffer.push(h,g,this.reducePos,-1),this.curContext&&this.updateContext(this.curContext.tracker.reuse(this.curContext.context,s,this,this.p.stream.reset(this.pos-s.length)))}split(){let s=this,u=s.buffer.length;for(;u>0&&s.buffer[u-2]>s.reducePos;)u-=4;let h=s.buffer.slice(u),g=s.bufferBase+u;for(;s&&g==s.bufferBase;)s=s.parent;return new che(this.p,this.stack.slice(),this.state,this.reducePos,this.pos,this.score,h,g,this.curContext,this.lookAhead,s)}recoverByDelete(s,u){let h=s<=this.p.parser.maxNode;h&&this.storeNode(s,this.pos,u,4),this.storeNode(0,this.pos,u,h?8:4),this.pos=this.reducePos=u,this.score-=190}canShift(s){for(let u=new Ygn(this);;){let h=this.p.parser.stateSlot(u.state,4)||this.p.parser.hasAction(u.state,s);if(h==0)return!1;if((h&65536)==0)return!0;u.reduce(h)}}recoverByInsert(s){if(this.stack.length>=300)return[];let u=this.p.parser.nextStates(this.state);if(u.length>8||this.stack.length>=120){let g=[];for(let w=0,p;w<u.length;w+=2)(p=u[w+1])!=this.state&&this.p.parser.hasAction(p,s)&&g.push(u[w],p);if(this.stack.length<120)for(let w=0;g.length<8&&w<u.length;w+=2){let p=u[w+1];g.some((k,j)=>j&1&&k==p)||g.push(u[w],p)}u=g}let h=[];for(let g=0;g<u.length&&h.length<4;g+=2){let w=u[g+1];if(w==this.state)continue;let p=this.split();p.pushState(w,this.pos),p.storeNode(0,p.pos,p.pos,4,!0),p.shiftContext(u[g],this.pos),p.reducePos=this.pos,p.score-=200,h.push(p)}return h}forceReduce(){let{parser:s}=this.p,u=s.stateSlot(this.state,5);if((u&65536)==0)return!1;if(!s.validAction(this.state,u)){let h=u>>19,g=u&65535,w=this.stack.length-h*3;if(w<0||s.getGoto(this.stack[w],g,!1)<0){let p=this.findForcedReduction();if(p==null)return!1;u=p}this.storeNode(0,this.pos,this.pos,4,!0),this.score-=100}return this.reducePos=this.pos,this.reduce(u),!0}findForcedReduction(){let{parser:s}=this.p,u=[],h=(g,w)=>{if(!u.includes(g))return u.push(g),s.allActions(g,p=>{if(!(p&393216))if(p&65536){let k=(p>>19)-w;if(k>1){let j=p&65535,A=this.stack.length-k*3;if(A>=0&&s.getGoto(this.stack[A],j,!1)>=0)return k<<19|65536|j}}else{let k=h(p,w+1);if(k!=null)return k}})};return h(this.state,0)}forceAll(){for(;!this.p.parser.stateFlag(this.state,2);)if(!this.forceReduce()){this.storeNode(0,this.pos,this.pos,4,!0);break}return this}get deadEnd(){if(this.stack.length!=3)return!1;let{parser:s}=this.p;return s.data[s.stateSlot(this.state,1)]==65535&&!s.stateSlot(this.state,4)}restart(){this.storeNode(0,this.pos,this.pos,4,!0),this.state=this.stack[0],this.stack.length=0}sameState(s){if(this.state!=s.state||this.stack.length!=s.stack.length)return!1;for(let u=0;u<this.stack.length;u+=3)if(this.stack[u]!=s.stack[u])return!1;return!0}get parser(){return this.p.parser}dialectEnabled(s){return this.p.parser.dialect.flags[s]}shiftContext(s,u){this.curContext&&this.updateContext(this.curContext.tracker.shift(this.curContext.context,s,this,this.p.stream.reset(u)))}reduceContext(s,u){this.curContext&&this.updateContext(this.curContext.tracker.reduce(this.curContext.context,s,this,this.p.stream.reset(u)))}emitContext(){let s=this.buffer.length-1;(s<0||this.buffer[s]!=-3)&&this.buffer.push(this.curContext.hash,this.pos,this.pos,-3)}emitLookAhead(){let s=this.buffer.length-1;(s<0||this.buffer[s]!=-4)&&this.buffer.push(this.lookAhead,this.pos,this.pos,-4)}updateContext(s){if(s!=this.curContext.context){let u=new s3t(this.curContext.tracker,s);u.hash!=this.curContext.hash&&this.emitContext(),this.curContext=u}}setLookAhead(s){return s<=this.lookAhead?!1:(this.emitLookAhead(),this.lookAhead=s,!0)}close(){this.curContext&&this.curContext.tracker.strict&&this.emitContext(),this.lookAhead>0&&this.emitLookAhead()}}class s3t{constructor(s,u){this.tracker=s,this.context=u,this.hash=s.strict?s.hash(u):0}}class Ygn{constructor(s){this.start=s,this.state=s.state,this.stack=s.stack,this.base=this.stack.length}reduce(s){let u=s&65535,h=s>>19;h==0?(this.stack==this.start.stack&&(this.stack=this.stack.slice()),this.stack.push(this.state,0,0),this.base+=3):this.base-=(h-1)*3;let g=this.start.p.parser.getGoto(this.stack[this.base-3],u,!0);this.state=g}}class lhe{constructor(s,u,h){this.stack=s,this.pos=u,this.index=h,this.buffer=s.buffer,this.index==0&&this.maybeNext()}static create(s,u=s.bufferBase+s.buffer.length){return new lhe(s,u,u-s.bufferBase)}maybeNext(){let s=this.stack.parent;s!=null&&(this.index=this.stack.bufferBase-s.bufferBase,this.stack=s,this.buffer=s.buffer)}get id(){return this.buffer[this.index-4]}get start(){return this.buffer[this.index-3]}get end(){return this.buffer[this.index-2]}get size(){return this.buffer[this.index-1]}next(){this.index-=4,this.pos-=4,this.index==0&&this.maybeNext()}fork(){return new lhe(this.stack,this.pos,this.index)}}function ofe(l,s=Uint16Array){if(typeof l!="string")return l;let u=null;for(let h=0,g=0;h<l.length;){let w=0;for(;;){let p=l.charCodeAt(h++),k=!1;if(p==126){w=65535;break}p>=92&&p--,p>=34&&p--;let j=p-32;if(j>=46&&(j-=46,k=!0),w+=j,k)break;w*=46}u?u[g++]=w:u=new s(w)}return u}class Nfe{constructor(){this.start=-1,this.value=-1,this.end=-1,this.extended=-1,this.lookAhead=0,this.mask=0,this.context=0}}const o3t=new Nfe;class Zgn{constructor(s,u){this.input=s,this.ranges=u,this.chunk="",this.chunkOff=0,this.chunk2="",this.chunk2Pos=0,this.next=-1,this.token=o3t,this.rangeIndex=0,this.pos=this.chunkPos=u[0].from,this.range=u[0],this.end=u[u.length-1].to,this.readNext()}resolveOffset(s,u){let h=this.range,g=this.rangeIndex,w=this.pos+s;for(;w<h.from;){if(!g)return null;let p=this.ranges[--g];w-=h.from-p.to,h=p}for(;u<0?w>h.to:w>=h.to;){if(g==this.ranges.length-1)return null;let p=this.ranges[++g];w+=p.from-h.to,h=p}return w}clipPos(s){if(s>=this.range.from&&s<this.range.to)return s;for(let u of this.ranges)if(u.to>s)return Math.max(s,u.from);return this.end}peek(s){let u=this.chunkOff+s,h,g;if(u>=0&&u<this.chunk.length)h=this.pos+s,g=this.chunk.charCodeAt(u);else{let w=this.resolveOffset(s,1);if(w==null)return-1;if(h=w,h>=this.chunk2Pos&&h<this.chunk2Pos+this.chunk2.length)g=this.chunk2.charCodeAt(h-this.chunk2Pos);else{let p=this.rangeIndex,k=this.range;for(;k.to<=h;)k=this.ranges[++p];this.chunk2=this.input.chunk(this.chunk2Pos=h),h+this.chunk2.length>k.to&&(this.chunk2=this.chunk2.slice(0,k.to-h)),g=this.chunk2.charCodeAt(0)}}return h>=this.token.lookAhead&&(this.token.lookAhead=h+1),g}acceptToken(s,u=0){let h=u?this.resolveOffset(u,-1):this.pos;if(h==null||h<this.token.start)throw new RangeError("Token end out of bounds");this.token.value=s,this.token.end=h}acceptTokenTo(s,u){this.token.value=s,this.token.end=u}getChunk(){if(this.pos>=this.chunk2Pos&&this.pos<this.chunk2Pos+this.chunk2.length){let{chunk:s,chunkPos:u}=this;this.chunk=this.chunk2,this.chunkPos=this.chunk2Pos,this.chunk2=s,this.chunk2Pos=u,this.chunkOff=this.pos-this.chunkPos}else{this.chunk2=this.chunk,this.chunk2Pos=this.chunkPos;let s=this.input.chunk(this.pos),u=this.pos+s.length;this.chunk=u>this.range.to?s.slice(0,this.range.to-this.pos):s,this.chunkPos=this.pos,this.chunkOff=0}}readNext(){return this.chunkOff>=this.chunk.length&&(this.getChunk(),this.chunkOff==this.chunk.length)?this.next=-1:this.next=this.chunk.charCodeAt(this.chunkOff)}advance(s=1){for(this.chunkOff+=s;this.pos+s>=this.range.to;){if(this.rangeIndex==this.ranges.length-1)return this.setDone();s-=this.range.to-this.pos,this.range=this.ranges[++this.rangeIndex],this.pos=this.range.from}return this.pos+=s,this.pos>=this.token.lookAhead&&(this.token.lookAhead=this.pos+1),this.readNext()}setDone(){return this.pos=this.chunkPos=this.end,this.range=this.ranges[this.rangeIndex=this.ranges.length-1],this.chunk="",this.next=-1}reset(s,u){if(u?(this.token=u,u.start=s,u.lookAhead=s+1,u.value=u.extended=-1):this.token=o3t,this.pos!=s){if(this.pos=s,s==this.end)return this.setDone(),this;for(;s<this.range.from;)this.range=this.ranges[--this.rangeIndex];for(;s>=this.range.to;)this.range=this.ranges[++this.rangeIndex];s>=this.chunkPos&&s<this.chunkPos+this.chunk.length?this.chunkOff=s-this.chunkPos:(this.chunk="",this.chunkOff=0),this.readNext()}return this}read(s,u){if(s>=this.chunkPos&&u<=this.chunkPos+this.chunk.length)return this.chunk.slice(s-this.chunkPos,u-this.chunkPos);if(s>=this.chunk2Pos&&u<=this.chunk2Pos+this.chunk2.length)return this.chunk2.slice(s-this.chunk2Pos,u-this.chunk2Pos);if(s>=this.range.from&&u<=this.range.to)return this.input.read(s,u);let h="";for(let g of this.ranges){if(g.from>=u)break;g.to>s&&(h+=this.input.read(Math.max(g.from,s),Math.min(g.to,u)))}return h}}class yI{constructor(s,u){this.data=s,this.id=u}token(s,u){let{parser:h}=u.p;e0n(this.data,s,u,this.id,h.data,h.tokenPrecTable)}}yI.prototype.contextual=yI.prototype.fallback=yI.prototype.extend=!1;yI.prototype.fallback=yI.prototype.extend=!1;class Xhe{constructor(s,u={}){this.token=s,this.contextual=!!u.contextual,this.fallback=!!u.fallback,this.extend=!!u.extend}}function e0n(l,s,u,h,g,w){let p=0,k=1<<h,{dialect:j}=u.p.parser;e:for(;(k&l[p])!=0;){let A=l[p+1];for(let B=p+3;B<A;B+=2)if((l[B+1]&k)>0){let F=l[B];if(j.allows(F)&&(s.token.value==-1||s.token.value==F||t0n(F,s.token.value,g,w))){s.acceptToken(F);break}}let _=s.next,D=0,I=l[p+2];if(s.next<0&&I>D&&l[A+I*3-3]==65535){p=l[A+I*3-1];continue e}for(;D<I;){let B=D+I>>1,F=A+B+(B<<1),U=l[F],K=l[F+1]||65536;if(_<U)I=B;else if(_>=K)D=B+1;else{p=l[F+2],s.advance();continue e}}break}}function c3t(l,s,u){for(let h=s,g;(g=l[h])!=65535;h++)if(g==u)return h-s;return-1}function t0n(l,s,u,h){let g=c3t(u,h,s);return g<0||c3t(u,h,l)<g}const Wb=typeof process<"u"&&r3t&&/\bparse\b/.test(r3t.LOG);let HEe=null;function l3t(l,s,u){let h=l.cursor(La.IncludeAnonymous);for(h.moveTo(s);;)if(!(u<0?h.childBefore(s):h.childAfter(s)))for(;;){if((u<0?h.to<s:h.from>s)&&!h.type.isError)return u<0?Math.max(0,Math.min(h.to-1,s-25)):Math.min(l.length,Math.max(h.from+1,s+25));if(u<0?h.prevSibling():h.nextSibling())break;if(!h.parent())return u<0?0:l.length}}class n0n{constructor(s,u){this.fragments=s,this.nodeSet=u,this.i=0,this.fragment=null,this.safeFrom=-1,this.safeTo=-1,this.trees=[],this.start=[],this.index=[],this.nextFragment()}nextFragment(){let s=this.fragment=this.i==this.fragments.length?null:this.fragments[this.i++];if(s){for(this.safeFrom=s.openStart?l3t(s.tree,s.from+s.offset,1)-s.offset:s.from,this.safeTo=s.openEnd?l3t(s.tree,s.to+s.offset,-1)-s.offset:s.to;this.trees.length;)this.trees.pop(),this.start.pop(),this.index.pop();this.trees.push(s.tree),this.start.push(-s.offset),this.index.push(0),this.nextStart=this.safeFrom}else this.nextStart=1e9}nodeAt(s){if(s<this.nextStart)return null;for(;this.fragment&&this.safeTo<=s;)this.nextFragment();if(!this.fragment)return null;for(;;){let u=this.trees.length-1;if(u<0)return this.nextFragment(),null;let h=this.trees[u],g=this.index[u];if(g==h.children.length){this.trees.pop(),this.start.pop(),this.index.pop();continue}let w=h.children[g],p=this.start[u]+h.positions[g];if(p>s)return this.nextStart=p,null;if(w instanceof Bf){if(p==s){if(p<this.safeFrom)return null;let k=p+w.length;if(k<=this.safeTo){let j=w.prop(Eo.lookAhead);if(!j||k+j<this.fragment.to)return w}}this.index[u]++,p+w.length>=Math.max(this.safeFrom,s)&&(this.trees.push(w),this.start.push(p),this.index.push(0))}else this.index[u]++,this.nextStart=p+w.length}}}class i0n{constructor(s,u){this.stream=u,this.tokens=[],this.mainToken=null,this.actions=[],this.tokens=s.tokenizers.map(h=>new Nfe)}getActions(s){let u=0,h=null,{parser:g}=s.p,{tokenizers:w}=g,p=g.stateSlot(s.state,3),k=s.curContext?s.curContext.hash:0,j=0;for(let A=0;A<w.length;A++){if((1<<A&p)==0)continue;let _=w[A],D=this.tokens[A];if(!(h&&!_.fallback)&&((_.contextual||D.start!=s.pos||D.mask!=p||D.context!=k)&&(this.updateCachedToken(D,_,s),D.mask=p,D.context=k),D.lookAhead>D.end+25&&(j=Math.max(D.lookAhead,j)),D.value!=0)){let I=u;if(D.extended>-1&&(u=this.addActions(s,D.extended,D.end,u)),u=this.addActions(s,D.value,D.end,u),!_.extend&&(h=D,u>I))break}}for(;this.actions.length>u;)this.actions.pop();return j&&s.setLookAhead(j),!h&&s.pos==this.stream.end&&(h=new Nfe,h.value=s.p.parser.eofTerm,h.start=h.end=s.pos,u=this.addActions(s,h.value,h.end,u)),this.mainToken=h,this.actions}getMainToken(s){if(this.mainToken)return this.mainToken;let u=new Nfe,{pos:h,p:g}=s;return u.start=h,u.end=Math.min(h+1,g.stream.end),u.value=h==g.stream.end?g.parser.eofTerm:0,u}updateCachedToken(s,u,h){let g=this.stream.clipPos(h.pos);if(u.token(this.stream.reset(g,s),h),s.value>-1){let{parser:w}=h.p;for(let p=0;p<w.specialized.length;p++)if(w.specialized[p]==s.value){let k=w.specializers[p](this.stream.read(s.start,s.end),h);if(k>=0&&h.p.parser.dialect.allows(k>>1)){(k&1)==0?s.value=k>>1:s.extended=k>>1;break}}}else s.value=0,s.end=this.stream.clipPos(g+1)}putAction(s,u,h,g){for(let w=0;w<g;w+=3)if(this.actions[w]==s)return g;return this.actions[g++]=s,this.actions[g++]=u,this.actions[g++]=h,g}addActions(s,u,h,g){let{state:w}=s,{parser:p}=s.p,{data:k}=p;for(let j=0;j<2;j++)for(let A=p.stateSlot(w,j?2:1);;A+=3){if(k[A]==65535)if(k[A+1]==1)A=Yk(k,A+2);else{g==0&&k[A+1]==2&&(g=this.putAction(Yk(k,A+2),u,h,g));break}k[A]==u&&(g=this.putAction(Yk(k,A+1),u,h,g))}return g}}class r0n{constructor(s,u,h,g){this.parser=s,this.input=u,this.ranges=g,this.recovering=0,this.nextStackID=9812,this.minStackPos=0,this.reused=[],this.stoppedAt=null,this.lastBigReductionStart=-1,this.lastBigReductionSize=0,this.bigReductionCount=0,this.stream=new Zgn(u,g),this.tokens=new i0n(s,this.stream),this.topTerm=s.top[1];let{from:w}=g[0];this.stacks=[che.start(this,s.top[0],w)],this.fragments=h.length&&this.stream.end-w>s.bufferLength*4?new n0n(h,s.nodeSet):null}get parsedPos(){return this.minStackPos}advance(){let s=this.stacks,u=this.minStackPos,h=this.stacks=[],g,w;if(this.bigReductionCount>300&&s.length==1){let[p]=s;for(;p.forceReduce()&&p.stack.length&&p.stack[p.stack.length-2]>=this.lastBigReductionStart;);this.bigReductionCount=this.lastBigReductionSize=0}for(let p=0;p<s.length;p++){let k=s[p];for(;;){if(this.tokens.mainToken=null,k.pos>u)h.push(k);else{if(this.advanceStack(k,h,s))continue;{g||(g=[],w=[]),g.push(k);let j=this.tokens.getMainToken(k);w.push(j.value,j.end)}}break}}if(!h.length){let p=g&&c0n(g);if(p)return Wb&&console.log("Finish with "+this.stackID(p)),this.stackToTree(p);if(this.parser.strict)throw Wb&&g&&console.log("Stuck with token "+(this.tokens.mainToken?this.parser.getName(this.tokens.mainToken.value):"none")),new SyntaxError("No parse at "+u);this.recovering||(this.recovering=5)}if(this.recovering&&g){let p=this.stoppedAt!=null&&g[0].pos>this.stoppedAt?g[0]:this.runRecovery(g,w,h);if(p)return Wb&&console.log("Force-finish "+this.stackID(p)),this.stackToTree(p.forceAll())}if(this.recovering){let p=this.recovering==1?1:this.recovering*3;if(h.length>p)for(h.sort((k,j)=>j.score-k.score);h.length>p;)h.pop();h.some(k=>k.reducePos>u)&&this.recovering--}else if(h.length>1){e:for(let p=0;p<h.length-1;p++){let k=h[p];for(let j=p+1;j<h.length;j++){let A=h[j];if(k.sameState(A)||k.buffer.length>500&&A.buffer.length>500)if((k.score-A.score||k.buffer.length-A.buffer.length)>0)h.splice(j--,1);else{h.splice(p--,1);continue e}}}h.length>12&&(h.sort((p,k)=>k.score-p.score),h.splice(12,h.length-12))}this.minStackPos=h[0].pos;for(let p=1;p<h.length;p++)h[p].pos<this.minStackPos&&(this.minStackPos=h[p].pos);return null}stopAt(s){if(this.stoppedAt!=null&&this.stoppedAt<s)throw new RangeError("Can't move stoppedAt forward");this.stoppedAt=s}advanceStack(s,u,h){let g=s.pos,{parser:w}=this,p=Wb?this.stackID(s)+" -> ":"";if(this.stoppedAt!=null&&g>this.stoppedAt)return s.forceReduce()?s:null;if(this.fragments){let A=s.curContext&&s.curContext.tracker.strict,_=A?s.curContext.hash:0;for(let D=this.fragments.nodeAt(g);D;){let I=this.parser.nodeSet.types[D.type.id]==D.type?w.getGoto(s.state,D.type.id):-1;if(I>-1&&D.length&&(!A||(D.prop(Eo.contextHash)||0)==_))return s.useNode(D,I),Wb&&console.log(p+this.stackID(s)+` (via reuse of ${w.getName(D.type.id)})`),!0;if(!(D instanceof Bf)||D.children.length==0||D.positions[0]>0)break;let B=D.children[0];if(B instanceof Bf&&D.positions[0]==0)D=B;else break}}let k=w.stateSlot(s.state,4);if(k>0)return s.reduce(k),Wb&&console.log(p+this.stackID(s)+` (via always-reduce ${w.getName(k&65535)})`),!0;if(s.stack.length>=8400)for(;s.stack.length>6e3&&s.forceReduce(););let j=this.tokens.getActions(s);for(let A=0;A<j.length;){let _=j[A++],D=j[A++],I=j[A++],B=A==j.length||!h,F=B?s:s.split(),U=this.tokens.mainToken;if(F.apply(_,D,U?U.start:F.pos,I),Wb&&console.log(p+this.stackID(F)+` (via ${(_&65536)==0?"shift":`reduce of ${w.getName(_&65535)}`} for ${w.getName(D)} @ ${g}${F==s?"":", split"})`),B)return!0;F.pos>g?u.push(F):h.push(F)}return!1}advanceFully(s,u){let h=s.pos;for(;;){if(!this.advanceStack(s,null,null))return!1;if(s.pos>h)return u3t(s,u),!0}}runRecovery(s,u,h){let g=null,w=!1;for(let p=0;p<s.length;p++){let k=s[p],j=u[p<<1],A=u[(p<<1)+1],_=Wb?this.stackID(k)+" -> ":"";if(k.deadEnd&&(w||(w=!0,k.restart(),Wb&&console.log(_+this.stackID(k)+" (restarted)"),this.advanceFully(k,h))))continue;let D=k.split(),I=_;for(let B=0;B<10&&D.forceReduce()&&(Wb&&console.log(I+this.stackID(D)+" (via force-reduce)"),!this.advanceFully(D,h));B++)Wb&&(I=this.stackID(D)+" -> ");for(let B of k.recoverByInsert(j))Wb&&console.log(_+this.stackID(B)+" (via recover-insert)"),this.advanceFully(B,h);this.stream.end>k.pos?(A==k.pos&&(A++,j=0),k.recoverByDelete(j,A),Wb&&console.log(_+this.stackID(k)+` (via recover-delete ${this.parser.getName(j)})`),u3t(k,h)):(!g||g.score<D.score)&&(g=D)}return g}stackToTree(s){return s.close(),Bf.build({buffer:lhe.create(s),nodeSet:this.parser.nodeSet,topID:this.topTerm,maxBufferLength:this.parser.bufferLength,reused:this.reused,start:this.ranges[0].from,length:s.pos-this.ranges[0].from,minRepeatType:this.parser.minRepeatTerm})}stackID(s){let u=(HEe||(HEe=new WeakMap)).get(s);return u||HEe.set(s,u=String.fromCodePoint(this.nextStackID++)),u+s}}function u3t(l,s){for(let u=0;u<s.length;u++){let h=s[u];if(h.pos==l.pos&&h.sameState(l)){s[u].score<l.score&&(s[u]=l);return}}s.push(l)}class s0n{constructor(s,u,h){this.source=s,this.flags=u,this.disabled=h}allows(s){return!this.disabled||this.disabled[s]==0}}const QEe=l=>l;class o0n{constructor(s){this.start=s.start,this.shift=s.shift||QEe,this.reduce=s.reduce||QEe,this.reuse=s.reuse||QEe,this.hash=s.hash||(()=>0),this.strict=s.strict!==!1}}class uhe extends XOt{constructor(s){if(super(),this.wrappers=[],s.version!=14)throw new RangeError(`Parser version (${s.version}) doesn't match runtime version (14)`);let u=s.nodeNames.split(" ");this.minRepeatTerm=u.length;for(let k=0;k<s.repeatNodeCount;k++)u.push("");let h=Object.keys(s.topRules).map(k=>s.topRules[k][1]),g=[];for(let k=0;k<u.length;k++)g.push([]);function w(k,j,A){g[k].push([j,j.deserialize(String(A))])}if(s.nodeProps)for(let k of s.nodeProps){let j=k[0];typeof j=="string"&&(j=Eo[j]);for(let A=1;A<k.length;){let _=k[A++];if(_>=0)w(_,j,k[A++]);else{let D=k[A+-_];for(let I=-_;I>0;I--)w(k[A++],j,D);A++}}}this.nodeSet=new uAe(u.map((k,j)=>Ep.define({name:j>=this.minRepeatTerm?void 0:k,id:j,props:g[j],top:h.indexOf(j)>-1,error:j==0,skipped:s.skippedNodes&&s.skippedNodes.indexOf(j)>-1}))),s.propSources&&(this.nodeSet=this.nodeSet.extend(...s.propSources)),this.strict=!1,this.bufferLength=QOt;let p=ofe(s.tokenData);this.context=s.context,this.specializerSpecs=s.specialized||[],this.specialized=new Uint16Array(this.specializerSpecs.length);for(let k=0;k<this.specializerSpecs.length;k++)this.specialized[k]=this.specializerSpecs[k].term;this.specializers=this.specializerSpecs.map(a3t),this.states=ofe(s.states,Uint32Array),this.data=ofe(s.stateData),this.goto=ofe(s.goto),this.maxTerm=s.maxTerm,this.tokenizers=s.tokenizers.map(k=>typeof k=="number"?new yI(p,k):k),this.topRules=s.topRules,this.dialects=s.dialects||{},this.dynamicPrecedences=s.dynamicPrecedences||null,this.tokenPrecTable=s.tokenPrec,this.termNames=s.termNames||null,this.maxNode=this.nodeSet.types.length-1,this.dialect=this.parseDialect(),this.top=this.topRules[Object.keys(this.topRules)[0]]}createParse(s,u,h){let g=new r0n(this,s,u,h);for(let w of this.wrappers)g=w(g,s,u,h);return g}getGoto(s,u,h=!1){let g=this.goto;if(u>=g[0])return-1;for(let w=g[u+1];;){let p=g[w++],k=p&1,j=g[w++];if(k&&h)return j;for(let A=w+(p>>1);w<A;w++)if(g[w]==s)return j;if(k)return-1}}hasAction(s,u){let h=this.data;for(let g=0;g<2;g++)for(let w=this.stateSlot(s,g?2:1),p;;w+=3){if((p=h[w])==65535)if(h[w+1]==1)p=h[w=Yk(h,w+2)];else{if(h[w+1]==2)return Yk(h,w+2);break}if(p==u||p==0)return Yk(h,w+1)}return 0}stateSlot(s,u){return this.states[s*6+u]}stateFlag(s,u){return(this.stateSlot(s,0)&u)>0}validAction(s,u){return!!this.allActions(s,h=>h==u?!0:null)}allActions(s,u){let h=this.stateSlot(s,4),g=h?u(h):void 0;for(let w=this.stateSlot(s,1);g==null;w+=3){if(this.data[w]==65535)if(this.data[w+1]==1)w=Yk(this.data,w+2);else break;g=u(Yk(this.data,w+1))}return g}nextStates(s){let u=[];for(let h=this.stateSlot(s,1);;h+=3){if(this.data[h]==65535)if(this.data[h+1]==1)h=Yk(this.data,h+2);else break;if((this.data[h+2]&1)==0){let g=this.data[h+1];u.some((w,p)=>p&1&&w==g)||u.push(this.data[h],g)}}return u}configure(s){let u=Object.assign(Object.create(uhe.prototype),this);if(s.props&&(u.nodeSet=this.nodeSet.extend(...s.props)),s.top){let h=this.topRules[s.top];if(!h)throw new RangeError(`Invalid top rule name ${s.top}`);u.top=h}return s.tokenizers&&(u.tokenizers=this.tokenizers.map(h=>{let g=s.tokenizers.find(w=>w.from==h);return g?g.to:h})),s.specializers&&(u.specializers=this.specializers.slice(),u.specializerSpecs=this.specializerSpecs.map((h,g)=>{let w=s.specializers.find(k=>k.from==h.external);if(!w)return h;let p=Object.assign(Object.assign({},h),{external:w.to});return u.specializers[g]=a3t(p),p})),s.contextTracker&&(u.context=s.contextTracker),s.dialect&&(u.dialect=this.parseDialect(s.dialect)),s.strict!=null&&(u.strict=s.strict),s.wrap&&(u.wrappers=u.wrappers.concat(s.wrap)),s.bufferLength!=null&&(u.bufferLength=s.bufferLength),u}hasWrappers(){return this.wrappers.length>0}getName(s){return this.termNames?this.termNames[s]:String(s<=this.maxNode&&this.nodeSet.types[s].name||s)}get eofTerm(){return this.maxNode+1}get topNode(){return this.nodeSet.types[this.top[1]]}dynamicPrecedence(s){let u=this.dynamicPrecedences;return u==null?0:u[s]||0}parseDialect(s){let u=Object.keys(this.dialects),h=u.map(()=>!1);if(s)for(let w of s.split(" ")){let p=u.indexOf(w);p>=0&&(h[p]=!0)}let g=null;for(let w=0;w<u.length;w++)if(!h[w])for(let p=this.dialects[u[w]],k;(k=this.data[p++])!=65535;)(g||(g=new Uint8Array(this.maxTerm+1)))[k]=1;return new s0n(s,h,g)}static deserialize(s){return new uhe(s)}}function Yk(l,s){return l[s]|l[s+1]<<16}function c0n(l){let s=null;for(let u of l){let h=u.p.stoppedAt;(u.pos==u.p.stream.end||h!=null&&u.pos>h)&&u.p.parser.stateFlag(u.state,2)&&(!s||s.score<u.score)&&(s=u)}return s}function a3t(l){if(l.external){let s=l.extend?1:0;return(u,h)=>l.external(u,h)<<1|s}return l.get}let l0n=0;class Qw{constructor(s,u,h,g){this.name=s,this.set=u,this.base=h,this.modified=g,this.id=l0n++}toString(){let{name:s}=this;for(let u of this.modified)u.name&&(s=`${u.name}(${s})`);return s}static define(s,u){let h=typeof s=="string"?s:"?";if(s instanceof Qw&&(u=s),u!=null&&u.base)throw new Error("Can not derive from a modified tag");let g=new Qw(h,[],null,[]);if(g.set.push(g),u)for(let w of u.set)g.set.push(w);return g}static defineModifier(s){let u=new ahe(s);return h=>h.modified.indexOf(u)>-1?h:ahe.get(h.base||h,h.modified.concat(u).sort((g,w)=>g.id-w.id))}}let u0n=0;class ahe{constructor(s){this.name=s,this.instances=[],this.id=u0n++}static get(s,u){if(!u.length)return s;let h=u[0].instances.find(k=>k.base==s&&a0n(u,k.modified));if(h)return h;let g=[],w=new Qw(s.name,g,s,u);for(let k of u)k.instances.push(w);let p=f0n(u);for(let k of s.set)if(!k.modified.length)for(let j of p)g.push(ahe.get(k,j));return w}}function a0n(l,s){return l.length==s.length&&l.every((u,h)=>u==s[h])}function f0n(l){let s=[[]];for(let u=0;u<l.length;u++)for(let h=0,g=s.length;h<g;h++)s.push(s[h].concat(l[u]));return s.sort((u,h)=>h.length-u.length)}function VOt(l){let s=Object.create(null);for(let u in l){let h=l[u];Array.isArray(h)||(h=[h]);for(let g of u.split(" "))if(g){let w=[],p=2,k=g;for(let D=0;;){if(k=="..."&&D>0&&D+3==g.length){p=1;break}let I=/^"(?:[^"\\]|\\.)*?"|[^\/!]+/.exec(k);if(!I)throw new RangeError("Invalid path: "+g);if(w.push(I[0]=="*"?"":I[0][0]=='"'?JSON.parse(I[0]):I[0]),D+=I[0].length,D==g.length)break;let B=g[D++];if(D==g.length&&B=="!"){p=0;break}if(B!="/")throw new RangeError("Invalid path: "+g);k=g.slice(D)}let j=w.length-1,A=w[j];if(!A)throw new RangeError("Invalid path: "+g);let _=new aV(h,p,j>0?w.slice(0,j):null);s[A]=_.sort(s[A])}}return WOt.add(s)}const WOt=new Eo({combine(l,s){let u,h,g;for(;l||s;){if(!l||s&&l.depth>=s.depth?(g=s,s=s.next):(g=l,l=l.next),u&&u.mode==g.mode&&!g.context&&!u.context)continue;let w=new aV(g.tags,g.mode,g.context);u?u.next=w:h=w,u=w}return h}});class aV{constructor(s,u,h,g){this.tags=s,this.mode=u,this.context=h,this.next=g}get opaque(){return this.mode==0}get inherit(){return this.mode==1}sort(s){return!s||s.depth<this.depth?(this.next=s,this):(s.next=this.sort(s.next),s)}get depth(){return this.context?this.context.length:0}}aV.empty=new aV([],2,null);function KOt(l,s){let u=Object.create(null);for(let w of l)if(!Array.isArray(w.tag))u[w.tag.id]=w.class;else for(let p of w.tag)u[p.id]=w.class;let{scope:h,all:g=null}=s||{};return{style:w=>{let p=g;for(let k of w)for(let j of k.set){let A=u[j.id];if(A){p=p?p+" "+A:A;break}}return p},scope:h}}function h0n(l,s){let u=null;for(let h of l){let g=h.style(s);g&&(u=u?u+" "+g:g)}return u}function d0n(l,s,u,h=0,g=l.length){let w=new g0n(h,Array.isArray(s)?s:[s],u);w.highlightRange(l.cursor(),h,g,"",w.highlighters),w.flush(g)}class g0n{constructor(s,u,h){this.at=s,this.highlighters=u,this.span=h,this.class=""}startSpan(s,u){u!=this.class&&(this.flush(s),s>this.at&&(this.at=s),this.class=u)}flush(s){s>this.at&&this.class&&this.span(this.at,s,this.class)}highlightRange(s,u,h,g,w){let{type:p,from:k,to:j}=s;if(k>=h||j<=u)return;p.isTop&&(w=this.highlighters.filter(B=>!B.scope||B.scope(p)));let A=g,_=p0n(s)||aV.empty,D=h0n(w,_.tags);if(D&&(A&&(A+=" "),A+=D,_.mode==1&&(g+=(g?" ":"")+D)),this.startSpan(Math.max(u,k),A),_.opaque)return;let I=s.tree&&s.tree.prop(Eo.mounted);if(I&&I.overlay){let B=s.node.enter(I.overlay[0].from+k,1),F=this.highlighters.filter(K=>!K.scope||K.scope(I.tree.type)),U=s.firstChild();for(let K=0,Y=k;;K++){let Z=K<I.overlay.length?I.overlay[K]:null,ee=Z?Z.from+k:j,ce=Math.max(u,Y),fe=Math.min(h,ee);if(ce<fe&&U)for(;s.from<fe&&(this.highlightRange(s,ce,fe,g,w),this.startSpan(Math.min(fe,s.to),A),!(s.to>=ee||!s.nextSibling())););if(!Z||ee>h)break;Y=Z.to+k,Y>u&&(this.highlightRange(B.cursor(),Math.max(u,Z.from+k),Math.min(h,Y),"",F),this.startSpan(Math.min(h,Y),A))}U&&s.parent()}else if(s.firstChild()){I&&(g="");do if(!(s.to<=u)){if(s.from>=h)break;this.highlightRange(s,u,h,g,w),this.startSpan(Math.min(h,s.to),A)}while(s.nextSibling());s.parent()}}}function p0n(l){let s=l.type.prop(WOt);for(;s&&s.context&&!l.matchContext(s.context);)s=s.next;return s||null}const Mi=Qw.define,cfe=Mi(),h8=Mi(),f3t=Mi(h8),h3t=Mi(h8),d8=Mi(),lfe=Mi(d8),GEe=Mi(d8),B3=Mi(),nM=Mi(B3),R3=Mi(),$3=Mi(),aMe=Mi(),OX=Mi(aMe),ufe=Mi(),qn={comment:cfe,lineComment:Mi(cfe),blockComment:Mi(cfe),docComment:Mi(cfe),name:h8,variableName:Mi(h8),typeName:f3t,tagName:Mi(f3t),propertyName:h3t,attributeName:Mi(h3t),className:Mi(h8),labelName:Mi(h8),namespace:Mi(h8),macroName:Mi(h8),literal:d8,string:lfe,docString:Mi(lfe),character:Mi(lfe),attributeValue:Mi(lfe),number:GEe,integer:Mi(GEe),float:Mi(GEe),bool:Mi(d8),regexp:Mi(d8),escape:Mi(d8),color:Mi(d8),url:Mi(d8),keyword:R3,self:Mi(R3),null:Mi(R3),atom:Mi(R3),unit:Mi(R3),modifier:Mi(R3),operatorKeyword:Mi(R3),controlKeyword:Mi(R3),definitionKeyword:Mi(R3),moduleKeyword:Mi(R3),operator:$3,derefOperator:Mi($3),arithmeticOperator:Mi($3),logicOperator:Mi($3),bitwiseOperator:Mi($3),compareOperator:Mi($3),updateOperator:Mi($3),definitionOperator:Mi($3),typeOperator:Mi($3),controlOperator:Mi($3),punctuation:aMe,separator:Mi(aMe),bracket:OX,angleBracket:Mi(OX),squareBracket:Mi(OX),paren:Mi(OX),brace:Mi(OX),content:B3,heading:nM,heading1:Mi(nM),heading2:Mi(nM),heading3:Mi(nM),heading4:Mi(nM),heading5:Mi(nM),heading6:Mi(nM),contentSeparator:Mi(B3),list:Mi(B3),quote:Mi(B3),emphasis:Mi(B3),strong:Mi(B3),link:Mi(B3),monospace:Mi(B3),strikethrough:Mi(B3),inserted:Mi(),deleted:Mi(),changed:Mi(),invalid:Mi(),meta:ufe,documentMeta:Mi(ufe),annotation:Mi(ufe),processingInstruction:Mi(ufe),definition:Qw.defineModifier("definition"),constant:Qw.defineModifier("constant"),function:Qw.defineModifier("function"),standard:Qw.defineModifier("standard"),local:Qw.defineModifier("local"),special:Qw.defineModifier("special")};for(let l in qn){let s=qn[l];s instanceof Qw&&(s.name=l)}KOt([{tag:qn.link,class:"tok-link"},{tag:qn.heading,class:"tok-heading"},{tag:qn.emphasis,class:"tok-emphasis"},{tag:qn.strong,class:"tok-strong"},{tag:qn.keyword,class:"tok-keyword"},{tag:qn.atom,class:"tok-atom"},{tag:qn.bool,class:"tok-bool"},{tag:qn.url,class:"tok-url"},{tag:qn.labelName,class:"tok-labelName"},{tag:qn.inserted,class:"tok-inserted"},{tag:qn.deleted,class:"tok-deleted"},{tag:qn.literal,class:"tok-literal"},{tag:qn.string,class:"tok-string"},{tag:qn.number,class:"tok-number"},{tag:[qn.regexp,qn.escape,qn.special(qn.string)],class:"tok-string2"},{tag:qn.variableName,class:"tok-variableName"},{tag:qn.local(qn.variableName),class:"tok-variableName tok-local"},{tag:qn.definition(qn.variableName),class:"tok-variableName tok-definition"},{tag:qn.special(qn.variableName),class:"tok-variableName2"},{tag:qn.definition(qn.propertyName),class:"tok-propertyName tok-definition"},{tag:qn.typeName,class:"tok-typeName"},{tag:qn.namespace,class:"tok-namespace"},{tag:qn.className,class:"tok-className"},{tag:qn.macroName,class:"tok-macroName"},{tag:qn.propertyName,class:"tok-propertyName"},{tag:qn.operator,class:"tok-operator"},{tag:qn.comment,class:"tok-comment"},{tag:qn.meta,class:"tok-meta"},{tag:qn.invalid,class:"tok-invalid"},{tag:qn.punctuation,class:"tok-punctuation"}]);const b0n=1,YOt=194,ZOt=195,m0n=196,d3t=197,w0n=198,v0n=199,y0n=200,x0n=2,e6t=3,g3t=201,k0n=24,O0n=25,S0n=49,j0n=50,T0n=55,E0n=56,C0n=57,M0n=59,A0n=60,N0n=61,_0n=62,D0n=63,L0n=65,P0n=238,I0n=71,R0n=241,$0n=242,B0n=243,z0n=244,F0n=245,q0n=246,H0n=247,Q0n=248,t6t=72,G0n=249,U0n=250,J0n=251,X0n=252,V0n=253,W0n=254,K0n=255,Y0n=256,Z0n=73,epn=77,tpn=263,npn=112,ipn=130,rpn=151,spn=152,opn=155,SM=10,fV=13,dAe=32,Vhe=9,gAe=35,cpn=40,lpn=46,fMe=123,p3t=125,n6t=39,i6t=34,b3t=92,upn=111,apn=120,fpn=78,hpn=117,dpn=85,gpn=new Set([O0n,S0n,j0n,tpn,L0n,ipn,E0n,C0n,P0n,_0n,D0n,t6t,Z0n,epn,A0n,N0n,rpn,spn,opn,npn]);function UEe(l){return l==SM||l==fV}function JEe(l){return l>=48&&l<=57||l>=65&&l<=70||l>=97&&l<=102}const ppn=new Xhe((l,s)=>{let u;if(l.next<0)l.acceptToken(v0n);else if(s.context.flags&_fe)UEe(l.next)&&l.acceptToken(w0n,1);else if(((u=l.peek(-1))<0||UEe(u))&&s.canShift(d3t)){let h=0;for(;l.next==dAe||l.next==Vhe;)l.advance(),h++;(l.next==SM||l.next==fV||l.next==gAe)&&l.acceptToken(d3t,-h)}else UEe(l.next)&&l.acceptToken(m0n,1)},{contextual:!0}),bpn=new Xhe((l,s)=>{let u=s.context;if(u.flags)return;let h=l.peek(-1);if(h==SM||h==fV){let g=0,w=0;for(;;){if(l.next==dAe)g++;else if(l.next==Vhe)g+=8-g%8;else break;l.advance(),w++}g!=u.indent&&l.next!=SM&&l.next!=fV&&l.next!=gAe&&(g<u.indent?l.acceptToken(ZOt,-w):l.acceptToken(YOt))}}),_fe=1,r6t=2,Xk=4,Vk=8,Wk=16,Kk=32;function Dfe(l,s,u){this.parent=l,this.indent=s,this.flags=u,this.hash=(l?l.hash+l.hash<<8:0)+s+(s<<4)+u+(u<<6)}const mpn=new Dfe(null,0,0);function wpn(l){let s=0;for(let u=0;u<l.length;u++)s+=l.charCodeAt(u)==Vhe?8-s%8:1;return s}const m3t=new Map([[R0n,0],[$0n,Xk],[B0n,Vk],[z0n,Vk|Xk],[F0n,Wk],[q0n,Wk|Xk],[H0n,Wk|Vk],[Q0n,Wk|Vk|Xk],[G0n,Kk],[U0n,Kk|Xk],[J0n,Kk|Vk],[X0n,Kk|Vk|Xk],[V0n,Kk|Wk],[W0n,Kk|Wk|Xk],[K0n,Kk|Wk|Vk],[Y0n,Kk|Wk|Vk|Xk]].map(([l,s])=>[l,s|r6t])),vpn=new o0n({start:mpn,reduce(l,s,u,h){return l.flags&_fe&&gpn.has(s)||(s==I0n||s==t6t)&&l.flags&r6t?l.parent:l},shift(l,s,u,h){return s==YOt?new Dfe(l,wpn(h.read(h.pos,u.pos)),0):s==ZOt?l.parent:s==k0n||s==T0n||s==M0n||s==e6t?new Dfe(l,0,_fe):m3t.has(s)?new Dfe(l,0,m3t.get(s)|l.flags&_fe):l},hash(l){return l.hash}}),ypn=new Xhe(l=>{for(let s=0;s<5;s++){if(l.next!="print".charCodeAt(s))return;l.advance()}if(!/\w/.test(String.fromCharCode(l.next)))for(let s=0;;s++){let u=l.peek(s);if(!(u==dAe||u==Vhe)){u!=cpn&&u!=lpn&&u!=SM&&u!=fV&&u!=gAe&&l.acceptToken(b0n);return}}}),xpn=new Xhe((l,s)=>{let{flags:u}=s.context,h=u&Xk?i6t:n6t,g=(u&Vk)>0,w=!(u&Wk),p=(u&Kk)>0,k=l.pos;for(;!(l.next<0);)if(p&&l.next==fMe)if(l.peek(1)==fMe)l.advance(2);else{if(l.pos==k){l.acceptToken(e6t,1);return}break}else if(w&&l.next==b3t){if(l.pos==k){l.advance();let j=l.next;j>=0&&(l.advance(),kpn(l,j)),l.acceptToken(x0n);return}break}else if(l.next==b3t&&!w&&l.peek(1)>-1)l.advance(2);else if(l.next==h&&(!g||l.peek(1)==h&&l.peek(2)==h)){if(l.pos==k){l.acceptToken(g3t,g?3:1);return}break}else if(l.next==SM){if(g)l.advance();else if(l.pos==k){l.acceptToken(g3t);return}break}else l.advance();l.pos>k&&l.acceptToken(y0n)});function kpn(l,s){if(s==upn)for(let u=0;u<2&&l.next>=48&&l.next<=55;u++)l.advance();else if(s==apn)for(let u=0;u<2&&JEe(l.next);u++)l.advance();else if(s==hpn)for(let u=0;u<4&&JEe(l.next);u++)l.advance();else if(s==dpn)for(let u=0;u<8&&JEe(l.next);u++)l.advance();else if(s==fpn&&l.next==fMe){for(l.advance();l.next>=0&&l.next!=p3t&&l.next!=n6t&&l.next!=i6t&&l.next!=SM;)l.advance();l.next==p3t&&l.advance()}}const Opn=VOt({'async "*" "**" FormatConversion FormatSpec':qn.modifier,"for while if elif else try except finally return raise break continue with pass assert await yield match case":qn.controlKeyword,"in not and or is del":qn.operatorKeyword,"from def class global nonlocal lambda":qn.definitionKeyword,import:qn.moduleKeyword,"with as print":qn.keyword,Boolean:qn.bool,None:qn.null,VariableName:qn.variableName,"CallExpression/VariableName":qn.function(qn.variableName),"FunctionDefinition/VariableName":qn.function(qn.definition(qn.variableName)),"ClassDefinition/VariableName":qn.definition(qn.className),PropertyName:qn.propertyName,"CallExpression/MemberExpression/PropertyName":qn.function(qn.propertyName),Comment:qn.lineComment,Number:qn.number,String:qn.string,FormatString:qn.special(qn.string),Escape:qn.escape,UpdateOp:qn.updateOperator,"ArithOp!":qn.arithmeticOperator,BitOp:qn.bitwiseOperator,CompareOp:qn.compareOperator,AssignOp:qn.definitionOperator,Ellipsis:qn.punctuation,At:qn.meta,"( )":qn.paren,"[ ]":qn.squareBracket,"{ }":qn.brace,".":qn.derefOperator,", ;":qn.separator}),Spn={__proto__:null,await:44,or:54,and:56,in:60,not:62,is:64,if:70,else:72,lambda:76,yield:94,from:96,async:102,for:104,None:162,True:164,False:164,del:178,pass:182,break:186,continue:190,return:194,raise:202,import:206,as:208,global:212,nonlocal:214,assert:218,type:223,elif:236,while:240,try:246,except:248,finally:250,with:254,def:258,class:268,match:279,case:285},jpn=uhe.deserialize({version:14,states:"##jO`QeOOP$}OSOOO&WQtO'#HUOOQS'#Co'#CoOOQS'#Cp'#CpO'vQdO'#CnO*UQtO'#HTOOQS'#HU'#HUOOQS'#DU'#DUOOQS'#HT'#HTO*rQdO'#D_O+VQdO'#DfO+gQdO'#DjO+zOWO'#DuO,VOWO'#DvO.[QtO'#GuOOQS'#Gu'#GuO'vQdO'#GtO0ZQtO'#GtOOQS'#Eb'#EbO0rQdO'#EcOOQS'#Gs'#GsO0|QdO'#GrOOQV'#Gr'#GrO1XQdO'#FYOOQS'#G^'#G^O1^QdO'#FXOOQV'#IS'#ISOOQV'#Gq'#GqOOQV'#Fq'#FqQ`QeOOO'vQdO'#CqO1lQdO'#C}O1sQdO'#DRO2RQdO'#HYO2cQtO'#EVO'vQdO'#EWOOQS'#EY'#EYOOQS'#E['#E[OOQS'#E^'#E^O2wQdO'#E`O3_QdO'#EdO3rQdO'#EfO3zQtO'#EfO1XQdO'#EiO0rQdO'#ElO1XQdO'#EnO0rQdO'#EtO0rQdO'#EwO4VQdO'#EyO4^QdO'#FOO4iQdO'#EzO0rQdO'#FOO1XQdO'#FQO1XQdO'#FVO4nQdO'#F[P4uOdO'#GpPOOO)CBd)CBdOOQS'#Ce'#CeOOQS'#Cf'#CfOOQS'#Cg'#CgOOQS'#Ch'#ChOOQS'#Ci'#CiOOQS'#Cj'#CjOOQS'#Cl'#ClO'vQdO,59OO'vQdO,59OO'vQdO,59OO'vQdO,59OO'vQdO,59OO'vQdO,59OO5TQdO'#DoOOQS,5:Y,5:YO5hQdO'#HdOOQS,5:],5:]O5uQ!fO,5:]O5zQtO,59YO1lQdO,59bO1lQdO,59bO1lQdO,59bO8jQdO,59bO8oQdO,59bO8vQdO,59jO8}QdO'#HTO:TQdO'#HSOOQS'#HS'#HSOOQS'#D['#D[O:lQdO,59aO'vQdO,59aO:zQdO,59aOOQS,59y,59yO;PQdO,5:RO'vQdO,5:ROOQS,5:Q,5:QO;_QdO,5:QO;dQdO,5:XO'vQdO,5:XO'vQdO,5:VOOQS,5:U,5:UO;uQdO,5:UO;zQdO,5:WOOOW'#Fy'#FyO<POWO,5:aOOQS,5:a,5:aO<[QdO'#HwOOOW'#Dw'#DwOOOW'#Fz'#FzO<lOWO,5:bOOQS,5:b,5:bOOQS'#F}'#F}O<zQtO,5:iO?lQtO,5=`O@VQ#xO,5=`O@vQtO,5=`OOQS,5:},5:}OA_QeO'#GWOBqQdO,5;^OOQV,5=^,5=^OB|QtO'#IPOCkQdO,5;tOOQS-E:[-E:[OOQV,5;s,5;sO4dQdO'#FQOOQV-E9o-E9oOCsQtO,59]OEzQtO,59iOFeQdO'#HVOFpQdO'#HVO1XQdO'#HVOF{QdO'#DTOGTQdO,59mOGYQdO'#HZO'vQdO'#HZO0rQdO,5=tOOQS,5=t,5=tO0rQdO'#EROOQS'#ES'#ESOGwQdO'#GPOHXQdO,58|OHXQdO,58|O*xQdO,5:oOHgQtO'#H]OOQS,5:r,5:rOOQS,5:z,5:zOHzQdO,5;OOI]QdO'#IOO1XQdO'#H}OOQS,5;Q,5;QOOQS'#GT'#GTOIqQtO,5;QOJPQdO,5;QOJUQdO'#IQOOQS,5;T,5;TOJdQdO'#H|OOQS,5;W,5;WOJuQdO,5;YO4iQdO,5;`O4iQdO,5;cOJ}QtO'#ITO'vQdO'#ITOKXQdO,5;eO4VQdO,5;eO0rQdO,5;jO1XQdO,5;lOK^QeO'#EuOLjQgO,5;fO!!kQdO'#IUO4iQdO,5;jO!!vQdO,5;lO!#OQdO,5;qO!#ZQtO,5;vO'vQdO,5;vPOOO,5=[,5=[P!#bOSO,5=[P!#jOdO,5=[O!&bQtO1G.jO!&iQtO1G.jO!)YQtO1G.jO!)dQtO1G.jO!+}QtO1G.jO!,bQtO1G.jO!,uQdO'#HcO!-TQtO'#GuO0rQdO'#HcO!-_QdO'#HbOOQS,5:Z,5:ZO!-gQdO,5:ZO!-lQdO'#HeO!-wQdO'#HeO!.[QdO,5>OOOQS'#Ds'#DsOOQS1G/w1G/wOOQS1G.|1G.|O!/[QtO1G.|O!/cQtO1G.|O1lQdO1G.|O!0OQdO1G/UOOQS'#DZ'#DZO0rQdO,59tOOQS1G.{1G.{O!0VQdO1G/eO!0gQdO1G/eO!0oQdO1G/fO'vQdO'#H[O!0tQdO'#H[O!0yQtO1G.{O!1ZQdO,59iO!2aQdO,5=zO!2qQdO,5=zO!2yQdO1G/mO!3OQtO1G/mOOQS1G/l1G/lO!3`QdO,5=uO!4VQdO,5=uO0rQdO1G/qO!4tQdO1G/sO!4yQtO1G/sO!5ZQtO1G/qOOQS1G/p1G/pOOQS1G/r1G/rOOOW-E9w-E9wOOQS1G/{1G/{O!5kQdO'#HxO0rQdO'#HxO!5|QdO,5>cOOOW-E9x-E9xOOQS1G/|1G/|OOQS-E9{-E9{O!6[Q#xO1G2zO!6{QtO1G2zO'vQdO,5<jOOQS,5<j,5<jOOQS-E9|-E9|OOQS,5<r,5<rOOQS-E:U-E:UOOQV1G0x1G0xO1XQdO'#GRO!7dQtO,5>kOOQS1G1`1G1`O!8RQdO1G1`OOQS'#DV'#DVO0rQdO,5=qOOQS,5=q,5=qO!8WQdO'#FrO!8cQdO,59oO!8kQdO1G/XO!8uQtO,5=uOOQS1G3`1G3`OOQS,5:m,5:mO!9fQdO'#GtOOQS,5<k,5<kOOQS-E9}-E9}O!9wQdO1G.hOOQS1G0Z1G0ZO!:VQdO,5=wO!:gQdO,5=wO0rQdO1G0jO0rQdO1G0jO!:xQdO,5>jO!;ZQdO,5>jO1XQdO,5>jO!;lQdO,5>iOOQS-E:R-E:RO!;qQdO1G0lO!;|QdO1G0lO!<RQdO,5>lO!<aQdO,5>lO!<oQdO,5>hO!=VQdO,5>hO!=hQdO'#EpO0rQdO1G0tO!=sQdO1G0tO!=xQgO1G0zO!AvQgO1G0}O!EqQdO,5>oO!E{QdO,5>oO!FTQtO,5>oO0rQdO1G1PO!F_QdO1G1PO4iQdO1G1UO!!vQdO1G1WOOQV,5;a,5;aO!FdQfO,5;aO!FiQgO1G1QO!JjQdO'#GZO4iQdO1G1QO4iQdO1G1QO!JzQdO,5>pO!KXQdO,5>pO1XQdO,5>pOOQV1G1U1G1UO!KaQdO'#FSO!KrQ!fO1G1WO!KzQdO1G1WOOQV1G1]1G1]O4iQdO1G1]O!LPQdO1G1]O!LXQdO'#F^OOQV1G1b1G1bO!#ZQtO1G1bPOOO1G2v1G2vP!L^OSO1G2vOOQS,5=},5=}OOQS'#Dp'#DpO0rQdO,5=}O!LfQdO,5=|O!LyQdO,5=|OOQS1G/u1G/uO!MRQdO,5>PO!McQdO,5>PO!MkQdO,5>PO!NOQdO,5>PO!N`QdO,5>POOQS1G3j1G3jOOQS7+$h7+$hO!8kQdO7+$pO#!RQdO1G.|O#!YQdO1G.|OOQS1G/`1G/`OOQS,5<`,5<`O'vQdO,5<`OOQS7+%P7+%PO#!aQdO7+%POOQS-E9r-E9rOOQS7+%Q7+%QO#!qQdO,5=vO'vQdO,5=vOOQS7+$g7+$gO#!vQdO7+%PO##OQdO7+%QO##TQdO1G3fOOQS7+%X7+%XO##eQdO1G3fO##mQdO7+%XOOQS,5<_,5<_O'vQdO,5<_O##rQdO1G3aOOQS-E9q-E9qO#$iQdO7+%]OOQS7+%_7+%_O#$wQdO1G3aO#%fQdO7+%_O#%kQdO1G3gO#%{QdO1G3gO#&TQdO7+%]O#&YQdO,5>dO#&sQdO,5>dO#&sQdO,5>dOOQS'#Dx'#DxO#'UO&jO'#DzO#'aO`O'#HyOOOW1G3}1G3}O#'fQdO1G3}O#'nQdO1G3}O#'yQ#xO7+(fO#(jQtO1G2UP#)TQdO'#GOOOQS,5<m,5<mOOQS-E:P-E:POOQS7+&z7+&zOOQS1G3]1G3]OOQS,5<^,5<^OOQS-E9p-E9pOOQS7+$s7+$sO#)bQdO,5=`O#){QdO,5=`O#*^QtO,5<aO#*qQdO1G3cOOQS-E9s-E9sOOQS7+&U7+&UO#+RQdO7+&UO#+aQdO,5<nO#+uQdO1G4UOOQS-E:Q-E:QO#,WQdO1G4UOOQS1G4T1G4TOOQS7+&W7+&WO#,iQdO7+&WOOQS,5<p,5<pO#,tQdO1G4WOOQS-E:S-E:SOOQS,5<l,5<lO#-SQdO1G4SOOQS-E:O-E:OO1XQdO'#EqO#-jQdO'#EqO#-uQdO'#IRO#-}QdO,5;[OOQS7+&`7+&`O0rQdO7+&`O#.SQgO7+&fO!JmQdO'#GXO4iQdO7+&fO4iQdO7+&iO#2QQtO,5<tO'vQdO,5<tO#2[QdO1G4ZOOQS-E:W-E:WO#2fQdO1G4ZO4iQdO7+&kO0rQdO7+&kOOQV7+&p7+&pO!KrQ!fO7+&rO!KzQdO7+&rO`QeO1G0{OOQV-E:X-E:XO4iQdO7+&lO4iQdO7+&lOOQV,5<u,5<uO#2nQdO,5<uO!JmQdO,5<uOOQV7+&l7+&lO#2yQgO7+&lO#6tQdO,5<vO#7PQdO1G4[OOQS-E:Y-E:YO#7^QdO1G4[O#7fQdO'#IWO#7tQdO'#IWO1XQdO'#IWOOQS'#IW'#IWO#8PQdO'#IVOOQS,5;n,5;nO#8XQdO,5;nO0rQdO'#FUOOQV7+&r7+&rO4iQdO7+&rOOQV7+&w7+&wO4iQdO7+&wO#8^QfO,5;xOOQV7+&|7+&|POOO7+(b7+(bO#8cQdO1G3iOOQS,5<c,5<cO#8qQdO1G3hOOQS-E9u-E9uO#9UQdO,5<dO#9aQdO,5<dO#9tQdO1G3kOOQS-E9v-E9vO#:UQdO1G3kO#:^QdO1G3kO#:nQdO1G3kO#:UQdO1G3kOOQS<<H[<<H[O#:yQtO1G1zOOQS<<Hk<<HkP#;WQdO'#FtO8vQdO1G3bO#;eQdO1G3bO#;jQdO<<HkOOQS<<Hl<<HlO#;zQdO7+)QOOQS<<Hs<<HsO#<[QtO1G1yP#<{QdO'#FsO#=YQdO7+)RO#=jQdO7+)RO#=rQdO<<HwO#=wQdO7+({OOQS<<Hy<<HyO#>nQdO,5<bO'vQdO,5<bOOQS-E9t-E9tOOQS<<Hw<<HwOOQS,5<g,5<gO0rQdO,5<gO#>sQdO1G4OOOQS-E9y-E9yO#?^QdO1G4OO<[QdO'#H{OOOO'#D{'#D{OOOO'#F|'#F|O#?oO&jO,5:fOOOW,5>e,5>eOOOW7+)i7+)iO#?zQdO7+)iO#@SQdO1G2zO#@mQdO1G2zP'vQdO'#FuO0rQdO<<IpO1XQdO1G2YP1XQdO'#GSO#AOQdO7+)pO#AaQdO7+)pOOQS<<Ir<<IrP1XQdO'#GUP0rQdO'#GQOOQS,5;],5;]O#ArQdO,5>mO#BQQdO,5>mOOQS1G0v1G0vOOQS<<Iz<<IzOOQV-E:V-E:VO4iQdO<<JQOOQV,5<s,5<sO4iQdO,5<sOOQV<<JQ<<JQOOQV<<JT<<JTO#BYQtO1G2`P#BdQdO'#GYO#BkQdO7+)uO#BuQgO<<JVO4iQdO<<JVOOQV<<J^<<J^O4iQdO<<J^O!KrQ!fO<<J^O#FpQgO7+&gOOQV<<JW<<JWO#FzQgO<<JWOOQV1G2a1G2aO1XQdO1G2aO#JuQdO1G2aO4iQdO<<JWO1XQdO1G2bP0rQdO'#G[O#KQQdO7+)vO#K_QdO7+)vOOQS'#FT'#FTO0rQdO,5>rO#KgQdO,5>rO#KrQdO,5>rO#K}QdO,5>qO#L`QdO,5>qOOQS1G1Y1G1YOOQS,5;p,5;pOOQV<<Jc<<JcO#LhQdO1G1dOOQS7+)T7+)TP#LmQdO'#FwO#L}QdO1G2OO#MbQdO1G2OO#MrQdO1G2OP#M}QdO'#FxO#N[QdO7+)VO#NlQdO7+)VO#NlQdO7+)VO#NtQdO7+)VO$ UQdO7+(|O8vQdO7+(|OOQSAN>VAN>VO$ oQdO<<LmOOQSAN>cAN>cO0rQdO1G1|O$!PQtO1G1|P$!ZQdO'#FvOOQS1G2R1G2RP$!hQdO'#F{O$!uQdO7+)jO$#`QdO,5>gOOOO-E9z-E9zOOOW<<MT<<MTO$#nQdO7+(fOOQSAN?[AN?[OOQS7+'t7+'tO$$XQdO<<M[OOQS,5<q,5<qO$$jQdO1G4XOOQS-E:T-E:TOOQVAN?lAN?lOOQV1G2_1G2_O4iQdOAN?qO$$xQgOAN?qOOQVAN?xAN?xO4iQdOAN?xOOQV<<JR<<JRO4iQdOAN?rO4iQdO7+'{OOQV7+'{7+'{O1XQdO7+'{OOQVAN?rAN?rOOQS7+'|7+'|O$(sQdO<<MbOOQS1G4^1G4^O0rQdO1G4^OOQS,5<w,5<wO$)QQdO1G4]OOQS-E:Z-E:ZOOQU'#G_'#G_O$)cQfO7+'OO$)nQdO'#F_O$*uQdO7+'jO$+VQdO7+'jOOQS7+'j7+'jO$+bQdO<<LqO$+rQdO<<LqO$+rQdO<<LqO$+zQdO'#H^OOQS<<Lh<<LhO$,UQdO<<LhOOQS7+'h7+'hOOQS'#D|'#D|OOOO1G4R1G4RO$,oQdO1G4RO$,wQdO1G4RP!=hQdO'#GVOOQVG25]G25]O4iQdOG25]OOQVG25dG25dOOQVG25^G25^OOQV<<Kg<<KgO4iQdO<<KgOOQS7+)x7+)xP$-SQdO'#G]OOQU-E:]-E:]OOQV<<Jj<<JjO$-vQtO'#FaOOQS'#Fc'#FcO$.WQdO'#FbO$.xQdO'#FbOOQS'#Fb'#FbO$.}QdO'#IYO$)nQdO'#FiO$)nQdO'#FiO$/fQdO'#FjO$)nQdO'#FkO$/mQdO'#IZOOQS'#IZ'#IZO$0[QdO,5;yOOQS<<KU<<KUO$0dQdO<<KUO$0tQdOANB]O$1UQdOANB]O$1^QdO'#H_OOQS'#H_'#H_O1sQdO'#DcO$1wQdO,5=xOOQSANBSANBSOOOO7+)m7+)mO$2`QdO7+)mOOQVLD*wLD*wOOQVANARANARO5uQ!fO'#GaO$2hQtO,5<SO$)nQdO'#FmOOQS,5<W,5<WOOQS'#Fd'#FdO$3YQdO,5;|O$3_QdO,5;|OOQS'#Fg'#FgO$)nQdO'#G`O$4PQdO,5<QO$4kQdO,5>tO$4{QdO,5>tO1XQdO,5<PO$5^QdO,5<TO$5cQdO,5<TO$)nQdO'#I[O$5hQdO'#I[O$5mQdO,5<UOOQS,5<V,5<VO0rQdO'#FpOOQU1G1e1G1eO4iQdO1G1eOOQSAN@pAN@pO$5rQdOG27wO$6SQdO,59}OOQS1G3d1G3dOOOO<<MX<<MXOOQS,5<{,5<{OOQS-E:_-E:_O$6XQtO'#FaO$6`QdO'#I]O$6nQdO'#I]O$6vQdO,5<XOOQS1G1h1G1hO$6{QdO1G1hO$7QQdO,5<zOOQS-E:^-E:^O$7lQdO,5=OO$8TQdO1G4`OOQS-E:b-E:bOOQS1G1k1G1kOOQS1G1o1G1oO$8eQdO,5>vO$)nQdO,5>vOOQS1G1p1G1pOOQS,5<[,5<[OOQU7+'P7+'PO$+zQdO1G/iO$)nQdO,5<YO$8sQdO,5>wO$8zQdO,5>wOOQS1G1s1G1sOOQS7+'S7+'SP$)nQdO'#GdO$9SQdO1G4bO$9^QdO1G4bO$9fQdO1G4bOOQS7+%T7+%TO$9tQdO1G1tO$:SQtO'#FaO$:ZQdO,5<}OOQS,5<},5<}O$:iQdO1G4cOOQS-E:a-E:aO$)nQdO,5<|O$:pQdO,5<|O$:uQdO7+)|OOQS-E:`-E:`O$;PQdO7+)|O$)nQdO,5<ZP$)nQdO'#GcO$;XQdO1G2hO$)nQdO1G2hP$;gQdO'#GbO$;nQdO<<MhO$;xQdO1G1uO$<WQdO7+(SO8vQdO'#C}O8vQdO,59bO8vQdO,59bO8vQdO,59bO$<fQtO,5=`O8vQdO1G.|O0rQdO1G/XO0rQdO7+$pP$<yQdO'#GOO'vQdO'#GtO$=WQdO,59bO$=]QdO,59bO$=dQdO,59mO$=iQdO1G/UO1sQdO'#DRO8vQdO,59j",stateData:"$>S~O%cOS%^OSSOS%]PQ~OPdOVaOfoOhYOopOs!POvqO!PrO!Q{O!T!SO!U!RO!XZO!][O!h`O!r`O!s`O!t`O!{tO!}uO#PvO#RwO#TxO#XyO#ZzO#^|O#_|O#a}O#c!OO#l!QO#o!TO#s!UO#u!VO#z!WO#}hO$P!XO%oRO%pRO%tSO%uWO&Z]O&[]O&]]O&^]O&_]O&`]O&a]O&b]O&c^O&d^O&e^O&f^O&g^O&h^O&i^O&j^O~O%]!YO~OV!aO_!aOa!bOh!iO!X!kO!f!mO%j![O%k!]O%l!^O%m!_O%n!_O%o!`O%p!`O%q!aO%r!aO%s!aO~Ok%xXl%xXm%xXn%xXo%xXp%xXs%xXz%xX{%xX!x%xX#g%xX%[%xX%_%xX%z%xXg%xX!T%xX!U%xX%{%xX!W%xX![%xX!Q%xX#[%xXt%xX!m%xX~P%SOfoOhYO!XZO!][O!h`O!r`O!s`O!t`O%oRO%pRO%tSO%uWO&Z]O&[]O&]]O&^]O&_]O&`]O&a]O&b]O&c^O&d^O&e^O&f^O&g^O&h^O&i^O&j^O~Oz%wX{%wX#g%wX%[%wX%_%wX%z%wX~Ok!pOl!qOm!oOn!oOo!rOp!sOs!tO!x%wX~P)pOV!zOg!|Oo0cOv0qO!PrO~P'vOV#OOo0cOv0qO!W#PO~P'vOV#SOa#TOo0cOv0qO![#UO~P'vOQ#XO%`#XO%a#ZO~OQ#^OR#[O%`#^O%a#`O~OV%iX_%iXa%iXh%iXk%iXl%iXm%iXn%iXo%iXp%iXs%iXz%iX!X%iX!f%iX%j%iX%k%iX%l%iX%m%iX%n%iX%o%iX%p%iX%q%iX%r%iX%s%iXg%iX!T%iX!U%iX~O&Z]O&[]O&]]O&^]O&_]O&`]O&a]O&b]O&c^O&d^O&e^O&f^O&g^O&h^O&i^O&j^O{%iX!x%iX#g%iX%[%iX%_%iX%z%iX%{%iX!W%iX![%iX!Q%iX#[%iXt%iX!m%iX~P,eOz#dO{%hX!x%hX#g%hX%[%hX%_%hX%z%hX~Oo0cOv0qO~P'vO#g#gO%[#iO%_#iO~O%uWO~O!T#nO#u!VO#z!WO#}hO~OopO~P'vOV#sOa#tO%uWO{wP~OV#xOo0cOv0qO!Q#yO~P'vO{#{O!x$QO%z#|O#g!yX%[!yX%_!yX~OV#xOo0cOv0qO#g#SX%[#SX%_#SX~P'vOo0cOv0qO#g#WX%[#WX%_#WX~P'vOh$WO%uWO~O!f$YO!r$YO%uWO~OV$eO~P'vO!U$gO#s$hO#u$iO~O{$jO~OV$qO~P'vOS$sO%[$rO%_$rO%c$tO~OV$}Oa$}Og%POo0cOv0qO~P'vOo0cOv0qO{%SO~P'vO&Y%UO~Oa!bOh!iO!X!kO!f!mOVba_bakbalbambanbaobapbasbazba{ba!xba#gba%[ba%_ba%jba%kba%lba%mba%nba%oba%pba%qba%rba%sba%zbagba!Tba!Uba%{ba!Wba![ba!Qba#[batba!mba~On%ZO~Oo%ZO~P'vOo0cO~P'vOk0eOl0fOm0dOn0dOo0mOp0nOs0rOg%wX!T%wX!U%wX%{%wX!W%wX![%wX!Q%wX#[%wX!m%wX~P)pO%{%]Og%vXz%vX!T%vX!U%vX!W%vX{%vX~Og%_Oz%`O!T%dO!U%cO~Og%_O~Oz%gO!T%dO!U%cO!W&SX~O!W%kO~Oz%lO{%nO!T%dO!U%cO![%}X~O![%rO~O![%sO~OQ#XO%`#XO%a%uO~OV%wOo0cOv0qO!PrO~P'vOQ#^OR#[O%`#^O%a%zO~OV!qa_!qaa!qah!qak!qal!qam!qan!qao!qap!qas!qaz!qa{!qa!X!qa!f!qa!x!qa#g!qa%[!qa%_!qa%j!qa%k!qa%l!qa%m!qa%n!qa%o!qa%p!qa%q!qa%r!qa%s!qa%z!qag!qa!T!qa!U!qa%{!qa!W!qa![!qa!Q!qa#[!qat!qa!m!qa~P#yOz%|O{%ha!x%ha#g%ha%[%ha%_%ha%z%ha~P%SOV&OOopOvqO{%ha!x%ha#g%ha%[%ha%_%ha%z%ha~P'vOz%|O{%ha!x%ha#g%ha%[%ha%_%ha%z%ha~OPdOVaOopOvqO!PrO!Q{O!{tO!}uO#PvO#RwO#TxO#XyO#ZzO#^|O#_|O#a}O#c!OO#g$zX%[$zX%_$zX~P'vO#g#gO%[&TO%_&TO~O!f&UOh&sX%[&sXz&sX#[&sX#g&sX%_&sX#Z&sXg&sX~Oh!iO%[&WO~Okealeameaneaoeapeaseazea{ea!xea#gea%[ea%_ea%zeagea!Tea!Uea%{ea!Wea![ea!Qea#[eatea!mea~P%SOsqazqa{qa#gqa%[qa%_qa%zqa~Ok!pOl!qOm!oOn!oOo!rOp!sO!xqa~PEcO%z&YOz%yX{%yX~O%uWOz%yX{%yX~Oz&]O{wX~O{&_O~Oz%lO#g%}X%[%}X%_%}Xg%}X{%}X![%}X!m%}X%z%}X~OV0lOo0cOv0qO!PrO~P'vO%z#|O#gUa%[Ua%_Ua~Oz&hO#g&PX%[&PX%_&PXn&PX~P%SOz&kO!Q&jO#g#Wa%[#Wa%_#Wa~Oz&lO#[&nO#g&rX%[&rX%_&rXg&rX~O!f$YO!r$YO#Z&qO%uWO~O#Z&qO~Oz&sO#g&tX%[&tX%_&tX~Oz&uO#g&pX%[&pX%_&pX{&pX~O!X&wO%z&xO~Oz&|On&wX~P%SOn'PO~OPdOVaOopOvqO!PrO!Q{O!{tO!}uO#PvO#RwO#TxO#XyO#ZzO#^|O#_|O#a}O#c!OO%['UO~P'vOt'YO#p'WO#q'XOP#naV#naf#nah#nao#nas#nav#na!P#na!Q#na!T#na!U#na!X#na!]#na!h#na!r#na!s#na!t#na!{#na!}#na#P#na#R#na#T#na#X#na#Z#na#^#na#_#na#a#na#c#na#l#na#o#na#s#na#u#na#z#na#}#na$P#na%X#na%o#na%p#na%t#na%u#na&Z#na&[#na&]#na&^#na&_#na&`#na&a#na&b#na&c#na&d#na&e#na&f#na&g#na&h#na&i#na&j#na%Z#na%_#na~Oz'ZO#[']O{&xX~Oh'_O!X&wO~Oh!iO{$jO!X&wO~O{'eO~P%SO%['hO%_'hO~OS'iO%['hO%_'hO~OV!aO_!aOa!bOh!iO!X!kO!f!mO%l!^O%m!_O%n!_O%o!`O%p!`O%q!aO%r!aO%s!aOkWilWimWinWioWipWisWizWi{Wi!xWi#gWi%[Wi%_Wi%jWi%zWigWi!TWi!UWi%{Wi!WWi![Wi!QWi#[WitWi!mWi~O%k!]O~P!#uO%kWi~P!#uOV!aO_!aOa!bOh!iO!X!kO!f!mO%o!`O%p!`O%q!aO%r!aO%s!aOkWilWimWinWioWipWisWizWi{Wi!xWi#gWi%[Wi%_Wi%jWi%kWi%lWi%zWigWi!TWi!UWi%{Wi!WWi![Wi!QWi#[WitWi!mWi~O%m!_O%n!_O~P!&pO%mWi%nWi~P!&pOa!bOh!iO!X!kO!f!mOkWilWimWinWioWipWisWizWi{Wi!xWi#gWi%[Wi%_Wi%jWi%kWi%lWi%mWi%nWi%oWi%pWi%zWigWi!TWi!UWi%{Wi!WWi![Wi!QWi#[WitWi!mWi~OV!aO_!aO%q!aO%r!aO%s!aO~P!)nOVWi_Wi%qWi%rWi%sWi~P!)nO!T%dO!U%cOg&VXz&VX~O%z'kO%{'kO~P,eOz'mOg&UX~Og'oO~Oz'pO{'rO!W&XX~Oo0cOv0qOz'pO{'sO!W&XX~P'vO!W'uO~Om!oOn!oOo!rOp!sOkjisjizji{ji!xji#gji%[ji%_ji%zji~Ol!qO~P!.aOlji~P!.aOk0eOl0fOm0dOn0dOo0mOp0nO~Ot'wO~P!/jOV'|Og'}Oo0cOv0qO~P'vOg'}Oz(OO~Og(QO~O!U(SO~Og(TOz(OO!T%dO!U%cO~P%SOk0eOl0fOm0dOn0dOo0mOp0nOgqa!Tqa!Uqa%{qa!Wqa![qa!Qqa#[qatqa!mqa~PEcOV'|Oo0cOv0qO!W&Sa~P'vOz(WO!W&Sa~O!W(XO~Oz(WO!T%dO!U%cO!W&Sa~P%SOV(]Oo0cOv0qO![%}a#g%}a%[%}a%_%}ag%}a{%}a!m%}a%z%}a~P'vOz(^O![%}a#g%}a%[%}a%_%}ag%}a{%}a!m%}a%z%}a~O![(aO~Oz(^O!T%dO!U%cO![%}a~P%SOz(dO!T%dO!U%cO![&Ta~P%SOz(gO{&lX![&lX!m&lX%z&lX~O{(kO![(mO!m(nO%z(jO~OV&OOopOvqO{%hi!x%hi#g%hi%[%hi%_%hi%z%hi~P'vOz(pO{%hi!x%hi#g%hi%[%hi%_%hi%z%hi~O!f&UOh&sa%[&saz&sa#[&sa#g&sa%_&sa#Z&sag&sa~O%[(uO~OV#sOa#tO%uWO~Oz&]O{wa~OopOvqO~P'vOz(^O#g%}a%[%}a%_%}ag%}a{%}a![%}a!m%}a%z%}a~P%SOz(zO#g%hX%[%hX%_%hX%z%hX~O%z#|O#gUi%[Ui%_Ui~O#g&Pa%[&Pa%_&Pan&Pa~P'vOz(}O#g&Pa%[&Pa%_&Pan&Pa~O%uWO#g&ra%[&ra%_&rag&ra~Oz)SO#g&ra%[&ra%_&rag&ra~Og)VO~OV)WOh$WO%uWO~O#Z)XO~O%uWO#g&ta%[&ta%_&ta~Oz)ZO#g&ta%[&ta%_&ta~Oo0cOv0qO#g&pa%[&pa%_&pa{&pa~P'vOz)^O#g&pa%[&pa%_&pa{&pa~OV)`Oa)`O%uWO~O%z)eO~Ot)hO#j)gOP#hiV#hif#hih#hio#his#hiv#hi!P#hi!Q#hi!T#hi!U#hi!X#hi!]#hi!h#hi!r#hi!s#hi!t#hi!{#hi!}#hi#P#hi#R#hi#T#hi#X#hi#Z#hi#^#hi#_#hi#a#hi#c#hi#l#hi#o#hi#s#hi#u#hi#z#hi#}#hi$P#hi%X#hi%o#hi%p#hi%t#hi%u#hi&Z#hi&[#hi&]#hi&^#hi&_#hi&`#hi&a#hi&b#hi&c#hi&d#hi&e#hi&f#hi&g#hi&h#hi&i#hi&j#hi%Z#hi%_#hi~Ot)iOP#kiV#kif#kih#kio#kis#kiv#ki!P#ki!Q#ki!T#ki!U#ki!X#ki!]#ki!h#ki!r#ki!s#ki!t#ki!{#ki!}#ki#P#ki#R#ki#T#ki#X#ki#Z#ki#^#ki#_#ki#a#ki#c#ki#l#ki#o#ki#s#ki#u#ki#z#ki#}#ki$P#ki%X#ki%o#ki%p#ki%t#ki%u#ki&Z#ki&[#ki&]#ki&^#ki&_#ki&`#ki&a#ki&b#ki&c#ki&d#ki&e#ki&f#ki&g#ki&h#ki&i#ki&j#ki%Z#ki%_#ki~OV)kOn&wa~P'vOz)lOn&wa~Oz)lOn&wa~P%SOn)pO~O%Y)tO~Ot)wO#p'WO#q)vOP#niV#nif#nih#nio#nis#niv#ni!P#ni!Q#ni!T#ni!U#ni!X#ni!]#ni!h#ni!r#ni!s#ni!t#ni!{#ni!}#ni#P#ni#R#ni#T#ni#X#ni#Z#ni#^#ni#_#ni#a#ni#c#ni#l#ni#o#ni#s#ni#u#ni#z#ni#}#ni$P#ni%X#ni%o#ni%p#ni%t#ni%u#ni&Z#ni&[#ni&]#ni&^#ni&_#ni&`#ni&a#ni&b#ni&c#ni&d#ni&e#ni&f#ni&g#ni&h#ni&i#ni&j#ni%Z#ni%_#ni~OV)zOo0cOv0qO{$jO~P'vOo0cOv0qO{&xa~P'vOz*OO{&xa~OV*SOa*TOg*WO%q*UO%uWO~O{$jO&{*YO~Oh'_O~Oh!iO{$jO~O%[*_O~O%[*aO%_*aO~OV$}Oa$}Oo0cOv0qOg&Ua~P'vOz*dOg&Ua~Oo0cOv0qO{*gO!W&Xa~P'vOz*hO!W&Xa~Oo0cOv0qOz*hO{*kO!W&Xa~P'vOo0cOv0qOz*hO!W&Xa~P'vOz*hO{*kO!W&Xa~Om0dOn0dOo0mOp0nOgjikjisjizji!Tji!Uji%{ji!Wji{ji![ji#gji%[ji%_ji!Qji#[jitji!mji%zji~Ol0fO~P!NkOlji~P!NkOV'|Og*pOo0cOv0qO~P'vOn*rO~Og*pOz*tO~Og*uO~OV'|Oo0cOv0qO!W&Si~P'vOz*vO!W&Si~O!W*wO~OV(]Oo0cOv0qO![%}i#g%}i%[%}i%_%}ig%}i{%}i!m%}i%z%}i~P'vOz*zO!T%dO!U%cO![&Ti~Oz*}O![%}i#g%}i%[%}i%_%}ig%}i{%}i!m%}i%z%}i~O![+OO~Oa+QOo0cOv0qO![&Ti~P'vOz*zO![&Ti~O![+SO~OV+UOo0cOv0qO{&la![&la!m&la%z&la~P'vOz+VO{&la![&la!m&la%z&la~O!]+YO&n+[O![!nX~O![+^O~O{(kO![+_O~O{(kO![+_O!m+`O~OV&OOopOvqO{%hq!x%hq#g%hq%[%hq%_%hq%z%hq~P'vOz$ri{$ri!x$ri#g$ri%[$ri%_$ri%z$ri~P%SOV&OOopOvqO~P'vOV&OOo0cOv0qO#g%ha%[%ha%_%ha%z%ha~P'vOz+aO#g%ha%[%ha%_%ha%z%ha~Oz$ia#g$ia%[$ia%_$ian$ia~P%SO#g&Pi%[&Pi%_&Pin&Pi~P'vOz+dO#g#Wq%[#Wq%_#Wq~O#[+eOz$va#g$va%[$va%_$vag$va~O%uWO#g&ri%[&ri%_&rig&ri~Oz+gO#g&ri%[&ri%_&rig&ri~OV+iOh$WO%uWO~O%uWO#g&ti%[&ti%_&ti~Oo0cOv0qO#g&pi%[&pi%_&pi{&pi~P'vO{#{Oz#eX!W#eX~Oz+mO!W&uX~O!W+oO~Ot+rO#j)gOP#hqV#hqf#hqh#hqo#hqs#hqv#hq!P#hq!Q#hq!T#hq!U#hq!X#hq!]#hq!h#hq!r#hq!s#hq!t#hq!{#hq!}#hq#P#hq#R#hq#T#hq#X#hq#Z#hq#^#hq#_#hq#a#hq#c#hq#l#hq#o#hq#s#hq#u#hq#z#hq#}#hq$P#hq%X#hq%o#hq%p#hq%t#hq%u#hq&Z#hq&[#hq&]#hq&^#hq&_#hq&`#hq&a#hq&b#hq&c#hq&d#hq&e#hq&f#hq&g#hq&h#hq&i#hq&j#hq%Z#hq%_#hq~On$|az$|a~P%SOV)kOn&wi~P'vOz+yOn&wi~Oz,TO{$jO#[,TO~O#q,VOP#nqV#nqf#nqh#nqo#nqs#nqv#nq!P#nq!Q#nq!T#nq!U#nq!X#nq!]#nq!h#nq!r#nq!s#nq!t#nq!{#nq!}#nq#P#nq#R#nq#T#nq#X#nq#Z#nq#^#nq#_#nq#a#nq#c#nq#l#nq#o#nq#s#nq#u#nq#z#nq#}#nq$P#nq%X#nq%o#nq%p#nq%t#nq%u#nq&Z#nq&[#nq&]#nq&^#nq&_#nq&`#nq&a#nq&b#nq&c#nq&d#nq&e#nq&f#nq&g#nq&h#nq&i#nq&j#nq%Z#nq%_#nq~O#[,WOz%Oa{%Oa~Oo0cOv0qO{&xi~P'vOz,YO{&xi~O{#{O%z,[Og&zXz&zX~O%uWOg&zXz&zX~Oz,`Og&yX~Og,bO~O%Y,eO~O!T%dO!U%cOg&Viz&Vi~OV$}Oa$}Oo0cOv0qOg&Ui~P'vO{,hOz$la!W$la~Oo0cOv0qO{,iOz$la!W$la~P'vOo0cOv0qO{*gO!W&Xi~P'vOz,lO!W&Xi~Oo0cOv0qOz,lO!W&Xi~P'vOz,lO{,oO!W&Xi~Og$hiz$hi!W$hi~P%SOV'|Oo0cOv0qO~P'vOn,qO~OV'|Og,rOo0cOv0qO~P'vOV'|Oo0cOv0qO!W&Sq~P'vOz$gi![$gi#g$gi%[$gi%_$gig$gi{$gi!m$gi%z$gi~P%SOV(]Oo0cOv0qO~P'vOa+QOo0cOv0qO![&Tq~P'vOz,sO![&Tq~O![,tO~OV(]Oo0cOv0qO![%}q#g%}q%[%}q%_%}qg%}q{%}q!m%}q%z%}q~P'vO{,uO~OV+UOo0cOv0qO{&li![&li!m&li%z&li~P'vOz,zO{&li![&li!m&li%z&li~O!]+YO&n+[O![!na~O{(kO![,}O~OV&OOo0cOv0qO#g%hi%[%hi%_%hi%z%hi~P'vOz-OO#g%hi%[%hi%_%hi%z%hi~O%uWO#g&rq%[&rq%_&rqg&rq~Oz-RO#g&rq%[&rq%_&rqg&rq~OV)`Oa)`O%uWO!W&ua~Oz-TO!W&ua~On$|iz$|i~P%SOV)kO~P'vOV)kOn&wq~P'vOt-XOP#myV#myf#myh#myo#mys#myv#my!P#my!Q#my!T#my!U#my!X#my!]#my!h#my!r#my!s#my!t#my!{#my!}#my#P#my#R#my#T#my#X#my#Z#my#^#my#_#my#a#my#c#my#l#my#o#my#s#my#u#my#z#my#}#my$P#my%X#my%o#my%p#my%t#my%u#my&Z#my&[#my&]#my&^#my&_#my&`#my&a#my&b#my&c#my&d#my&e#my&f#my&g#my&h#my&i#my&j#my%Z#my%_#my~O%Z-]O%_-]O~P`O#q-^OP#nyV#nyf#nyh#nyo#nys#nyv#ny!P#ny!Q#ny!T#ny!U#ny!X#ny!]#ny!h#ny!r#ny!s#ny!t#ny!{#ny!}#ny#P#ny#R#ny#T#ny#X#ny#Z#ny#^#ny#_#ny#a#ny#c#ny#l#ny#o#ny#s#ny#u#ny#z#ny#}#ny$P#ny%X#ny%o#ny%p#ny%t#ny%u#ny&Z#ny&[#ny&]#ny&^#ny&_#ny&`#ny&a#ny&b#ny&c#ny&d#ny&e#ny&f#ny&g#ny&h#ny&i#ny&j#ny%Z#ny%_#ny~Oz-aO{$jO#[-aO~Oo0cOv0qO{&xq~P'vOz-dO{&xq~O%z,[Og&zaz&za~O{#{Og&zaz&za~OV*SOa*TO%q*UO%uWOg&ya~Oz-hOg&ya~O$S-lO~OV$}Oa$}Oo0cOv0qO~P'vOo0cOv0qO{-mOz$li!W$li~P'vOo0cOv0qOz$li!W$li~P'vO{-mOz$li!W$li~Oo0cOv0qO{*gO~P'vOo0cOv0qO{*gO!W&Xq~P'vOz-pO!W&Xq~Oo0cOv0qOz-pO!W&Xq~P'vOs-sO!T%dO!U%cOg&Oq!W&Oq![&Oqz&Oq~P!/jOa+QOo0cOv0qO![&Ty~P'vOz$ji![$ji~P%SOa+QOo0cOv0qO~P'vOV+UOo0cOv0qO~P'vOV+UOo0cOv0qO{&lq![&lq!m&lq%z&lq~P'vO{(kO![-xO!m-yO%z-wO~OV&OOo0cOv0qO#g%hq%[%hq%_%hq%z%hq~P'vO%uWO#g&ry%[&ry%_&ryg&ry~OV)`Oa)`O%uWO!W&ui~Ot-}OP#m!RV#m!Rf#m!Rh#m!Ro#m!Rs#m!Rv#m!R!P#m!R!Q#m!R!T#m!R!U#m!R!X#m!R!]#m!R!h#m!R!r#m!R!s#m!R!t#m!R!{#m!R!}#m!R#P#m!R#R#m!R#T#m!R#X#m!R#Z#m!R#^#m!R#_#m!R#a#m!R#c#m!R#l#m!R#o#m!R#s#m!R#u#m!R#z#m!R#}#m!R$P#m!R%X#m!R%o#m!R%p#m!R%t#m!R%u#m!R&Z#m!R&[#m!R&]#m!R&^#m!R&_#m!R&`#m!R&a#m!R&b#m!R&c#m!R&d#m!R&e#m!R&f#m!R&g#m!R&h#m!R&i#m!R&j#m!R%Z#m!R%_#m!R~Oo0cOv0qO{&xy~P'vOV*SOa*TO%q*UO%uWOg&yi~O$S-lO%Z.VO%_.VO~OV.aOh._O!X.^O!].`O!h.YO!s.[O!t.[O%p.XO%uWO&Z]O&[]O&]]O&^]O&_]O&`]O&a]O&b]O~Oo0cOv0qOz$lq!W$lq~P'vO{.fOz$lq!W$lq~Oo0cOv0qO{*gO!W&Xy~P'vOz.gO!W&Xy~Oo0cOv.kO~P'vOs-sO!T%dO!U%cOg&Oy!W&Oy![&Oyz&Oy~P!/jO{(kO![.nO~O{(kO![.nO!m.oO~OV*SOa*TO%q*UO%uWO~Oh.tO!f.rOz$TX#[$TX%j$TXg$TX~Os$TX{$TX!W$TX![$TX~P$-bO%o.vO%p.vOs$UXz$UX{$UX#[$UX%j$UX!W$UXg$UX![$UX~O!h.xO~Oz.|O#[/OO%j.yOs&|X{&|X!W&|Xg&|X~Oa/RO~P$)zOh.tOs&}Xz&}X{&}X#[&}X%j&}X!W&}Xg&}X![&}X~Os/VO{$jO~Oo0cOv0qOz$ly!W$ly~P'vOo0cOv0qO{*gO!W&X!R~P'vOz/ZO!W&X!R~Og&RXs&RX!T&RX!U&RX!W&RX![&RXz&RX~P!/jOs-sO!T%dO!U%cOg&Qa!W&Qa![&Qaz&Qa~O{(kO![/^O~O!f.rOh$[as$[az$[a{$[a#[$[a%j$[a!W$[ag$[a![$[a~O!h/eO~O%o.vO%p.vOs$Uaz$Ua{$Ua#[$Ua%j$Ua!W$Uag$Ua![$Ua~O%j.yOs$Yaz$Ya{$Ya#[$Ya!W$Yag$Ya![$Ya~Os&|a{&|a!W&|ag&|a~P$)nOz/jOs&|a{&|a!W&|ag&|a~O!W/mO~Og/mO~O{/oO~O![/pO~Oo0cOv0qO{*gO!W&X!Z~P'vO{/sO~O%z/tO~P$-bOz/uO#[/OO%j.yOg'PX~Oz/uOg'PX~Og/wO~O!h/xO~O#[/OOs%Saz%Sa{%Sa%j%Sa!W%Sag%Sa![%Sa~O#[/OO%j.yOs%Waz%Wa{%Wa!W%Wag%Wa~Os&|i{&|i!W&|ig&|i~P$)nOz/zO#[/OO%j.yO!['Oa~Og'Pa~P$)nOz0SOg'Pa~Oa0UO!['Oi~P$)zOz0WO!['Oi~Oz0WO#[/OO%j.yO!['Oi~O#[/OO%j.yOg$biz$bi~O%z0ZO~P$-bO#[/OO%j.yOg%Vaz%Va~Og'Pi~P$)nO{0^O~Oa0UO!['Oq~P$)zOz0`O!['Oq~O#[/OO%j.yOz%Ui![%Ui~Oa0UO~P$)zOa0UO!['Oy~P$)zO#[/OO%j.yOg$ciz$ci~O#[/OO%j.yOz%Uq![%Uq~Oz+aO#g%ha%[%ha%_%ha%z%ha~P%SOV&OOo0cOv0qO~P'vOn0hO~Oo0hO~P'vO{0iO~Ot0jO~P!/jO&]&Z&j&h&i&g&f&d&e&c&b&`&a&_&^&[%u~",goto:"!=j'QPPPPPP'RP'Z*s+[+t,_,y-fP.SP'Z.r.r'ZPPP'Z2[PPPPPP2[5PPP5PP7b7k=sPP=v>h>kPP'Z'ZPP>zPP'Z'ZPP'Z'Z'Z'Z'Z?O?w'ZP?zP@QDXGuGyPG|HWH['ZPPPH_Hk'RP'R'RP'RP'RP'RP'RP'R'R'RP'RPP'RPP'RP'RPHqH}IVPI^IdPI^PI^I^PPPI^PKrPK{LVL]KrPI^LfPI^PLmLsPLwM]MzNeLwLwNkNxLwLwLwLw! ^! d! g! l! o! y!!P!!]!!o!!u!#P!#V!#s!#y!$P!$Z!$a!$g!$y!%T!%Z!%a!%k!%q!%w!%}!&T!&Z!&e!&k!&u!&{!'U!'[!'k!'s!'}!(UPPPPPPPPPPP!([!(_!(e!(n!(x!)TPPPPPPPPPPPP!-u!/Z!3^!6oPP!6w!7W!7a!8Y!8P!8c!8i!8l!8o!8r!8z!9jPPPPPPPPPPPPPPPPP!9m!9q!9wP!:]!:a!:m!:v!;S!;j!;m!;p!;v!;|!<S!<VP!<_!<h!=d!=g]eOn#g$j)t,P'}`OTYZ[adnoprtxy}!P!Q!R!U!X!c!d!e!f!g!h!i!k!o!p!q!s!t!z#O#S#T#[#d#g#x#y#{#}$Q$e$g$h$j$q$}%S%Z%^%`%c%g%l%n%w%|&O&Z&_&h&j&k&u&x&|'P'W'Z'l'm'p'r's'w'|(O(S(W(](^(d(g(p(r(z(})^)e)g)k)l)p)t)z*O*Y*d*g*h*k*q*r*t*v*y*z*}+Q+U+V+Y+a+c+d+k+x+y,P,X,Y,],g,h,i,k,l,o,q,s,u,w,y,z-O-d-f-m-p-s.f.g/V/Z/s0c0d0e0f0h0i0j0k0l0n0r{!cQ#c#p$R$d$p%e%j%p%q&`'O'g(q(|)j*o*x+w,v0g}!dQ#c#p$R$d$p$u%e%j%p%q&`'O'g(q(|)j*o*x+w,v0g!P!eQ#c#p$R$d$p$u$v%e%j%p%q&`'O'g(q(|)j*o*x+w,v0g!R!fQ#c#p$R$d$p$u$v$w%e%j%p%q&`'O'g(q(|)j*o*x+w,v0g!T!gQ#c#p$R$d$p$u$v$w$x%e%j%p%q&`'O'g(q(|)j*o*x+w,v0g!V!hQ#c#p$R$d$p$u$v$w$x$y%e%j%p%q&`'O'g(q(|)j*o*x+w,v0g!Z!hQ!n#c#p$R$d$p$u$v$w$x$y$z%e%j%p%q&`'O'g(q(|)j*o*x+w,v0g'}TOTYZ[adnoprtxy}!P!Q!R!U!X!c!d!e!f!g!h!i!k!o!p!q!s!t!z#O#S#T#[#d#g#x#y#{#}$Q$e$g$h$j$q$}%S%Z%^%`%c%g%l%n%w%|&O&Z&_&h&j&k&u&x&|'P'W'Z'l'm'p'r's'w'|(O(S(W(](^(d(g(p(r(z(})^)e)g)k)l)p)t)z*O*Y*d*g*h*k*q*r*t*v*y*z*}+Q+U+V+Y+a+c+d+k+x+y,P,X,Y,],g,h,i,k,l,o,q,s,u,w,y,z-O-d-f-m-p-s.f.g/V/Z/s0c0d0e0f0h0i0j0k0l0n0r&eVOYZ[dnprxy}!P!Q!U!i!k!o!p!q!s!t#[#d#g#y#{#}$Q$h$j$}%S%Z%^%`%g%l%n%w%|&Z&_&j&k&u&x'P'W'Z'l'm'p'r's'w(O(W(^(d(g(p(r(z)^)e)g)p)t)z*O*Y*d*g*h*k*q*r*t*v*y*z*}+U+V+Y+a+d+k,P,X,Y,],g,h,i,k,l,o,q,s,u,w,y,z-O-d-f-m-p-s.f.g/V/Z/s0c0d0e0f0h0i0j0k0n0r%oXOYZ[dnrxy}!P!Q!U!i!k#[#d#g#y#{#}$Q$h$j$}%S%^%`%g%l%n%w%|&Z&_&j&k&u&x'P'W'Z'l'm'p'r's'w(O(W(^(d(g(p(r(z)^)e)g)p)t)z*O*Y*d*g*h*k*q*t*v*y*z*}+U+V+Y+a+d+k,P,X,Y,],g,h,i,k,l,o,s,u,w,y,z-O-d-f-m-p.f.g/V/Z0i0j0kQ#vqQ/[.kR0o0q't`OTYZ[adnoprtxy}!P!Q!R!U!X!c!d!e!f!g!h!k!o!p!q!s!t!z#O#S#T#[#d#g#x#y#{#}$Q$e$g$h$j$q$}%S%Z%^%`%c%g%l%n%w%|&O&Z&_&h&j&k&u&x&|'P'W'Z'l'p'r's'w'|(O(S(W(](^(d(g(p(r(z(})^)e)g)k)l)p)t)z*O*Y*g*h*k*q*r*t*v*y*z*}+Q+U+V+Y+a+c+d+k+x+y,P,X,Y,],h,i,k,l,o,q,s,u,w,y,z-O-d-f-m-p-s.f.g/V/Z/s0c0d0e0f0h0i0j0k0l0n0rh#jhz{$W$Z&l&q)S)X+f+g-RW#rq&].k0qQ$]|Q$a!OQ$n!VQ$o!WW$|!i'm*d,gS&[#s#tQ'S$iQ(s&UQ)U&nU)Y&s)Z+jW)a&w+m-T-{Q*Q']W*R'_,`-h.TQ+l)`S,_*S*TQ-Q+eQ-_,TQ-c,WQ.R-al.W-l.^._.a.z.|/R/j/o/t/y0U0Z0^Q/S.`Q/a.tQ/l/OU0P/u0S0[X0V/z0W0_0`R&Z#r!_!wYZ!P!Q!k%S%`%g'p'r's(O(W)g*g*h*k*q*t*v,h,i,k,l,o-m-p.f.g/ZR%^!vQ!{YQ%x#[Q&d#}Q&g$QR,{+YT.j-s/s!Y!jQ!n#c#p$R$d$p$u$v$w$x$y$z%e%j%p%q&`'O'g(q(|)j*o*x+w,v0gQ&X#kQ'c$oR*^'dR'l$|Q%V!mR/_.r'|_OTYZ[adnoprtxy}!P!Q!R!U!X!c!d!e!f!g!h!i!k!o!p!q!s!t!z#O#S#T#[#d#g#x#y#{#}$Q$e$g$h$j$q$}%S%Z%^%`%c%g%l%n%w%|&O&Z&_&h&j&k&u&x&|'P'W'Z'l'm'p'r's'w'|(O(S(W(](^(d(g(p(r(z(})^)e)g)k)l)p)t)z*O*Y*d*g*h*k*q*r*t*v*y*z*}+Q+U+V+Y+a+c+d+k+x+y,P,X,Y,],g,h,i,k,l,o,q,s,u,w,y,z-O-d-f-m-p-s.f.g/V/Z/s0c0d0e0f0h0i0j0k0l0n0rS#a_#b!P.[-l.^._.`.a.t.z.|/R/j/o/t/u/y/z0S0U0W0Z0[0^0_0`'|_OTYZ[adnoprtxy}!P!Q!R!U!X!c!d!e!f!g!h!i!k!o!p!q!s!t!z#O#S#T#[#d#g#x#y#{#}$Q$e$g$h$j$q$}%S%Z%^%`%c%g%l%n%w%|&O&Z&_&h&j&k&u&x&|'P'W'Z'l'm'p'r's'w'|(O(S(W(](^(d(g(p(r(z(})^)e)g)k)l)p)t)z*O*Y*d*g*h*k*q*r*t*v*y*z*}+Q+U+V+Y+a+c+d+k+x+y,P,X,Y,],g,h,i,k,l,o,q,s,u,w,y,z-O-d-f-m-p-s.f.g/V/Z/s0c0d0e0f0h0i0j0k0l0n0rT#a_#bT#^^#_R(o%xa(l%x(n(o+`,{-y-z.oT+[(k+]R-z,{Q$PsQ+l)aQ,^*RR-e,_X#}s$O$P&fQ&y$aQ'a$nQ'd$oR)s'SQ)b&wV-S+m-T-{ZgOn$j)t,PXkOn)t,PQ$k!TQ&z$bQ&{$cQ'^$mQ'b$oQ)q'RQ)x'WQ){'XQ)|'YQ*Z'`S*]'c'dQ+s)gQ+u)hQ+v)iQ+z)oS+|)r*[Q,Q)vQ,R)wS,S)y)zQ,d*^Q-V+rQ-W+tQ-Y+{S-Z+},OQ-`,UQ-b,VQ-|-XQ.O-[Q.P-^Q.Q-_Q.p-}Q.q.RQ/W.dR/r/XWkOn)t,PR#mjQ'`$nS)r'S'aR,O)sQ,]*RR-f,^Q*['`Q+})rR-[,OZiOjn)t,PQ'f$pR*`'gT-j,e-ku.c-l.^._.a.t.z.|/R/j/o/t/u/y0S0U0Z0[0^t.c-l.^._.a.t.z.|/R/j/o/t/u/y0S0U0Z0[0^Q/S.`X0V/z0W0_0`!P.Z-l.^._.`.a.t.z.|/R/j/o/t/u/y/z0S0U0W0Z0[0^0_0`Q.w.YR/f.xg.z.].{/b/i/n/|0O0Q0]0a0bu.b-l.^._.a.t.z.|/R/j/o/t/u/y0S0U0Z0[0^X.u.W.b/a0PR/c.tV0R/u0S0[R/X.dQnOS#on,PR,P)tQ&^#uR(x&^S%m#R#wS(_%m(bT(b%p&`Q%a!yQ%h!}W(P%a%h(U(YQ(U%eR(Y%jQ&i$RR)O&iQ(e%qQ*{(`T+R(e*{Q'n%OR*e'nS'q%R%SY*i'q*j,m-q.hU*j'r's'tU,m*k*l*mS-q,n,oR.h-rQ#Y]R%t#YQ#_^R%y#_Q(h%vS+W(h+XR+X(iQ+](kR,|+]Q#b_R%{#bQ#ebQ%}#cW&Q#e%}({+bQ({&cR+b0gQ$OsS&e$O&fR&f$PQ&v$_R)_&vQ&V#jR(t&VQ&m$VS)T&m+hR+h)UQ$Z{R&p$ZQ&t$]R)[&tQ+n)bR-U+nQ#hfR&S#hQ)f&zR+q)fQ&}$dS)m&})nR)n'OQ'V$kR)u'VQ'[$lS*P'[,ZR,Z*QQ,a*VR-i,aWjOn)t,PR#ljQ-k,eR.U-kd.{.]/b/i/n/|0O0Q0]0a0bR/h.{U.s.W/a0PR/`.sQ/{/nS0X/{0YR0Y/|S/v/b/cR0T/vQ.}.]R/k.}R!ZPXmOn)t,PWlOn)t,PR'T$jYfOn$j)t,PR&R#g[sOn#g$j)t,PR&d#}&dQOYZ[dnprxy}!P!Q!U!i!k!o!p!q!s!t#[#d#g#y#{#}$Q$h$j$}%S%Z%^%`%g%l%n%w%|&Z&_&j&k&u&x'P'W'Z'l'm'p'r's'w(O(W(^(d(g(p(r(z)^)e)g)p)t)z*O*Y*d*g*h*k*q*r*t*v*y*z*}+U+V+Y+a+d+k,P,X,Y,],g,h,i,k,l,o,q,s,u,w,y,z-O-d-f-m-p-s.f.g/V/Z/s0c0d0e0f0h0i0j0k0n0rQ!nTQ#caQ#poU$Rt%c(SS$d!R$gQ$p!XQ$u!cQ$v!dQ$w!eQ$x!fQ$y!gQ$z!hQ%e!zQ%j#OQ%p#SQ%q#TQ&`#xQ'O$eQ'g$qQ(q&OU(|&h(}+cW)j&|)l+x+yQ*o'|Q*x(]Q+w)kQ,v+QR0g0lQ!yYQ!}ZQ$b!PQ$c!QQ%R!kQ't%S^'{%`%g(O(W*q*t*v^*f'p*h,k,l-p.g/ZQ*l'rQ*m'sQ+t)gQ,j*gQ,n*kQ-n,hQ-o,iQ-r,oQ.e-mR/Y.f[bOn#g$j)t,P!^!vYZ!P!Q!k%S%`%g'p'r's(O(W)g*g*h*k*q*t*v,h,i,k,l,o-m-p.f.g/ZQ#R[Q#fdS#wrxQ$UyW$_}$Q'P)pS$l!U$hW${!i'm*d,gS%v#[+Y`&P#d%|(p(r(z+a-O0kQ&a#yQ&b#{Q&c#}Q'j$}Q'z%^W([%l(^*y*}Q(`%nQ(i%wQ(v&ZS(y&_0iQ)P&jQ)Q&kU)]&u)^+kQ)d&xQ)y'WY)}'Z*O,X,Y-dQ*b'lS*n'w0jW+P(d*z,s,wW+T(g+V,y,zQ+p)eQ,U)zQ,c*YQ,x+UQ-P+dQ-e,]Q-v,uQ.S-fR/q/VhUOn#d#g$j%|&_'w(p(r)t,P%U!uYZ[drxy}!P!Q!U!i!k#[#y#{#}$Q$h$}%S%^%`%g%l%n%w&Z&j&k&u&x'P'W'Z'l'm'p'r's(O(W(^(d(g(z)^)e)g)p)z*O*Y*d*g*h*k*q*t*v*y*z*}+U+V+Y+a+d+k,X,Y,],g,h,i,k,l,o,s,u,w,y,z-O-d-f-m-p.f.g/V/Z0i0j0kQ#qpW%W!o!s0d0nQ%X!pQ%Y!qQ%[!tQ%f0cS'v%Z0hQ'x0eQ'y0fQ,p*rQ-u,qS.i-s/sR0p0rU#uq.k0qR(w&][cOn#g$j)t,PZ!xY#[#}$Q+YQ#W[Q#zrR$TxQ%b!yQ%i!}Q%o#RQ'j${Q(V%eQ(Z%jQ(c%pQ(f%qQ*|(`Q,f*bQ-t,pQ.m-uR/].lQ$StQ(R%cR*s(SQ.l-sR/}/sR#QZR#V[R%Q!iQ%O!iV*c'm*d,g!Z!lQ!n#c#p$R$d$p$u$v$w$x$y$z%e%j%p%q&`'O'g(q(|)j*o*x+w,v0gR%T!kT#]^#_Q%x#[R,{+YQ(m%xS+_(n(oQ,}+`Q-x,{S.n-y-zR/^.oT+Z(k+]Q$`}Q&g$QQ)o'PR+{)pQ$XzQ)W&qR+i)XQ$XzQ&o$WQ)W&qR+i)XQ#khW$Vz$W&q)XQ$[{Q&r$ZZ)R&l)S+f+g-RR$^|R)c&wXlOn)t,PQ$f!RR'Q$gQ$m!UR'R$hR*X'_Q*V'_V-g,`-h.TQ.d-lQ/P.^R/Q._U.]-l.^._Q/U.aQ/b.tQ/g.zU/i.|/j/yQ/n/RQ/|/oQ0O/tU0Q/u0S0[Q0]0UQ0a0ZR0b0^R/T.`R/d.t",nodeNames:"⚠ print Escape { Comment Script AssignStatement * BinaryExpression BitOp BitOp BitOp BitOp ArithOp ArithOp @ ArithOp ** UnaryExpression ArithOp BitOp AwaitExpression await ) ( ParenthesizedExpression BinaryExpression or and CompareOp in not is UnaryExpression ConditionalExpression if else LambdaExpression lambda ParamList VariableName AssignOp , : NamedExpression AssignOp YieldExpression yield from TupleExpression ComprehensionExpression async for LambdaExpression ] [ ArrayExpression ArrayComprehensionExpression } { DictionaryExpression DictionaryComprehensionExpression SetExpression SetComprehensionExpression CallExpression ArgList AssignOp MemberExpression . PropertyName Number String FormatString FormatReplacement FormatSelfDoc FormatConversion FormatSpec FormatReplacement FormatSelfDoc ContinuedString Ellipsis None Boolean TypeDef AssignOp UpdateStatement UpdateOp ExpressionStatement DeleteStatement del PassStatement pass BreakStatement break ContinueStatement continue ReturnStatement return YieldStatement PrintStatement RaiseStatement raise ImportStatement import as ScopeStatement global nonlocal AssertStatement assert TypeDefinition type TypeParamList TypeParam StatementGroup ; IfStatement Body elif WhileStatement while ForStatement TryStatement try except finally WithStatement with FunctionDefinition def ParamList AssignOp TypeDef ClassDefinition class DecoratedStatement Decorator At MatchStatement match MatchBody MatchClause case CapturePattern LiteralPattern ArithOp ArithOp AsPattern OrPattern LogicOp AttributePattern SequencePattern MappingPattern StarPattern ClassPattern PatternArgList KeywordPattern KeywordPattern Guard",maxTerm:277,context:vpn,nodeProps:[["isolate",-5,4,71,72,73,77,""],["group",-15,6,85,87,88,90,92,94,96,98,99,100,102,105,108,110,"Statement Statement",-22,8,18,21,25,40,49,50,56,57,60,61,62,63,64,67,70,71,72,79,80,81,82,"Expression",-10,114,116,119,121,122,126,128,133,135,138,"Statement",-9,143,144,147,148,150,151,152,153,154,"Pattern"],["openedBy",23,"(",54,"[",58,"{"],["closedBy",24,")",55,"]",59,"}"]],propSources:[Opn],skippedNodes:[0,4],repeatNodeCount:34,tokenData:"!2|~R!`OX%TXY%oY[%T[]%o]p%Tpq%oqr'ars)Yst*xtu%Tuv,dvw-hwx.Uxy/tyz0[z{0r{|2S|}2p}!O3W!O!P4_!P!Q:Z!Q!R;k!R![>_![!]Do!]!^Es!^!_FZ!_!`Gk!`!aHX!a!b%T!b!cIf!c!dJU!d!eK^!e!hJU!h!i!#f!i!tJU!t!u!,|!u!wJU!w!x!.t!x!}JU!}#O!0S#O#P&o#P#Q!0j#Q#R!1Q#R#SJU#S#T%T#T#UJU#U#VK^#V#YJU#Y#Z!#f#Z#fJU#f#g!,|#g#iJU#i#j!.t#j#oJU#o#p!1n#p#q!1s#q#r!2a#r#s!2f#s$g%T$g;'SJU;'S;=`KW<%lOJU`%YT&n`O#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%T`%lP;=`<%l%To%v]&n`%c_OX%TXY%oY[%T[]%o]p%Tpq%oq#O%T#O#P&o#P#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%To&tX&n`OY%TYZ%oZ]%T]^%o^#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tc'f[&n`O!_%T!_!`([!`#T%T#T#U(r#U#f%T#f#g(r#g#h(r#h#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tc(cTmR&n`O#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tc(yT!mR&n`O#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk)aV&n`&[ZOr%Trs)vs#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk){V&n`Or%Trs*bs#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk*iT&n`&^ZO#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%To+PZS_&n`OY*xYZ%TZ]*x]^%T^#o*x#o#p+r#p#q*x#q#r+r#r;'S*x;'S;=`,^<%lO*x_+wTS_OY+rZ]+r^;'S+r;'S;=`,W<%lO+r_,ZP;=`<%l+ro,aP;=`<%l*xj,kV%rQ&n`O!_%T!_!`-Q!`#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tj-XT!xY&n`O#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tj-oV%lQ&n`O!_%T!_!`-Q!`#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk.]V&n`&ZZOw%Twx.rx#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk.wV&n`Ow%Twx/^x#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk/eT&n`&]ZO#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk/{ThZ&n`O#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tc0cTgR&n`O#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk0yXVZ&n`Oz%Tz{1f{!_%T!_!`-Q!`#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk1mVaR&n`O!_%T!_!`-Q!`#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk2ZV%oZ&n`O!_%T!_!`-Q!`#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tc2wTzR&n`O#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%To3_W%pZ&n`O!_%T!_!`-Q!`!a3w!a#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Td4OT&{S&n`O#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk4fX!fQ&n`O!O%T!O!P5R!P!Q%T!Q![6T![#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk5WV&n`O!O%T!O!P5m!P#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk5tT!rZ&n`O#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Ti6[a!hX&n`O!Q%T!Q![6T![!g%T!g!h7a!h!l%T!l!m9s!m#R%T#R#S6T#S#X%T#X#Y7a#Y#^%T#^#_9s#_#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Ti7fZ&n`O{%T{|8X|}%T}!O8X!O!Q%T!Q![8s![#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Ti8^V&n`O!Q%T!Q![8s![#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Ti8z]!hX&n`O!Q%T!Q![8s![!l%T!l!m9s!m#R%T#R#S8s#S#^%T#^#_9s#_#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Ti9zT!hX&n`O#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk:bX%qR&n`O!P%T!P!Q:}!Q!_%T!_!`-Q!`#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tj;UV%sQ&n`O!_%T!_!`-Q!`#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Ti;ro!hX&n`O!O%T!O!P=s!P!Q%T!Q![>_![!d%T!d!e?q!e!g%T!g!h7a!h!l%T!l!m9s!m!q%T!q!rA]!r!z%T!z!{Bq!{#R%T#R#S>_#S#U%T#U#V?q#V#X%T#X#Y7a#Y#^%T#^#_9s#_#c%T#c#dA]#d#l%T#l#mBq#m#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Ti=xV&n`O!Q%T!Q![6T![#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Ti>fc!hX&n`O!O%T!O!P=s!P!Q%T!Q![>_![!g%T!g!h7a!h!l%T!l!m9s!m#R%T#R#S>_#S#X%T#X#Y7a#Y#^%T#^#_9s#_#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Ti?vY&n`O!Q%T!Q!R@f!R!S@f!S#R%T#R#S@f#S#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Ti@mY!hX&n`O!Q%T!Q!R@f!R!S@f!S#R%T#R#S@f#S#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%TiAbX&n`O!Q%T!Q!YA}!Y#R%T#R#SA}#S#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%TiBUX!hX&n`O!Q%T!Q!YA}!Y#R%T#R#SA}#S#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%TiBv]&n`O!Q%T!Q![Co![!c%T!c!iCo!i#R%T#R#SCo#S#T%T#T#ZCo#Z#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%TiCv]!hX&n`O!Q%T!Q![Co![!c%T!c!iCo!i#R%T#R#SCo#S#T%T#T#ZCo#Z#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%ToDvV{_&n`O!_%T!_!`E]!`#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%TcEdT%{R&n`O#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%TkEzT#gZ&n`O#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%TkFbXmR&n`O!^%T!^!_F}!_!`([!`!a([!a#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%TjGUV%mQ&n`O!_%T!_!`-Q!`#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%TkGrV%zZ&n`O!_%T!_!`([!`#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%TkH`WmR&n`O!_%T!_!`([!`!aHx!a#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%TjIPV%nQ&n`O!_%T!_!`-Q!`#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%TkIoV_Q#}P&n`O!_%T!_!`-Q!`#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%ToJ_]&n`&YS%uZO!Q%T!Q![JU![!c%T!c!}JU!}#R%T#R#SJU#S#T%T#T#oJU#p#q%T#r$g%T$g;'SJU;'S;=`KW<%lOJUoKZP;=`<%lJUoKge&n`&YS%uZOr%Trs)Ysw%Twx.Ux!Q%T!Q![JU![!c%T!c!tJU!t!uLx!u!}JU!}#R%T#R#SJU#S#T%T#T#fJU#f#gLx#g#oJU#p#q%T#r$g%T$g;'SJU;'S;=`KW<%lOJUoMRa&n`&YS%uZOr%TrsNWsw%Twx! vx!Q%T!Q![JU![!c%T!c!}JU!}#R%T#R#SJU#S#T%T#T#oJU#p#q%T#r$g%T$g;'SJU;'S;=`KW<%lOJUkN_V&n`&`ZOr%TrsNts#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%TkNyV&n`Or%Trs! `s#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk! gT&n`&bZO#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk! }V&n`&_ZOw%Twx!!dx#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk!!iV&n`Ow%Twx!#Ox#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk!#VT&n`&aZO#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%To!#oe&n`&YS%uZOr%Trs!%Qsw%Twx!&px!Q%T!Q![JU![!c%T!c!tJU!t!u!(`!u!}JU!}#R%T#R#SJU#S#T%T#T#fJU#f#g!(`#g#oJU#p#q%T#r$g%T$g;'SJU;'S;=`KW<%lOJUk!%XV&n`&dZOr%Trs!%ns#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk!%sV&n`Or%Trs!&Ys#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk!&aT&n`&fZO#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk!&wV&n`&cZOw%Twx!'^x#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk!'cV&n`Ow%Twx!'xx#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk!(PT&n`&eZO#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%To!(ia&n`&YS%uZOr%Trs!)nsw%Twx!+^x!Q%T!Q![JU![!c%T!c!}JU!}#R%T#R#SJU#S#T%T#T#oJU#p#q%T#r$g%T$g;'SJU;'S;=`KW<%lOJUk!)uV&n`&hZOr%Trs!*[s#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk!*aV&n`Or%Trs!*vs#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk!*}T&n`&jZO#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk!+eV&n`&gZOw%Twx!+zx#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk!,PV&n`Ow%Twx!,fx#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk!,mT&n`&iZO#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%To!-Vi&n`&YS%uZOr%TrsNWsw%Twx! vx!Q%T!Q![JU![!c%T!c!dJU!d!eLx!e!hJU!h!i!(`!i!}JU!}#R%T#R#SJU#S#T%T#T#UJU#U#VLx#V#YJU#Y#Z!(`#Z#oJU#p#q%T#r$g%T$g;'SJU;'S;=`KW<%lOJUo!.}a&n`&YS%uZOr%Trs)Ysw%Twx.Ux!Q%T!Q![JU![!c%T!c!}JU!}#R%T#R#SJU#S#T%T#T#oJU#p#q%T#r$g%T$g;'SJU;'S;=`KW<%lOJUk!0ZT!XZ&n`O#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tc!0qT!WR&n`O#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tj!1XV%kQ&n`O!_%T!_!`-Q!`#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%T~!1sO!]~k!1zV%jR&n`O!_%T!_!`-Q!`#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%T~!2fO![~i!2mT%tX&n`O#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%T",tokenizers:[ypn,bpn,ppn,xpn,0,1,2,3,4],topRules:{Script:[0,5]},specialized:[{term:221,get:l=>Spn[l]||-1}],tokenPrec:7668});var XEe;const hI=new Eo;function Tpn(l){return Qi.define({combine:l?s=>s.concat(l):void 0})}const Epn=new Eo;class jy{constructor(s,u,h=[],g=""){this.data=s,this.name=g,Ic.prototype.hasOwnProperty("tree")||Object.defineProperty(Ic.prototype,"tree",{get(){return jd(this)}}),this.parser=u,this.extension=[T8.of(this),Ic.languageData.of((w,p,k)=>{let j=w3t(w,p,k),A=j.type.prop(hI);if(!A)return[];let _=w.facet(A),D=j.type.prop(Epn);if(D){let I=j.resolve(p-j.from,k);for(let B of D)if(B.test(I,w)){let F=w.facet(B.facet);return B.type=="replace"?F:F.concat(_)}}return _})].concat(h)}isActiveAt(s,u,h=-1){return w3t(s,u,h).type.prop(hI)==this.data}findRegions(s){let u=s.facet(T8);if((u==null?void 0:u.data)==this.data)return[{from:0,to:s.doc.length}];if(!u||!u.allowsNesting)return[];let h=[],g=(w,p)=>{if(w.prop(hI)==this.data){h.push({from:p,to:p+w.length});return}let k=w.prop(Eo.mounted);if(k){if(k.tree.prop(hI)==this.data){if(k.overlay)for(let j of k.overlay)h.push({from:j.from+p,to:j.to+p});else h.push({from:p,to:p+w.length});return}else if(k.overlay){let j=h.length;if(g(k.tree,k.overlay[0].from+p),h.length>j)return}}for(let j=0;j<w.children.length;j++){let A=w.children[j];A instanceof Bf&&g(A,w.positions[j]+p)}};return g(jd(s),0),h}get allowsNesting(){return!0}}jy.setState=Ds.define();function w3t(l,s,u){let h=l.facet(T8),g=jd(l).topNode;if(!h||h.allowsNesting)for(let w=g;w;w=w.enter(s,u,La.ExcludeBuffers|La.EnterBracketed))w.type.isTop&&(g=w);return g}class fhe extends jy{constructor(s,u,h){super(s,u,[],h),this.parser=u}static define(s){let u=Tpn(s.languageData);return new fhe(u,s.parser.configure({props:[hI.add(h=>h.isTop?u:void 0)]}),s.name)}configure(s,u){return new fhe(this.data,this.parser.configure(s),u||this.name)}get allowsNesting(){return this.parser.hasWrappers()}}function jd(l){let s=l.field(jy.state,!1);return s?s.tree:Bf.empty}class Cpn{constructor(s){this.doc=s,this.cursorPos=0,this.string="",this.cursor=s.iter()}get length(){return this.doc.length}syncTo(s){return this.string=this.cursor.next(s-this.cursorPos).value,this.cursorPos=s+this.string.length,this.cursorPos-this.string.length}chunk(s){return this.syncTo(s),this.string}get lineChunks(){return!0}read(s,u){let h=this.cursorPos-this.string.length;return s<h||u>=this.cursorPos?this.doc.sliceString(s,u):this.string.slice(s-h,u-h)}}let SX=null;class hhe{constructor(s,u,h=[],g,w,p,k,j){this.parser=s,this.state=u,this.fragments=h,this.tree=g,this.treeLen=w,this.viewport=p,this.skipped=k,this.scheduleOn=j,this.parse=null,this.tempSkipped=[]}static create(s,u,h){return new hhe(s,u,[],Bf.empty,0,h,[],null)}startParse(){return this.parser.startParse(new Cpn(this.state.doc),this.fragments)}work(s,u){return u!=null&&u>=this.state.doc.length&&(u=void 0),this.tree!=Bf.empty&&this.isDone(u??this.state.doc.length)?(this.takeTree(),!0):this.withContext(()=>{var h;if(typeof s=="number"){let g=Date.now()+s;s=()=>Date.now()>g}for(this.parse||(this.parse=this.startParse()),u!=null&&(this.parse.stoppedAt==null||this.parse.stoppedAt>u)&&u<this.state.doc.length&&this.parse.stopAt(u);;){let g=this.parse.advance();if(g)if(this.fragments=this.withoutTempSkipped(gM.addTree(g,this.fragments,this.parse.stoppedAt!=null)),this.treeLen=(h=this.parse.stoppedAt)!==null&&h!==void 0?h:this.state.doc.length,this.tree=g,this.parse=null,this.treeLen<(u??this.state.doc.length))this.parse=this.startParse();else return!0;if(s())return!1}})}takeTree(){let s,u;this.parse&&(s=this.parse.parsedPos)>=this.treeLen&&((this.parse.stoppedAt==null||this.parse.stoppedAt>s)&&this.parse.stopAt(s),this.withContext(()=>{for(;!(u=this.parse.advance()););}),this.treeLen=s,this.tree=u,this.fragments=this.withoutTempSkipped(gM.addTree(this.tree,this.fragments,!0)),this.parse=null)}withContext(s){let u=SX;SX=this;try{return s()}finally{SX=u}}withoutTempSkipped(s){for(let u;u=this.tempSkipped.pop();)s=v3t(s,u.from,u.to);return s}changes(s,u){let{fragments:h,tree:g,treeLen:w,viewport:p,skipped:k}=this;if(this.takeTree(),!s.empty){let j=[];if(s.iterChangedRanges((A,_,D,I)=>j.push({fromA:A,toA:_,fromB:D,toB:I})),h=gM.applyChanges(h,j),g=Bf.empty,w=0,p={from:s.mapPos(p.from,-1),to:s.mapPos(p.to,1)},this.skipped.length){k=[];for(let A of this.skipped){let _=s.mapPos(A.from,1),D=s.mapPos(A.to,-1);_<D&&k.push({from:_,to:D})}}}return new hhe(this.parser,u,h,g,w,p,k,this.scheduleOn)}updateViewport(s){if(this.viewport.from==s.from&&this.viewport.to==s.to)return!1;this.viewport=s;let u=this.skipped.length;for(let h=0;h<this.skipped.length;h++){let{from:g,to:w}=this.skipped[h];g<s.to&&w>s.from&&(this.fragments=v3t(this.fragments,g,w),this.skipped.splice(h--,1))}return this.skipped.length>=u?!1:(this.reset(),!0)}reset(){this.parse&&(this.takeTree(),this.parse=null)}skipUntilInView(s,u){this.skipped.push({from:s,to:u})}static getSkippingParser(s){return new class extends XOt{createParse(u,h,g){let w=g[0].from,p=g[g.length-1].to;return{parsedPos:w,advance(){let j=SX;if(j){for(let A of g)j.tempSkipped.push(A);s&&(j.scheduleOn=j.scheduleOn?Promise.all([j.scheduleOn,s]):s)}return this.parsedPos=p,new Bf(Ep.none,[],[],p-w)},stoppedAt:null,stopAt(){}}}}}isDone(s){s=Math.min(s,this.state.doc.length);let u=this.fragments;return this.treeLen>=s&&u.length&&u[0].from==0&&u[0].to>=s}static get(){return SX}}function v3t(l,s,u){return gM.applyChanges(l,[{fromA:s,toA:u,fromB:s,toB:u}])}class II{constructor(s){this.context=s,this.tree=s.tree}apply(s){if(!s.docChanged&&this.tree==this.context.tree)return this;let u=this.context.changes(s.changes,s.state),h=this.context.treeLen==s.startState.doc.length?void 0:Math.max(s.changes.mapPos(this.context.treeLen),u.viewport.to);return u.work(20,h)||u.takeTree(),new II(u)}static init(s){let u=Math.min(3e3,s.doc.length),h=hhe.create(s.facet(T8).parser,s,{from:0,to:u});return h.work(20,u)||h.takeTree(),new II(h)}}jy.state=Td.define({create:II.init,update(l,s){for(let u of s.effects)if(u.is(jy.setState))return u.value;return s.startState.facet(T8)!=s.state.facet(T8)?II.init(s.state):l.apply(s)}});let s6t=l=>{let s=setTimeout(()=>l(),500);return()=>clearTimeout(s)};typeof requestIdleCallback<"u"&&(s6t=l=>{let s=-1,u=setTimeout(()=>{s=requestIdleCallback(l,{timeout:400})},100);return()=>s<0?clearTimeout(u):cancelIdleCallback(s)});const VEe=typeof navigator<"u"&&(!((XEe=navigator.scheduling)===null||XEe===void 0)&&XEe.isInputPending)?()=>navigator.scheduling.isInputPending():null,Mpn=Xh.fromClass(class{constructor(s){this.view=s,this.working=null,this.workScheduled=0,this.chunkEnd=-1,this.chunkBudget=-1,this.work=this.work.bind(this),this.scheduleWork()}update(s){let u=this.view.state.field(jy.state).context;(u.updateViewport(s.view.viewport)||this.view.viewport.to>u.treeLen)&&this.scheduleWork(),(s.docChanged||s.selectionSet)&&(this.view.hasFocus&&(this.chunkBudget+=50),this.scheduleWork()),this.checkAsyncSchedule(u)}scheduleWork(){if(this.working)return;let{state:s}=this.view,u=s.field(jy.state);(u.tree!=u.context.tree||!u.context.isDone(s.doc.length))&&(this.working=s6t(this.work))}work(s){this.working=null;let u=Date.now();if(this.chunkEnd<u&&(this.chunkEnd<0||this.view.hasFocus)&&(this.chunkEnd=u+3e4,this.chunkBudget=3e3),this.chunkBudget<=0)return;let{state:h,viewport:{to:g}}=this.view,w=h.field(jy.state);if(w.tree==w.context.tree&&w.context.isDone(g+1e5))return;let p=Date.now()+Math.min(this.chunkBudget,100,s&&!VEe?Math.max(25,s.timeRemaining()-5):1e9),k=w.context.treeLen<g&&h.doc.length>g+1e3,j=w.context.work(()=>VEe&&VEe()||Date.now()>p,g+(k?0:1e5));this.chunkBudget-=Date.now()-u,(j||this.chunkBudget<=0)&&(w.context.takeTree(),this.view.dispatch({effects:jy.setState.of(new II(w.context))})),this.chunkBudget>0&&!(j&&!k)&&this.scheduleWork(),this.checkAsyncSchedule(w.context)}checkAsyncSchedule(s){s.scheduleOn&&(this.workScheduled++,s.scheduleOn.then(()=>this.scheduleWork()).catch(u=>kp(this.view.state,u)).then(()=>this.workScheduled--),s.scheduleOn=null)}destroy(){this.working&&this.working()}isWorking(){return!!(this.working||this.workScheduled>0)}},{eventHandlers:{focus(){this.scheduleWork()}}}),T8=Qi.define({combine(l){return l.length?l[0]:null},enables:l=>[jy.state,Mpn,Bi.contentAttributes.compute([l],s=>{let u=s.facet(l);return u&&u.name?{"data-language":u.name}:{}})]});class Apn{constructor(s,u=[]){this.language=s,this.support=u,this.extension=[s,u]}}const Npn=Qi.define(),_V=Qi.define({combine:l=>{if(!l.length)return"  ";let s=l[0];if(!s||/\S/.test(s)||Array.from(s).some(u=>u!=s[0]))throw new Error("Invalid indent unit: "+JSON.stringify(l[0]));return s}});function dhe(l){let s=l.facet(_V);return s.charCodeAt(0)==9?l.tabSize*s.length:s.length}function hV(l,s){let u="",h=l.tabSize,g=l.facet(_V)[0];if(g=="	"){for(;s>=h;)u+="	",s-=h;g=" "}for(let w=0;w<s;w++)u+=g;return u}function pAe(l,s){l instanceof Ic&&(l=new Whe(l));for(let h of l.state.facet(Npn)){let g=h(l,s);if(g!==void 0)return g}let u=jd(l.state);return u.length>=s?_pn(l,u,s):null}class Whe{constructor(s,u={}){this.state=s,this.options=u,this.unit=dhe(s)}lineAt(s,u=1){let h=this.state.doc.lineAt(s),{simulateBreak:g,simulateDoubleBreak:w}=this.options;return g!=null&&g>=h.from&&g<=h.to?w&&g==s?{text:"",from:s}:(u<0?g<s:g<=s)?{text:h.text.slice(g-h.from),from:g}:{text:h.text.slice(0,g-h.from),from:h.from}:h}textAfterPos(s,u=1){if(this.options.simulateDoubleBreak&&s==this.options.simulateBreak)return"";let{text:h,from:g}=this.lineAt(s,u);return h.slice(s-g,Math.min(h.length,s+100-g))}column(s,u=1){let{text:h,from:g}=this.lineAt(s,u),w=this.countColumn(h,s-g),p=this.options.overrideIndentation?this.options.overrideIndentation(g):-1;return p>-1&&(w+=p-this.countColumn(h,h.search(/\S|$/))),w}countColumn(s,u=s.length){return EV(s,this.state.tabSize,u)}lineIndent(s,u=1){let{text:h,from:g}=this.lineAt(s,u),w=this.options.overrideIndentation;if(w){let p=w(g);if(p>-1)return p}return this.countColumn(h,h.search(/\S|$/))}get simulatedBreak(){return this.options.simulateBreak||null}}const o6t=new Eo;function _pn(l,s,u){let h=s.resolveStack(u),g=s.resolveInner(u,-1).resolve(u,0).enterUnfinishedNodesBefore(u);if(g!=h.node){let w=[];for(let p=g;p&&!(p.from<h.node.from||p.to>h.node.to||p.from==h.node.from&&p.type==h.node.type);p=p.parent)w.push(p);for(let p=w.length-1;p>=0;p--)h={node:w[p],next:h}}return c6t(h,l,u)}function c6t(l,s,u){for(let h=l;h;h=h.next){let g=Lpn(h.node);if(g)return g(bAe.create(s,u,h))}return 0}function Dpn(l){return l.pos==l.options.simulateBreak&&l.options.simulateDoubleBreak}function Lpn(l){let s=l.type.prop(o6t);if(s)return s;let u=l.firstChild,h;if(u&&(h=u.type.prop(Eo.closedBy))){let g=l.lastChild,w=g&&h.indexOf(g.name)>-1;return p=>l6t(p,!0,1,void 0,w&&!Dpn(p)?g.from:void 0)}return l.parent==null?Ppn:null}function Ppn(){return 0}class bAe extends Whe{constructor(s,u,h){super(s.state,s.options),this.base=s,this.pos=u,this.context=h}get node(){return this.context.node}static create(s,u,h){return new bAe(s,u,h)}get textAfter(){return this.textAfterPos(this.pos)}get baseIndent(){return this.baseIndentFor(this.node)}baseIndentFor(s){let u=this.state.doc.lineAt(s.from);for(;;){let h=s.resolve(u.from);for(;h.parent&&h.parent.from==h.from;)h=h.parent;if(Ipn(h,s))break;u=this.state.doc.lineAt(h.from)}return this.lineIndent(u.from)}continue(){return c6t(this.context.next,this.base,this.pos)}}function Ipn(l,s){for(let u=s;u;u=u.parent)if(l==u)return!0;return!1}function Rpn(l){let s=l.node,u=s.childAfter(s.from),h=s.lastChild;if(!u)return null;let g=l.options.simulateBreak,w=l.state.doc.lineAt(u.from),p=g==null||g<=w.from?w.to:Math.min(w.to,g);for(let k=u.to;;){let j=s.childAfter(k);if(!j||j==h)return null;if(!j.type.isSkipped){if(j.from>=p)return null;let A=/^ */.exec(w.text.slice(u.to-w.from))[0].length;return{from:u.from,to:u.to+A}}k=j.to}}function WEe({closing:l,align:s=!0,units:u=1}){return h=>l6t(h,s,u,l)}function l6t(l,s,u,h,g){let w=l.textAfter,p=w.match(/^\s*/)[0].length,k=h&&w.slice(p,p+h.length)==h||g==l.pos+p,j=s?Rpn(l):null;return j?k?l.column(j.from):l.column(j.to):l.baseIndent+(k?0:l.unit*u)}const $pn=200;function Bpn(){return Ic.transactionFilter.of(l=>{if(!l.docChanged||!l.isUserEvent("input.type")&&!l.isUserEvent("input.complete"))return l;let s=l.startState.languageDataAt("indentOnInput",l.startState.selection.main.head);if(!s.length)return l;let u=l.newDoc,{head:h}=l.newSelection.main,g=u.lineAt(h);if(h>g.from+$pn)return l;let w=u.sliceString(g.from,h);if(!s.some(A=>A.test(w)))return l;let{state:p}=l,k=-1,j=[];for(let{head:A}of p.selection.ranges){let _=p.doc.lineAt(A);if(_.from==k)continue;k=_.from;let D=pAe(p,_.from);if(D==null)continue;let I=/^\s*/.exec(_.text)[0],B=hV(p,D);I!=B&&j.push({from:_.from,to:_.from+I.length,insert:B})}return j.length?[l,{changes:j,sequential:!0}]:l})}const zpn=Qi.define(),u6t=new Eo;function Fpn(l){let s=l.firstChild,u=l.lastChild;return s&&s.to<u.from?{from:s.to,to:u.type.isError?l.to:u.from}:null}function qpn(l,s,u){let h=jd(l);if(h.length<u)return null;let g=h.resolveStack(u,1),w=null;for(let p=g;p;p=p.next){let k=p.node;if(k.to<=u||k.from>u)continue;if(w&&k.from<s)break;let j=k.type.prop(u6t);if(j&&(k.to<h.length-50||h.length==l.doc.length||!Hpn(k))){let A=j(k,l);A&&A.from<=u&&A.from>=s&&A.to>u&&(w=A)}}return w}function Hpn(l){let s=l.lastChild;return s&&s.to==l.to&&s.type.isError}function ghe(l,s,u){for(let h of l.facet(zpn)){let g=h(l,s,u);if(g)return g}return qpn(l,s,u)}function a6t(l,s){let u=s.mapPos(l.from,1),h=s.mapPos(l.to,-1);return u>=h?void 0:{from:u,to:h}}const Khe=Ds.define({map:a6t}),DV=Ds.define({map:a6t});function f6t(l){let s=[];for(let{head:u}of l.state.selection.ranges)s.some(h=>h.from<=u&&h.to>=u)||s.push(l.lineBlockAt(u));return s}const jM=Td.define({create(){return Fr.none},update(l,s){s.isUserEvent("delete")&&s.changes.iterChangedRanges((u,h)=>l=y3t(l,u,h)),l=l.map(s.changes);for(let u of s.effects)if(u.is(Khe)&&!Qpn(l,u.value.from,u.value.to)){let{preparePlaceholder:h}=s.state.facet(g6t),g=h?Fr.replace({widget:new Kpn(h(s.state,u.value))}):x3t;l=l.update({add:[g.range(u.value.from,u.value.to)]})}else u.is(DV)&&(l=l.update({filter:(h,g)=>u.value.from!=h||u.value.to!=g,filterFrom:u.value.from,filterTo:u.value.to}));return s.selection&&(l=y3t(l,s.selection.main.head)),l},provide:l=>Bi.decorations.from(l),toJSON(l,s){let u=[];return l.between(0,s.doc.length,(h,g)=>{u.push(h,g)}),u},fromJSON(l){if(!Array.isArray(l)||l.length%2)throw new RangeError("Invalid JSON for fold state");let s=[];for(let u=0;u<l.length;){let h=l[u++],g=l[u++];if(typeof h!="number"||typeof g!="number")throw new RangeError("Invalid JSON for fold state");s.push(x3t.range(h,g))}return Fr.set(s,!0)}});function y3t(l,s,u=s){let h=!1;return l.between(s,u,(g,w)=>{g<u&&w>s&&(h=!0)}),h?l.update({filterFrom:s,filterTo:u,filter:(g,w)=>g>=u||w<=s}):l}function phe(l,s,u){var h;let g=null;return(h=l.field(jM,!1))===null||h===void 0||h.between(s,u,(w,p)=>{(!g||g.from>w)&&(g={from:w,to:p})}),g}function Qpn(l,s,u){let h=!1;return l.between(s,s,(g,w)=>{g==s&&w==u&&(h=!0)}),h}function h6t(l,s){return l.field(jM,!1)?s:s.concat(Ds.appendConfig.of(p6t()))}const Gpn=l=>{for(let s of f6t(l)){let u=ghe(l.state,s.from,s.to);if(u)return l.dispatch({effects:h6t(l.state,[Khe.of(u),d6t(l,u)])}),!0}return!1},Upn=l=>{if(!l.state.field(jM,!1))return!1;let s=[];for(let u of f6t(l)){let h=phe(l.state,u.from,u.to);h&&s.push(DV.of(h),d6t(l,h,!1))}return s.length&&l.dispatch({effects:s}),s.length>0};function d6t(l,s,u=!0){let h=l.state.doc.lineAt(s.from).number,g=l.state.doc.lineAt(s.to).number;return Bi.announce.of(`${l.state.phrase(u?"Folded lines":"Unfolded lines")} ${h} ${l.state.phrase("to")} ${g}.`)}const Jpn=l=>{let{state:s}=l,u=[];for(let h=0;h<s.doc.length;){let g=l.lineBlockAt(h),w=ghe(s,g.from,g.to);w&&u.push(Khe.of(w)),h=(w?l.lineBlockAt(w.to):g).to+1}return u.length&&l.dispatch({effects:h6t(l.state,u)}),!!u.length},Xpn=l=>{let s=l.state.field(jM,!1);if(!s||!s.size)return!1;let u=[];return s.between(0,l.state.doc.length,(h,g)=>{u.push(DV.of({from:h,to:g}))}),l.dispatch({effects:u}),!0},Vpn=[{key:"Ctrl-Shift-[",mac:"Cmd-Alt-[",run:Gpn},{key:"Ctrl-Shift-]",mac:"Cmd-Alt-]",run:Upn},{key:"Ctrl-Alt-[",run:Jpn},{key:"Ctrl-Alt-]",run:Xpn}],Wpn={placeholderDOM:null,preparePlaceholder:null,placeholderText:"…"},g6t=Qi.define({combine(l){return Z3(l,Wpn)}});function p6t(l){return[jM,ebn]}function b6t(l,s){let{state:u}=l,h=u.facet(g6t),g=p=>{let k=l.lineBlockAt(l.posAtDOM(p.target)),j=phe(l.state,k.from,k.to);j&&l.dispatch({effects:DV.of(j)}),p.preventDefault()};if(h.placeholderDOM)return h.placeholderDOM(l,g,s);let w=document.createElement("span");return w.textContent=h.placeholderText,w.setAttribute("aria-label",u.phrase("folded code")),w.title=u.phrase("unfold"),w.className="cm-foldPlaceholder",w.onclick=g,w}const x3t=Fr.replace({widget:new class extends lO{toDOM(l){return b6t(l,null)}}});class Kpn extends lO{constructor(s){super(),this.value=s}eq(s){return this.value==s.value}toDOM(s){return b6t(s,this.value)}}const Ypn={openText:"⌄",closedText:"›",markerDOM:null,domEventHandlers:{},foldingChanged:()=>!1};class KEe extends K3{constructor(s,u){super(),this.config=s,this.open=u}eq(s){return this.config==s.config&&this.open==s.open}toDOM(s){if(this.config.markerDOM)return this.config.markerDOM(this.open);let u=document.createElement("span");return u.textContent=this.open?this.config.openText:this.config.closedText,u.title=s.state.phrase(this.open?"Fold line":"Unfold line"),u}}function Zpn(l={}){let s={...Ypn,...l},u=new KEe(s,!0),h=new KEe(s,!1),g=Xh.fromClass(class{constructor(p){this.from=p.viewport.from,this.markers=this.buildMarkers(p)}update(p){(p.docChanged||p.viewportChanged||p.startState.facet(T8)!=p.state.facet(T8)||p.startState.field(jM,!1)!=p.state.field(jM,!1)||jd(p.startState)!=jd(p.state)||s.foldingChanged(p))&&(this.markers=this.buildMarkers(p.view))}buildMarkers(p){let k=new x8;for(let j of p.viewportLineBlocks){let A=phe(p.state,j.from,j.to)?h:ghe(p.state,j.from,j.to)?u:null;A&&k.add(j.from,j.from,A)}return k.finish()}}),{domEventHandlers:w}=s;return[g,FOt({class:"cm-foldGutter",markers(p){var k;return((k=p.plugin(g))===null||k===void 0?void 0:k.markers)||xo.empty},initialSpacer(){return new KEe(s,!1)},domEventHandlers:{...w,click:(p,k,j)=>{if(w.click&&w.click(p,k,j))return!0;let A=phe(p.state,k.from,k.to);if(A)return p.dispatch({effects:DV.of(A)}),!0;let _=ghe(p.state,k.from,k.to);return _?(p.dispatch({effects:Khe.of(_)}),!0):!1}}}),p6t()]}const ebn=Bi.baseTheme({".cm-foldPlaceholder":{backgroundColor:"#eee",border:"1px solid #ddd",color:"#888",borderRadius:".2em",margin:"0 1px",padding:"0 1px",cursor:"pointer"},".cm-foldGutter span":{padding:"0 1px",cursor:"pointer"}});class Yhe{constructor(s,u){this.specs=s;let h;function g(k){let j=k8.newName();return(h||(h=Object.create(null)))["."+j]=k,j}const w=typeof u.all=="string"?u.all:u.all?g(u.all):void 0,p=u.scope;this.scope=p instanceof jy?k=>k.prop(hI)==p.data:p?k=>k==p:void 0,this.style=KOt(s.map(k=>({tag:k.tag,class:k.class||g(Object.assign({},k,{tag:null}))})),{all:w}).style,this.module=h?new k8(h):null,this.themeType=u.themeType}static define(s,u){return new Yhe(s,u||{})}}const hMe=Qi.define(),tbn=Qi.define({combine(l){return l.length?[l[0]]:null}});function YEe(l){let s=l.facet(hMe);return s.length?s:l.facet(tbn)}function nbn(l,s){let u=[rbn],h;return l instanceof Yhe&&(l.module&&u.push(Bi.styleModule.of(l.module)),h=l.themeType),h?u.push(hMe.computeN([Bi.darkTheme],g=>g.facet(Bi.darkTheme)==(h=="dark")?[l]:[])):u.push(hMe.of(l)),u}class ibn{constructor(s){this.markCache=Object.create(null),this.tree=jd(s.state),this.decorations=this.buildDeco(s,YEe(s.state)),this.decoratedTo=s.viewport.to}update(s){let u=jd(s.state),h=YEe(s.state),g=h!=YEe(s.startState),{viewport:w}=s.view,p=s.changes.mapPos(this.decoratedTo,1);u.length<w.to&&!g&&u.type==this.tree.type&&p>=w.to?(this.decorations=this.decorations.map(s.changes),this.decoratedTo=p):(u!=this.tree||s.viewportChanged||g)&&(this.tree=u,this.decorations=this.buildDeco(s.view,h),this.decoratedTo=w.to)}buildDeco(s,u){if(!u||!this.tree.length)return Fr.none;let h=new x8;for(let{from:g,to:w}of s.visibleRanges)d0n(this.tree,u,(p,k,j)=>{h.add(p,k,this.markCache[j]||(this.markCache[j]=Fr.mark({class:j})))},g,w);return h.finish()}}const rbn=E8.high(Xh.fromClass(ibn,{decorations:l=>l.decorations})),sbn=Bi.baseTheme({"&.cm-focused .cm-matchingBracket":{backgroundColor:"#328c8252"},"&.cm-focused .cm-nonmatchingBracket":{backgroundColor:"#bb555544"}}),m6t=1e4,w6t="()[]{}",v6t=Qi.define({combine(l){return Z3(l,{afterCursor:!0,brackets:w6t,maxScanDistance:m6t,renderMatch:lbn})}}),obn=Fr.mark({class:"cm-matchingBracket"}),cbn=Fr.mark({class:"cm-nonmatchingBracket"});function lbn(l){let s=[],u=l.matched?obn:cbn;return s.push(u.range(l.start.from,l.start.to)),l.end&&s.push(u.range(l.end.from,l.end.to)),s}function k3t(l){let s=[],u=l.facet(v6t);for(let h of l.selection.ranges){if(!h.empty)continue;let g=U3(l,h.head,-1,u)||h.head>0&&U3(l,h.head-1,1,u)||u.afterCursor&&(U3(l,h.head,1,u)||h.head<l.doc.length&&U3(l,h.head+1,-1,u));g&&(s=s.concat(u.renderMatch(g,l)))}return Fr.set(s,!0)}const ubn=Xh.fromClass(class{constructor(l){this.paused=!1,this.decorations=k3t(l.state)}update(l){(l.docChanged||l.selectionSet||this.paused)&&(l.view.composing?(this.decorations=this.decorations.map(l.changes),this.paused=!0):(this.decorations=k3t(l.state),this.paused=!1))}},{decorations:l=>l.decorations}),abn=[ubn,sbn];function fbn(l={}){return[v6t.of(l),abn]}const hbn=new Eo;function dMe(l,s,u){let h=l.prop(s<0?Eo.openedBy:Eo.closedBy);if(h)return h;if(l.name.length==1){let g=u.indexOf(l.name);if(g>-1&&g%2==(s<0?1:0))return[u[g+s]]}return null}function gMe(l){let s=l.type.prop(hbn);return s?s(l.node):l}function U3(l,s,u,h={}){let g=h.maxScanDistance||m6t,w=h.brackets||w6t,p=jd(l),k=p.resolveInner(s,u);for(let j=k;j;j=j.parent){let A=dMe(j.type,u,w);if(A&&j.from<j.to){let _=gMe(j);if(_&&(u>0?s>=_.from&&s<_.to:s>_.from&&s<=_.to))return dbn(l,s,u,j,_,A,w)}}return gbn(l,s,u,p,k.type,g,w)}function dbn(l,s,u,h,g,w,p){let k=h.parent,j={from:g.from,to:g.to},A=0,_=k==null?void 0:k.cursor();if(_&&(u<0?_.childBefore(h.from):_.childAfter(h.to)))do if(u<0?_.to<=h.from:_.from>=h.to){if(A==0&&w.indexOf(_.type.name)>-1&&_.from<_.to){let D=gMe(_);return{start:j,end:D?{from:D.from,to:D.to}:void 0,matched:!0}}else if(dMe(_.type,u,p))A++;else if(dMe(_.type,-u,p)){if(A==0){let D=gMe(_);return{start:j,end:D&&D.from<D.to?{from:D.from,to:D.to}:void 0,matched:!1}}A--}}while(u<0?_.prevSibling():_.nextSibling());return{start:j,matched:!1}}function gbn(l,s,u,h,g,w,p){let k=u<0?l.sliceDoc(s-1,s):l.sliceDoc(s,s+1),j=p.indexOf(k);if(j<0||j%2==0!=u>0)return null;let A={from:u<0?s-1:s,to:u>0?s+1:s},_=l.doc.iterRange(s,u>0?l.doc.length:0),D=0;for(let I=0;!_.next().done&&I<=w;){let B=_.value;u<0&&(I+=B.length);let F=s+I*u;for(let U=u>0?0:B.length-1,K=u>0?B.length:-1;U!=K;U+=u){let Y=p.indexOf(B[U]);if(!(Y<0||h.resolveInner(F+U,1).type!=g))if(Y%2==0==u>0)D++;else{if(D==1)return{start:A,end:{from:F+U,to:F+U+1},matched:Y>>1==j>>1};D--}}u>0&&(I+=B.length)}return _.done?{start:A,matched:!1}:null}const pbn=Object.create(null),O3t=[Ep.none],S3t=[],j3t=Object.create(null),bbn=Object.create(null);for(let[l,s]of[["variable","variableName"],["variable-2","variableName.special"],["string-2","string.special"],["def","variableName.definition"],["tag","tagName"],["attribute","attributeName"],["type","typeName"],["builtin","variableName.standard"],["qualifier","modifier"],["error","invalid"],["header","heading"],["property","propertyName"]])bbn[l]=mbn(pbn,s);function ZEe(l,s){S3t.indexOf(l)>-1||(S3t.push(l),console.warn(s))}function mbn(l,s){let u=[];for(let k of s.split(" ")){let j=[];for(let A of k.split(".")){let _=l[A]||qn[A];_?typeof _=="function"?j.length?j=j.map(_):ZEe(A,`Modifier ${A} used at start of tag`):j.length?ZEe(A,`Tag ${A} used as modifier`):j=Array.isArray(_)?_:[_]:ZEe(A,`Unknown highlighting tag ${A}`)}for(let A of j)u.push(A)}if(!u.length)return 0;let h=s.replace(/ /g,"_"),g=h+" "+u.map(k=>k.id),w=j3t[g];if(w)return w.id;let p=j3t[g]=Ep.define({id:O3t.length,name:h,props:[VOt({[h]:u})]});return O3t.push(p),p.id}Yl.RTL,Yl.LTR;class y6t{constructor(s,u,h,g){this.state=s,this.pos=u,this.explicit=h,this.view=g,this.abortListeners=[],this.abortOnDocChange=!1}tokenBefore(s){let u=jd(this.state).resolveInner(this.pos,-1);for(;u&&s.indexOf(u.name)<0;)u=u.parent;return u?{from:u.from,to:this.pos,text:this.state.sliceDoc(u.from,this.pos),type:u.type}:null}matchBefore(s){let u=this.state.doc.lineAt(this.pos),h=Math.max(u.from,this.pos-250),g=u.text.slice(h-u.from,this.pos-u.from),w=g.search(k6t(s,!1));return w<0?null:{from:h+w,to:this.pos,text:g.slice(w)}}get aborted(){return this.abortListeners==null}addEventListener(s,u,h){s=="abort"&&this.abortListeners&&(this.abortListeners.push(u),h&&h.onDocChange&&(this.abortOnDocChange=!0))}}function T3t(l){let s=Object.keys(l).join(""),u=/\w/.test(s);return u&&(s=s.replace(/\w/g,"")),`[${u?"\\w":""}${s.replace(/[^\w\s]/g,"\\$&")}]`}function wbn(l){let s=Object.create(null),u=Object.create(null);for(let{label:g}of l){s[g[0]]=!0;for(let w=1;w<g.length;w++)u[g[w]]=!0}let h=T3t(s)+T3t(u)+"*$";return[new RegExp("^"+h),new RegExp(h)]}function x6t(l){let s=l.map(g=>typeof g=="string"?{label:g}:g),[u,h]=s.every(g=>/^\w+$/.test(g.label))?[/\w*$/,/\w+$/]:wbn(s);return g=>{let w=g.matchBefore(h);return w||g.explicit?{from:w?w.from:g.pos,options:s,validFor:u}:null}}function vbn(l,s){return u=>{for(let h=jd(u.state).resolveInner(u.pos,-1);h;h=h.parent){if(l.indexOf(h.name)>-1)return null;if(h.type.isTop)break}return s(u)}}class E3t{constructor(s,u,h,g){this.completion=s,this.source=u,this.match=h,this.score=g}}function pM(l){return l.selection.main.from}function k6t(l,s){var u;let{source:h}=l,g=s&&h[0]!="^",w=h[h.length-1]!="$";return!g&&!w?l:new RegExp(`${g?"^":""}(?:${h})${w?"$":""}`,(u=l.flags)!==null&&u!==void 0?u:l.ignoreCase?"i":"")}const mAe=cO.define();function ybn(l,s,u,h){let{main:g}=l.selection,w=u-g.from,p=h-g.from;return{...l.changeByRange(k=>{if(k!=g&&u!=h&&l.sliceDoc(k.from+w,k.from+p)!=l.sliceDoc(u,h))return{range:k};let j=l.toText(s);return{changes:{from:k.from+w,to:h==g.from?k.to:k.from+p,insert:j},range:kn.cursor(k.from+w+j.length)}}),scrollIntoView:!0,userEvent:"input.complete"}}const C3t=new WeakMap;function xbn(l){if(!Array.isArray(l))return l;let s=C3t.get(l);return s||C3t.set(l,s=x6t(l)),s}const bhe=Ds.define(),dV=Ds.define();class kbn{constructor(s){this.pattern=s,this.chars=[],this.folded=[],this.any=[],this.precise=[],this.byWord=[],this.score=0,this.matched=[];for(let u=0;u<s.length;){let h=em(s,u),g=q3(h);this.chars.push(h);let w=s.slice(u,u+g),p=w.toUpperCase();this.folded.push(em(p==w?w.toLowerCase():p,0)),u+=g}this.astral=s.length!=this.chars.length}ret(s,u){return this.score=s,this.matched=u,this}match(s){if(this.pattern.length==0)return this.ret(-100,[]);if(s.length<this.pattern.length)return null;let{chars:u,folded:h,any:g,precise:w,byWord:p}=this;if(u.length==1){let Z=em(s,0),ee=q3(Z),ce=ee==s.length?0:-100;if(Z!=u[0])if(Z==h[0])ce+=-200;else return null;return this.ret(ce,[0,ee])}let k=s.indexOf(this.pattern);if(k==0)return this.ret(s.length==this.pattern.length?0:-100,[0,this.pattern.length]);let j=u.length,A=0;if(k<0){for(let Z=0,ee=Math.min(s.length,200);Z<ee&&A<j;){let ce=em(s,Z);(ce==u[A]||ce==h[A])&&(g[A++]=Z),Z+=q3(ce)}if(A<j)return null}let _=0,D=0,I=!1,B=0,F=-1,U=-1,K=/[a-z]/.test(s),Y=!0;for(let Z=0,ee=Math.min(s.length,200),ce=0;Z<ee&&D<j;){let fe=em(s,Z);k<0&&(_<j&&fe==u[_]&&(w[_++]=Z),B<j&&(fe==u[B]||fe==h[B]?(B==0&&(F=Z),U=Z+1,B++):B=0));let be,me=fe<255?fe>=48&&fe<=57||fe>=97&&fe<=122?2:fe>=65&&fe<=90?1:0:(be=UMe(fe))!=be.toLowerCase()?1:be!=be.toUpperCase()?2:0;(!Z||me==1&&K||ce==0&&me!=0)&&(u[D]==fe||h[D]==fe&&(I=!0)?p[D++]=Z:p.length&&(Y=!1)),ce=me,Z+=q3(fe)}return D==j&&p[0]==0&&Y?this.result(-100+(I?-200:0),p,s):B==j&&F==0?this.ret(-200-s.length+(U==s.length?0:-100),[0,U]):k>-1?this.ret(-700-s.length,[k,k+this.pattern.length]):B==j?this.ret(-900-s.length,[F,U]):D==j?this.result(-100+(I?-200:0)+-700+(Y?0:-1100),p,s):u.length==2?null:this.result((g[0]?-700:0)+-200+-1100,g,s)}result(s,u,h){let g=[],w=0;for(let p of u){let k=p+(this.astral?q3(em(h,p)):1);w&&g[w-1]==p?g[w-1]=k:(g[w++]=p,g[w++]=k)}return this.ret(s-h.length,g)}}class Obn{constructor(s){this.pattern=s,this.matched=[],this.score=0,this.folded=s.toLowerCase()}match(s){if(s.length<this.pattern.length)return null;let u=s.slice(0,this.pattern.length),h=u==this.pattern?0:u.toLowerCase()==this.folded?-200:null;return h==null?null:(this.matched=[0,u.length],this.score=h+(s.length==this.pattern.length?0:-100),this)}}const Od=Qi.define({combine(l){return Z3(l,{activateOnTyping:!0,activateOnCompletion:()=>!1,activateOnTypingDelay:100,selectOnOpen:!0,override:null,closeOnBlur:!0,maxRenderedOptions:100,defaultKeymap:!0,tooltipClass:()=>"",optionClass:()=>"",aboveCursor:!1,icons:!0,addToOptions:[],positionInfo:Sbn,filterStrict:!1,compareCompletions:(s,u)=>(s.sortText||s.label).localeCompare(u.sortText||u.label),interactionDelay:75,updateSyncTime:100},{defaultKeymap:(s,u)=>s&&u,closeOnBlur:(s,u)=>s&&u,icons:(s,u)=>s&&u,tooltipClass:(s,u)=>h=>M3t(s(h),u(h)),optionClass:(s,u)=>h=>M3t(s(h),u(h)),addToOptions:(s,u)=>s.concat(u),filterStrict:(s,u)=>s||u})}});function M3t(l,s){return l?s?l+" "+s:l:s}function Sbn(l,s,u,h,g,w){let p=l.textDirection==Yl.RTL,k=p,j=!1,A="top",_,D,I=s.left-g.left,B=g.right-s.right,F=h.right-h.left,U=h.bottom-h.top;if(k&&I<Math.min(F,B)?k=!1:!k&&B<Math.min(F,I)&&(k=!0),F<=(k?I:B))_=Math.max(g.top,Math.min(u.top,g.bottom-U))-s.top,D=Math.min(400,k?I:B);else{j=!0,D=Math.min(400,(p?s.right:g.right-s.left)-30);let Z=g.bottom-s.bottom;Z>=U||Z>s.top?_=u.bottom-s.top:(A="bottom",_=s.bottom-u.top)}let K=(s.bottom-s.top)/w.offsetHeight,Y=(s.right-s.left)/w.offsetWidth;return{style:`${A}: ${_/K}px; max-width: ${D/Y}px`,class:"cm-completionInfo-"+(j?p?"left-narrow":"right-narrow":k?"left":"right")}}const wAe=Ds.define();function jbn(l){let s=l.addToOptions.slice();return l.icons&&s.push({render(u){let h=document.createElement("div");return h.classList.add("cm-completionIcon"),u.type&&h.classList.add(...u.type.split(/\s+/g).map(g=>"cm-completionIcon-"+g)),h.setAttribute("aria-hidden","true"),h},position:20}),s.push({render(u,h,g,w){let p=document.createElement("span");p.className="cm-completionLabel";let k=u.displayLabel||u.label,j=0;for(let A=0;A<w.length;){let _=w[A++],D=w[A++];_>j&&p.appendChild(document.createTextNode(k.slice(j,_)));let I=p.appendChild(document.createElement("span"));I.appendChild(document.createTextNode(k.slice(_,D))),I.className="cm-completionMatchedText",j=D}return j<k.length&&p.appendChild(document.createTextNode(k.slice(j))),p},position:50},{render(u){if(!u.detail)return null;let h=document.createElement("span");return h.className="cm-completionDetail",h.textContent=u.detail,h},position:80}),s.sort((u,h)=>u.position-h.position).map(u=>u.render)}function eCe(l,s,u){if(l<=u)return{from:0,to:l};if(s<0&&(s=0),s<=l>>1){let g=Math.floor(s/u);return{from:g*u,to:(g+1)*u}}let h=Math.floor((l-s)/u);return{from:l-(h+1)*u,to:l-h*u}}class Tbn{constructor(s,u,h){this.view=s,this.stateField=u,this.applyCompletion=h,this.info=null,this.infoDestroy=null,this.placeInfoReq={read:()=>this.measureInfo(),write:j=>this.placeInfo(j),key:this},this.space=null,this.currentClass="";let g=s.state.field(u),{options:w,selected:p}=g.open,k=s.state.facet(Od);this.optionContent=jbn(k),this.optionClass=k.optionClass,this.tooltipClass=k.tooltipClass,this.range=eCe(w.length,p,k.maxRenderedOptions),this.dom=document.createElement("div"),this.dom.className="cm-tooltip-autocomplete",this.updateTooltipClass(s.state),this.dom.addEventListener("mousedown",j=>{let{options:A}=s.state.field(u).open;for(let _=j.target,D;_&&_!=this.dom;_=_.parentNode)if(_.nodeName=="LI"&&(D=/-(\d+)$/.exec(_.id))&&+D[1]<A.length){this.applyCompletion(s,A[+D[1]]),j.preventDefault();return}if(j.target==this.list){let _=this.list.classList.contains("cm-completionListIncompleteTop")&&j.clientY<this.list.firstChild.getBoundingClientRect().top?this.range.from-1:this.list.classList.contains("cm-completionListIncompleteBottom")&&j.clientY>this.list.lastChild.getBoundingClientRect().bottom?this.range.to:null;_!=null&&(s.dispatch({effects:wAe.of(_)}),j.preventDefault())}}),this.dom.addEventListener("focusout",j=>{let A=s.state.field(this.stateField,!1);A&&A.tooltip&&s.state.facet(Od).closeOnBlur&&j.relatedTarget!=s.contentDOM&&s.dispatch({effects:dV.of(null)})}),this.showOptions(w,g.id)}mount(){this.updateSel()}showOptions(s,u){this.list&&this.list.remove(),this.list=this.dom.appendChild(this.createListBox(s,u,this.range)),this.list.addEventListener("scroll",()=>{this.info&&this.view.requestMeasure(this.placeInfoReq)})}update(s){var u;let h=s.state.field(this.stateField),g=s.startState.field(this.stateField);if(this.updateTooltipClass(s.state),h!=g){let{options:w,selected:p,disabled:k}=h.open;(!g.open||g.open.options!=w)&&(this.range=eCe(w.length,p,s.state.facet(Od).maxRenderedOptions),this.showOptions(w,h.id)),this.updateSel(),k!=((u=g.open)===null||u===void 0?void 0:u.disabled)&&this.dom.classList.toggle("cm-tooltip-autocomplete-disabled",!!k)}}updateTooltipClass(s){let u=this.tooltipClass(s);if(u!=this.currentClass){for(let h of this.currentClass.split(" "))h&&this.dom.classList.remove(h);for(let h of u.split(" "))h&&this.dom.classList.add(h);this.currentClass=u}}positioned(s){this.space=s,this.info&&this.view.requestMeasure(this.placeInfoReq)}updateSel(){let s=this.view.state.field(this.stateField),u=s.open;(u.selected>-1&&u.selected<this.range.from||u.selected>=this.range.to)&&(this.range=eCe(u.options.length,u.selected,this.view.state.facet(Od).maxRenderedOptions),this.showOptions(u.options,s.id));let h=this.updateSelectedOption(u.selected);if(h){this.destroyInfo();let{completion:g}=u.options[u.selected],{info:w}=g;if(!w)return;let p=typeof w=="string"?document.createTextNode(w):w(g);if(!p)return;"then"in p?p.then(k=>{k&&this.view.state.field(this.stateField,!1)==s&&this.addInfoPane(k,g)}).catch(k=>kp(this.view.state,k,"completion info")):(this.addInfoPane(p,g),h.setAttribute("aria-describedby",this.info.id))}}addInfoPane(s,u){this.destroyInfo();let h=this.info=document.createElement("div");if(h.className="cm-tooltip cm-completionInfo",h.id="cm-completionInfo-"+Math.floor(Math.random()*65535).toString(16),s.nodeType!=null)h.appendChild(s),this.infoDestroy=null;else{let{dom:g,destroy:w}=s;h.appendChild(g),this.infoDestroy=w||null}this.dom.appendChild(h),this.view.requestMeasure(this.placeInfoReq)}updateSelectedOption(s){let u=null;for(let h=this.list.firstChild,g=this.range.from;h;h=h.nextSibling,g++)h.nodeName!="LI"||!h.id?g--:g==s?h.hasAttribute("aria-selected")||(h.setAttribute("aria-selected","true"),u=h):h.hasAttribute("aria-selected")&&(h.removeAttribute("aria-selected"),h.removeAttribute("aria-describedby"));return u&&Cbn(this.list,u),u}measureInfo(){let s=this.dom.querySelector("[aria-selected]");if(!s||!this.info)return null;let u=this.dom.getBoundingClientRect(),h=this.info.getBoundingClientRect(),g=s.getBoundingClientRect(),w=this.space;if(!w){let p=this.dom.ownerDocument.documentElement;w={left:0,top:0,right:p.clientWidth,bottom:p.clientHeight}}return g.top>Math.min(w.bottom,u.bottom)-10||g.bottom<Math.max(w.top,u.top)+10?null:this.view.state.facet(Od).positionInfo(this.view,u,g,h,w,this.dom)}placeInfo(s){this.info&&(s?(s.style&&(this.info.style.cssText=s.style),this.info.className="cm-tooltip cm-completionInfo "+(s.class||"")):this.info.style.cssText="top: -1e6px")}createListBox(s,u,h){const g=document.createElement("ul");g.id=u,g.setAttribute("role","listbox"),g.setAttribute("aria-expanded","true"),g.setAttribute("aria-label",this.view.state.phrase("Completions")),g.addEventListener("mousedown",p=>{p.target==g&&p.preventDefault()});let w=null;for(let p=h.from;p<h.to;p++){let{completion:k,match:j}=s[p],{section:A}=k;if(A){let I=typeof A=="string"?A:A.name;if(I!=w&&(p>h.from||h.from==0))if(w=I,typeof A!="string"&&A.header)g.appendChild(A.header(A));else{let B=g.appendChild(document.createElement("completion-section"));B.textContent=I}}const _=g.appendChild(document.createElement("li"));_.id=u+"-"+p,_.setAttribute("role","option");let D=this.optionClass(k);D&&(_.className=D);for(let I of this.optionContent){let B=I(k,this.view.state,this.view,j);B&&_.appendChild(B)}}return h.from&&g.classList.add("cm-completionListIncompleteTop"),h.to<s.length&&g.classList.add("cm-completionListIncompleteBottom"),g}destroyInfo(){this.info&&(this.infoDestroy&&this.infoDestroy(),this.info.remove(),this.info=null)}destroy(){this.destroyInfo()}}function Ebn(l,s){return u=>new Tbn(u,l,s)}function Cbn(l,s){let u=l.getBoundingClientRect(),h=s.getBoundingClientRect(),g=u.height/l.offsetHeight;h.top<u.top?l.scrollTop-=(u.top-h.top)/g:h.bottom>u.bottom&&(l.scrollTop+=(h.bottom-u.bottom)/g)}function A3t(l){return(l.boost||0)*100+(l.apply?10:0)+(l.info?5:0)+(l.type?1:0)}function Mbn(l,s){let u=[],h=null,g=null,w=_=>{u.push(_);let{section:D}=_.completion;if(D){h||(h=[]);let I=typeof D=="string"?D:D.name;h.some(B=>B.name==I)||h.push(typeof D=="string"?{name:I}:D)}},p=s.facet(Od);for(let _ of l)if(_.hasResult()){let D=_.result.getMatch;if(_.result.filter===!1)for(let I of _.result.options)w(new E3t(I,_.source,D?D(I):[],1e9-u.length));else{let I=s.sliceDoc(_.from,_.to),B,F=p.filterStrict?new Obn(I):new kbn(I);for(let U of _.result.options)if(B=F.match(U.label)){let K=U.displayLabel?D?D(U,B.matched):[]:B.matched,Y=B.score+(U.boost||0);if(w(new E3t(U,_.source,K,Y)),typeof U.section=="object"&&U.section.rank==="dynamic"){let{name:Z}=U.section;g||(g=Object.create(null)),g[Z]=Math.max(Y,g[Z]||-1e9)}}}}if(h){let _=Object.create(null),D=0,I=(B,F)=>(B.rank==="dynamic"&&F.rank==="dynamic"?g[F.name]-g[B.name]:0)||(typeof B.rank=="number"?B.rank:1e9)-(typeof F.rank=="number"?F.rank:1e9)||(B.name<F.name?-1:1);for(let B of h.sort(I))D-=1e5,_[B.name]=D;for(let B of u){let{section:F}=B.completion;F&&(B.score+=_[typeof F=="string"?F:F.name])}}let k=[],j=null,A=p.compareCompletions;for(let _ of u.sort((D,I)=>I.score-D.score||A(D.completion,I.completion))){let D=_.completion;!j||j.label!=D.label||j.detail!=D.detail||j.type!=null&&D.type!=null&&j.type!=D.type||j.apply!=D.apply||j.boost!=D.boost?k.push(_):A3t(_.completion)>A3t(j)&&(k[k.length-1]=_),j=_.completion}return k}class dI{constructor(s,u,h,g,w,p){this.options=s,this.attrs=u,this.tooltip=h,this.timestamp=g,this.selected=w,this.disabled=p}setSelected(s,u){return s==this.selected||s>=this.options.length?this:new dI(this.options,N3t(u,s),this.tooltip,this.timestamp,s,this.disabled)}static build(s,u,h,g,w,p){if(g&&!p&&s.some(A=>A.isPending))return g.setDisabled();let k=Mbn(s,u);if(!k.length)return g&&s.some(A=>A.isPending)?g.setDisabled():null;let j=u.facet(Od).selectOnOpen?0:-1;if(g&&g.selected!=j&&g.selected!=-1){let A=g.options[g.selected].completion;for(let _=0;_<k.length;_++)if(k[_].completion==A){j=_;break}}return new dI(k,N3t(h,j),{pos:s.reduce((A,_)=>_.hasResult()?Math.min(A,_.from):A,1e8),create:Pbn,above:w.aboveCursor},g?g.timestamp:Date.now(),j,!1)}map(s){return new dI(this.options,this.attrs,{...this.tooltip,pos:s.mapPos(this.tooltip.pos)},this.timestamp,this.selected,this.disabled)}setDisabled(){return new dI(this.options,this.attrs,this.tooltip,this.timestamp,this.selected,!0)}}class mhe{constructor(s,u,h){this.active=s,this.id=u,this.open=h}static start(){return new mhe(Dbn,"cm-ac-"+Math.floor(Math.random()*2e6).toString(36),null)}update(s){let{state:u}=s,h=u.facet(Od),w=(h.override||u.languageDataAt("autocomplete",pM(u)).map(xbn)).map(j=>(this.active.find(_=>_.source==j)||new Jw(j,this.active.some(_=>_.state!=0)?1:0)).update(s,h));w.length==this.active.length&&w.every((j,A)=>j==this.active[A])&&(w=this.active);let p=this.open,k=s.effects.some(j=>j.is(vAe));p&&s.docChanged&&(p=p.map(s.changes)),s.selection||w.some(j=>j.hasResult()&&s.changes.touchesRange(j.from,j.to))||!Abn(w,this.active)||k?p=dI.build(w,u,this.id,p,h,k):p&&p.disabled&&!w.some(j=>j.isPending)&&(p=null),!p&&w.every(j=>!j.isPending)&&w.some(j=>j.hasResult())&&(w=w.map(j=>j.hasResult()?new Jw(j.source,0):j));for(let j of s.effects)j.is(wAe)&&(p=p&&p.setSelected(j.value,this.id));return w==this.active&&p==this.open?this:new mhe(w,this.id,p)}get tooltip(){return this.open?this.open.tooltip:null}get attrs(){return this.open?this.open.attrs:this.active.length?Nbn:_bn}}function Abn(l,s){if(l==s)return!0;for(let u=0,h=0;;){for(;u<l.length&&!l[u].hasResult();)u++;for(;h<s.length&&!s[h].hasResult();)h++;let g=u==l.length,w=h==s.length;if(g||w)return g==w;if(l[u++].result!=s[h++].result)return!1}}const Nbn={"aria-autocomplete":"list"},_bn={};function N3t(l,s){let u={"aria-autocomplete":"list","aria-haspopup":"listbox","aria-controls":l};return s>-1&&(u["aria-activedescendant"]=l+"-"+s),u}const Dbn=[];function O6t(l,s){if(l.isUserEvent("input.complete")){let h=l.annotation(mAe);if(h&&s.activateOnCompletion(h))return 12}let u=l.isUserEvent("input.type");return u&&s.activateOnTyping?5:u?1:l.isUserEvent("delete.backward")?2:l.selection?8:l.docChanged?16:0}class Jw{constructor(s,u,h=!1){this.source=s,this.state=u,this.explicit=h}hasResult(){return!1}get isPending(){return this.state==1}update(s,u){let h=O6t(s,u),g=this;(h&8||h&16&&this.touches(s))&&(g=new Jw(g.source,0)),h&4&&g.state==0&&(g=new Jw(this.source,1)),g=g.updateFor(s,h);for(let w of s.effects)if(w.is(bhe))g=new Jw(g.source,1,w.value);else if(w.is(dV))g=new Jw(g.source,0);else if(w.is(vAe))for(let p of w.value)p.source==g.source&&(g=p);return g}updateFor(s,u){return this.map(s.changes)}map(s){return this}touches(s){return s.changes.touchesRange(pM(s.state))}}class xI extends Jw{constructor(s,u,h,g,w,p){super(s,3,u),this.limit=h,this.result=g,this.from=w,this.to=p}hasResult(){return!0}updateFor(s,u){var h;if(!(u&3))return this.map(s.changes);let g=this.result;g.map&&!s.changes.empty&&(g=g.map(g,s.changes));let w=s.changes.mapPos(this.from),p=s.changes.mapPos(this.to,1),k=pM(s.state);if(k>p||!g||u&2&&(pM(s.startState)==this.from||k<this.limit))return new Jw(this.source,u&4?1:0);let j=s.changes.mapPos(this.limit);return Lbn(g.validFor,s.state,w,p)?new xI(this.source,this.explicit,j,g,w,p):g.update&&(g=g.update(g,w,p,new y6t(s.state,k,!1)))?new xI(this.source,this.explicit,j,g,g.from,(h=g.to)!==null&&h!==void 0?h:pM(s.state)):new Jw(this.source,1,this.explicit)}map(s){return s.empty?this:(this.result.map?this.result.map(this.result,s):this.result)?new xI(this.source,this.explicit,s.mapPos(this.limit),this.result,s.mapPos(this.from),s.mapPos(this.to,1)):new Jw(this.source,0)}touches(s){return s.changes.touchesRange(this.from,this.to)}}function Lbn(l,s,u,h){if(!l)return!1;let g=s.sliceDoc(u,h);return typeof l=="function"?l(g,u,h,s):k6t(l,!0).test(g)}const vAe=Ds.define({map(l,s){return l.map(u=>u.map(s))}}),vp=Td.define({create(){return mhe.start()},update(l,s){return l.update(s)},provide:l=>[Uhe.from(l,s=>s.tooltip),Bi.contentAttributes.from(l,s=>s.attrs)]});function yAe(l,s){const u=s.completion.apply||s.completion.label;let h=l.state.field(vp).active.find(g=>g.source==s.source);return h instanceof xI?(typeof u=="string"?l.dispatch({...ybn(l.state,u,h.from,h.to),annotations:mAe.of(s.completion)}):u(l,s.completion,h.from,h.to),!0):!1}const Pbn=Ebn(vp,yAe);function afe(l,s="option"){return u=>{let h=u.state.field(vp,!1);if(!h||!h.open||h.open.disabled||Date.now()-h.open.timestamp<u.state.facet(Od).interactionDelay)return!1;let g=1,w;s=="page"&&(w=IOt(u,h.open.tooltip))&&(g=Math.max(2,Math.floor(w.dom.offsetHeight/w.dom.querySelector("li").offsetHeight)-1));let{length:p}=h.open.options,k=h.open.selected>-1?h.open.selected+g*(l?1:-1):l?0:p-1;return k<0?k=s=="page"?0:p-1:k>=p&&(k=s=="page"?p-1:0),u.dispatch({effects:wAe.of(k)}),!0}}const Ibn=l=>{let s=l.state.field(vp,!1);return l.state.readOnly||!s||!s.open||s.open.selected<0||s.open.disabled||Date.now()-s.open.timestamp<l.state.facet(Od).interactionDelay?!1:yAe(l,s.open.options[s.open.selected])},tCe=l=>l.state.field(vp,!1)?(l.dispatch({effects:bhe.of(!0)}),!0):!1,Rbn=l=>{let s=l.state.field(vp,!1);return!s||!s.active.some(u=>u.state!=0)?!1:(l.dispatch({effects:dV.of(null)}),!0)};class $bn{constructor(s,u){this.active=s,this.context=u,this.time=Date.now(),this.updates=[],this.done=void 0}}const Bbn=50,zbn=1e3,Fbn=Xh.fromClass(class{constructor(l){this.view=l,this.debounceUpdate=-1,this.running=[],this.debounceAccept=-1,this.pendingStart=!1,this.composing=0;for(let s of l.state.field(vp).active)s.isPending&&this.startQuery(s)}update(l){let s=l.state.field(vp),u=l.state.facet(Od);if(!l.selectionSet&&!l.docChanged&&l.startState.field(vp)==s)return;let h=l.transactions.some(w=>{let p=O6t(w,u);return p&8||(w.selection||w.docChanged)&&!(p&3)});for(let w=0;w<this.running.length;w++){let p=this.running[w];if(h||p.context.abortOnDocChange&&l.docChanged||p.updates.length+l.transactions.length>Bbn&&Date.now()-p.time>zbn){for(let k of p.context.abortListeners)try{k()}catch(j){kp(this.view.state,j)}p.context.abortListeners=null,this.running.splice(w--,1)}else p.updates.push(...l.transactions)}this.debounceUpdate>-1&&clearTimeout(this.debounceUpdate),l.transactions.some(w=>w.effects.some(p=>p.is(bhe)))&&(this.pendingStart=!0);let g=this.pendingStart?50:u.activateOnTypingDelay;if(this.debounceUpdate=s.active.some(w=>w.isPending&&!this.running.some(p=>p.active.source==w.source))?setTimeout(()=>this.startUpdate(),g):-1,this.composing!=0)for(let w of l.transactions)w.isUserEvent("input.type")?this.composing=2:this.composing==2&&w.selection&&(this.composing=3)}startUpdate(){this.debounceUpdate=-1,this.pendingStart=!1;let{state:l}=this.view,s=l.field(vp);for(let u of s.active)u.isPending&&!this.running.some(h=>h.active.source==u.source)&&this.startQuery(u);this.running.length&&s.open&&s.open.disabled&&(this.debounceAccept=setTimeout(()=>this.accept(),this.view.state.facet(Od).updateSyncTime))}startQuery(l){let{state:s}=this.view,u=pM(s),h=new y6t(s,u,l.explicit,this.view),g=new $bn(l,h);this.running.push(g),Promise.resolve(l.source(h)).then(w=>{g.context.aborted||(g.done=w||null,this.scheduleAccept())},w=>{this.view.dispatch({effects:dV.of(null)}),kp(this.view.state,w)})}scheduleAccept(){this.running.every(l=>l.done!==void 0)?this.accept():this.debounceAccept<0&&(this.debounceAccept=setTimeout(()=>this.accept(),this.view.state.facet(Od).updateSyncTime))}accept(){var l;this.debounceAccept>-1&&clearTimeout(this.debounceAccept),this.debounceAccept=-1;let s=[],u=this.view.state.facet(Od),h=this.view.state.field(vp);for(let g=0;g<this.running.length;g++){let w=this.running[g];if(w.done===void 0)continue;if(this.running.splice(g--,1),w.done){let k=pM(w.updates.length?w.updates[0].startState:this.view.state),j=Math.min(k,w.done.from+(w.active.explicit?0:1)),A=new xI(w.active.source,w.active.explicit,j,w.done,w.done.from,(l=w.done.to)!==null&&l!==void 0?l:k);for(let _ of w.updates)A=A.update(_,u);if(A.hasResult()){s.push(A);continue}}let p=h.active.find(k=>k.source==w.active.source);if(p&&p.isPending)if(w.done==null){let k=new Jw(w.active.source,0);for(let j of w.updates)k=k.update(j,u);k.isPending||s.push(k)}else this.startQuery(p)}(s.length||h.open&&h.open.disabled)&&this.view.dispatch({effects:vAe.of(s)})}},{eventHandlers:{blur(l){let s=this.view.state.field(vp,!1);if(s&&s.tooltip&&this.view.state.facet(Od).closeOnBlur){let u=s.open&&IOt(this.view,s.open.tooltip);(!u||!u.dom.contains(l.relatedTarget))&&setTimeout(()=>this.view.dispatch({effects:dV.of(null)}),10)}},compositionstart(){this.composing=1},compositionend(){this.composing==3&&setTimeout(()=>this.view.dispatch({effects:bhe.of(!1)}),20),this.composing=0}}}),qbn=typeof navigator=="object"&&/Win/.test(navigator.platform),Hbn=E8.highest(Bi.domEventHandlers({keydown(l,s){let u=s.state.field(vp,!1);if(!u||!u.open||u.open.disabled||u.open.selected<0||l.key.length>1||l.ctrlKey&&!(qbn&&l.altKey)||l.metaKey)return!1;let h=u.open.options[u.open.selected],g=u.active.find(p=>p.source==h.source),w=h.completion.commitCharacters||g.result.commitCharacters;return w&&w.indexOf(l.key)>-1&&yAe(s,h),!1}})),S6t=Bi.baseTheme({".cm-tooltip.cm-tooltip-autocomplete":{"& > ul":{fontFamily:"monospace",whiteSpace:"nowrap",overflow:"hidden auto",maxWidth_fallback:"700px",maxWidth:"min(700px, 95vw)",minWidth:"250px",maxHeight:"10em",height:"100%",listStyle:"none",margin:0,padding:0,"& > li, & > completion-section":{padding:"1px 3px",lineHeight:1.2},"& > li":{overflowX:"hidden",textOverflow:"ellipsis",cursor:"pointer"},"& > completion-section":{display:"list-item",borderBottom:"1px solid silver",paddingLeft:"0.5em",opacity:.7}}},"&light .cm-tooltip-autocomplete ul li[aria-selected]":{background:"#17c",color:"white"},"&light .cm-tooltip-autocomplete-disabled ul li[aria-selected]":{background:"#777"},"&dark .cm-tooltip-autocomplete ul li[aria-selected]":{background:"#347",color:"white"},"&dark .cm-tooltip-autocomplete-disabled ul li[aria-selected]":{background:"#444"},".cm-completionListIncompleteTop:before, .cm-completionListIncompleteBottom:after":{content:'"···"',opacity:.5,display:"block",textAlign:"center"},".cm-tooltip.cm-completionInfo":{position:"absolute",padding:"3px 9px",width:"max-content",maxWidth:"400px",boxSizing:"border-box",whiteSpace:"pre-line"},".cm-completionInfo.cm-completionInfo-left":{right:"100%"},".cm-completionInfo.cm-completionInfo-right":{left:"100%"},".cm-completionInfo.cm-completionInfo-left-narrow":{right:"30px"},".cm-completionInfo.cm-completionInfo-right-narrow":{left:"30px"},"&light .cm-snippetField":{backgroundColor:"#00000022"},"&dark .cm-snippetField":{backgroundColor:"#ffffff22"},".cm-snippetFieldPosition":{verticalAlign:"text-top",width:0,height:"1.15em",display:"inline-block",margin:"0 -0.7px -.7em",borderLeft:"1.4px dotted #888"},".cm-completionMatchedText":{textDecoration:"underline"},".cm-completionDetail":{marginLeft:"0.5em",fontStyle:"italic"},".cm-completionIcon":{fontSize:"90%",width:".8em",display:"inline-block",textAlign:"center",paddingRight:".6em",opacity:"0.6",boxSizing:"content-box"},".cm-completionIcon-function, .cm-completionIcon-method":{"&:after":{content:"'ƒ'"}},".cm-completionIcon-class":{"&:after":{content:"'○'"}},".cm-completionIcon-interface":{"&:after":{content:"'◌'"}},".cm-completionIcon-variable":{"&:after":{content:"'𝑥'"}},".cm-completionIcon-constant":{"&:after":{content:"'𝐶'"}},".cm-completionIcon-type":{"&:after":{content:"'𝑡'"}},".cm-completionIcon-enum":{"&:after":{content:"'∪'"}},".cm-completionIcon-property":{"&:after":{content:"'□'"}},".cm-completionIcon-keyword":{"&:after":{content:"'🔑︎'"}},".cm-completionIcon-namespace":{"&:after":{content:"'▢'"}},".cm-completionIcon-text":{"&:after":{content:"'abc'",fontSize:"50%",verticalAlign:"middle"}}});class Qbn{constructor(s,u,h,g){this.field=s,this.line=u,this.from=h,this.to=g}}class xAe{constructor(s,u,h){this.field=s,this.from=u,this.to=h}map(s){let u=s.mapPos(this.from,-1,u1.TrackDel),h=s.mapPos(this.to,1,u1.TrackDel);return u==null||h==null?null:new xAe(this.field,u,h)}}class kAe{constructor(s,u){this.lines=s,this.fieldPositions=u}instantiate(s,u){let h=[],g=[u],w=s.doc.lineAt(u),p=/^\s*/.exec(w.text)[0];for(let j of this.lines){if(h.length){let A=p,_=/^\t*/.exec(j)[0].length;for(let D=0;D<_;D++)A+=s.facet(_V);g.push(u+A.length-_),j=A+j.slice(_)}h.push(j),u+=j.length+1}let k=this.fieldPositions.map(j=>new xAe(j.field,g[j.line]+j.from,g[j.line]+j.to));return{text:h,ranges:k}}static parse(s){let u=[],h=[],g=[],w;for(let p of s.split(/\r\n?|\n/)){for(;w=/[#$]\{(?:(\d+)(?::([^{}]*))?|((?:\\[{}]|[^{}])*))\}/.exec(p);){let k=w[1]?+w[1]:null,j=w[2]||w[3]||"",A=-1,_=j.replace(/\\[{}]/g,D=>D[1]);for(let D=0;D<u.length;D++)(k!=null?u[D].seq==k:_&&u[D].name==_)&&(A=D);if(A<0){let D=0;for(;D<u.length&&(k==null||u[D].seq!=null&&u[D].seq<k);)D++;u.splice(D,0,{seq:k,name:_}),A=D;for(let I of g)I.field>=A&&I.field++}for(let D of g)if(D.line==h.length&&D.from>w.index){let I=w[2]?3+(w[1]||"").length:2;D.from-=I,D.to-=I}g.push(new Qbn(A,h.length,w.index,w.index+_.length)),p=p.slice(0,w.index)+j+p.slice(w.index+w[0].length)}p=p.replace(/\\([{}])/g,(k,j,A)=>{for(let _ of g)_.line==h.length&&_.from>A&&(_.from--,_.to--);return j}),h.push(p)}return new kAe(h,g)}}let Gbn=Fr.widget({widget:new class extends lO{toDOM(){let l=document.createElement("span");return l.className="cm-snippetFieldPosition",l}ignoreEvent(){return!1}}}),Ubn=Fr.mark({class:"cm-snippetField"});class FI{constructor(s,u){this.ranges=s,this.active=u,this.deco=Fr.set(s.map(h=>(h.from==h.to?Gbn:Ubn).range(h.from,h.to)),!0)}map(s){let u=[];for(let h of this.ranges){let g=h.map(s);if(!g)return null;u.push(g)}return new FI(u,this.active)}selectionInsideField(s){return s.ranges.every(u=>this.ranges.some(h=>h.field==this.active&&h.from<=u.from&&h.to>=u.to))}}const LV=Ds.define({map(l,s){return l&&l.map(s)}}),Jbn=Ds.define(),gV=Td.define({create(){return null},update(l,s){for(let u of s.effects){if(u.is(LV))return u.value;if(u.is(Jbn)&&l)return new FI(l.ranges,u.value)}return l&&s.docChanged&&(l=l.map(s.changes)),l&&s.selection&&!l.selectionInsideField(s.selection)&&(l=null),l},provide:l=>Bi.decorations.from(l,s=>s?s.deco:Fr.none)});function OAe(l,s){return kn.create(l.filter(u=>u.field==s).map(u=>kn.range(u.from,u.to)))}function Xbn(l){let s=kAe.parse(l);return(u,h,g,w)=>{let{text:p,ranges:k}=s.instantiate(u.state,g),{main:j}=u.state.selection,A={changes:{from:g,to:w==j.from?j.to:w,insert:uc.of(p)},scrollIntoView:!0,annotations:h?[mAe.of(h),hh.userEvent.of("input.complete")]:void 0};if(k.length&&(A.selection=OAe(k,0)),k.some(_=>_.field>0)){let _=new FI(k,0),D=A.effects=[LV.of(_)];u.state.field(gV,!1)===void 0&&D.push(Ds.appendConfig.of([gV,Zbn,emn,S6t]))}u.dispatch(u.state.update(A))}}function j6t(l){return({state:s,dispatch:u})=>{let h=s.field(gV,!1);if(!h||l<0&&h.active==0)return!1;let g=h.active+l,w=l>0&&!h.ranges.some(p=>p.field==g+l);return u(s.update({selection:OAe(h.ranges,g),effects:LV.of(w?null:new FI(h.ranges,g)),scrollIntoView:!0})),!0}}const Vbn=({state:l,dispatch:s})=>l.field(gV,!1)?(s(l.update({effects:LV.of(null)})),!0):!1,Wbn=j6t(1),Kbn=j6t(-1),Ybn=[{key:"Tab",run:Wbn,shift:Kbn},{key:"Escape",run:Vbn}],_3t=Qi.define({combine(l){return l.length?l[0]:Ybn}}),Zbn=E8.highest(Ghe.compute([_3t],l=>l.facet(_3t)));function Jk(l,s){return{...s,apply:Xbn(l)}}const emn=Bi.domEventHandlers({mousedown(l,s){let u=s.state.field(gV,!1),h;if(!u||(h=s.posAtCoords({x:l.clientX,y:l.clientY}))==null)return!1;let g=u.ranges.find(w=>w.from<=h&&w.to>=h);return!g||g.field==u.active?!1:(s.dispatch({selection:OAe(u.ranges,g.field),effects:LV.of(u.ranges.some(w=>w.field>g.field)?new FI(u.ranges,g.field):null),scrollIntoView:!0}),!0)}}),pV={brackets:["(","[","{","'",'"'],before:")]}:;>",stringPrefixes:[]},fM=Ds.define({map(l,s){let u=s.mapPos(l,-1,u1.TrackAfter);return u??void 0}}),SAe=new class extends y8{};SAe.startSide=1;SAe.endSide=-1;const T6t=Td.define({create(){return xo.empty},update(l,s){if(l=l.map(s.changes),s.selection){let u=s.state.doc.lineAt(s.selection.main.head);l=l.update({filter:h=>h>=u.from&&h<=u.to})}for(let u of s.effects)u.is(fM)&&(l=l.update({add:[SAe.range(u.value,u.value+1)]}));return l}});function tmn(){return[imn,T6t]}const nCe="()[]{}<>«»»«［］｛｝";function E6t(l){for(let s=0;s<nCe.length;s+=2)if(nCe.charCodeAt(s)==l)return nCe.charAt(s+1);return UMe(l<128?l:l+1)}function C6t(l,s){return l.languageDataAt("closeBrackets",s)[0]||pV}const nmn=typeof navigator=="object"&&/Android\b/.test(navigator.userAgent),imn=Bi.inputHandler.of((l,s,u,h)=>{if((nmn?l.composing:l.compositionStarted)||l.state.readOnly)return!1;let g=l.state.selection.main;if(h.length>2||h.length==2&&q3(em(h,0))==1||s!=g.from||u!=g.to)return!1;let w=omn(l.state,h);return w?(l.dispatch(w),!0):!1}),rmn=({state:l,dispatch:s})=>{if(l.readOnly)return!1;let h=C6t(l,l.selection.main.head).brackets||pV.brackets,g=null,w=l.changeByRange(p=>{if(p.empty){let k=cmn(l.doc,p.head);for(let j of h)if(j==k&&Zhe(l.doc,p.head)==E6t(em(j,0)))return{changes:{from:p.head-j.length,to:p.head+j.length},range:kn.cursor(p.head-j.length)}}return{range:g=p}});return g||s(l.update(w,{scrollIntoView:!0,userEvent:"delete.backward"})),!g},smn=[{key:"Backspace",run:rmn}];function omn(l,s){let u=C6t(l,l.selection.main.head),h=u.brackets||pV.brackets;for(let g of h){let w=E6t(em(g,0));if(s==g)return w==g?amn(l,g,h.indexOf(g+g+g)>-1,u):lmn(l,g,w,u.before||pV.before);if(s==w&&M6t(l,l.selection.main.from))return umn(l,g,w)}return null}function M6t(l,s){let u=!1;return l.field(T6t).between(0,l.doc.length,h=>{h==s&&(u=!0)}),u}function Zhe(l,s){let u=l.sliceString(s,s+2);return u.slice(0,q3(em(u,0)))}function cmn(l,s){let u=l.sliceString(s-2,s);return q3(em(u,0))==u.length?u:u.slice(1)}function lmn(l,s,u,h){let g=null,w=l.changeByRange(p=>{if(!p.empty)return{changes:[{insert:s,from:p.from},{insert:u,from:p.to}],effects:fM.of(p.to+s.length),range:kn.range(p.anchor+s.length,p.head+s.length)};let k=Zhe(l.doc,p.head);return!k||/\s/.test(k)||h.indexOf(k)>-1?{changes:{insert:s+u,from:p.head},effects:fM.of(p.head+s.length),range:kn.cursor(p.head+s.length)}:{range:g=p}});return g?null:l.update(w,{scrollIntoView:!0,userEvent:"input.type"})}function umn(l,s,u){let h=null,g=l.changeByRange(w=>w.empty&&Zhe(l.doc,w.head)==u?{changes:{from:w.head,to:w.head+u.length,insert:u},range:kn.cursor(w.head+u.length)}:h={range:w});return h?null:l.update(g,{scrollIntoView:!0,userEvent:"input.type"})}function amn(l,s,u,h){let g=h.stringPrefixes||pV.stringPrefixes,w=null,p=l.changeByRange(k=>{if(!k.empty)return{changes:[{insert:s,from:k.from},{insert:s,from:k.to}],effects:fM.of(k.to+s.length),range:kn.range(k.anchor+s.length,k.head+s.length)};let j=k.head,A=Zhe(l.doc,j),_;if(A==s){if(D3t(l,j))return{changes:{insert:s+s,from:j},effects:fM.of(j+s.length),range:kn.cursor(j+s.length)};if(M6t(l,j)){let I=u&&l.sliceDoc(j,j+s.length*3)==s+s+s?s+s+s:s;return{changes:{from:j,to:j+I.length,insert:I},range:kn.cursor(j+I.length)}}}else{if(u&&l.sliceDoc(j-2*s.length,j)==s+s&&(_=L3t(l,j-2*s.length,g))>-1&&D3t(l,_))return{changes:{insert:s+s+s+s,from:j},effects:fM.of(j+s.length),range:kn.cursor(j+s.length)};if(l.charCategorizer(j)(A)!=ea.Word&&L3t(l,j,g)>-1&&!fmn(l,j,s,g))return{changes:{insert:s+s,from:j},effects:fM.of(j+s.length),range:kn.cursor(j+s.length)}}return{range:w=k}});return w?null:l.update(p,{scrollIntoView:!0,userEvent:"input.type"})}function D3t(l,s){let u=jd(l).resolveInner(s+1);return u.parent&&u.from==s}function fmn(l,s,u,h){let g=jd(l).resolveInner(s,-1),w=h.reduce((p,k)=>Math.max(p,k.length),0);for(let p=0;p<5;p++){let k=l.sliceDoc(g.from,Math.min(g.to,g.from+u.length+w)),j=k.indexOf(u);if(!j||j>-1&&h.indexOf(k.slice(0,j))>-1){let _=g.firstChild;for(;_&&_.from==g.from&&_.to-_.from>u.length+j;){if(l.sliceDoc(_.to-u.length,_.to)==u)return!1;_=_.firstChild}return!0}let A=g.to==s&&g.parent;if(!A)break;g=A}return!1}function L3t(l,s,u){let h=l.charCategorizer(s);if(h(l.sliceDoc(s-1,s))!=ea.Word)return s;for(let g of u){let w=s-g.length;if(l.sliceDoc(w,s)==g&&h(l.sliceDoc(w-1,w))!=ea.Word)return w}return-1}function hmn(l={}){return[Hbn,vp,Od.of(l),Fbn,dmn,S6t]}const A6t=[{key:"Ctrl-Space",run:tCe},{mac:"Alt-`",run:tCe},{mac:"Alt-i",run:tCe},{key:"Escape",run:Rbn},{key:"ArrowDown",run:afe(!0)},{key:"ArrowUp",run:afe(!1)},{key:"PageDown",run:afe(!0,"page")},{key:"PageUp",run:afe(!1,"page")},{key:"Enter",run:Ibn}],dmn=E8.highest(Ghe.computeN([Od],l=>l.facet(Od).defaultKeymap?[A6t]:[])),P3t=new Wgn,N6t=new Set(["Script","Body","FunctionDefinition","ClassDefinition","LambdaExpression","ForStatement","MatchClause"]);function ffe(l){return(s,u,h)=>{if(h)return!1;let g=s.node.getChild("VariableName");return g&&u(g,l),!0}}const gmn={FunctionDefinition:ffe("function"),ClassDefinition:ffe("class"),ForStatement(l,s,u){if(u){for(let h=l.node.firstChild;h;h=h.nextSibling)if(h.name=="VariableName")s(h,"variable");else if(h.name=="in")break}},ImportStatement(l,s){var u,h;let{node:g}=l,w=((u=g.firstChild)===null||u===void 0?void 0:u.name)=="from";for(let p=g.getChild("import");p;p=p.nextSibling)p.name=="VariableName"&&((h=p.nextSibling)===null||h===void 0?void 0:h.name)!="as"&&s(p,w?"variable":"namespace")},AssignStatement(l,s){for(let u=l.node.firstChild;u;u=u.nextSibling)if(u.name=="VariableName")s(u,"variable");else if(u.name==":"||u.name=="AssignOp")break},ParamList(l,s){for(let u=null,h=l.node.firstChild;h;h=h.nextSibling)h.name=="VariableName"&&(!u||!/\*|AssignOp/.test(u.name))&&s(h,"variable"),u=h},CapturePattern:ffe("variable"),AsPattern:ffe("variable"),__proto__:null};function _6t(l,s){let u=P3t.get(s);if(u)return u;let h=[],g=!0;function w(p,k){let j=l.sliceString(p.from,p.to);h.push({label:j,type:k})}return s.cursor(La.IncludeAnonymous).iterate(p=>{if(p.name){let k=gmn[p.name];if(k&&k(p,w,g)||!g&&N6t.has(p.name))return!1;g=!1}else if(p.to-p.from>8192){for(let k of _6t(l,p.node))h.push(k);return!1}}),P3t.set(s,h),h}const I3t=/^[\w\xa1-\uffff][\w\d\xa1-\uffff]*$/,D6t=["String","FormatString","Comment","PropertyName"];function pmn(l){let s=jd(l.state).resolveInner(l.pos,-1);if(D6t.indexOf(s.name)>-1)return null;let u=s.name=="VariableName"||s.to-s.from<20&&I3t.test(l.state.sliceDoc(s.from,s.to));if(!u&&!l.explicit)return null;let h=[];for(let g=s;g;g=g.parent)N6t.has(g.name)&&(h=h.concat(_6t(l.state.doc,g)));return{options:h,from:u?s.from:l.pos,validFor:I3t}}const bmn=["__annotations__","__builtins__","__debug__","__doc__","__import__","__name__","__loader__","__package__","__spec__","False","None","True"].map(l=>({label:l,type:"constant"})).concat(["ArithmeticError","AssertionError","AttributeError","BaseException","BlockingIOError","BrokenPipeError","BufferError","BytesWarning","ChildProcessError","ConnectionAbortedError","ConnectionError","ConnectionRefusedError","ConnectionResetError","DeprecationWarning","EOFError","Ellipsis","EncodingWarning","EnvironmentError","Exception","FileExistsError","FileNotFoundError","FloatingPointError","FutureWarning","GeneratorExit","IOError","ImportError","ImportWarning","IndentationError","IndexError","InterruptedError","IsADirectoryError","KeyError","KeyboardInterrupt","LookupError","MemoryError","ModuleNotFoundError","NameError","NotADirectoryError","NotImplemented","NotImplementedError","OSError","OverflowError","PendingDeprecationWarning","PermissionError","ProcessLookupError","RecursionError","ReferenceError","ResourceWarning","RuntimeError","RuntimeWarning","StopAsyncIteration","StopIteration","SyntaxError","SyntaxWarning","SystemError","SystemExit","TabError","TimeoutError","TypeError","UnboundLocalError","UnicodeDecodeError","UnicodeEncodeError","UnicodeError","UnicodeTranslateError","UnicodeWarning","UserWarning","ValueError","Warning","ZeroDivisionError"].map(l=>({label:l,type:"type"}))).concat(["bool","bytearray","bytes","classmethod","complex","float","frozenset","int","list","map","memoryview","object","range","set","staticmethod","str","super","tuple","type"].map(l=>({label:l,type:"class"}))).concat(["abs","aiter","all","anext","any","ascii","bin","breakpoint","callable","chr","compile","delattr","dict","dir","divmod","enumerate","eval","exec","exit","filter","format","getattr","globals","hasattr","hash","help","hex","id","input","isinstance","issubclass","iter","len","license","locals","max","min","next","oct","open","ord","pow","print","property","quit","repr","reversed","round","setattr","slice","sorted","sum","vars","zip"].map(l=>({label:l,type:"function"}))),mmn=[Jk("def ${name}(${params}):\n	${}",{label:"def",detail:"function",type:"keyword"}),Jk("for ${name} in ${collection}:\n	${}",{label:"for",detail:"loop",type:"keyword"}),Jk("while ${}:\n	${}",{label:"while",detail:"loop",type:"keyword"}),Jk("try:\n	${}\nexcept ${error}:\n	${}",{label:"try",detail:"/ except block",type:"keyword"}),Jk(`if \${}:
	
`,{label:"if",detail:"block",type:"keyword"}),Jk("if ${}:\n	${}\nelse:\n	${}",{label:"if",detail:"/ else block",type:"keyword"}),Jk("class ${name}:\n	def __init__(self, ${params}):\n			${}",{label:"class",detail:"definition",type:"keyword"}),Jk("import ${module}",{label:"import",detail:"statement",type:"keyword"}),Jk("from ${module} import ${names}",{label:"from",detail:"import",type:"keyword"})],wmn=vbn(D6t,x6t(bmn.concat(mmn)));function iCe(l){let{node:s,pos:u}=l,h=l.lineIndent(u,-1),g=null;for(;;){let w=s.childBefore(u);if(w)if(w.name=="Comment")u=w.from;else if(w.name=="Body"||w.name=="MatchBody")l.baseIndentFor(w)+l.unit<=h&&(g=w),s=w;else if(w.name=="MatchClause")s=w;else if(w.type.is("Statement"))s=w;else break;else break}return g}function rCe(l,s){let u=l.baseIndentFor(s),h=l.lineAt(l.pos,-1),g=h.from+h.text.length;return/^\s*($|#)/.test(h.text)&&l.node.to<g+100&&!/\S/.test(l.state.sliceDoc(g,l.node.to))&&l.lineIndent(l.pos,-1)<=u||/^\s*(else:|elif |except |finally:|case\s+[^=:]+:)/.test(l.textAfter)&&l.lineIndent(l.pos,-1)>u?null:u+l.unit}const sCe=fhe.define({name:"python",parser:jpn.configure({props:[o6t.add({Body:l=>{var s;let u=/^\s*(#|$)/.test(l.textAfter)&&iCe(l)||l.node;return(s=rCe(l,u))!==null&&s!==void 0?s:l.continue()},MatchBody:l=>{var s;let u=iCe(l);return(s=rCe(l,u||l.node))!==null&&s!==void 0?s:l.continue()},IfStatement:l=>/^\s*(else:|elif )/.test(l.textAfter)?l.baseIndent:l.continue(),"ForStatement WhileStatement":l=>/^\s*else:/.test(l.textAfter)?l.baseIndent:l.continue(),TryStatement:l=>/^\s*(except[ :]|finally:|else:)/.test(l.textAfter)?l.baseIndent:l.continue(),MatchStatement:l=>/^\s*case /.test(l.textAfter)?l.baseIndent+l.unit:l.continue(),"TupleExpression ComprehensionExpression ParamList ArgList ParenthesizedExpression":WEe({closing:")"}),"DictionaryExpression DictionaryComprehensionExpression SetExpression SetComprehensionExpression":WEe({closing:"}"}),"ArrayExpression ArrayComprehensionExpression":WEe({closing:"]"}),MemberExpression:l=>l.baseIndent+l.unit,"String FormatString":()=>null,Script:l=>{var s;let u=iCe(l);return(s=u&&rCe(l,u))!==null&&s!==void 0?s:l.continue()}}),u6t.add({"ArrayExpression DictionaryExpression SetExpression TupleExpression":Fpn,Body:(l,s)=>({from:l.from+1,to:l.to-(l.to==s.doc.length?0:1)}),"String FormatString":(l,s)=>({from:s.doc.lineAt(l.from).to,to:l.to})})]}),languageData:{closeBrackets:{brackets:["(","[","{","'",'"',"'''",'"""'],stringPrefixes:["f","fr","rf","r","u","b","br","rb","F","FR","RF","R","U","B","BR","RB"]},commentTokens:{line:"#"},indentOnInput:/^\s*([\}\]\)]|else:|elif |except |finally:|case\s+[^:]*:?)$/}});function vmn(){return new Apn(sCe,[sCe.data.of({autocomplete:pmn}),sCe.data.of({autocomplete:wmn})])}const ymn=l=>{let{state:s}=l,u=s.doc.lineAt(s.selection.main.from),h=TAe(l.state,u.from);return h.line?xmn(l):h.block?Omn(l):!1};function jAe(l,s){return({state:u,dispatch:h})=>{if(u.readOnly)return!1;let g=l(s,u);return g?(h(u.update(g)),!0):!1}}const xmn=jAe(Tmn,0),kmn=jAe(L6t,0),Omn=jAe((l,s)=>L6t(l,s,jmn(s)),0);function TAe(l,s){let u=l.languageDataAt("commentTokens",s,1);return u.length?u[0]:{}}const jX=50;function Smn(l,{open:s,close:u},h,g){let w=l.sliceDoc(h-jX,h),p=l.sliceDoc(g,g+jX),k=/\s*$/.exec(w)[0].length,j=/^\s*/.exec(p)[0].length,A=w.length-k;if(w.slice(A-s.length,A)==s&&p.slice(j,j+u.length)==u)return{open:{pos:h-k,margin:k&&1},close:{pos:g+j,margin:j&&1}};let _,D;g-h<=2*jX?_=D=l.sliceDoc(h,g):(_=l.sliceDoc(h,h+jX),D=l.sliceDoc(g-jX,g));let I=/^\s*/.exec(_)[0].length,B=/\s*$/.exec(D)[0].length,F=D.length-B-u.length;return _.slice(I,I+s.length)==s&&D.slice(F,F+u.length)==u?{open:{pos:h+I+s.length,margin:/\s/.test(_.charAt(I+s.length))?1:0},close:{pos:g-B-u.length,margin:/\s/.test(D.charAt(F-1))?1:0}}:null}function jmn(l){let s=[];for(let u of l.selection.ranges){let h=l.doc.lineAt(u.from),g=u.to<=h.to?h:l.doc.lineAt(u.to);g.from>h.from&&g.from==u.to&&(g=u.to==h.to+1?h:l.doc.lineAt(u.to-1));let w=s.length-1;w>=0&&s[w].to>h.from?s[w].to=g.to:s.push({from:h.from+/^\s*/.exec(h.text)[0].length,to:g.to})}return s}function L6t(l,s,u=s.selection.ranges){let h=u.map(w=>TAe(s,w.from).block);if(!h.every(w=>w))return null;let g=u.map((w,p)=>Smn(s,h[p],w.from,w.to));if(l!=2&&!g.every(w=>w))return{changes:s.changes(u.map((w,p)=>g[p]?[]:[{from:w.from,insert:h[p].open+" "},{from:w.to,insert:" "+h[p].close}]))};if(l!=1&&g.some(w=>w)){let w=[];for(let p=0,k;p<g.length;p++)if(k=g[p]){let j=h[p],{open:A,close:_}=k;w.push({from:A.pos-j.open.length,to:A.pos+A.margin},{from:_.pos-_.margin,to:_.pos+j.close.length})}return{changes:w}}return null}function Tmn(l,s,u=s.selection.ranges){let h=[],g=-1;e:for(let{from:w,to:p}of u){let k=h.length,j=1e9,A;for(let _=w;_<=p;){let D=s.doc.lineAt(_);if(A==null&&(A=TAe(s,D.from).line,!A))continue e;if(D.from>g&&(w==p||p>D.from)){g=D.from;let I=/^\s*/.exec(D.text)[0].length,B=I==D.length,F=D.text.slice(I,I+A.length)==A?I:-1;I<D.text.length&&I<j&&(j=I),h.push({line:D,comment:F,token:A,indent:I,empty:B,single:!1})}_=D.to+1}if(j<1e9)for(let _=k;_<h.length;_++)h[_].indent<h[_].line.text.length&&(h[_].indent=j);h.length==k+1&&(h[k].single=!0)}if(l!=2&&h.some(w=>w.comment<0&&(!w.empty||w.single))){let w=[];for(let{line:k,token:j,indent:A,empty:_,single:D}of h)(D||!_)&&w.push({from:k.from+A,insert:j+" "});let p=s.changes(w);return{changes:p,selection:s.selection.map(p,1)}}else if(l!=1&&h.some(w=>w.comment>=0)){let w=[];for(let{line:p,comment:k,token:j}of h)if(k>=0){let A=p.from+k,_=A+j.length;p.text[_-p.from]==" "&&_++,w.push({from:A,to:_})}return{changes:w}}return null}const pMe=cO.define(),Emn=cO.define(),Cmn=Qi.define(),P6t=Qi.define({combine(l){return Z3(l,{minDepth:100,newGroupDelay:500,joinToEvent:(s,u)=>u},{minDepth:Math.max,newGroupDelay:Math.min,joinToEvent:(s,u)=>(h,g)=>s(h,g)||u(h,g)})}}),I6t=Td.define({create(){return J3.empty},update(l,s){let u=s.state.facet(P6t),h=s.annotation(pMe);if(h){let j=Op.fromTransaction(s,h.selection),A=h.side,_=A==0?l.undone:l.done;return j?_=whe(_,_.length,u.minDepth,j):_=B6t(_,s.startState.selection),new J3(A==0?h.rest:_,A==0?_:h.rest)}let g=s.annotation(Emn);if((g=="full"||g=="before")&&(l=l.isolate()),s.annotation(hh.addToHistory)===!1)return s.changes.empty?l:l.addMapping(s.changes.desc);let w=Op.fromTransaction(s),p=s.annotation(hh.time),k=s.annotation(hh.userEvent);return w?l=l.addChanges(w,p,k,u,s):s.selection&&(l=l.addSelection(s.startState.selection,p,k,u.newGroupDelay)),(g=="full"||g=="after")&&(l=l.isolate()),l},toJSON(l){return{done:l.done.map(s=>s.toJSON()),undone:l.undone.map(s=>s.toJSON())}},fromJSON(l){return new J3(l.done.map(Op.fromJSON),l.undone.map(Op.fromJSON))}});function Mmn(l={}){return[I6t,P6t.of(l),Bi.domEventHandlers({beforeinput(s,u){let h=s.inputType=="historyUndo"?R6t:s.inputType=="historyRedo"?bMe:null;return h?(s.preventDefault(),h(u)):!1}})]}function ede(l,s){return function({state:u,dispatch:h}){if(!s&&u.readOnly)return!1;let g=u.field(I6t,!1);if(!g)return!1;let w=g.pop(l,u,s);return w?(h(w),!0):!1}}const R6t=ede(0,!1),bMe=ede(1,!1),Amn=ede(0,!0),Nmn=ede(1,!0);class Op{constructor(s,u,h,g,w){this.changes=s,this.effects=u,this.mapped=h,this.startSelection=g,this.selectionsAfter=w}setSelAfter(s){return new Op(this.changes,this.effects,this.mapped,this.startSelection,s)}toJSON(){var s,u,h;return{changes:(s=this.changes)===null||s===void 0?void 0:s.toJSON(),mapped:(u=this.mapped)===null||u===void 0?void 0:u.toJSON(),startSelection:(h=this.startSelection)===null||h===void 0?void 0:h.toJSON(),selectionsAfter:this.selectionsAfter.map(g=>g.toJSON())}}static fromJSON(s){return new Op(s.changes&&Jh.fromJSON(s.changes),[],s.mapped&&V3.fromJSON(s.mapped),s.startSelection&&kn.fromJSON(s.startSelection),s.selectionsAfter.map(kn.fromJSON))}static fromTransaction(s,u){let h=Xw;for(let g of s.startState.facet(Cmn)){let w=g(s);w.length&&(h=h.concat(w))}return!h.length&&s.changes.empty?null:new Op(s.changes.invert(s.startState.doc),h,void 0,u||s.startState.selection,Xw)}static selection(s){return new Op(void 0,Xw,void 0,void 0,s)}}function whe(l,s,u,h){let g=s+1>u+20?s-u-1:0,w=l.slice(g,s);return w.push(h),w}function _mn(l,s){let u=[],h=!1;return l.iterChangedRanges((g,w)=>u.push(g,w)),s.iterChangedRanges((g,w,p,k)=>{for(let j=0;j<u.length;){let A=u[j++],_=u[j++];k>=A&&p<=_&&(h=!0)}}),h}function Dmn(l,s){return l.ranges.length==s.ranges.length&&l.ranges.filter((u,h)=>u.empty!=s.ranges[h].empty).length===0}function $6t(l,s){return l.length?s.length?l.concat(s):l:s}const Xw=[],Lmn=200;function B6t(l,s){if(l.length){let u=l[l.length-1],h=u.selectionsAfter.slice(Math.max(0,u.selectionsAfter.length-Lmn));return h.length&&h[h.length-1].eq(s)?l:(h.push(s),whe(l,l.length-1,1e9,u.setSelAfter(h)))}else return[Op.selection([s])]}function Pmn(l){let s=l[l.length-1],u=l.slice();return u[l.length-1]=s.setSelAfter(s.selectionsAfter.slice(0,s.selectionsAfter.length-1)),u}function oCe(l,s){if(!l.length)return l;let u=l.length,h=Xw;for(;u;){let g=Imn(l[u-1],s,h);if(g.changes&&!g.changes.empty||g.effects.length){let w=l.slice(0,u);return w[u-1]=g,w}else s=g.mapped,u--,h=g.selectionsAfter}return h.length?[Op.selection(h)]:Xw}function Imn(l,s,u){let h=$6t(l.selectionsAfter.length?l.selectionsAfter.map(k=>k.map(s)):Xw,u);if(!l.changes)return Op.selection(h);let g=l.changes.map(s),w=s.mapDesc(l.changes,!0),p=l.mapped?l.mapped.composeDesc(w):w;return new Op(g,Ds.mapEffects(l.effects,s),p,l.startSelection.map(w),h)}const Rmn=/^(input\.type|delete)($|\.)/;class J3{constructor(s,u,h=0,g=void 0){this.done=s,this.undone=u,this.prevTime=h,this.prevUserEvent=g}isolate(){return this.prevTime?new J3(this.done,this.undone):this}addChanges(s,u,h,g,w){let p=this.done,k=p[p.length-1];return k&&k.changes&&!k.changes.empty&&s.changes&&(!h||Rmn.test(h))&&(!k.selectionsAfter.length&&u-this.prevTime<g.newGroupDelay&&g.joinToEvent(w,_mn(k.changes,s.changes))||h=="input.type.compose")?p=whe(p,p.length-1,g.minDepth,new Op(s.changes.compose(k.changes),$6t(Ds.mapEffects(s.effects,k.changes),k.effects),k.mapped,k.startSelection,Xw)):p=whe(p,p.length,g.minDepth,s),new J3(p,Xw,u,h)}addSelection(s,u,h,g){let w=this.done.length?this.done[this.done.length-1].selectionsAfter:Xw;return w.length>0&&u-this.prevTime<g&&h==this.prevUserEvent&&h&&/^select($|\.)/.test(h)&&Dmn(w[w.length-1],s)?this:new J3(B6t(this.done,s),this.undone,u,h)}addMapping(s){return new J3(oCe(this.done,s),oCe(this.undone,s),this.prevTime,this.prevUserEvent)}pop(s,u,h){let g=s==0?this.done:this.undone;if(g.length==0)return null;let w=g[g.length-1],p=w.selectionsAfter[0]||(w.startSelection?w.startSelection.map(w.changes.invertedDesc,1):u.selection);if(h&&w.selectionsAfter.length)return u.update({selection:w.selectionsAfter[w.selectionsAfter.length-1],annotations:pMe.of({side:s,rest:Pmn(g),selection:p}),userEvent:s==0?"select.undo":"select.redo",scrollIntoView:!0});if(w.changes){let k=g.length==1?Xw:g.slice(0,g.length-1);return w.mapped&&(k=oCe(k,w.mapped)),u.update({changes:w.changes,selection:w.startSelection,effects:w.effects,annotations:pMe.of({side:s,rest:k,selection:p}),filter:!1,userEvent:s==0?"undo":"redo",scrollIntoView:!0})}else return null}}J3.empty=new J3(Xw,Xw);const $mn=[{key:"Mod-z",run:R6t,preventDefault:!0},{key:"Mod-y",mac:"Mod-Shift-z",run:bMe,preventDefault:!0},{linux:"Ctrl-Shift-z",run:bMe,preventDefault:!0},{key:"Mod-u",run:Amn,preventDefault:!0},{key:"Alt-u",mac:"Mod-Shift-u",run:Nmn,preventDefault:!0}];function qI(l,s){return kn.create(l.ranges.map(s),l.mainIndex)}function Ay(l,s){return l.update({selection:s,scrollIntoView:!0,userEvent:"select"})}function Ny({state:l,dispatch:s},u){let h=qI(l.selection,u);return h.eq(l.selection,!0)?!1:(s(Ay(l,h)),!0)}function tde(l,s){return kn.cursor(s?l.to:l.from)}function z6t(l,s){return Ny(l,u=>u.empty?l.moveByChar(u,s):tde(u,s))}function cg(l){return l.textDirectionAt(l.state.selection.main.head)==Yl.LTR}const F6t=l=>z6t(l,!cg(l)),q6t=l=>z6t(l,cg(l));function H6t(l,s){return Ny(l,u=>u.empty?l.moveByGroup(u,s):tde(u,s))}const Bmn=l=>H6t(l,!cg(l)),zmn=l=>H6t(l,cg(l));function Fmn(l,s,u){if(s.type.prop(u))return!0;let h=s.to-s.from;return h&&(h>2||/[^\s,.;:]/.test(l.sliceDoc(s.from,s.to)))||s.firstChild}function nde(l,s,u){let h=jd(l).resolveInner(s.head),g=u?Eo.closedBy:Eo.openedBy;for(let j=s.head;;){let A=u?h.childAfter(j):h.childBefore(j);if(!A)break;Fmn(l,A,g)?h=A:j=u?A.to:A.from}let w=h.type.prop(g),p,k;return w&&(p=u?U3(l,h.from,1):U3(l,h.to,-1))&&p.matched?k=u?p.end.to:p.end.from:k=u?h.to:h.from,kn.cursor(k,u?-1:1)}const qmn=l=>Ny(l,s=>nde(l.state,s,!cg(l))),Hmn=l=>Ny(l,s=>nde(l.state,s,cg(l)));function Q6t(l,s){return Ny(l,u=>{if(!u.empty)return tde(u,s);let h=l.moveVertically(u,s);return h.head!=u.head?h:l.moveToLineBoundary(u,s)})}const G6t=l=>Q6t(l,!1),U6t=l=>Q6t(l,!0);function J6t(l){let s=l.scrollDOM.clientHeight<l.scrollDOM.scrollHeight-2,u=0,h=0,g;if(s){for(let w of l.state.facet(Bi.scrollMargins)){let p=w(l);p!=null&&p.top&&(u=Math.max(p==null?void 0:p.top,u)),p!=null&&p.bottom&&(h=Math.max(p==null?void 0:p.bottom,h))}g=l.scrollDOM.clientHeight-u-h}else g=(l.dom.ownerDocument.defaultView||window).innerHeight;return{marginTop:u,marginBottom:h,selfScroll:s,height:Math.max(l.defaultLineHeight,g-5)}}function X6t(l,s){let u=J6t(l),{state:h}=l,g=qI(h.selection,p=>p.empty?l.moveVertically(p,s,u.height):tde(p,s));if(g.eq(h.selection))return!1;let w;if(u.selfScroll){let p=l.coordsAtPos(h.selection.main.head),k=l.scrollDOM.getBoundingClientRect(),j=k.top+u.marginTop,A=k.bottom-u.marginBottom;p&&p.top>j&&p.bottom<A&&(w=Bi.scrollIntoView(g.main.head,{y:"start",yMargin:p.top-j}))}return l.dispatch(Ay(h,g),{effects:w}),!0}const R3t=l=>X6t(l,!1),mMe=l=>X6t(l,!0);function C8(l,s,u){let h=l.lineBlockAt(s.head),g=l.moveToLineBoundary(s,u);if(g.head==s.head&&g.head!=(u?h.to:h.from)&&(g=l.moveToLineBoundary(s,u,!1)),!u&&g.head==h.from&&h.length){let w=/^\s*/.exec(l.state.sliceDoc(h.from,Math.min(h.from+100,h.to)))[0].length;w&&s.head!=h.from+w&&(g=kn.cursor(h.from+w))}return g}const Qmn=l=>Ny(l,s=>C8(l,s,!0)),Gmn=l=>Ny(l,s=>C8(l,s,!1)),Umn=l=>Ny(l,s=>C8(l,s,!cg(l))),Jmn=l=>Ny(l,s=>C8(l,s,cg(l))),Xmn=l=>Ny(l,s=>kn.cursor(l.lineBlockAt(s.head).from,1)),Vmn=l=>Ny(l,s=>kn.cursor(l.lineBlockAt(s.head).to,-1));function Wmn(l,s,u){let h=!1,g=qI(l.selection,w=>{let p=U3(l,w.head,-1)||U3(l,w.head,1)||w.head>0&&U3(l,w.head-1,1)||w.head<l.doc.length&&U3(l,w.head+1,-1);if(!p||!p.end)return w;h=!0;let k=p.start.from==w.head?p.end.to:p.end.from;return kn.cursor(k)});return h?(s(Ay(l,g)),!0):!1}const Kmn=({state:l,dispatch:s})=>Wmn(l,s);function Ww(l,s){let u=qI(l.state.selection,h=>{let g=s(h);return kn.range(h.anchor,g.head,g.goalColumn,g.bidiLevel||void 0)});return u.eq(l.state.selection)?!1:(l.dispatch(Ay(l.state,u)),!0)}function V6t(l,s){return Ww(l,u=>l.moveByChar(u,s))}const W6t=l=>V6t(l,!cg(l)),K6t=l=>V6t(l,cg(l));function Y6t(l,s){return Ww(l,u=>l.moveByGroup(u,s))}const Ymn=l=>Y6t(l,!cg(l)),Zmn=l=>Y6t(l,cg(l)),ewn=l=>Ww(l,s=>nde(l.state,s,!cg(l))),twn=l=>Ww(l,s=>nde(l.state,s,cg(l)));function Z6t(l,s){return Ww(l,u=>l.moveVertically(u,s))}const eSt=l=>Z6t(l,!1),tSt=l=>Z6t(l,!0);function nSt(l,s){return Ww(l,u=>l.moveVertically(u,s,J6t(l).height))}const $3t=l=>nSt(l,!1),B3t=l=>nSt(l,!0),nwn=l=>Ww(l,s=>C8(l,s,!0)),iwn=l=>Ww(l,s=>C8(l,s,!1)),rwn=l=>Ww(l,s=>C8(l,s,!cg(l))),swn=l=>Ww(l,s=>C8(l,s,cg(l))),own=l=>Ww(l,s=>kn.cursor(l.lineBlockAt(s.head).from)),cwn=l=>Ww(l,s=>kn.cursor(l.lineBlockAt(s.head).to)),z3t=({state:l,dispatch:s})=>(s(Ay(l,{anchor:0})),!0),F3t=({state:l,dispatch:s})=>(s(Ay(l,{anchor:l.doc.length})),!0),q3t=({state:l,dispatch:s})=>(s(Ay(l,{anchor:l.selection.main.anchor,head:0})),!0),H3t=({state:l,dispatch:s})=>(s(Ay(l,{anchor:l.selection.main.anchor,head:l.doc.length})),!0),lwn=({state:l,dispatch:s})=>(s(l.update({selection:{anchor:0,head:l.doc.length},userEvent:"select"})),!0),uwn=({state:l,dispatch:s})=>{let u=ide(l).map(({from:h,to:g})=>kn.range(h,Math.min(g+1,l.doc.length)));return s(l.update({selection:kn.create(u),userEvent:"select"})),!0},awn=({state:l,dispatch:s})=>{let u=qI(l.selection,h=>{let g=jd(l),w=g.resolveStack(h.from,1);if(h.empty){let p=g.resolveStack(h.from,-1);p.node.from>=w.node.from&&p.node.to<=w.node.to&&(w=p)}for(let p=w;p;p=p.next){let{node:k}=p;if((k.from<h.from&&k.to>=h.to||k.to>h.to&&k.from<=h.from)&&p.next)return kn.range(k.to,k.from)}return h});return u.eq(l.selection)?!1:(s(Ay(l,u)),!0)};function iSt(l,s){let{state:u}=l,h=u.selection,g=u.selection.ranges.slice();for(let w of u.selection.ranges){let p=u.doc.lineAt(w.head);if(s?p.to<l.state.doc.length:p.from>0)for(let k=w;;){let j=l.moveVertically(k,s);if(j.head<p.from||j.head>p.to){g.some(A=>A.head==j.head)||g.push(j);break}else{if(j.head==k.head)break;k=j}}}return g.length==h.ranges.length?!1:(l.dispatch(Ay(u,kn.create(g,g.length-1))),!0)}const fwn=l=>iSt(l,!1),hwn=l=>iSt(l,!0),dwn=({state:l,dispatch:s})=>{let u=l.selection,h=null;return u.ranges.length>1?h=kn.create([u.main]):u.main.empty||(h=kn.create([kn.cursor(u.main.head)])),h?(s(Ay(l,h)),!0):!1};function PV(l,s){if(l.state.readOnly)return!1;let u="delete.selection",{state:h}=l,g=h.changeByRange(w=>{let{from:p,to:k}=w;if(p==k){let j=s(w);j<p?(u="delete.backward",j=hfe(l,j,!1)):j>p&&(u="delete.forward",j=hfe(l,j,!0)),p=Math.min(p,j),k=Math.max(k,j)}else p=hfe(l,p,!1),k=hfe(l,k,!0);return p==k?{range:w}:{changes:{from:p,to:k},range:kn.cursor(p,p<w.head?-1:1)}});return g.changes.empty?!1:(l.dispatch(h.update(g,{scrollIntoView:!0,userEvent:u,effects:u=="delete.selection"?Bi.announce.of(h.phrase("Selection deleted")):void 0})),!0)}function hfe(l,s,u){if(l instanceof Bi)for(let h of l.state.facet(Bi.atomicRanges).map(g=>g(l)))h.between(s,s,(g,w)=>{g<s&&w>s&&(s=u?w:g)});return s}const rSt=(l,s,u)=>PV(l,h=>{let g=h.from,{state:w}=l,p=w.doc.lineAt(g),k,j;if(u&&!s&&g>p.from&&g<p.from+200&&!/[^ \t]/.test(k=p.text.slice(0,g-p.from))){if(k[k.length-1]=="	")return g-1;let A=EV(k,w.tabSize),_=A%dhe(w)||dhe(w);for(let D=0;D<_&&k[k.length-1-D]==" ";D++)g--;j=g}else j=Sd(p.text,g-p.from,s,s)+p.from,j==g&&p.number!=(s?w.doc.lines:1)?j+=s?1:-1:!s&&/[\ufe00-\ufe0f]/.test(p.text.slice(j-p.from,g-p.from))&&(j=Sd(p.text,j-p.from,!1,!1)+p.from);return j}),wMe=l=>rSt(l,!1,!0),sSt=l=>rSt(l,!0,!1),oSt=(l,s)=>PV(l,u=>{let h=u.head,{state:g}=l,w=g.doc.lineAt(h),p=g.charCategorizer(h);for(let k=null;;){if(h==(s?w.to:w.from)){h==u.head&&w.number!=(s?g.doc.lines:1)&&(h+=s?1:-1);break}let j=Sd(w.text,h-w.from,s)+w.from,A=w.text.slice(Math.min(h,j)-w.from,Math.max(h,j)-w.from),_=p(A);if(k!=null&&_!=k)break;(A!=" "||h!=u.head)&&(k=_),h=j}return h}),cSt=l=>oSt(l,!1),gwn=l=>oSt(l,!0),pwn=l=>PV(l,s=>{let u=l.lineBlockAt(s.head).to;return s.head<u?u:Math.min(l.state.doc.length,s.head+1)}),bwn=l=>PV(l,s=>{let u=l.moveToLineBoundary(s,!1).head;return s.head>u?u:Math.max(0,s.head-1)}),mwn=l=>PV(l,s=>{let u=l.moveToLineBoundary(s,!0).head;return s.head<u?u:Math.min(l.state.doc.length,s.head+1)}),wwn=({state:l,dispatch:s})=>{if(l.readOnly)return!1;let u=l.changeByRange(h=>({changes:{from:h.from,to:h.to,insert:uc.of(["",""])},range:kn.cursor(h.from)}));return s(l.update(u,{scrollIntoView:!0,userEvent:"input"})),!0},vwn=({state:l,dispatch:s})=>{if(l.readOnly)return!1;let u=l.changeByRange(h=>{if(!h.empty||h.from==0||h.from==l.doc.length)return{range:h};let g=h.from,w=l.doc.lineAt(g),p=g==w.from?g-1:Sd(w.text,g-w.from,!1)+w.from,k=g==w.to?g+1:Sd(w.text,g-w.from,!0)+w.from;return{changes:{from:p,to:k,insert:l.doc.slice(g,k).append(l.doc.slice(p,g))},range:kn.cursor(k)}});return u.changes.empty?!1:(s(l.update(u,{scrollIntoView:!0,userEvent:"move.character"})),!0)};function ide(l){let s=[],u=-1;for(let h of l.selection.ranges){let g=l.doc.lineAt(h.from),w=l.doc.lineAt(h.to);if(!h.empty&&h.to==w.from&&(w=l.doc.lineAt(h.to-1)),u>=g.number){let p=s[s.length-1];p.to=w.to,p.ranges.push(h)}else s.push({from:g.from,to:w.to,ranges:[h]});u=w.number+1}return s}function lSt(l,s,u){if(l.readOnly)return!1;let h=[],g=[];for(let w of ide(l)){if(u?w.to==l.doc.length:w.from==0)continue;let p=l.doc.lineAt(u?w.to+1:w.from-1),k=p.length+1;if(u){h.push({from:w.to,to:p.to},{from:w.from,insert:p.text+l.lineBreak});for(let j of w.ranges)g.push(kn.range(Math.min(l.doc.length,j.anchor+k),Math.min(l.doc.length,j.head+k)))}else{h.push({from:p.from,to:w.from},{from:w.to,insert:l.lineBreak+p.text});for(let j of w.ranges)g.push(kn.range(j.anchor-k,j.head-k))}}return h.length?(s(l.update({changes:h,scrollIntoView:!0,selection:kn.create(g,l.selection.mainIndex),userEvent:"move.line"})),!0):!1}const ywn=({state:l,dispatch:s})=>lSt(l,s,!1),xwn=({state:l,dispatch:s})=>lSt(l,s,!0);function uSt(l,s,u){if(l.readOnly)return!1;let h=[];for(let w of ide(l))u?h.push({from:w.from,insert:l.doc.slice(w.from,w.to)+l.lineBreak}):h.push({from:w.to,insert:l.lineBreak+l.doc.slice(w.from,w.to)});let g=l.changes(h);return s(l.update({changes:g,selection:l.selection.map(g,u?1:-1),scrollIntoView:!0,userEvent:"input.copyline"})),!0}const kwn=({state:l,dispatch:s})=>uSt(l,s,!1),Own=({state:l,dispatch:s})=>uSt(l,s,!0),Swn=l=>{if(l.state.readOnly)return!1;let{state:s}=l,u=s.changes(ide(s).map(({from:g,to:w})=>(g>0?g--:w<s.doc.length&&w++,{from:g,to:w}))),h=qI(s.selection,g=>{let w;if(l.lineWrapping){let p=l.lineBlockAt(g.head),k=l.coordsAtPos(g.head,g.assoc||1);k&&(w=p.bottom+l.documentTop-k.bottom+l.defaultLineHeight/2)}return l.moveVertically(g,!0,w)}).map(u);return l.dispatch({changes:u,selection:h,scrollIntoView:!0,userEvent:"delete.line"}),!0};function jwn(l,s){if(/\(\)|\[\]|\{\}/.test(l.sliceDoc(s-1,s+1)))return{from:s,to:s};let u=jd(l).resolveInner(s),h=u.childBefore(s),g=u.childAfter(s),w;return h&&g&&h.to<=s&&g.from>=s&&(w=h.type.prop(Eo.closedBy))&&w.indexOf(g.name)>-1&&l.doc.lineAt(h.to).from==l.doc.lineAt(g.from).from&&!/\S/.test(l.sliceDoc(h.to,g.from))?{from:h.to,to:g.from}:null}const Q3t=aSt(!1),Twn=aSt(!0);function aSt(l){return({state:s,dispatch:u})=>{if(s.readOnly)return!1;let h=s.changeByRange(g=>{let{from:w,to:p}=g,k=s.doc.lineAt(w),j=!l&&w==p&&jwn(s,w);l&&(w=p=(p<=k.to?k:s.doc.lineAt(p)).to);let A=new Whe(s,{simulateBreak:w,simulateDoubleBreak:!!j}),_=pAe(A,w);for(_==null&&(_=EV(/^\s*/.exec(s.doc.lineAt(w).text)[0],s.tabSize));p<k.to&&/\s/.test(k.text[p-k.from]);)p++;j?{from:w,to:p}=j:w>k.from&&w<k.from+100&&!/\S/.test(k.text.slice(0,w))&&(w=k.from);let D=["",hV(s,_)];return j&&D.push(hV(s,A.lineIndent(k.from,-1))),{changes:{from:w,to:p,insert:uc.of(D)},range:kn.cursor(w+1+D[1].length)}});return u(s.update(h,{scrollIntoView:!0,userEvent:"input"})),!0}}function EAe(l,s){let u=-1;return l.changeByRange(h=>{let g=[];for(let p=h.from;p<=h.to;){let k=l.doc.lineAt(p);k.number>u&&(h.empty||h.to>k.from)&&(s(k,g,h),u=k.number),p=k.to+1}let w=l.changes(g);return{changes:g,range:kn.range(w.mapPos(h.anchor,1),w.mapPos(h.head,1))}})}const Ewn=({state:l,dispatch:s})=>{if(l.readOnly)return!1;let u=Object.create(null),h=new Whe(l,{overrideIndentation:w=>{let p=u[w];return p??-1}}),g=EAe(l,(w,p,k)=>{let j=pAe(h,w.from);if(j==null)return;/\S/.test(w.text)||(j=0);let A=/^\s*/.exec(w.text)[0],_=hV(l,j);(A!=_||k.from<w.from+A.length)&&(u[w.from]=j,p.push({from:w.from,to:w.from+A.length,insert:_}))});return g.changes.empty||s(l.update(g,{userEvent:"indent"})),!0},fSt=({state:l,dispatch:s})=>l.readOnly?!1:(s(l.update(EAe(l,(u,h)=>{h.push({from:u.from,insert:l.facet(_V)})}),{userEvent:"input.indent"})),!0),hSt=({state:l,dispatch:s})=>l.readOnly?!1:(s(l.update(EAe(l,(u,h)=>{let g=/^\s*/.exec(u.text)[0];if(!g)return;let w=EV(g,l.tabSize),p=0,k=hV(l,Math.max(0,w-dhe(l)));for(;p<g.length&&p<k.length&&g.charCodeAt(p)==k.charCodeAt(p);)p++;h.push({from:u.from+p,to:u.from+g.length,insert:k.slice(p)})}),{userEvent:"delete.dedent"})),!0),Cwn=l=>(l.setTabFocusMode(),!0),Mwn=[{key:"Ctrl-b",run:F6t,shift:W6t,preventDefault:!0},{key:"Ctrl-f",run:q6t,shift:K6t},{key:"Ctrl-p",run:G6t,shift:eSt},{key:"Ctrl-n",run:U6t,shift:tSt},{key:"Ctrl-a",run:Xmn,shift:own},{key:"Ctrl-e",run:Vmn,shift:cwn},{key:"Ctrl-d",run:sSt},{key:"Ctrl-h",run:wMe},{key:"Ctrl-k",run:pwn},{key:"Ctrl-Alt-h",run:cSt},{key:"Ctrl-o",run:wwn},{key:"Ctrl-t",run:vwn},{key:"Ctrl-v",run:mMe}],Awn=[{key:"ArrowLeft",run:F6t,shift:W6t,preventDefault:!0},{key:"Mod-ArrowLeft",mac:"Alt-ArrowLeft",run:Bmn,shift:Ymn,preventDefault:!0},{mac:"Cmd-ArrowLeft",run:Umn,shift:rwn,preventDefault:!0},{key:"ArrowRight",run:q6t,shift:K6t,preventDefault:!0},{key:"Mod-ArrowRight",mac:"Alt-ArrowRight",run:zmn,shift:Zmn,preventDefault:!0},{mac:"Cmd-ArrowRight",run:Jmn,shift:swn,preventDefault:!0},{key:"ArrowUp",run:G6t,shift:eSt,preventDefault:!0},{mac:"Cmd-ArrowUp",run:z3t,shift:q3t},{mac:"Ctrl-ArrowUp",run:R3t,shift:$3t},{key:"ArrowDown",run:U6t,shift:tSt,preventDefault:!0},{mac:"Cmd-ArrowDown",run:F3t,shift:H3t},{mac:"Ctrl-ArrowDown",run:mMe,shift:B3t},{key:"PageUp",run:R3t,shift:$3t},{key:"PageDown",run:mMe,shift:B3t},{key:"Home",run:Gmn,shift:iwn,preventDefault:!0},{key:"Mod-Home",run:z3t,shift:q3t},{key:"End",run:Qmn,shift:nwn,preventDefault:!0},{key:"Mod-End",run:F3t,shift:H3t},{key:"Enter",run:Q3t,shift:Q3t},{key:"Mod-a",run:lwn},{key:"Backspace",run:wMe,shift:wMe,preventDefault:!0},{key:"Delete",run:sSt,preventDefault:!0},{key:"Mod-Backspace",mac:"Alt-Backspace",run:cSt,preventDefault:!0},{key:"Mod-Delete",mac:"Alt-Delete",run:gwn,preventDefault:!0},{mac:"Mod-Backspace",run:bwn,preventDefault:!0},{mac:"Mod-Delete",run:mwn,preventDefault:!0}].concat(Mwn.map(l=>({mac:l.key,run:l.run,shift:l.shift}))),Nwn=[{key:"Alt-ArrowLeft",mac:"Ctrl-ArrowLeft",run:qmn,shift:ewn},{key:"Alt-ArrowRight",mac:"Ctrl-ArrowRight",run:Hmn,shift:twn},{key:"Alt-ArrowUp",run:ywn},{key:"Shift-Alt-ArrowUp",run:kwn},{key:"Alt-ArrowDown",run:xwn},{key:"Shift-Alt-ArrowDown",run:Own},{key:"Mod-Alt-ArrowUp",run:fwn},{key:"Mod-Alt-ArrowDown",run:hwn},{key:"Escape",run:dwn},{key:"Mod-Enter",run:Twn},{key:"Alt-l",mac:"Ctrl-l",run:uwn},{key:"Mod-i",run:awn,preventDefault:!0},{key:"Mod-[",run:hSt},{key:"Mod-]",run:fSt},{key:"Mod-Alt-\\",run:Ewn},{key:"Shift-Mod-k",run:Swn},{key:"Shift-Mod-\\",run:Kmn},{key:"Mod-/",run:ymn},{key:"Alt-A",run:kmn},{key:"Ctrl-m",mac:"Shift-Alt-m",run:Cwn}].concat(Awn),_wn={key:"Tab",run:fSt,shift:hSt},G3t=typeof String.prototype.normalize=="function"?l=>l.normalize("NFKD"):l=>l;class RI{constructor(s,u,h=0,g=s.length,w,p){this.test=p,this.value={from:0,to:0},this.done=!1,this.matches=[],this.buffer="",this.bufferPos=0,this.iter=s.iterRange(h,g),this.bufferStart=h,this.normalize=w?k=>w(G3t(k)):G3t,this.query=this.normalize(u)}peek(){if(this.bufferPos==this.buffer.length){if(this.bufferStart+=this.buffer.length,this.iter.next(),this.iter.done)return-1;this.bufferPos=0,this.buffer=this.iter.value}return em(this.buffer,this.bufferPos)}next(){for(;this.matches.length;)this.matches.pop();return this.nextOverlapping()}nextOverlapping(){for(;;){let s=this.peek();if(s<0)return this.done=!0,this;let u=UMe(s),h=this.bufferStart+this.bufferPos;this.bufferPos+=q3(s);let g=this.normalize(u);if(g.length)for(let w=0,p=h;;w++){let k=g.charCodeAt(w),j=this.match(k,p,this.bufferPos+this.bufferStart);if(w==g.length-1){if(j)return this.value=j,this;break}p==h&&w<u.length&&u.charCodeAt(w)==k&&p++}}}match(s,u,h){let g=null;for(let w=0;w<this.matches.length;w+=2){let p=this.matches[w],k=!1;this.query.charCodeAt(p)==s&&(p==this.query.length-1?g={from:this.matches[w+1],to:h}:(this.matches[w]++,k=!0)),k||(this.matches.splice(w,2),w-=2)}return this.query.charCodeAt(0)==s&&(this.query.length==1?g={from:u,to:h}:this.matches.push(1,u)),g&&this.test&&!this.test(g.from,g.to,this.buffer,this.bufferStart)&&(g=null),g}}typeof Symbol<"u"&&(RI.prototype[Symbol.iterator]=function(){return this});const dSt={from:-1,to:-1,match:/.*/.exec("")},CAe="gm"+(/x/.unicode==null?"":"u");class gSt{constructor(s,u,h,g=0,w=s.length){if(this.text=s,this.to=w,this.curLine="",this.done=!1,this.value=dSt,/\\[sWDnr]|\n|\r|\[\^/.test(u))return new pSt(s,u,h,g,w);this.re=new RegExp(u,CAe+(h!=null&&h.ignoreCase?"i":"")),this.test=h==null?void 0:h.test,this.iter=s.iter();let p=s.lineAt(g);this.curLineStart=p.from,this.matchPos=vhe(s,g),this.getLine(this.curLineStart)}getLine(s){this.iter.next(s),this.iter.lineBreak?this.curLine="":(this.curLine=this.iter.value,this.curLineStart+this.curLine.length>this.to&&(this.curLine=this.curLine.slice(0,this.to-this.curLineStart)),this.iter.next())}nextLine(){this.curLineStart=this.curLineStart+this.curLine.length+1,this.curLineStart>this.to?this.curLine="":this.getLine(0)}next(){for(let s=this.matchPos-this.curLineStart;;){this.re.lastIndex=s;let u=this.matchPos<=this.to&&this.re.exec(this.curLine);if(u){let h=this.curLineStart+u.index,g=h+u[0].length;if(this.matchPos=vhe(this.text,g+(h==g?1:0)),h==this.curLineStart+this.curLine.length&&this.nextLine(),(h<g||h>this.value.to)&&(!this.test||this.test(h,g,u)))return this.value={from:h,to:g,match:u},this;s=this.matchPos-this.curLineStart}else if(this.curLineStart+this.curLine.length<this.to)this.nextLine(),s=0;else return this.done=!0,this}}}const cCe=new WeakMap;class kI{constructor(s,u){this.from=s,this.text=u}get to(){return this.from+this.text.length}static get(s,u,h){let g=cCe.get(s);if(!g||g.from>=h||g.to<=u){let k=new kI(u,s.sliceString(u,h));return cCe.set(s,k),k}if(g.from==u&&g.to==h)return g;let{text:w,from:p}=g;return p>u&&(w=s.sliceString(u,p)+w,p=u),g.to<h&&(w+=s.sliceString(g.to,h)),cCe.set(s,new kI(p,w)),new kI(u,w.slice(u-p,h-p))}}class pSt{constructor(s,u,h,g,w){this.text=s,this.to=w,this.done=!1,this.value=dSt,this.matchPos=vhe(s,g),this.re=new RegExp(u,CAe+(h!=null&&h.ignoreCase?"i":"")),this.test=h==null?void 0:h.test,this.flat=kI.get(s,g,this.chunkEnd(g+5e3))}chunkEnd(s){return s>=this.to?this.to:this.text.lineAt(s).to}next(){for(;;){let s=this.re.lastIndex=this.matchPos-this.flat.from,u=this.re.exec(this.flat.text);if(u&&!u[0]&&u.index==s&&(this.re.lastIndex=s+1,u=this.re.exec(this.flat.text)),u){let h=this.flat.from+u.index,g=h+u[0].length;if((this.flat.to>=this.to||u.index+u[0].length<=this.flat.text.length-10)&&(!this.test||this.test(h,g,u)))return this.value={from:h,to:g,match:u},this.matchPos=vhe(this.text,g+(h==g?1:0)),this}if(this.flat.to==this.to)return this.done=!0,this;this.flat=kI.get(this.text,this.flat.from,this.chunkEnd(this.flat.from+this.flat.text.length*2))}}}typeof Symbol<"u"&&(gSt.prototype[Symbol.iterator]=pSt.prototype[Symbol.iterator]=function(){return this});function Dwn(l){try{return new RegExp(l,CAe),!0}catch{return!1}}function vhe(l,s){if(s>=l.length)return s;let u=l.lineAt(s),h;for(;s<u.to&&(h=u.text.charCodeAt(s-u.from))>=56320&&h<57344;)s++;return s}const Lwn=l=>{let{state:s}=l,u=String(s.doc.lineAt(l.state.selection.main.head).number),{close:h,result:g}=Agn(l,{label:s.phrase("Go to line"),input:{type:"text",name:"line",value:u},focus:!0,submitLabel:s.phrase("go")});return g.then(w=>{let p=w&&/^([+-])?(\d+)?(:\d+)?(%)?$/.exec(w.elements.line.value);if(!p){l.dispatch({effects:h});return}let k=s.doc.lineAt(s.selection.main.head),[,j,A,_,D]=p,I=_?+_.slice(1):0,B=A?+A:k.number;if(A&&D){let K=B/100;j&&(K=K*(j=="-"?-1:1)+k.number/s.doc.lines),B=Math.round(s.doc.lines*K)}else A&&j&&(B=B*(j=="-"?-1:1)+k.number);let F=s.doc.line(Math.max(1,Math.min(s.doc.lines,B))),U=kn.cursor(F.from+Math.max(0,Math.min(I,F.length)));l.dispatch({effects:[h,Bi.scrollIntoView(U.from,{y:"center"})],selection:U})}),!0},Pwn={highlightWordAroundCursor:!1,minSelectionLength:1,maxMatches:100,wholeWords:!1},Iwn=Qi.define({combine(l){return Z3(l,Pwn,{highlightWordAroundCursor:(s,u)=>s||u,minSelectionLength:Math.min,maxMatches:Math.min})}});function Rwn(l){return[qwn,Fwn]}const $wn=Fr.mark({class:"cm-selectionMatch"}),Bwn=Fr.mark({class:"cm-selectionMatch cm-selectionMatch-main"});function U3t(l,s,u,h){return(u==0||l(s.sliceDoc(u-1,u))!=ea.Word)&&(h==s.doc.length||l(s.sliceDoc(h,h+1))!=ea.Word)}function zwn(l,s,u,h){return l(s.sliceDoc(u,u+1))==ea.Word&&l(s.sliceDoc(h-1,h))==ea.Word}const Fwn=Xh.fromClass(class{constructor(l){this.decorations=this.getDeco(l)}update(l){(l.selectionSet||l.docChanged||l.viewportChanged)&&(this.decorations=this.getDeco(l.view))}getDeco(l){let s=l.state.facet(Iwn),{state:u}=l,h=u.selection;if(h.ranges.length>1)return Fr.none;let g=h.main,w,p=null;if(g.empty){if(!s.highlightWordAroundCursor)return Fr.none;let j=u.wordAt(g.head);if(!j)return Fr.none;p=u.charCategorizer(g.head),w=u.sliceDoc(j.from,j.to)}else{let j=g.to-g.from;if(j<s.minSelectionLength||j>200)return Fr.none;if(s.wholeWords){if(w=u.sliceDoc(g.from,g.to),p=u.charCategorizer(g.head),!(U3t(p,u,g.from,g.to)&&zwn(p,u,g.from,g.to)))return Fr.none}else if(w=u.sliceDoc(g.from,g.to),!w)return Fr.none}let k=[];for(let j of l.visibleRanges){let A=new RI(u.doc,w,j.from,j.to);for(;!A.next().done;){let{from:_,to:D}=A.value;if((!p||U3t(p,u,_,D))&&(g.empty&&_<=g.from&&D>=g.to?k.push(Bwn.range(_,D)):(_>=g.to||D<=g.from)&&k.push($wn.range(_,D)),k.length>s.maxMatches))return Fr.none}}return Fr.set(k)}},{decorations:l=>l.decorations}),qwn=Bi.baseTheme({".cm-selectionMatch":{backgroundColor:"#99ff7780"},".cm-searchMatch .cm-selectionMatch":{backgroundColor:"transparent"}}),Hwn=({state:l,dispatch:s})=>{let{selection:u}=l,h=kn.create(u.ranges.map(g=>l.wordAt(g.head)||kn.cursor(g.head)),u.mainIndex);return h.eq(u)?!1:(s(l.update({selection:h})),!0)};function Qwn(l,s){let{main:u,ranges:h}=l.selection,g=l.wordAt(u.head),w=g&&g.from==u.from&&g.to==u.to;for(let p=!1,k=new RI(l.doc,s,h[h.length-1].to);;)if(k.next(),k.done){if(p)return null;k=new RI(l.doc,s,0,Math.max(0,h[h.length-1].from-1)),p=!0}else{if(p&&h.some(j=>j.from==k.value.from))continue;if(w){let j=l.wordAt(k.value.from);if(!j||j.from!=k.value.from||j.to!=k.value.to)continue}return k.value}}const Gwn=({state:l,dispatch:s})=>{let{ranges:u}=l.selection;if(u.some(w=>w.from===w.to))return Hwn({state:l,dispatch:s});let h=l.sliceDoc(u[0].from,u[0].to);if(l.selection.ranges.some(w=>l.sliceDoc(w.from,w.to)!=h))return!1;let g=Qwn(l,h);return g?(s(l.update({selection:l.selection.addRange(kn.range(g.from,g.to),!1),effects:Bi.scrollIntoView(g.to)})),!0):!1},HI=Qi.define({combine(l){return Z3(l,{top:!1,caseSensitive:!1,literal:!1,regexp:!1,wholeWord:!1,createPanel:s=>new s2n(s),scrollToMatch:s=>Bi.scrollIntoView(s)})}});class bSt{constructor(s){this.search=s.search,this.caseSensitive=!!s.caseSensitive,this.literal=!!s.literal,this.regexp=!!s.regexp,this.replace=s.replace||"",this.valid=!!this.search&&(!this.regexp||Dwn(this.search)),this.unquoted=this.unquote(this.search),this.wholeWord=!!s.wholeWord,this.test=s.test}unquote(s){return this.literal?s:s.replace(/\\([nrt\\])/g,(u,h)=>h=="n"?`
`:h=="r"?"\r":h=="t"?"	":"\\")}eq(s){return this.search==s.search&&this.replace==s.replace&&this.caseSensitive==s.caseSensitive&&this.regexp==s.regexp&&this.wholeWord==s.wholeWord&&this.test==s.test}create(){return this.regexp?new Kwn(this):new Xwn(this)}getCursor(s,u=0,h){let g=s.doc?s:Ic.create({doc:s});return h==null&&(h=g.doc.length),this.regexp?cI(this,g,u,h):oI(this,g,u,h)}}class mSt{constructor(s){this.spec=s}}function Uwn(l,s,u){return(h,g,w,p)=>{if(u&&!u(h,g,w,p))return!1;let k=h>=p&&g<=p+w.length?w.slice(h-p,g-p):s.doc.sliceString(h,g);return l(k,s,h,g)}}function oI(l,s,u,h){let g;return l.wholeWord&&(g=Jwn(s.doc,s.charCategorizer(s.selection.main.head))),l.test&&(g=Uwn(l.test,s,g)),new RI(s.doc,l.unquoted,u,h,l.caseSensitive?void 0:w=>w.toLowerCase(),g)}function Jwn(l,s){return(u,h,g,w)=>((w>u||w+g.length<h)&&(w=Math.max(0,u-2),g=l.sliceString(w,Math.min(l.length,h+2))),(s(yhe(g,u-w))!=ea.Word||s(xhe(g,u-w))!=ea.Word)&&(s(xhe(g,h-w))!=ea.Word||s(yhe(g,h-w))!=ea.Word))}class Xwn extends mSt{constructor(s){super(s)}nextMatch(s,u,h){let g=oI(this.spec,s,h,s.doc.length).nextOverlapping();if(g.done){let w=Math.min(s.doc.length,u+this.spec.unquoted.length);g=oI(this.spec,s,0,w).nextOverlapping()}return g.done||g.value.from==u&&g.value.to==h?null:g.value}prevMatchInRange(s,u,h){for(let g=h;;){let w=Math.max(u,g-1e4-this.spec.unquoted.length),p=oI(this.spec,s,w,g),k=null;for(;!p.nextOverlapping().done;)k=p.value;if(k)return k;if(w==u)return null;g-=1e4}}prevMatch(s,u,h){let g=this.prevMatchInRange(s,0,u);return g||(g=this.prevMatchInRange(s,Math.max(0,h-this.spec.unquoted.length),s.doc.length)),g&&(g.from!=u||g.to!=h)?g:null}getReplacement(s){return this.spec.unquote(this.spec.replace)}matchAll(s,u){let h=oI(this.spec,s,0,s.doc.length),g=[];for(;!h.next().done;){if(g.length>=u)return null;g.push(h.value)}return g}highlight(s,u,h,g){let w=oI(this.spec,s,Math.max(0,u-this.spec.unquoted.length),Math.min(h+this.spec.unquoted.length,s.doc.length));for(;!w.next().done;)g(w.value.from,w.value.to)}}function Vwn(l,s,u){return(h,g,w)=>(!u||u(h,g,w))&&l(w[0],s,h,g)}function cI(l,s,u,h){let g;return l.wholeWord&&(g=Wwn(s.charCategorizer(s.selection.main.head))),l.test&&(g=Vwn(l.test,s,g)),new gSt(s.doc,l.search,{ignoreCase:!l.caseSensitive,test:g},u,h)}function yhe(l,s){return l.slice(Sd(l,s,!1),s)}function xhe(l,s){return l.slice(s,Sd(l,s))}function Wwn(l){return(s,u,h)=>!h[0].length||(l(yhe(h.input,h.index))!=ea.Word||l(xhe(h.input,h.index))!=ea.Word)&&(l(xhe(h.input,h.index+h[0].length))!=ea.Word||l(yhe(h.input,h.index+h[0].length))!=ea.Word)}class Kwn extends mSt{nextMatch(s,u,h){let g=cI(this.spec,s,h,s.doc.length).next();return g.done&&(g=cI(this.spec,s,0,u).next()),g.done?null:g.value}prevMatchInRange(s,u,h){for(let g=1;;g++){let w=Math.max(u,h-g*1e4),p=cI(this.spec,s,w,h),k=null;for(;!p.next().done;)k=p.value;if(k&&(w==u||k.from>w+10))return k;if(w==u)return null}}prevMatch(s,u,h){return this.prevMatchInRange(s,0,u)||this.prevMatchInRange(s,h,s.doc.length)}getReplacement(s){return this.spec.unquote(this.spec.replace).replace(/\$([$&]|\d+)/g,(u,h)=>{if(h=="&")return s.match[0];if(h=="$")return"$";for(let g=h.length;g>0;g--){let w=+h.slice(0,g);if(w>0&&w<s.match.length)return s.match[w]+h.slice(g)}return u})}matchAll(s,u){let h=cI(this.spec,s,0,s.doc.length),g=[];for(;!h.next().done;){if(g.length>=u)return null;g.push(h.value)}return g}highlight(s,u,h,g){let w=cI(this.spec,s,Math.max(0,u-250),Math.min(h+250,s.doc.length));for(;!w.next().done;)g(w.value.from,w.value.to)}}const bV=Ds.define(),MAe=Ds.define(),m8=Td.define({create(l){return new lCe(vMe(l).create(),null)},update(l,s){for(let u of s.effects)u.is(bV)?l=new lCe(u.value.create(),l.panel):u.is(MAe)&&(l=new lCe(l.query,u.value?AAe:null));return l},provide:l=>lV.from(l,s=>s.panel)});class lCe{constructor(s,u){this.query=s,this.panel=u}}const Ywn=Fr.mark({class:"cm-searchMatch"}),Zwn=Fr.mark({class:"cm-searchMatch cm-searchMatch-selected"}),e2n=Xh.fromClass(class{constructor(l){this.view=l,this.decorations=this.highlight(l.state.field(m8))}update(l){let s=l.state.field(m8);(s!=l.startState.field(m8)||l.docChanged||l.selectionSet||l.viewportChanged)&&(this.decorations=this.highlight(s))}highlight({query:l,panel:s}){if(!s||!l.spec.valid)return Fr.none;let{view:u}=this,h=new x8;for(let g=0,w=u.visibleRanges,p=w.length;g<p;g++){let{from:k,to:j}=w[g];for(;g<p-1&&j>w[g+1].from-500;)j=w[++g].to;l.highlight(u.state,k,j,(A,_)=>{let D=u.state.selection.ranges.some(I=>I.from==A&&I.to==_);h.add(A,_,D?Zwn:Ywn)})}return h.finish()}},{decorations:l=>l.decorations});function IV(l){return s=>{let u=s.state.field(m8,!1);return u&&u.query.spec.valid?l(s,u):ySt(s)}}const khe=IV((l,{query:s})=>{let{to:u}=l.state.selection.main,h=s.nextMatch(l.state,u,u);if(!h)return!1;let g=kn.single(h.from,h.to),w=l.state.facet(HI);return l.dispatch({selection:g,effects:[NAe(l,h),w.scrollToMatch(g.main,l)],userEvent:"select.search"}),vSt(l),!0}),Ohe=IV((l,{query:s})=>{let{state:u}=l,{from:h}=u.selection.main,g=s.prevMatch(u,h,h);if(!g)return!1;let w=kn.single(g.from,g.to),p=l.state.facet(HI);return l.dispatch({selection:w,effects:[NAe(l,g),p.scrollToMatch(w.main,l)],userEvent:"select.search"}),vSt(l),!0}),t2n=IV((l,{query:s})=>{let u=s.matchAll(l.state,1e3);return!u||!u.length?!1:(l.dispatch({selection:kn.create(u.map(h=>kn.range(h.from,h.to))),userEvent:"select.search.matches"}),!0)}),n2n=({state:l,dispatch:s})=>{let u=l.selection;if(u.ranges.length>1||u.main.empty)return!1;let{from:h,to:g}=u.main,w=[],p=0;for(let k=new RI(l.doc,l.sliceDoc(h,g));!k.next().done;){if(w.length>1e3)return!1;k.value.from==h&&(p=w.length),w.push(kn.range(k.value.from,k.value.to))}return s(l.update({selection:kn.create(w,p),userEvent:"select.search.matches"})),!0},J3t=IV((l,{query:s})=>{let{state:u}=l,{from:h,to:g}=u.selection.main;if(u.readOnly)return!1;let w=s.nextMatch(u,h,h);if(!w)return!1;let p=w,k=[],j,A,_=[];p.from==h&&p.to==g&&(A=u.toText(s.getReplacement(p)),k.push({from:p.from,to:p.to,insert:A}),p=s.nextMatch(u,p.from,p.to),_.push(Bi.announce.of(u.phrase("replaced match on line $",u.doc.lineAt(h).number)+".")));let D=l.state.changes(k);return p&&(j=kn.single(p.from,p.to).map(D),_.push(NAe(l,p)),_.push(u.facet(HI).scrollToMatch(j.main,l))),l.dispatch({changes:D,selection:j,effects:_,userEvent:"input.replace"}),!0}),i2n=IV((l,{query:s})=>{if(l.state.readOnly)return!1;let u=s.matchAll(l.state,1e9).map(g=>{let{from:w,to:p}=g;return{from:w,to:p,insert:s.getReplacement(g)}});if(!u.length)return!1;let h=l.state.phrase("replaced $ matches",u.length)+".";return l.dispatch({changes:u,effects:Bi.announce.of(h),userEvent:"input.replace.all"}),!0});function AAe(l){return l.state.facet(HI).createPanel(l)}function vMe(l,s){var u,h,g,w,p;let k=l.selection.main,j=k.empty||k.to>k.from+100?"":l.sliceDoc(k.from,k.to);if(s&&!j)return s;let A=l.facet(HI);return new bSt({search:((u=s==null?void 0:s.literal)!==null&&u!==void 0?u:A.literal)?j:j.replace(/\n/g,"\\n"),caseSensitive:(h=s==null?void 0:s.caseSensitive)!==null&&h!==void 0?h:A.caseSensitive,literal:(g=s==null?void 0:s.literal)!==null&&g!==void 0?g:A.literal,regexp:(w=s==null?void 0:s.regexp)!==null&&w!==void 0?w:A.regexp,wholeWord:(p=s==null?void 0:s.wholeWord)!==null&&p!==void 0?p:A.wholeWord})}function wSt(l){let s=ROt(l,AAe);return s&&s.dom.querySelector("[main-field]")}function vSt(l){let s=wSt(l);s&&s==l.root.activeElement&&s.select()}const ySt=l=>{let s=l.state.field(m8,!1);if(s&&s.panel){let u=wSt(l);if(u&&u!=l.root.activeElement){let h=vMe(l.state,s.query.spec);h.valid&&l.dispatch({effects:bV.of(h)}),u.focus(),u.select()}}else l.dispatch({effects:[MAe.of(!0),s?bV.of(vMe(l.state,s.query.spec)):Ds.appendConfig.of(c2n)]});return!0},xSt=l=>{let s=l.state.field(m8,!1);if(!s||!s.panel)return!1;let u=ROt(l,AAe);return u&&u.dom.contains(l.root.activeElement)&&l.focus(),l.dispatch({effects:MAe.of(!1)}),!0},r2n=[{key:"Mod-f",run:ySt,scope:"editor search-panel"},{key:"F3",run:khe,shift:Ohe,scope:"editor search-panel",preventDefault:!0},{key:"Mod-g",run:khe,shift:Ohe,scope:"editor search-panel",preventDefault:!0},{key:"Escape",run:xSt,scope:"editor search-panel"},{key:"Mod-Shift-l",run:n2n},{key:"Mod-Alt-g",run:Lwn},{key:"Mod-d",run:Gwn,preventDefault:!0}];class s2n{constructor(s){this.view=s;let u=this.query=s.state.field(m8).query.spec;this.commit=this.commit.bind(this),this.searchField=$l("input",{value:u.search,placeholder:Kb(s,"Find"),"aria-label":Kb(s,"Find"),class:"cm-textfield",name:"search",form:"","main-field":"true",onchange:this.commit,onkeyup:this.commit}),this.replaceField=$l("input",{value:u.replace,placeholder:Kb(s,"Replace"),"aria-label":Kb(s,"Replace"),class:"cm-textfield",name:"replace",form:"",onchange:this.commit,onkeyup:this.commit}),this.caseField=$l("input",{type:"checkbox",name:"case",form:"",checked:u.caseSensitive,onchange:this.commit}),this.reField=$l("input",{type:"checkbox",name:"re",form:"",checked:u.regexp,onchange:this.commit}),this.wordField=$l("input",{type:"checkbox",name:"word",form:"",checked:u.wholeWord,onchange:this.commit});function h(g,w,p){return $l("button",{class:"cm-button",name:g,onclick:w,type:"button"},p)}this.dom=$l("div",{onkeydown:g=>this.keydown(g),class:"cm-search"},[this.searchField,h("next",()=>khe(s),[Kb(s,"next")]),h("prev",()=>Ohe(s),[Kb(s,"previous")]),h("select",()=>t2n(s),[Kb(s,"all")]),$l("label",null,[this.caseField,Kb(s,"match case")]),$l("label",null,[this.reField,Kb(s,"regexp")]),$l("label",null,[this.wordField,Kb(s,"by word")]),...s.state.readOnly?[]:[$l("br"),this.replaceField,h("replace",()=>J3t(s),[Kb(s,"replace")]),h("replaceAll",()=>i2n(s),[Kb(s,"replace all")])],$l("button",{name:"close",onclick:()=>xSt(s),"aria-label":Kb(s,"close"),type:"button"},["×"])])}commit(){let s=new bSt({search:this.searchField.value,caseSensitive:this.caseField.checked,regexp:this.reField.checked,wholeWord:this.wordField.checked,replace:this.replaceField.value});s.eq(this.query)||(this.query=s,this.view.dispatch({effects:bV.of(s)}))}keydown(s){ign(this.view,s,"search-panel")?s.preventDefault():s.keyCode==13&&s.target==this.searchField?(s.preventDefault(),(s.shiftKey?Ohe:khe)(this.view)):s.keyCode==13&&s.target==this.replaceField&&(s.preventDefault(),J3t(this.view))}update(s){for(let u of s.transactions)for(let h of u.effects)h.is(bV)&&!h.value.eq(this.query)&&this.setQuery(h.value)}setQuery(s){this.query=s,this.searchField.value=s.search,this.replaceField.value=s.replace,this.caseField.checked=s.caseSensitive,this.reField.checked=s.regexp,this.wordField.checked=s.wholeWord}mount(){this.searchField.select()}get pos(){return 80}get top(){return this.view.state.facet(HI).top}}function Kb(l,s){return l.state.phrase(s)}const dfe=30,gfe=/[\s\.,:;?!]/;function NAe(l,{from:s,to:u}){let h=l.state.doc.lineAt(s),g=l.state.doc.lineAt(u).to,w=Math.max(h.from,s-dfe),p=Math.min(g,u+dfe),k=l.state.sliceDoc(w,p);if(w!=h.from){for(let j=0;j<dfe;j++)if(!gfe.test(k[j+1])&&gfe.test(k[j])){k=k.slice(j);break}}if(p!=g){for(let j=k.length-1;j>k.length-dfe;j--)if(!gfe.test(k[j-1])&&gfe.test(k[j])){k=k.slice(0,j);break}}return Bi.announce.of(`${l.state.phrase("current match")}. ${k} ${l.state.phrase("on line")} ${h.number}.`)}const o2n=Bi.baseTheme({".cm-panel.cm-search":{padding:"2px 6px 4px",position:"relative","& [name=close]":{position:"absolute",top:"0",right:"4px",backgroundColor:"inherit",border:"none",font:"inherit",padding:0,margin:0},"& input, & button, & label":{margin:".2em .6em .2em 0"},"& input[type=checkbox]":{marginRight:".2em"},"& label":{fontSize:"80%",whiteSpace:"pre"}},"&light .cm-searchMatch":{backgroundColor:"#ffff0054"},"&dark .cm-searchMatch":{backgroundColor:"#00ffff8a"},"&light .cm-searchMatch-selected":{backgroundColor:"#ff6a0054"},"&dark .cm-searchMatch-selected":{backgroundColor:"#ff00ff8a"}}),c2n=[m8,E8.low(e2n),o2n];class X3t{constructor(s,u,h){this.from=s,this.to=u,this.diagnostic=h}}class cM{constructor(s,u,h){this.diagnostics=s,this.panel=u,this.selected=h}static init(s,u,h){let g=h.facet(mV).markerFilter;g&&(s=g(s,h));let w=s.slice().sort((B,F)=>B.from-F.from||B.to-F.to),p=new x8,k=[],j=0,A=h.doc.iter(),_=0,D=h.doc.length;for(let B=0;;){let F=B==w.length?null:w[B];if(!F&&!k.length)break;let U,K;if(k.length)U=j,K=k.reduce((ee,ce)=>Math.min(ee,ce.to),F&&F.from>U?F.from:1e8);else{if(U=F.from,U>D)break;K=F.to,k.push(F),B++}for(;B<w.length;){let ee=w[B];if(ee.from==U&&(ee.to>ee.from||ee.to==U))k.push(ee),B++,K=Math.min(ee.to,K);else{K=Math.min(ee.from,K);break}}K=Math.min(K,D);let Y=!1;if(k.some(ee=>ee.from==U&&(ee.to==K||K==D))&&(Y=U==K,!Y&&K-U<10)){let ee=U-(_+A.value.length);ee>0&&(A.next(ee),_=U);for(let ce=U;;){if(ce>=K){Y=!0;break}if(!A.lineBreak&&_+A.value.length>ce)break;ce=_+A.value.length,_+=A.value.length,A.next()}}let Z=CSt(k);if(Y)p.add(U,U,Fr.widget({widget:new f2n(Z),diagnostics:k.slice()}));else{let ee=k.reduce((ce,fe)=>fe.markClass?ce+" "+fe.markClass:ce,"");p.add(U,K,Fr.mark({class:"cm-lintRange cm-lintRange-"+Z+ee,diagnostics:k.slice(),inclusiveEnd:k.some(ce=>ce.to>K)}))}if(j=K,j==D)break;for(let ee=0;ee<k.length;ee++)k[ee].to<=j&&k.splice(ee--,1)}let I=p.finish();return new cM(I,u,$I(I))}}function $I(l,s=null,u=0){let h=null;return l.between(u,1e9,(g,w,{spec:p})=>{if(!(s&&p.diagnostics.indexOf(s)<0))if(!h)h=new X3t(g,w,s||p.diagnostics[0]);else{if(p.diagnostics.indexOf(h.diagnostic)<0)return!1;h=new X3t(h.from,w,h.diagnostic)}}),h}function kSt(l,s){let u=s.pos,h=s.end||u,g=l.state.facet(mV).hideOn(l,u,h);if(g!=null)return g;let w=l.startState.doc.lineAt(s.pos);return!!(l.effects.some(p=>p.is(rde))||l.changes.touchesRange(w.from,Math.max(w.to,h)))}function l2n(l,s){return l.field(Ty,!1)?s:s.concat(Ds.appendConfig.of(v2n))}function uCe(l,s){return{effects:l2n(l,[rde.of(s)])}}const rde=Ds.define(),OSt=Ds.define(),SSt=Ds.define(),Ty=Td.define({create(){return new cM(Fr.none,null,null)},update(l,s){if(s.docChanged&&l.diagnostics.size){let u=l.diagnostics.map(s.changes),h=null,g=l.panel;if(l.selected){let w=s.changes.mapPos(l.selected.from,1);h=$I(u,l.selected.diagnostic,w)||$I(u,null,w)}!u.size&&g&&s.state.facet(mV).autoPanel&&(g=null),l=new cM(u,g,h)}for(let u of s.effects)if(u.is(rde)){let h=s.state.facet(mV).autoPanel?u.value.length?She.open:null:l.panel;l=cM.init(u.value,h,s.state)}else u.is(OSt)?l=new cM(l.diagnostics,u.value?She.open:null,l.selected):u.is(SSt)&&(l=new cM(l.diagnostics,l.panel,u.value));return l},provide:l=>[lV.from(l,s=>s.panel),Bi.decorations.from(l,s=>s.diagnostics)]}),u2n=Fr.mark({class:"cm-lintRange cm-lintRange-active"});function a2n(l,s,u){let{diagnostics:h}=l.state.field(Ty),g,w=-1,p=-1;h.between(s-(u<0?1:0),s+(u>0?1:0),(j,A,{spec:_})=>{if(s>=j&&s<=A&&(j==A||(s>j||u>0)&&(s<A||u<0)))return g=_.diagnostics,w=j,p=A,!1});let k=l.state.facet(mV).tooltipFilter;return g&&k&&(g=k(g,l.state)),g?{pos:w,end:p,above:l.state.doc.lineAt(w).to<p,create(){return{dom:jSt(l,g)}}}:null}function jSt(l,s){return $l("ul",{class:"cm-tooltip-lint"},s.map(u=>ESt(l,u,!1)))}const V3t=l=>{let s=l.state.field(Ty,!1);return!s||!s.panel?!1:(l.dispatch({effects:OSt.of(!1)}),!0)},mV=Qi.define({combine(l){return{sources:l.map(s=>s.source).filter(s=>s!=null),...Z3(l.map(s=>s.config),{delay:750,markerFilter:null,tooltipFilter:null,needsRefresh:null,hideOn:()=>null},{delay:Math.max,markerFilter:W3t,tooltipFilter:W3t,needsRefresh:(s,u)=>s?u?h=>s(h)||u(h):s:u,hideOn:(s,u)=>s?u?(h,g,w)=>s(h,g,w)||u(h,g,w):s:u,autoPanel:(s,u)=>s||u})}}});function W3t(l,s){return l?s?(u,h)=>s(l(u,h),h):l:s}function TSt(l){let s=[];if(l)e:for(let{name:u}of l){for(let h=0;h<u.length;h++){let g=u[h];if(/[a-zA-Z]/.test(g)&&!s.some(w=>w.toLowerCase()==g.toLowerCase())){s.push(g);continue e}}s.push("")}return s}function ESt(l,s,u){var h;let g=u?TSt(s.actions):[];return $l("li",{class:"cm-diagnostic cm-diagnostic-"+s.severity},$l("span",{class:"cm-diagnosticText"},s.renderMessage?s.renderMessage(l):s.message),(h=s.actions)===null||h===void 0?void 0:h.map((w,p)=>{let k=!1,j=B=>{if(B.preventDefault(),k)return;k=!0;let F=$I(l.state.field(Ty).diagnostics,s);F&&w.apply(l,F.from,F.to)},{name:A}=w,_=g[p]?A.indexOf(g[p]):-1,D=_<0?A:[A.slice(0,_),$l("u",A.slice(_,_+1)),A.slice(_+1)],I=w.markClass?" "+w.markClass:"";return $l("button",{type:"button",class:"cm-diagnosticAction"+I,onclick:j,onmousedown:j,"aria-label":` Action: ${A}${_<0?"":` (access key "${g[p]})"`}.`},D)}),s.source&&$l("div",{class:"cm-diagnosticSource"},s.source))}class f2n extends lO{constructor(s){super(),this.sev=s}eq(s){return s.sev==this.sev}toDOM(){return $l("span",{class:"cm-lintPoint cm-lintPoint-"+this.sev})}}class K3t{constructor(s,u){this.diagnostic=u,this.id="item_"+Math.floor(Math.random()*4294967295).toString(16),this.dom=ESt(s,u,!0),this.dom.id=this.id,this.dom.setAttribute("role","option")}}class She{constructor(s){this.view=s,this.items=[];let u=g=>{if(!(g.ctrlKey||g.altKey||g.metaKey)){if(g.keyCode==27)V3t(this.view),this.view.focus();else if(g.keyCode==38||g.keyCode==33)this.moveSelection((this.selectedIndex-1+this.items.length)%this.items.length);else if(g.keyCode==40||g.keyCode==34)this.moveSelection((this.selectedIndex+1)%this.items.length);else if(g.keyCode==36)this.moveSelection(0);else if(g.keyCode==35)this.moveSelection(this.items.length-1);else if(g.keyCode==13)this.view.focus();else if(g.keyCode>=65&&g.keyCode<=90&&this.selectedIndex>=0){let{diagnostic:w}=this.items[this.selectedIndex],p=TSt(w.actions);for(let k=0;k<p.length;k++)if(p[k].toUpperCase().charCodeAt(0)==g.keyCode){let j=$I(this.view.state.field(Ty).diagnostics,w);j&&w.actions[k].apply(s,j.from,j.to)}}else return;g.preventDefault()}},h=g=>{for(let w=0;w<this.items.length;w++)this.items[w].dom.contains(g.target)&&this.moveSelection(w)};this.list=$l("ul",{tabIndex:0,role:"listbox","aria-label":this.view.state.phrase("Diagnostics"),onkeydown:u,onclick:h}),this.dom=$l("div",{class:"cm-panel-lint"},this.list,$l("button",{type:"button",name:"close","aria-label":this.view.state.phrase("close"),onclick:()=>V3t(this.view)},"×")),this.update()}get selectedIndex(){let s=this.view.state.field(Ty).selected;if(!s)return-1;for(let u=0;u<this.items.length;u++)if(this.items[u].diagnostic==s.diagnostic)return u;return-1}update(){let{diagnostics:s,selected:u}=this.view.state.field(Ty),h=0,g=!1,w=null,p=new Set;for(s.between(0,this.view.state.doc.length,(k,j,{spec:A})=>{for(let _ of A.diagnostics){if(p.has(_))continue;p.add(_);let D=-1,I;for(let B=h;B<this.items.length;B++)if(this.items[B].diagnostic==_){D=B;break}D<0?(I=new K3t(this.view,_),this.items.splice(h,0,I),g=!0):(I=this.items[D],D>h&&(this.items.splice(h,D-h),g=!0)),u&&I.diagnostic==u.diagnostic?I.dom.hasAttribute("aria-selected")||(I.dom.setAttribute("aria-selected","true"),w=I):I.dom.hasAttribute("aria-selected")&&I.dom.removeAttribute("aria-selected"),h++}});h<this.items.length&&!(this.items.length==1&&this.items[0].diagnostic.from<0);)g=!0,this.items.pop();this.items.length==0&&(this.items.push(new K3t(this.view,{from:-1,to:-1,severity:"info",message:this.view.state.phrase("No diagnostics")})),g=!0),w?(this.list.setAttribute("aria-activedescendant",w.id),this.view.requestMeasure({key:this,read:()=>({sel:w.dom.getBoundingClientRect(),panel:this.list.getBoundingClientRect()}),write:({sel:k,panel:j})=>{let A=j.height/this.list.offsetHeight;k.top<j.top?this.list.scrollTop-=(j.top-k.top)/A:k.bottom>j.bottom&&(this.list.scrollTop+=(k.bottom-j.bottom)/A)}})):this.selectedIndex<0&&this.list.removeAttribute("aria-activedescendant"),g&&this.sync()}sync(){let s=this.list.firstChild;function u(){let h=s;s=h.nextSibling,h.remove()}for(let h of this.items)if(h.dom.parentNode==this.list){for(;s!=h.dom;)u();s=h.dom.nextSibling}else this.list.insertBefore(h.dom,s);for(;s;)u()}moveSelection(s){if(this.selectedIndex<0)return;let u=this.view.state.field(Ty),h=$I(u.diagnostics,this.items[s].diagnostic);h&&this.view.dispatch({selection:{anchor:h.from,head:h.to},scrollIntoView:!0,effects:SSt.of(h)})}static open(s){return new She(s)}}function Lfe(l,s='viewBox="0 0 40 40"'){return`url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" ${s}>${encodeURIComponent(l)}</svg>')`}function pfe(l){return Lfe(`<path d="m0 2.5 l2 -1.5 l1 0 l2 1.5 l1 0" stroke="${l}" fill="none" stroke-width=".7"/>`,'width="6" height="3"')}const h2n=Bi.baseTheme({".cm-diagnostic":{padding:"3px 6px 3px 8px",marginLeft:"-1px",display:"block",whiteSpace:"pre-wrap"},".cm-diagnostic-error":{borderLeft:"5px solid #d11"},".cm-diagnostic-warning":{borderLeft:"5px solid orange"},".cm-diagnostic-info":{borderLeft:"5px solid #999"},".cm-diagnostic-hint":{borderLeft:"5px solid #66d"},".cm-diagnosticAction":{font:"inherit",border:"none",padding:"2px 4px",backgroundColor:"#444",color:"white",borderRadius:"3px",marginLeft:"8px",cursor:"pointer"},".cm-diagnosticSource":{fontSize:"70%",opacity:.7},".cm-lintRange":{backgroundPosition:"left bottom",backgroundRepeat:"repeat-x",paddingBottom:"0.7px"},".cm-lintRange-error":{backgroundImage:pfe("#d11")},".cm-lintRange-warning":{backgroundImage:pfe("orange")},".cm-lintRange-info":{backgroundImage:pfe("#999")},".cm-lintRange-hint":{backgroundImage:pfe("#66d")},".cm-lintRange-active":{backgroundColor:"#ffdd9980"},".cm-tooltip-lint":{padding:0,margin:0},".cm-lintPoint":{position:"relative","&:after":{content:'""',position:"absolute",bottom:0,left:"-2px",borderLeft:"3px solid transparent",borderRight:"3px solid transparent",borderBottom:"4px solid #d11"}},".cm-lintPoint-warning":{"&:after":{borderBottomColor:"orange"}},".cm-lintPoint-info":{"&:after":{borderBottomColor:"#999"}},".cm-lintPoint-hint":{"&:after":{borderBottomColor:"#66d"}},".cm-panel.cm-panel-lint":{position:"relative","& ul":{maxHeight:"100px",overflowY:"auto","& [aria-selected]":{backgroundColor:"#ddd","& u":{textDecoration:"underline"}},"&:focus [aria-selected]":{background_fallback:"#bdf",backgroundColor:"Highlight",color_fallback:"white",color:"HighlightText"},"& u":{textDecoration:"none"},padding:0,margin:0},"& [name=close]":{position:"absolute",top:"0",right:"2px",background:"inherit",border:"none",font:"inherit",padding:0,margin:0}},"&dark .cm-lintRange-active":{backgroundColor:"#86714a80"},"&dark .cm-panel.cm-panel-lint ul":{"& [aria-selected]":{backgroundColor:"#2e343e"}}});function d2n(l){return l=="error"?4:l=="warning"?3:l=="info"?2:1}function CSt(l){let s="hint",u=1;for(let h of l){let g=d2n(h.severity);g>u&&(u=g,s=h.severity)}return s}class MSt extends K3{constructor(s){super(),this.diagnostics=s,this.severity=CSt(s)}toDOM(s){let u=document.createElement("div");u.className="cm-lint-marker cm-lint-marker-"+this.severity;let h=this.diagnostics,g=s.state.facet(sde).tooltipFilter;return g&&(h=g(h,s.state)),h.length&&(u.onmouseover=()=>p2n(s,u,h)),u}}function g2n(l,s){let u=h=>{let g=s.getBoundingClientRect();if(!(h.clientX>g.left-10&&h.clientX<g.right+10&&h.clientY>g.top-10&&h.clientY<g.bottom+10)){for(let w=h.target;w;w=w.parentNode)if(w.nodeType==1&&w.classList.contains("cm-tooltip-lint"))return;window.removeEventListener("mousemove",u),l.state.field(ASt)&&l.dispatch({effects:_Ae.of(null)})}};window.addEventListener("mousemove",u)}function p2n(l,s,u){function h(){let p=l.elementAtHeight(s.getBoundingClientRect().top+5-l.documentTop);l.coordsAtPos(p.from)&&l.dispatch({effects:_Ae.of({pos:p.from,above:!1,clip:!1,create(){return{dom:jSt(l,u),getCoords:()=>s.getBoundingClientRect()}}})}),s.onmouseout=s.onmousemove=null,g2n(l,s)}let{hoverTime:g}=l.state.facet(sde),w=setTimeout(h,g);s.onmouseout=()=>{clearTimeout(w),s.onmouseout=s.onmousemove=null},s.onmousemove=()=>{clearTimeout(w),w=setTimeout(h,g)}}function b2n(l,s){let u=Object.create(null);for(let g of s){let w=l.lineAt(g.from);(u[w.from]||(u[w.from]=[])).push(g)}let h=[];for(let g in u)h.push(new MSt(u[g]).range(+g));return xo.of(h,!0)}const m2n=FOt({class:"cm-gutter-lint",markers:l=>l.state.field(yMe),widgetMarker:(l,s,u)=>{let h=[];return l.state.field(yMe).between(u.from,u.to,(g,w,p)=>{g>u.from&&g<u.to&&h.push(...p.diagnostics)}),h.length?new MSt(h):null}}),yMe=Td.define({create(){return xo.empty},update(l,s){l=l.map(s.changes);let u=s.state.facet(sde).markerFilter;for(let h of s.effects)if(h.is(rde)){let g=h.value;u&&(g=u(g||[],s.state)),l=b2n(s.state.doc,g.slice(0))}return l}}),_Ae=Ds.define(),ASt=Td.define({create(){return null},update(l,s){return l&&s.docChanged&&(l=kSt(s,l)?null:{...l,pos:s.changes.mapPos(l.pos)}),s.effects.reduce((u,h)=>h.is(_Ae)?h.value:u,l)},provide:l=>Uhe.from(l)}),w2n=Bi.baseTheme({".cm-gutter-lint":{width:"1.4em","& .cm-gutterElement":{padding:".2em"}},".cm-lint-marker":{width:"1em",height:"1em"},".cm-lint-marker-info":{content:Lfe('<path fill="#aaf" stroke="#77e" stroke-width="6" stroke-linejoin="round" d="M5 5L35 5L35 35L5 35Z"/>')},".cm-lint-marker-warning":{content:Lfe('<path fill="#fe8" stroke="#fd7" stroke-width="6" stroke-linejoin="round" d="M20 6L37 35L3 35Z"/>')},".cm-lint-marker-error":{content:Lfe('<circle cx="20" cy="20" r="15" fill="#f87" stroke="#f43" stroke-width="6"/>')}}),v2n=[Ty,Bi.decorations.compute([Ty],l=>{let{selected:s,panel:u}=l.field(Ty);return!s||!u||s.from==s.to?Fr.none:Fr.set([u2n.range(s.from,s.to)])}),Cgn(a2n,{hideOn:kSt}),h2n],sde=Qi.define({combine(l){return Z3(l,{hoverTime:300,markerFilter:null,tooltipFilter:null})}});function y2n(l={}){return[sde.of(l),yMe,m2n,w2n,ASt]}const sf={background:"var(--bg-input)",border:"1px solid var(--border)",color:"var(--text-primary)"},Zb=sf;function NSt(){const{mlflowStatus:l,mlflowBackend:s}=xhn();return E.jsx("div",{className:"flex items-center gap-2 px-2.5 py-1.5 rounded-lg text-[11px]",style:{background:l==="connected"?"rgba(34,197,94,.06)":l==="error"?"rgba(239,68,68,.06)":"var(--bg-surface)",border:`1px solid ${l==="connected"?"rgba(34,197,94,.2)":l==="error"?"rgba(239,68,68,.2)":"var(--border)"}`},children:l==="loading"?E.jsxs(E.Fragment,{children:[E.jsx(Ey,{size:11,className:"animate-spin",style:{color:"var(--text-muted)"}}),E.jsx("span",{style:{color:"var(--text-muted)"},children:"Connecting to MLflow..."})]}):l==="connected"?E.jsxs(E.Fragment,{children:[E.jsx(Ufe,{size:11,style:{color:"#22c55e"}}),E.jsxs("span",{style:{color:"var(--text-secondary)"},children:["MLflow (",s,")"]})]}):E.jsxs(E.Fragment,{children:[E.jsx(Oy,{size:11,style:{color:"#ef4444"}}),E.jsx("span",{style:{color:"#ef4444"},children:"MLflow not available"})]})})}function DAe({currentPath:l,onSelect:s,extensions:u}){const[h,g]=pe.useState("."),[w,p]=pe.useState([]),[k,j]=pe.useState(!0),[A,_]=pe.useState(null),[D,I]=pe.useState(l),B=Kc(Z=>Z.getFileListCache),F=Kc(Z=>Z.setFileListCache);pe.useEffect(()=>{const Z=`${h}|${u||""}`,ee=B(Z);if(ee){p(ee),j(!1);return}_(null),uhn(h,u).then(ce=>{const fe=ce.items||[];p(fe),F(Z,fe),j(!1)}).catch(ce=>{_(ce instanceof Error?ce.message:"Failed to load files"),p([]),j(!1)})},[h,u,B,F]);const U=()=>{if(h===".")return;const Z=h.split("/");Z.pop(),j(!0),g(Z.length>0?Z.join("/"):".")},K=Z=>{I(Z),s(Z)},Y=Z=>Z>1024*1024?`${(Z/(1024*1024)).toFixed(1)} MB`:`${(Z/1024).toFixed(1)} KB`;return E.jsxs("div",{children:[D&&E.jsxs("div",{className:"mb-2 px-2.5 py-2 rounded-lg flex items-center gap-2",style:{background:"rgba(34,197,94,.1)",border:"1px solid rgba(34,197,94,.2)"},children:[E.jsx(Ufe,{size:14,style:{color:"#22c55e"},className:"shrink-0"}),E.jsx("span",{className:"text-xs font-mono truncate",style:{color:"#4ade80"},children:D})]}),E.jsxs("div",{className:"rounded-lg overflow-hidden",style:{border:"1px solid var(--border)"},children:[E.jsxs("div",{className:"px-2 py-1.5 flex items-center gap-1.5",style:{background:"var(--bg-elevated)",borderBottom:"1px solid var(--border)"},children:[E.jsx("button",{onClick:U,disabled:h===".",className:"p-0.5 rounded disabled:opacity-30 disabled:cursor-not-allowed transition-colors",style:{color:"var(--text-secondary)"},children:E.jsx(qun,{size:14})}),E.jsx("span",{className:"text-xs font-mono truncate",style:{color:"var(--text-muted)"},children:h==="."?"/":h})]}),E.jsx("div",{className:"max-h-40 overflow-y-auto",style:{background:"var(--bg-input)"},children:k?E.jsx("div",{className:"px-3 py-2 text-xs",style:{color:"var(--text-muted)"},children:"Loading..."}):A?E.jsx("div",{className:"px-3 py-2 text-xs",style:{color:"#f87171"},children:A}):w.length===0?E.jsx("div",{className:"px-3 py-2 text-xs",style:{color:"var(--text-muted)"},children:"No matching files"}):w.map(Z=>{const ee=Z.type==="file"&&Z.path===D;return E.jsxs("button",{onClick:()=>{Z.type==="directory"?(j(!0),g(Z.path)):K(Z.path)},className:"w-full px-3 py-2 flex items-center gap-2 text-left transition-colors",style:{borderBottom:"1px solid var(--border)",background:ee?"var(--accent-soft)":"transparent"},onMouseEnter:ce=>{ee||(ce.currentTarget.style.background="var(--bg-hover)")},onMouseLeave:ce=>{ee||(ce.currentTarget.style.background="transparent")},children:[Z.type==="directory"?E.jsx(fan,{size:14,style:{color:"#f59e0b"},className:"shrink-0"}):ee?E.jsx(Ufe,{size:14,style:{color:"var(--accent)"},className:"shrink-0"}):E.jsx(ikt,{size:14,style:{color:"var(--text-muted)"},className:"shrink-0"}),E.jsx("span",{className:"text-xs truncate",style:{color:ee?"var(--accent)":"var(--text-secondary)",fontWeight:ee?500:400},children:Z.name}),Z.size!==void 0&&E.jsx("span",{className:"text-[11px] ml-auto shrink-0",style:{color:"var(--text-muted)"},children:Y(Z.size)})]},Z.path)})})]})]})}function _St({schema:l}){const[s,u]=pe.useState(!1);return!l||!l.columns?null:E.jsxs("div",{style:{borderTop:"1px solid var(--border)",background:"var(--bg-elevated)"},children:[E.jsxs("div",{className:"px-4 py-2 flex items-center justify-between",children:[E.jsxs("div",{className:"flex items-center gap-2",children:[E.jsx(Xfe,{size:14,style:{color:"var(--text-muted)"}}),E.jsx("span",{className:"text-xs font-semibold",style:{color:"var(--text-primary)"},children:"Schema"}),E.jsxs("span",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:[l.column_count??0," cols / ",(l.row_count??0).toLocaleString()," rows"]})]}),E.jsx("button",{onClick:()=>u(!s),className:"text-[11px] font-medium",style:{color:"var(--accent)"},children:s?"Hide preview":"Show preview"})]}),E.jsxs("div",{className:"px-4 pb-3",children:[E.jsx("div",{className:"rounded-lg overflow-hidden",style:{border:"1px solid var(--border)",background:"var(--bg-input)"},children:E.jsxs("table",{className:"w-full text-xs",children:[E.jsx("thead",{children:E.jsxs("tr",{style:{borderBottom:"1px solid var(--border)",background:"var(--bg-elevated)"},children:[E.jsx("th",{className:"text-left px-2.5 py-1.5 font-semibold",style:{color:"var(--text-muted)"},children:"Column"}),E.jsx("th",{className:"text-left px-2.5 py-1.5 font-semibold",style:{color:"var(--text-muted)"},children:"Type"})]})}),E.jsx("tbody",{children:l.columns.map(h=>E.jsxs("tr",{style:{borderBottom:"1px solid var(--border)"},children:[E.jsx("td",{className:"px-2.5 py-1.5 font-mono",style:{color:"var(--text-primary)"},children:h.name}),E.jsx("td",{className:"px-2.5 py-1.5",children:E.jsx("span",{className:`text-[11px] font-medium ${GMe(h.dtype)}`,children:h.dtype})})]},h.name))})]})}),s&&l.preview.length>0&&E.jsx("div",{className:"mt-2 rounded-lg overflow-x-auto",style:{border:"1px solid var(--border)",background:"var(--bg-input)"},children:E.jsxs("table",{className:"w-full text-[11px]",children:[E.jsx("thead",{children:E.jsx("tr",{style:{borderBottom:"1px solid var(--border)",background:"var(--bg-elevated)"},children:l.columns.map(h=>E.jsx("th",{className:"text-left px-2 py-1 font-semibold whitespace-nowrap",style:{color:"var(--text-muted)"},children:h.name},h.name))})}),E.jsx("tbody",{children:l.preview.map((h,g)=>E.jsx("tr",{style:{borderBottom:"1px solid var(--border)"},children:l.columns.map(w=>E.jsx("td",{className:"px-2 py-1 font-mono whitespace-nowrap",style:{color:"var(--text-secondary)"},children:String(h[w.name]??"")},w.name))},g))})]})})]})]})}const x2n=Bi.theme({"&":{backgroundColor:"var(--bg-input)",color:"var(--text-primary)",fontSize:"12px",fontFamily:"ui-monospace, SFMono-Regular, 'SF Mono', Menlo, Consolas, monospace",flex:"1",minHeight:"120px"},"&.cm-focused":{outline:"none"},".cm-scroller":{fontFamily:"inherit",lineHeight:"1.625",overflow:"auto"},".cm-content":{caretColor:"var(--accent)",padding:"10px 0"},".cm-line":{padding:"0 12px 0 4px"},".cm-gutters":{backgroundColor:"var(--bg-elevated)",color:"var(--text-muted)",border:"none",borderRight:"1px solid var(--border)"},".cm-gutter.cm-lineNumbers .cm-gutterElement":{padding:"0 8px 0 4px",minWidth:"28px"},".cm-activeLineGutter":{backgroundColor:"transparent",color:"var(--text-secondary)"},".cm-activeLine":{backgroundColor:"rgba(255,255,255,.03)"},".cm-selectionBackground":{backgroundColor:"rgba(59,130,246,.25) !important"},"&.cm-focused .cm-selectionBackground":{backgroundColor:"rgba(59,130,246,.3) !important"},".cm-cursor":{borderLeftColor:"var(--accent)"},".cm-matchingBracket":{backgroundColor:"rgba(59,130,246,.25)",outline:"1px solid rgba(59,130,246,.4)"},".cm-selectionMatch":{backgroundColor:"rgba(59,130,246,.15)"},".cm-searchMatch":{backgroundColor:"rgba(234,179,8,.3)",outline:"1px solid rgba(234,179,8,.5)"},".cm-searchMatch.cm-searchMatch-selected":{backgroundColor:"rgba(234,179,8,.5)"},".cm-foldGutter .cm-gutterElement":{color:"var(--text-muted)",padding:"0 4px"},".cm-tooltip":{backgroundColor:"var(--bg-elevated)",border:"1px solid var(--border)",color:"var(--text-primary)"},".cm-tooltip.cm-tooltip-autocomplete > ul > li":{padding:"4px 8px"},".cm-tooltip.cm-tooltip-autocomplete > ul > li[aria-selected]":{backgroundColor:"var(--accent-soft)",color:"var(--text-primary)"},".cm-panels":{backgroundColor:"var(--bg-elevated)",color:"var(--text-primary)",borderTop:"1px solid var(--border)"},".cm-panels.cm-panels-bottom":{borderTop:"1px solid var(--border)"},".cm-panel input":{backgroundColor:"var(--bg-input)",color:"var(--text-primary)",border:"1px solid var(--border)",borderRadius:"4px",padding:"2px 6px",fontSize:"12px"},".cm-panel button":{backgroundColor:"var(--bg-hover)",color:"var(--text-secondary)",border:"1px solid var(--border)",borderRadius:"4px",padding:"2px 8px",fontSize:"12px"},".cm-placeholder":{color:"var(--text-muted)",fontStyle:"italic"},".cm-lintRange-error":{backgroundImage:"none",backgroundColor:"rgba(239, 68, 68, 0.15)",borderBottom:"2px solid #ef4444"},".cm-gutter-lint":{width:"14px"},".cm-gutter-lint .cm-gutterElement":{padding:"0 2px"},".cm-lint-marker-error":{width:"8px !important",height:"8px !important",borderRadius:"50%",backgroundColor:"#ef4444",display:"inline-block",marginTop:"6px"},".cm-tooltip-lint":{backgroundColor:"var(--bg-elevated)",border:"1px solid var(--border)",color:"var(--text-primary)"}},{dark:!0}),k2n=Yhe.define([{tag:qn.keyword,color:"#c084fc"},{tag:qn.controlKeyword,color:"#c084fc"},{tag:qn.definitionKeyword,color:"#c084fc"},{tag:qn.operatorKeyword,color:"#c084fc"},{tag:qn.modifier,color:"#c084fc"},{tag:qn.self,color:"#f472b6"},{tag:qn.bool,color:"#fb923c"},{tag:qn.null,color:"#fb923c"},{tag:qn.number,color:"#fb923c"},{tag:qn.string,color:"#86efac"},{tag:qn.special(qn.string),color:"#86efac"},{tag:qn.regexp,color:"#fbbf24"},{tag:qn.comment,color:"var(--text-muted)",fontStyle:"italic"},{tag:qn.function(qn.definition(qn.variableName)),color:"var(--text-accent)"},{tag:qn.function(qn.variableName),color:"#93c5fd"},{tag:qn.className,color:"#fbbf24"},{tag:qn.definition(qn.className),color:"#fbbf24"},{tag:qn.propertyName,color:"#67e8f9"},{tag:qn.operator,color:"#94a3b8"},{tag:qn.punctuation,color:"#94a3b8"},{tag:qn.bracket,color:"#cbd5e1"},{tag:qn.meta,color:"#a78bfa"},{tag:qn.variableName,color:"var(--text-primary)"},{tag:qn.typeName,color:"#fbbf24"}]),O2n=Bi.theme({"&":{borderRadius:"8px",border:"1px solid var(--border)",overflow:"hidden",transition:"border-color 0.15s, box-shadow 0.15s"},"&.cm-focused":{borderColor:"rgba(59,130,246,.3)",boxShadow:"0 0 0 2px var(--accent-soft)"}});function RV({defaultValue:l,onChange:s,placeholder:u,errorLine:h}){const g=pe.useRef(null),w=pe.useRef(null),p=pe.useRef(s),k=pe.useRef(void 0),j=pe.useRef(new TV);return pe.useEffect(()=>{p.current=s},[s]),pe.useEffect(()=>{if(!g.current)return;const A=Bi.updateListener.of(I=>{if(I.docChanged){const B=I.state.doc.toString();k.current&&clearTimeout(k.current),k.current=setTimeout(()=>p.current(B),150),I.view&&I.view.dispatch(uCe(I.state,[]))}}),_=Ic.create({doc:l,extensions:[Mmn(),ugn(),ygn(),Bpn(),fbn(),tmn(),hmn(),dgn(),Hgn(),Rwn(),_V.of("    "),zgn(),Zpn(),y2n(),vmn(),nbn(k2n),x2n,O2n,j.current.of(u?Gxt(u):[]),Ghe.of([...smn,...r2n,...$mn,...Vpn,...A6t,_wn,...Nwn]),A,Bi.lineWrapping]}),D=new Bi({state:_,parent:g.current});return w.current=D,()=>{k.current&&clearTimeout(k.current),D.destroy()}},[]),pe.useEffect(()=>{const A=w.current;if(A)if(h!=null&&h>=1){const _=A.state.doc,D=Math.min(h,_.lines),I=_.line(D);A.dispatch(uCe(A.state,[{from:I.from,to:I.to,severity:"error",message:`Error on line ${h}`}]))}else A.dispatch(uCe(A.state,[]))},[h]),pe.useEffect(()=>{w.current&&w.current.dispatch({effects:j.current.reconfigure(u?Gxt(u):[])})},[u]),E.jsx("div",{ref:g,"data-testid":"code-editor-wrapper",className:"flex-1 min-h-[120px]"})}function CM({inputSources:l,onDeleteInput:s}){return l.length===0?null:E.jsx("div",{className:"rounded-lg px-3 py-1.5 shrink-0",style:{background:"var(--bg-input)",border:"1px solid var(--border)"},children:E.jsxs("div",{className:"flex items-center gap-2 flex-wrap",children:[E.jsx("span",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:l.length>1?"Inputs":"Input"}),l.map(u=>E.jsxs("span",{className:"inline-flex items-center gap-1 px-1.5 py-0.5 rounded",style:{background:"var(--accent-soft)"},children:[E.jsx("code",{className:"text-[11px] font-semibold",style:{color:"var(--accent)"},children:u.varName}),s&&E.jsx("button",{onClick:()=>s(u.edgeId),className:"p-0 rounded transition-colors",style:{color:"var(--text-muted)"},onMouseEnter:h=>{h.currentTarget.style.color="#ef4444"},onMouseLeave:h=>{h.currentTarget.style.color="var(--text-muted)"},title:`Remove connection from ${u.sourceLabel}`,children:E.jsx(jp,{size:10})})]},u.varName))]})})}function TM({value:l,onChange:s,options:u,accentColor:h}){return E.jsx("div",{className:"flex gap-1.5",children:u.map(g=>{const w=l===g.key;return E.jsxs("button",{onClick:()=>s(g.key),className:"flex-1 flex items-center justify-center gap-1.5 px-2 py-1.5 rounded-lg text-xs font-medium transition-colors",style:{background:w?zo(h,.1):"var(--bg-input)",border:w?`1px solid ${h}`:"1px solid var(--border)",color:w?h:"var(--text-secondary)"},children:[g.icon,g.label]},g.key)})})}function DSt(l){const[s,u]=pe.useState(null),[h,g]=pe.useState(!!l),w=pe.useCallback(p=>{g(!0),Mfn(p).then(k=>{u(k),g(!1)}).catch(()=>{u(null),g(!1)})},[]);return pe.useEffect(()=>{l&&w(l)},[l,w]),{schema:s,setSchema:u,loading:h,fetchForPath:w}}function S2n(l){return l<1024?`${l} B`:l<1024*1024?`${(l/1024).toFixed(1)} KB`:`${(l/(1024*1024)).toFixed(1)} MB`}function j2n(l){return l?new Date(l*1e3).toLocaleTimeString([],{hour:"2-digit",minute:"2-digit"}):""}function LSt({resourceKey:l,getStatus:s,startFetch:u,getProgress:h,deleteCache:g,timestampField:w,labels:p,onCacheReady:k}){const[j,A]=pe.useState(null),[_,D]=pe.useState(!1),[I,B]=pe.useState(null),[F,U]=pe.useState("");pe.useEffect(()=>{l&&s(l).then(ee=>{A(ee),ee.cached&&(k==null||k(ee))}).catch(()=>A(null))},[l]),pe.useEffect(()=>{if(!_||!l)return;const ee=setInterval(()=>{h(l).then(ce=>{ce.active&&B({rows:ce.rows||0,elapsed:ce.elapsed||0})}).catch(()=>{})},1e3);return()=>{clearInterval(ee),B(null)}},[_,l]);const K=()=>{l&&(D(!0),U(""),u(l).then(ee=>{A(ee),D(!1),k==null||k(ee)}).catch(ee=>{U(ee instanceof v8&&ee.detail||ee.message),D(!1)}))},Y=()=>{g(l).then(ee=>A(ee)).catch(ee=>U(ee instanceof v8&&ee.detail||ee.message))},Z=j?j[w]:0;return E.jsxs("div",{children:[E.jsx("button",{onClick:K,disabled:!l||_,className:"w-full flex items-center justify-center gap-2 px-3 py-2 rounded-lg text-xs font-medium transition-colors disabled:opacity-40",style:{background:j!=null&&j.cached?"rgba(34,197,94,.1)":"var(--accent-soft)",border:j!=null&&j.cached?"1px solid rgba(34,197,94,.3)":"1px solid var(--accent)",color:j!=null&&j.cached?"#22c55e":"var(--accent)"},children:_?E.jsxs(E.Fragment,{children:[E.jsx(Ey,{size:14,className:"animate-spin"})," ",I?`${I.rows.toLocaleString()} rows · ${I.elapsed}s`:p.pendingLabel]}):j!=null&&j.cached?E.jsxs(E.Fragment,{children:[E.jsx(Jfe,{size:14})," ",p.refreshLabel]}):E.jsxs(E.Fragment,{children:[E.jsx(Jfe,{size:14})," ",p.fetchLabel]})}),(j==null?void 0:j.cached)&&E.jsxs("div",{className:"mt-1.5 flex items-center gap-2 text-[10px] px-1",style:{color:"var(--text-muted)"},children:[E.jsxs("span",{children:[j.row_count.toLocaleString()," rows"]}),E.jsx("span",{children:"·"}),E.jsxs("span",{children:[j.column_count," cols"]}),E.jsx("span",{children:"·"}),E.jsx("span",{children:S2n(j.size_bytes)}),Z>0&&E.jsxs(E.Fragment,{children:[E.jsx("span",{children:"·"}),E.jsx("span",{children:j2n(Z)})]}),E.jsx("span",{children:"·"}),E.jsxs("button",{onClick:Y,className:"inline-flex items-center gap-0.5 hover:opacity-70 transition-opacity",style:{color:"#ef4444"},title:"Delete cached data",children:[E.jsx(BI,{size:10})," clear"]})]}),!(j!=null&&j.cached)&&l&&!_&&E.jsx("div",{className:"mt-1.5 text-[10px] px-1",style:{color:"#f59e0b"},children:p.notCachedHint}),F&&E.jsx("div",{className:"mt-1.5 text-[10px] px-2 py-1 rounded",style:{background:"rgba(239,68,68,.1)",color:"#ef4444"},children:F})]})}function T2n({httpPath:l,onSelect:s}){const[u,h]=pe.useState([]),[g,w]=pe.useState(!1),[p,k]=pe.useState(null),[j,A]=pe.useState(!1),_=pe.useRef(!1),D=()=>{if(_.current){A(!0);return}w(!0),k(null),qfn().then(B=>{h(B.warehouses||[]),_.current=!0,A(!0),w(!1)}).catch(B=>{k(B instanceof v8&&B.detail||B.message),w(!1)})},I=B=>B==="RUNNING"?"#22c55e":B==="STOPPED"||B==="DELETED"?"#ef4444":"#f59e0b";return E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"SQL Warehouse"}),E.jsxs("div",{className:"mt-1 flex gap-1.5",children:[E.jsx("input",{type:"text",placeholder:"/sql/1.0/warehouses/abc123",value:l,onChange:B=>s(B.target.value),className:"flex-1 px-2.5 py-1.5 text-xs font-mono rounded-lg focus:outline-none focus:ring-2",style:{background:"var(--bg-input)",border:"1px solid var(--border)",color:"var(--text-primary)"},onFocus:B=>{B.currentTarget.style.borderColor="rgba(59,130,246,.3)",B.currentTarget.style.boxShadow="0 0 0 2px var(--accent-soft)"},onBlur:B=>{B.currentTarget.style.borderColor="var(--border)",B.currentTarget.style.boxShadow="none"}}),E.jsxs("button",{onClick:D,disabled:g,className:"px-2 py-1.5 rounded-lg text-xs font-medium transition-colors flex items-center gap-1",style:{background:"var(--bg-input)",border:"1px solid var(--border)",color:"var(--text-secondary)"},title:"Fetch warehouses from Databricks",children:[g?E.jsx(Ey,{size:12,className:"animate-spin"}):E.jsx(Vw,{size:12}),E.jsx("span",{children:g?"":"Browse"})]})]}),p&&E.jsx("div",{className:"mt-1.5 text-[10px] px-2 py-1 rounded",style:{background:"rgba(239,68,68,.1)",color:"#ef4444"},children:p}),j&&u.length>0&&E.jsx("div",{className:"mt-1.5 rounded-lg overflow-hidden",style:{border:"1px solid var(--border)",background:"var(--bg-input)"},children:u.map(B=>E.jsxs("button",{onClick:()=>{s(B.http_path),A(!1)},className:"w-full flex items-center gap-2 px-2.5 py-2 text-xs transition-colors hover:brightness-110",style:{background:l===B.http_path?"var(--accent-soft)":"transparent",borderBottom:"1px solid var(--border)",color:"var(--text-primary)"},children:[E.jsx("span",{className:"w-1.5 h-1.5 rounded-full flex-shrink-0",style:{background:I(B.state)},title:B.state}),E.jsx("span",{className:"font-medium truncate",children:B.name}),B.size&&E.jsx("span",{className:"text-[10px] ml-auto flex-shrink-0",style:{color:"var(--text-muted)"},children:B.size}),l===B.http_path&&E.jsx(Ufe,{size:12,style:{color:"var(--accent)"},className:"flex-shrink-0"})]},B.id))}),j&&u.length===0&&!g&&!p&&E.jsx("div",{className:"mt-1.5 text-[10px]",style:{color:"var(--text-muted)"},children:"No SQL Warehouses found in this workspace"})]})}function E2n({table:l,onSelect:s}){const u=l?l.split("."):[],[h,g]=pe.useState(u[0]||""),[w,p]=pe.useState(u[1]||""),[k,j]=pe.useState(u[2]||""),[A,_]=pe.useState([]),[D,I]=pe.useState([]),[B,F]=pe.useState([]),[U,K]=pe.useState(!1),[Y,Z]=pe.useState(!1),[ee,ce]=pe.useState(!1),[fe,be]=pe.useState(null),me=je=>je instanceof v8&&je.detail||je.message,Re=()=>{K(!0),be(null),Hfn().then(je=>{_(je.catalogs||[]),K(!1)}).catch(je=>{be(me(je)),K(!1)})},Te=je=>{Z(!0),be(null),Qfn(je).then(te=>{I(te.schemas||[]),Z(!1)}).catch(te=>{be(me(te)),Z(!1)})},Ke=(je,te)=>{ce(!0),be(null),Gfn(je,te).then(ge=>{F(ge.tables||[]),ce(!1)}).catch(ge=>{be(me(ge)),ce(!1)})},ze={background:"var(--bg-input)",border:"1px solid var(--border)",color:"var(--text-primary)"};return E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Table"}),E.jsxs("div",{className:"mt-1 space-y-1.5",children:[E.jsxs("select",{value:h,onFocus:Re,onChange:je=>{const te=je.target.value;g(te),p(""),j(""),I([]),F([]),s(""),te&&Te(te)},className:"w-full px-2.5 py-1.5 text-xs rounded-lg focus:outline-none focus:ring-2",style:ze,children:[E.jsx("option",{value:"",children:U?"Loading...":"Select catalog..."}),h&&A.every(je=>je.name!==h)&&E.jsx("option",{value:h,children:h}),A.map(je=>E.jsxs("option",{value:je.name,children:[je.name,je.comment?` — ${je.comment}`:""]},je.name))]}),E.jsxs("select",{value:w,disabled:!h,onFocus:()=>{h&&Te(h)},onChange:je=>{const te=je.target.value;p(te),j(""),F([]),s(""),te&&Ke(h,te)},className:"w-full px-2.5 py-1.5 text-xs rounded-lg focus:outline-none focus:ring-2 disabled:opacity-40",style:ze,children:[E.jsx("option",{value:"",children:Y?"Loading...":h?"Select schema...":"Select catalog first"}),w&&D.every(je=>je.name!==w)&&E.jsx("option",{value:w,children:w}),D.map(je=>E.jsxs("option",{value:je.name,children:[je.name,je.comment?` — ${je.comment}`:""]},je.name))]}),E.jsxs("select",{value:k,disabled:!w,onFocus:()=>{h&&w&&Ke(h,w)},onChange:je=>{const te=je.target.value;j(te),s(te?`${h}.${w}.${te}`:"")},className:"w-full px-2.5 py-1.5 text-xs rounded-lg focus:outline-none focus:ring-2 disabled:opacity-40",style:ze,children:[E.jsx("option",{value:"",children:ee?"Loading...":w?"Select table...":"Select schema first"}),k&&B.every(je=>je.name!==k)&&E.jsx("option",{value:k,children:k}),B.map(je=>E.jsxs("option",{value:je.name,children:[je.name,je.table_type?` (${je.table_type})`:"",je.comment?` — ${je.comment}`:""]},je.name))]})]}),l&&E.jsx("div",{className:"mt-1.5 text-[10px] font-mono px-1",style:{color:"var(--text-muted)"},children:l}),fe&&E.jsx("div",{className:"mt-1.5 text-[10px] px-2 py-1 rounded",style:{background:"rgba(239,68,68,.1)",color:"#ef4444"},children:fe})]})}function C2n({table:l,httpPath:s,query:u,onFetched:h}){return E.jsx(LSt,{resourceKey:l,getStatus:g=>Ufn(g),startFetch:g=>Xfn({table:g,http_path:s||void 0,query:u||void 0}).then(w=>({cached:!0,...w})),getProgress:g=>Jfn(g),deleteCache:g=>Vfn(g),timestampField:"fetched_at",labels:{fetchLabel:"Fetch Data",refreshLabel:"Refresh Data",notCachedHint:"Not fetched yet — click to download from Databricks",pendingLabel:"Connecting..."},onCacheReady:h})}function M2n({config:l,onUpdate:s,onRefreshPreview:u,accentColor:h}){const[g,w]=pe.useState(ni(l,"sourceType","flat_file")),{schema:p,setSchema:k,loading:j,fetchForPath:A}=DSt(ni(l,"path",void 0));return E.jsxs(E.Fragment,{children:[E.jsxs("div",{className:"px-4 py-3 space-y-3",children:[E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Source Type"}),E.jsx("div",{className:"mt-1",children:E.jsx(TM,{value:g,onChange:_=>{w(_),s("sourceType",_)},options:[{key:"flat_file",label:"Flat File",icon:E.jsx(ikt,{size:12})},{key:"databricks",label:"Databricks",icon:E.jsx(tkt,{size:12})}],accentColor:h})})]}),g==="flat_file"&&E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em] mb-1.5 block",style:{color:"var(--text-muted)"},children:"File"}),E.jsx(DAe,{currentPath:ni(l,"path",void 0),onSelect:_=>{s("path",_),A(_)}})]}),g==="databricks"&&E.jsxs("div",{className:"space-y-3",children:[E.jsx(T2n,{httpPath:ni(l,"http_path",""),onSelect:_=>s("http_path",_||void 0)}),E.jsx(E2n,{table:ni(l,"table",""),onSelect:_=>s("table",_||void 0)}),E.jsxs("div",{children:[E.jsxs("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:["SQL Query",E.jsx("span",{className:"ml-1.5 normal-case tracking-normal font-normal",style:{color:"var(--text-muted)"},children:"(optional)"})]}),E.jsx("textarea",{placeholder:`SELECT *
FROM catalog.schema.table
WHERE status = 'active'`,defaultValue:ni(l,"query","")||"SELECT *",onChange:_=>s("query",_.target.value||void 0),rows:3,className:"mt-1 w-full px-2.5 py-1.5 text-xs font-mono rounded-lg focus:outline-none focus:ring-2 resize-y",style:{background:"var(--bg-input)",border:"1px solid var(--border)",color:"var(--text-primary)"},onFocus:_=>{_.currentTarget.style.borderColor="rgba(59,130,246,.3)",_.currentTarget.style.boxShadow="0 0 0 2px var(--accent-soft)"},onBlur:_=>{_.currentTarget.style.borderColor="var(--border)",_.currentTarget.style.boxShadow="none"}}),E.jsx("div",{className:"mt-1 text-[10px]",style:{color:"var(--text-muted)"},children:"Combined with table above as: query FROM table"})]}),E.jsx(C2n,{table:ni(l,"table",""),httpPath:ni(l,"http_path",""),query:ni(l,"query",""),onFetched:()=>{const _=ni(l,"table","");_&&Afn(_).then(D=>{k(D),u==null||u()}).catch(D=>{console.warn("Databricks schema fetch failed:",D),k(null)})}})]})]}),j&&E.jsx("div",{className:"px-4 py-3",style:{borderTop:"1px solid var(--border)"},children:E.jsx("span",{className:"text-xs",style:{color:"var(--text-muted)"},children:"Loading schema..."})}),E.jsx(_St,{schema:p})]})}function A2n({config:l,onUpdate:s,inputSources:u,onDeleteInput:h,errorLine:g}){var j;const w=ni(l,"code",""),p=u.length>1,k=u.length>0;return E.jsxs("div",{className:"flex-1 flex flex-col min-h-0 px-3 py-2 gap-2",children:[E.jsx(CM,{inputSources:u,onDeleteInput:h}),E.jsxs("div",{className:"flex items-center justify-between shrink-0",children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Polars Code"}),E.jsx("span",{className:"text-[11px] font-medium",style:{color:"var(--text-muted)"},children:k?"use input names":E.jsxs(E.Fragment,{children:["start with ",E.jsx("code",{className:"px-0.5 rounded",style:{background:"var(--bg-hover)"},children:"."})," to chain"]})})]}),E.jsx(RV,{defaultValue:w,onChange:A=>s("code",A),errorLine:g,placeholder:p?`${u[0].varName}.join(${((j=u[1])==null?void 0:j.varName)||"other"}, on="key", how="left")`:k?`${u[0].varName}
.with_columns(
    age=pl.col("YOA") - pl.col("DOB")
)
.select("age", "NCD")`:`.with_columns(
    age=pl.col("YOA") - pl.col("DOB")
)
.select("age", "NCD")`})]})}function PSt(l){const s=l==null?void 0:l.runTag,u=(l==null?void 0:l.initialExpId)??"",[h,g]=pe.useState([]),[w,p]=pe.useState([]),[k,j]=pe.useState([]),[A,_]=pe.useState([]),[D,I]=pe.useState(!1),[B,F]=pe.useState(!1),[U,K]=pe.useState(!1),[Y,Z]=pe.useState(!1),[ee,ce]=pe.useState(""),[fe,be]=pe.useState(""),[me,Re]=pe.useState(""),[Te,Ke]=pe.useState(""),[ze,je]=pe.useState(u),te=pe.useRef(!1),ge=pe.useRef(!1),He=pe.useRef(""),ae=pe.useRef(""),Le=mt=>mt instanceof v8&&mt.detail||mt.message,Oe=pe.useCallback(()=>{te.current||(te.current=!0,I(!0),ce(""),ehn().then(mt=>{g(Array.isArray(mt)?mt:[]),I(!1)}).catch(mt=>{g([]),I(!1),ce(Le(mt)||"Failed to load experiments"),te.current=!1}))},[]),Qe=pe.useCallback(mt=>{mt&&He.current!==mt&&(He.current=mt,F(!0),be(""),thn(mt,s).then(Ue=>{p(Array.isArray(Ue)?Ue:[]),F(!1)}).catch(Ue=>{p([]),F(!1),be(Le(Ue)||"Failed to load runs"),He.current=""}))},[s]),kt=pe.useCallback(()=>{ge.current||(ge.current=!0,K(!0),Re(""),nhn().then(mt=>{j(Array.isArray(mt)?mt:[]),K(!1)}).catch(mt=>{j([]),K(!1),Re(Le(mt)||"Failed to load models"),ge.current=!1}))},[]),Ae=pe.useCallback(mt=>{mt&&ae.current!==mt&&(ae.current=mt,Z(!0),Ke(""),ihn(mt).then(Ue=>{_(Array.isArray(Ue)?Ue:[]),Z(!1)}).catch(Ue=>{_([]),Z(!1),Ke(Le(Ue)||"Failed to load versions"),ae.current=""}))},[]),Ye=pe.useCallback(()=>{He.current=""},[]);return{experiments:h,runs:w,models:k,modelVersions:A,loadingExperiments:D,loadingRuns:B,loadingModels:U,loadingVersions:Y,errorExperiments:ee,errorRuns:fe,errorModels:me,errorVersions:Te,browseExpId:ze,setBrowseExpId:je,setRuns:p,refreshExperiments:Oe,refreshRuns:Qe,refreshModels:kt,refreshVersions:Ae,resetRunsGuard:Ye}}function N2n({config:l,onUpdate:s,inputSources:u,onDeleteInput:h,errorLine:g,accentColor:w}){const p=ni(l,"sourceType","registered"),k=ni(l,"task","regression"),j=ni(l,"output_column","prediction"),A=ni(l,"code",""),_=ni(l,"registered_model",""),{experiments:D,runs:I,models:B,modelVersions:F,loadingExperiments:U,loadingRuns:K,loadingModels:Y,errorExperiments:Z,errorRuns:ee,errorModels:ce,errorVersions:fe,browseExpId:be,setBrowseExpId:me,setRuns:Re,resetRunsGuard:Te,refreshExperiments:Ke,refreshRuns:ze,refreshModels:je,refreshVersions:te}=PSt({initialExpId:ni(l,"experiment_id","")}),[ge,He]=pe.useState(!!A);return E.jsxs("div",{className:"flex-1 flex flex-col min-h-0 px-3 py-2 gap-3",children:[E.jsx(CM,{inputSources:u,onDeleteInput:h}),E.jsx(NSt,{}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Model Source"}),E.jsx("div",{className:"mt-1",children:E.jsx(TM,{value:p,onChange:ae=>s("sourceType",ae),options:[{key:"registered",label:"Registered Model"},{key:"run",label:"Experiment Run"}],accentColor:w})})]}),p==="registered"&&E.jsxs("div",{className:"flex flex-col gap-2",children:[E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Model Name"}),E.jsxs("select",{className:"mt-1 w-full text-xs px-2.5 py-1.5 rounded-lg focus:outline-none focus:ring-2",style:Zb,value:_,onFocus:je,onChange:ae=>s({registered_model:ae.target.value,version:"latest"}),children:[E.jsx("option",{value:"",children:Y?"Loading...":"Select a model..."}),_&&!B.some(ae=>ae.name===_)&&E.jsx("option",{value:_,children:_}),B.map(ae=>E.jsx("option",{value:ae.name,children:ae.name},ae.name))]}),ce&&E.jsx("span",{className:"text-[10px] mt-0.5",style:{color:"#ef4444"},children:ce})]}),_&&E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Version"}),E.jsxs("select",{className:"mt-1 w-full text-xs px-2.5 py-1.5 rounded-lg focus:outline-none focus:ring-2",style:Zb,value:ni(l,"version","latest"),onFocus:()=>te(_),onChange:ae=>s("version",ae.target.value),children:[E.jsx("option",{value:"latest",children:"latest"}),F.map(ae=>E.jsxs("option",{value:ae.version,children:["v",ae.version," — ",ae.status,ae.description?` (${ae.description})`:""]},ae.version))]}),fe&&E.jsx("span",{className:"text-[10px] mt-0.5",style:{color:"#ef4444"},children:fe})]})]}),p==="run"&&E.jsxs("div",{className:"flex flex-col gap-2",children:[E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Experiment"}),E.jsxs("select",{className:"mt-1 w-full text-xs px-2.5 py-1.5 rounded-lg focus:outline-none focus:ring-2",style:Zb,value:be,onFocus:Ke,onChange:ae=>{const Le=ae.target.value,Oe=D.find(Qe=>Qe.experiment_id===Le);me(Le),s({experiment_id:Le,experiment_name:(Oe==null?void 0:Oe.name)||Le}),Re([]),Te(),Le&&ze(Le)},children:[E.jsx("option",{value:"",children:U?"Loading...":"Select an experiment..."}),be&&!D.some(ae=>ae.experiment_id===be)&&E.jsx("option",{value:be,children:ni(l,"experiment_name","")||be}),D.map(ae=>E.jsx("option",{value:ae.experiment_id,children:ae.name},ae.experiment_id))]}),Z&&E.jsx("span",{className:"text-[10px] mt-0.5",style:{color:"#ef4444"},children:Z})]}),be&&E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Run"}),E.jsxs("select",{className:"mt-1 w-full text-xs px-2.5 py-1.5 rounded-lg focus:outline-none focus:ring-2",style:Zb,value:ni(l,"run_id",""),onFocus:()=>ze(be),onChange:ae=>{const Le=ae.target.value,Oe=I.find(Qe=>Qe.run_id===Le);s({run_id:Le,run_name:(Oe==null?void 0:Oe.run_name)||"",artifact_path:(Oe==null?void 0:Oe.artifacts[0])||""})},children:[E.jsx("option",{value:"",children:K?"Loading...":"Select a run..."}),ni(l,"run_id","")&&!I.some(ae=>ae.run_id===l.run_id)&&E.jsx("option",{value:ni(l,"run_id",""),children:ni(l,"run_name","")||ni(l,"run_id","")}),I.map(ae=>E.jsxs("option",{value:ae.run_id,children:[ae.run_name||ae.run_id.slice(0,8),Object.entries(ae.metrics).slice(0,2).map(([Le,Oe])=>` ${Le}=${typeof Oe=="number"?Oe.toFixed(4):Oe}`).join("")]},ae.run_id))]}),ee&&E.jsx("span",{className:"text-[10px] mt-0.5",style:{color:"#ef4444"},children:ee})]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Run ID"}),E.jsx("input",{type:"text",className:"mt-1 w-full text-xs px-2.5 py-1.5 rounded-lg font-mono focus:outline-none focus:ring-2",style:Zb,value:ni(l,"run_id",""),onChange:ae=>s("run_id",ae.target.value),placeholder:"e.g. a1b2c3d4e5f6..."})]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Artifact Path"}),E.jsx("input",{type:"text",className:"mt-1 w-full text-xs px-2.5 py-1.5 rounded-lg font-mono focus:outline-none focus:ring-2",style:Zb,value:ni(l,"artifact_path",""),onChange:ae=>s("artifact_path",ae.target.value),placeholder:"e.g. model.cbm"})]})]}),E.jsxs("div",{className:"flex gap-2",children:[E.jsxs("div",{className:"flex-1",children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Task"}),E.jsxs("select",{className:"mt-1 w-full text-xs px-2.5 py-1.5 rounded-lg focus:outline-none focus:ring-2",style:Zb,value:k,onChange:ae=>s("task",ae.target.value),children:[E.jsx("option",{value:"regression",children:"Regression"}),E.jsx("option",{value:"classification",children:"Classification"})]})]}),E.jsxs("div",{className:"flex-1",children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Output Column"}),E.jsx("input",{type:"text",className:"mt-1 w-full text-xs px-2.5 py-1.5 rounded-lg focus:outline-none focus:ring-2",style:Zb,value:j,onChange:ae=>s("output_column",ae.target.value),placeholder:"prediction"})]})]}),k==="classification"&&E.jsxs("p",{className:"text-[10px]",style:{color:"var(--text-muted)"},children:["Classification models also generate a ",E.jsxs("code",{className:"px-0.5 rounded",style:{background:"var(--bg-hover)"},children:[j,"_proba"]})," column."]}),E.jsx("div",{children:E.jsxs("button",{onClick:()=>He(!ge),className:"flex items-center gap-1.5 text-[11px] font-medium transition-colors",style:{color:"var(--text-muted)"},children:[E.jsx(Vw,{size:11,style:{transform:ge?"rotate(0deg)":"rotate(-90deg)",transition:"transform 0.15s"}}),"Post-processing Code (optional)"]})}),ge&&E.jsx(RV,{defaultValue:A,onChange:ae=>s("code",ae),errorLine:g,placeholder:`# df has the prediction column already
# model is the loaded CatBoost model
df = df.with_columns(
    risk_band=pl.when(pl.col("${j}") > 0.5).then(pl.lit("high")).otherwise(pl.lit("low"))
)`})]})}function _2n(l){const s=l.factors;return Array.isArray(s)&&s.length>0?s:[{banding:"continuous",column:"",outputColumn:"",rules:[],default:null}]}function D2n(l){const s=l.toLowerCase();return s.startsWith("int")||s.startsWith("uint")||s.startsWith("float")||s==="f32"||s==="f64"||s==="i8"||s==="i16"||s==="i32"||s==="i64"||s==="u8"||s==="u16"||s==="u32"||s==="u64"}function L2n(l,s){const u=s[l];return u?D2n(u)?"continuous":"categorical":null}const Y3t=["<","<=",">",">=","="];function P2n({factor:l,onUpdateFactor:s}){const u=l.rules||[],h=l.banding||"continuous",g=k=>s({rules:k}),w=(k,j,A)=>{const _=[...u];_[k]={..._[k],[j]:A},g(_)},p=k=>g(u.filter((j,A)=>A!==k));return E.jsx("div",{className:"rounded-lg overflow-hidden",style:{border:"1px solid var(--border)",background:"var(--bg-input)"},children:h==="continuous"?E.jsxs("table",{className:"w-full text-[11px]",children:[E.jsx("thead",{children:E.jsxs("tr",{style:{borderBottom:"1px solid var(--border)",background:"var(--bg-elevated)"},children:[E.jsx("th",{className:"text-left px-2 py-1.5 font-semibold",style:{color:"var(--text-muted)",width:52},children:"Op"}),E.jsx("th",{className:"text-left px-2 py-1.5 font-semibold",style:{color:"var(--text-muted)",width:60},children:"Value"}),E.jsx("th",{className:"text-left px-2 py-1.5 font-semibold",style:{color:"var(--text-muted)",width:52,opacity:.55},children:"Op"}),E.jsx("th",{className:"text-left px-2 py-1.5 font-semibold",style:{color:"var(--text-muted)",width:60,opacity:.55},children:"Value"}),E.jsx("th",{className:"text-left px-2 py-1.5 font-semibold",style:{color:"var(--text-muted)"},children:"Band"}),E.jsx("th",{style:{width:28}})]})}),E.jsx("tbody",{children:u.length===0?E.jsx("tr",{children:E.jsx("td",{colSpan:6,className:"px-2 py-3 text-center",style:{color:"var(--text-muted)"},children:"No rules yet"})}):u.map((k,j)=>E.jsxs("tr",{style:{borderBottom:"1px solid var(--border)"},children:[E.jsx("td",{className:"px-1 py-1",children:E.jsxs("select",{value:k.op1||"",onChange:A=>w(j,"op1",A.target.value),className:"w-full px-1 py-1 rounded text-[11px] font-mono appearance-none",style:{background:"var(--bg-surface)",border:"1px solid var(--border)",color:"var(--text-primary)"},children:[E.jsx("option",{value:"",children:"—"}),Y3t.map(A=>E.jsx("option",{value:A,children:A},A))]})}),E.jsx("td",{className:"px-1 py-1",children:E.jsx("input",{type:"text",value:k.val1??"",onChange:A=>w(j,"val1",A.target.value),className:"w-full px-1.5 py-1 rounded text-[11px] font-mono focus:outline-none",style:{background:"var(--bg-surface)",border:"1px solid var(--border)",color:"var(--text-primary)"},placeholder:"0"})}),E.jsx("td",{className:"px-1 py-1",children:E.jsxs("select",{value:k.op2||"",onChange:A=>w(j,"op2",A.target.value),className:"w-full px-1 py-1 rounded text-[11px] font-mono appearance-none",style:{background:"var(--bg-surface)",border:"1px solid var(--border)",color:"var(--text-primary)"},children:[E.jsx("option",{value:"",children:"—"}),Y3t.map(A=>E.jsx("option",{value:A,children:A},A))]})}),E.jsx("td",{className:"px-1 py-1",children:E.jsx("input",{type:"text",value:k.val2??"",onChange:A=>w(j,"val2",A.target.value),className:"w-full px-1.5 py-1 rounded text-[11px] font-mono focus:outline-none",style:{background:"var(--bg-surface)",border:"1px solid var(--border)",color:"var(--text-primary)"},placeholder:""})}),E.jsx("td",{className:"px-1 py-1",children:E.jsx("input",{type:"text",value:k.assignment??"",onChange:A=>w(j,"assignment",A.target.value),className:"w-full px-1.5 py-1 rounded text-[11px] font-mono font-semibold focus:outline-none",style:{background:"var(--bg-surface)",border:"1px solid var(--border)",color:"#14b8a6"},placeholder:"band"})}),E.jsx("td",{className:"px-1 py-1 text-center",children:E.jsx("button",{onClick:()=>p(j),className:"p-0.5 rounded transition-colors",style:{color:"var(--text-muted)"},onMouseEnter:A=>{A.currentTarget.style.color="#ef4444"},onMouseLeave:A=>{A.currentTarget.style.color="var(--text-muted)"},children:E.jsx(Zyt,{size:11})})})]},j))})]}):E.jsxs("table",{className:"w-full text-[11px]",children:[E.jsx("thead",{children:E.jsxs("tr",{style:{borderBottom:"1px solid var(--border)",background:"var(--bg-elevated)"},children:[E.jsx("th",{className:"text-left px-2 py-1.5 font-semibold",style:{color:"var(--text-muted)"},children:"Value"}),E.jsx("th",{className:"text-left px-2 py-1.5 font-semibold",style:{color:"var(--text-muted)"},children:"Group"}),E.jsx("th",{style:{width:28}})]})}),E.jsx("tbody",{children:u.length===0?E.jsx("tr",{children:E.jsx("td",{colSpan:3,className:"px-2 py-3 text-center",style:{color:"var(--text-muted)"},children:"No rules yet"})}):u.map((k,j)=>E.jsxs("tr",{style:{borderBottom:"1px solid var(--border)"},children:[E.jsx("td",{className:"px-1 py-1",children:E.jsx("input",{type:"text",value:k.value??"",onChange:A=>w(j,"value",A.target.value),className:"w-full px-1.5 py-1 rounded text-[11px] font-mono focus:outline-none",style:{background:"var(--bg-surface)",border:"1px solid var(--border)",color:"var(--text-primary)"},placeholder:"Semi-detached House"})}),E.jsx("td",{className:"px-1 py-1",children:E.jsx("input",{type:"text",value:k.assignment??"",onChange:A=>w(j,"assignment",A.target.value),className:"w-full px-1.5 py-1 rounded text-[11px] font-mono font-semibold focus:outline-none",style:{background:"var(--bg-surface)",border:"1px solid var(--border)",color:"#14b8a6"},placeholder:"House"})}),E.jsx("td",{className:"px-1 py-1 text-center",children:E.jsx("button",{onClick:()=>p(j),className:"p-0.5 rounded transition-colors",style:{color:"var(--text-muted)"},onMouseEnter:A=>{A.currentTarget.style.color="#ef4444"},onMouseLeave:A=>{A.currentTarget.style.color="var(--text-muted)"},children:E.jsx(Zyt,{size:11})})})]},j))})]})})}const I2n={op1:">",val1:"",op2:"",val2:"",assignment:""},R2n={value:"",assignment:""};function $2n({config:l,onUpdate:s,inputSources:u,onDeleteInput:h,upstreamColumns:g=[],accentColor:w}){const p=_2n(l),[k,j]=pe.useState(0),A=Math.min(k,p.length-1),_=p[A],D=Object.fromEntries(g.map(Z=>[Z.name,Z.dtype])),I=Z=>{s("factors",Z)},B=(Z,ee)=>{const ce=p.map((fe,be)=>be===Z?{...fe,...ee}:fe);I(ce)},F=(Z,ee)=>{const ce={column:ee},fe=L2n(ee,D);fe&&fe!==p[Z].banding&&(ce.banding=fe,ce.rules=[]),B(Z,ce)},U=()=>{const Z=[...p,{banding:"continuous",column:"",outputColumn:"",rules:[],default:null}];I(Z),j(Z.length-1)},K=Z=>{if(p.length<=1)return;const ee=p.filter((ce,fe)=>fe!==Z);I(ee),A>=ee.length&&j(ee.length-1)},Y=(Z,ee)=>Z.outputColumn?Z.outputColumn:Z.column?Z.column:`Factor ${ee+1}`;return E.jsxs("div",{className:"px-4 py-3 space-y-3 overflow-y-auto",children:[E.jsx(CM,{inputSources:u,onDeleteInput:h}),E.jsxs("div",{className:"flex items-center gap-2 px-2.5 py-2 rounded-lg text-xs font-medium",style:{background:zo(w,.1),border:`1px solid ${zo(w,.3)}`,color:w},children:[E.jsx(ckt,{size:14}),E.jsxs("span",{children:["Group values into bands — ",p.length," factor",p.length!==1?"s":""]})]}),E.jsxs("div",{children:[E.jsxs("div",{className:"flex items-center gap-1 flex-wrap",children:[p.map((Z,ee)=>E.jsxs("button",{onClick:()=>j(ee),className:"relative flex items-center gap-1 px-2.5 py-1.5 rounded-t-lg text-[11px] font-medium transition-colors",style:{background:ee===A?"var(--bg-input)":"transparent",border:ee===A?"1px solid var(--border)":"1px solid transparent",borderBottom:ee===A?"1px solid var(--bg-input)":"1px solid var(--border)",color:ee===A?w:"var(--text-muted)"},children:[E.jsx("span",{className:"font-mono truncate max-w-[100px]",children:Y(Z,ee)}),p.length>1&&E.jsx("span",{onClick:ce=>{ce.stopPropagation(),K(ee)},className:"ml-0.5 p-0.5 rounded transition-colors cursor-pointer",style:{color:"var(--text-muted)"},onMouseEnter:ce=>{ce.currentTarget.style.color="#ef4444"},onMouseLeave:ce=>{ce.currentTarget.style.color="var(--text-muted)"},children:E.jsx(jp,{size:9})})]},ee)),E.jsx("button",{onClick:U,className:"flex items-center gap-0.5 px-2 py-1.5 rounded-lg text-[11px] font-medium transition-colors",style:{color:w},onMouseEnter:Z=>{Z.currentTarget.style.background=zo(w,.1)},onMouseLeave:Z=>{Z.currentTarget.style.background="transparent"},children:E.jsx(w8,{size:11})})]}),E.jsx("div",{style:{borderTop:"1px solid var(--border)",marginTop:-1}})]}),E.jsxs("div",{children:[E.jsxs("div",{className:"flex items-center gap-1.5",children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Type"}),_.column&&D[_.column]&&E.jsxs("span",{className:"text-[10px] font-medium",style:{color:"var(--text-muted)",opacity:.7},children:["auto: ",D[_.column]]})]}),E.jsx("div",{className:"mt-1",children:E.jsx(TM,{value:_.banding,onChange:Z=>B(A,{banding:Z,rules:[]}),options:[{key:"continuous",label:"Continuous"},{key:"categorical",label:"Categorical"}],accentColor:w})})]}),E.jsxs("div",{className:"grid grid-cols-2 gap-2",children:[E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em] block mb-1",style:{color:"var(--text-muted)"},children:"Input Column"}),g.length>0?E.jsxs("select",{value:_.column,onChange:Z=>F(A,Z.target.value),className:"w-full px-2 py-1.5 text-xs font-mono rounded-lg focus:outline-none focus:ring-2",style:sf,children:[E.jsx("option",{value:"",children:"Select column..."}),g.map(Z=>E.jsxs("option",{value:Z.name,children:[Z.name," (",Z.dtype,")"]},Z.name))]},`col-${A}`):E.jsx("input",{type:"text",placeholder:"driver_age",defaultValue:_.column,onChange:Z=>B(A,{column:Z.target.value}),className:"w-full px-2 py-1.5 text-xs font-mono rounded-lg focus:outline-none focus:ring-2",style:sf},`col-${A}`)]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em] block mb-1",style:{color:"var(--text-muted)"},children:"Output Column"}),E.jsx("input",{type:"text",placeholder:"age_band",defaultValue:_.outputColumn,onChange:Z=>B(A,{outputColumn:Z.target.value}),className:"w-full px-2 py-1.5 text-xs font-mono rounded-lg focus:outline-none focus:ring-2",style:sf},`out-${A}`)]})]}),E.jsxs("div",{children:[E.jsxs("div",{className:"flex items-center justify-between mb-1.5",children:[E.jsxs("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:["Rules (",(_.rules||[]).length,")"]}),E.jsxs("button",{onClick:()=>{const Z=_.banding==="continuous"?{...I2n}:{...R2n};B(A,{rules:[..._.rules||[],Z]})},className:"flex items-center gap-1 px-2 py-1 rounded-md text-[11px] font-medium transition-colors",style:{background:zo(w,.1),color:w,border:`1px solid ${zo(w,.3)}`},onMouseEnter:Z=>{Z.currentTarget.style.background=zo(w,.2)},onMouseLeave:Z=>{Z.currentTarget.style.background=zo(w,.1)},children:[E.jsx(w8,{size:11})," Add"]})]}),E.jsx(P2n,{factor:_,onUpdateFactor:Z=>B(A,Z)},A)]}),E.jsxs("div",{children:[E.jsxs("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em] block mb-1",style:{color:"var(--text-muted)"},children:["Default ",E.jsx("span",{className:"ml-1.5 normal-case tracking-normal font-normal",children:"(unmatched rows)"})]}),E.jsx("input",{type:"text",placeholder:"null",defaultValue:_.default||"",onChange:Z=>B(A,{default:Z.target.value||null}),className:"w-full px-2 py-1.5 text-xs font-mono rounded-lg focus:outline-none focus:ring-2",style:sf},`def-${A}`)]}),p.some(Z=>Z.column&&Z.outputColumn&&(Z.rules||[]).length>0)&&E.jsx("div",{className:"rounded-lg px-3 py-2 space-y-1",style:{background:"var(--bg-elevated)",border:"1px solid var(--border)"},children:p.map((Z,ee)=>!Z.column||!Z.outputColumn||!(Z.rules||[]).length?null:E.jsxs("div",{className:"text-[10px] leading-relaxed",style:{color:"var(--text-muted)"},children:[E.jsx("span",{className:"font-mono font-medium",style:{color:"var(--text-secondary)"},children:Z.column})," → ",E.jsx("span",{className:"font-mono font-medium",style:{color:w},children:Z.outputColumn})," · ",Z.rules.length," rule",Z.rules.length!==1?"s":""," · ",Z.banding]},ee))})]})}function B2n(l){const s=l.tables;return Array.isArray(s)&&s.length>0?s:[{name:"Table 1",factors:[],outputColumn:"",defaultValue:"1.0",entries:[]}]}function ISt(l){if(isNaN(l))return"transparent";const s=l-1,u=Math.min(Math.abs(s)/.5,1);return s>.005?`rgba(239, 68, 68, ${(u*.22).toFixed(3)})`:s<-.005?`rgba(59, 130, 246, ${(u*.22).toFixed(3)})`:"transparent"}function RSt(l){if(isNaN(l))return"var(--text-secondary)";const s=l-1;return s>.005?"#dc2626":s<-.005?"#2563eb":"#10b981"}function jhe(l){const s=l.map(w=>typeof w.value=="number"?w.value:parseFloat(String(w.value??""))).filter(w=>!isNaN(w));if(s.length===0)return null;const u=Math.min(...s),h=Math.max(...s),g=s.reduce((w,p)=>w+p,0)/s.length;return{min:u,max:h,avg:g,count:s.length}}function Z3t(l,s,u,h){if(l.length===0)return[];const g=l.map(A=>s[A]||[]);if(g.some(A=>A.length===0))return u;const w=new Map;for(const A of u){const _=l.map(I=>String(A[I]??"")).join("|"),D=A.value;D!=null&&D!==""&&w.set(_,typeof D=="number"?D:parseFloat(String(D)))}const p=h!=null&&String(h).trim()?parseFloat(String(h)):1,k=[];function j(A,_){if(A===l.length){const D=l.map(I=>_[I]).join("|");k.push({..._,value:w.get(D)??p});return}for(const D of g[A])j(A+1,{..._,[l[A]]:D})}return j(0,{}),k}function $St({stats:l}){return l?E.jsxs("div",{className:"flex items-center gap-3 px-2.5 py-1.5 text-[10px] font-mono rounded-b-lg",style:{background:"var(--bg-elevated)",borderTop:"1px solid var(--border)",color:"var(--text-muted)"},children:[E.jsxs("span",{children:["n=",l.count]}),E.jsxs("span",{style:{color:"#2563eb"},children:["min ",l.min.toFixed(3)]}),E.jsxs("span",{style:{color:"var(--text-secondary)"},children:["avg ",l.avg.toFixed(3)]}),E.jsxs("span",{style:{color:"#dc2626"},children:["max ",l.max.toFixed(3)]})]}):null}function z2n({table:l,bandingLevels:s,onUpdateEntries:u}){const h=l.factors[0],g=pe.useMemo(()=>l.entries||[],[l.entries]),w=pe.useMemo(()=>jhe(g),[g]);if(!h)return null;const p=s[h]||[],k=new Map;for(const _ of g){const D=String(_[h]??"");D&&k.set(D,typeof _.value=="number"?_.value:parseFloat(String(_.value??"1")))}const j=w?Math.max(Math.abs(w.max),Math.abs(w.min),1):1,A=(_,D)=>{const I=D===""?0:parseFloat(D),B=g.map(F=>String(F[h])===_?{...F,value:isNaN(I)?0:I}:F);B.some(F=>String(F[h])===_)||B.push({[h]:_,value:isNaN(I)?0:I}),u(B)};return E.jsxs("div",{className:"rounded-lg overflow-hidden",style:{border:"1px solid var(--border)"},children:[E.jsxs("table",{className:"w-full text-[11px]",style:{borderCollapse:"separate",borderSpacing:0},children:[E.jsx("thead",{children:E.jsxs("tr",{style:{background:"var(--bg-elevated)"},children:[E.jsx("th",{className:"text-left px-2.5 py-2 font-bold uppercase tracking-[0.06em] text-[10px]",style:{color:"var(--text-muted)",borderBottom:"2px solid var(--border)"},children:h}),E.jsx("th",{className:"text-center px-2 py-2 font-bold uppercase tracking-[0.06em] text-[10px]",style:{color:"var(--text-muted)",borderBottom:"2px solid var(--border)",width:80},children:"Relativity"}),E.jsx("th",{className:"px-2 py-2 text-[10px]",style:{color:"var(--text-muted)",borderBottom:"2px solid var(--border)",width:"40%"}})]})}),E.jsx("tbody",{children:p.length===0?E.jsx("tr",{children:E.jsx("td",{colSpan:3,className:"px-2 py-4 text-center",style:{color:"var(--text-muted)"},children:"No banding levels found"})}):p.map((_,D)=>{const I=k.get(_)??1,B=Math.min(Math.abs(I)/j*100,100);return E.jsxs("tr",{style:{borderBottom:"1px solid var(--border)",background:D%2===0?"var(--bg-input)":"var(--bg-surface)"},children:[E.jsx("td",{className:"px-2.5 py-1.5 font-mono text-[11px] font-medium",style:{color:"var(--text-primary)",borderBottom:"1px solid var(--border)"},children:_}),E.jsx("td",{className:"px-0.5 py-0.5",style:{borderBottom:"1px solid var(--border)"},children:E.jsx("input",{type:"number",step:"0.01",defaultValue:I,onBlur:F=>A(_,F.target.value),className:"w-full px-1.5 py-1 rounded text-[11px] font-mono text-center focus:outline-none focus:ring-1 focus:ring-emerald-500/40",style:{background:ISt(I),border:"1px solid var(--border)",color:RSt(I),fontWeight:600}})}),E.jsx("td",{className:"px-2 py-1.5",style:{borderBottom:"1px solid var(--border)"},children:E.jsx("div",{className:"relative h-3 rounded-full overflow-hidden",style:{background:"var(--bg-elevated)"},children:E.jsx("div",{className:"absolute inset-y-0 left-0 rounded-full transition-all",style:{width:`${B}%`,background:I>=1?"rgba(239, 68, 68, 0.35)":"rgba(59, 130, 246, 0.35)"}})})})]},_)})})]}),E.jsx($St,{stats:w})]})}function e4t({table:l,bandingLevels:s,onUpdateEntries:u,factorOverrides:h}){const g=(h==null?void 0:h.factors)||l.factors.slice(0,2),w=(h==null?void 0:h.sliceKey)||{},p=g[0],k=g[1],j=pe.useMemo(()=>l.entries||[],[l.entries]),A=pe.useMemo(()=>jhe(j),[j]);if(!p||!k)return null;const _=s[p]||[],D=s[k]||[],I=new Map;for(const F of j){if(!Object.entries(w).every(([Y,Z])=>String(F[Y])===Z))continue;const K=`${F[p]}|${F[k]}`;I.set(K,typeof F.value=="number"?F.value:parseFloat(String(F.value??"1")))}const B=(F,U,K)=>{const Y=K===""?0:parseFloat(K),Z=isNaN(Y)?0:Y,ee=be=>String(be[p])===F&&String(be[k])===U&&Object.entries(w).every(([me,Re])=>String(be[me])===Re);let ce=!1;const fe=j.map(be=>ee(be)?(ce=!0,{...be,value:Z}):be);ce||fe.push({...w,[p]:F,[k]:U,value:Z}),u(fe)};return _.length===0||D.length===0?E.jsx("div",{className:"px-2 py-3 text-center text-[11px]",style:{color:"var(--text-muted)"},children:"No banding levels found for selected factors"}):E.jsxs("div",{className:"rounded-lg overflow-hidden",style:{border:"1px solid var(--border)"},children:[E.jsx("div",{className:"overflow-x-auto",children:E.jsxs("table",{className:"w-full text-[11px]",style:{borderCollapse:"separate",borderSpacing:0},children:[E.jsx("thead",{children:E.jsxs("tr",{style:{background:"var(--bg-elevated)"},children:[E.jsxs("th",{className:"text-left px-2.5 py-2 font-bold uppercase tracking-[0.06em] text-[10px] sticky left-0 z-10",style:{color:"var(--text-muted)",borderBottom:"2px solid var(--border)",background:"var(--bg-elevated)"},children:[E.jsx("span",{style:{color:"var(--text-secondary)"},children:p}),E.jsx("span",{style:{color:"var(--text-muted)",margin:"0 4px"},children:"↓"}),E.jsx("span",{style:{color:"var(--text-secondary)"},children:k}),E.jsx("span",{style:{color:"var(--text-muted)",margin:"0 2px"},children:"→"})]}),D.map(F=>E.jsx("th",{className:"text-center px-1 py-2 font-bold font-mono text-[10px] uppercase tracking-[0.04em]",style:{color:"var(--text-muted)",minWidth:64,borderBottom:"2px solid var(--border)"},children:F},F))]})}),E.jsx("tbody",{children:_.map((F,U)=>E.jsxs("tr",{style:{background:U%2===0?"var(--bg-input)":"var(--bg-surface)"},children:[E.jsx("td",{className:"px-2.5 py-1 font-mono text-[11px] font-medium sticky left-0 z-10",style:{color:"var(--text-primary)",whiteSpace:"nowrap",borderBottom:"1px solid var(--border)",background:U%2===0?"var(--bg-input)":"var(--bg-surface)"},children:F}),D.map(K=>{const Y=I.get(`${F}|${K}`)??1;return E.jsx("td",{className:"px-0.5 py-0.5",style:{borderBottom:"1px solid var(--border)"},children:E.jsx("input",{type:"number",step:"0.01",defaultValue:Y,onBlur:Z=>B(F,K,Z.target.value),className:"w-full px-1 py-1 rounded text-[11px] font-mono text-center focus:outline-none focus:ring-1 focus:ring-emerald-500/40",style:{background:ISt(Y),border:"1px solid var(--border)",color:RSt(Y),fontWeight:600,minWidth:56}})},K)})]},F))})]})}),E.jsx($St,{stats:A})]})}function F2n({config:l,onUpdate:s,inputSources:u,onDeleteInput:h,allNodes:g,accentColor:w}){const[p,k]=pe.useState(0),[j,A]=pe.useState(0),_=B2n(l),D=Uhn(g),I=ni(l,"operation","multiply"),B=ni(l,"combinedColumn",""),F=Object.keys(D),U=Math.min(p,_.length-1),K=_[U]||{name:"Table 1",factors:[],outputColumn:"",defaultValue:"1.0",entries:[]},Y=ge=>s("tables",ge),Z=(ge,He)=>{const ae=_.map((Le,Oe)=>Oe===ge?{...Le,...He}:Le);Y(ae)},ee=(ge,He)=>{const ae=_[ge],Le=Z3t(He,D,ae.entries,ae.defaultValue);Z(ge,{factors:He,entries:Le})},ce=(ge,He)=>{const ae=_[ge];ae.factors.length>=3||ae.factors.includes(He)||ee(ge,[...ae.factors,He])},fe=(ge,He)=>{const Le=_[ge].factors.filter((Oe,Qe)=>Qe!==He);ee(ge,Le)},be=(ge,He)=>{Z(ge,{entries:He})},me=()=>{Y([..._,{name:`Table ${_.length+1}`,factors:[],outputColumn:"",defaultValue:"1.0",entries:[]}]),k(_.length)},Re=ge=>{if(_.length<=1)return;const He=_.filter((ae,Le)=>Le!==ge);Y(He),k(Math.min(p,He.length-1))},Te=()=>{const ge=_[U],He=Z3t(ge.factors,D,ge.entries,ge.defaultValue);Z(U,{entries:He})},Ke=K.factors.length,ze=Ke===3?K.factors[2]:null,je=ze?D[ze]||[]:[],te=Math.min(j,Math.max(0,je.length-1));return E.jsxs("div",{className:"px-4 py-3 space-y-3 overflow-y-auto",children:[E.jsx(CM,{inputSources:u,onDeleteInput:h}),E.jsxs("div",{className:"flex items-center gap-2 px-2.5 py-2 rounded-lg text-xs font-medium",style:{background:zo(w,.1),border:`1px solid ${zo(w,.3)}`,color:w},children:[E.jsx(Xfe,{size:13}),E.jsxs("span",{children:["Rating Tables · ",_.length," table",_.length!==1?"s":""]})]}),_.length>=2&&E.jsxs("div",{className:"space-y-2 p-2.5 rounded-lg",style:{background:"var(--bg-surface)",border:"1px solid var(--border)"},children:[E.jsxs("div",{className:"flex items-center gap-2",children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em] shrink-0",style:{color:"var(--text-muted)"},children:"Combine"}),E.jsxs("select",{value:I,onChange:ge=>s("operation",ge.target.value),className:"flex-1 px-2 py-1.5 text-xs font-mono rounded-lg focus:outline-none",style:sf,children:[E.jsx("option",{value:"multiply",children:"× Multiply (relativities)"}),E.jsx("option",{value:"add",children:"+ Add (loadings)"}),E.jsx("option",{value:"min",children:"↓ Min"}),E.jsx("option",{value:"max",children:"↑ Max"})]})]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em] block mb-1",style:{color:"var(--text-muted)"},children:"Combined Output Column"}),E.jsx("input",{type:"text",defaultValue:B,onBlur:ge=>s("combinedColumn",ge.target.value),className:"w-full px-2 py-1.5 text-xs font-mono rounded-lg focus:outline-none focus:ring-2",style:sf,placeholder:"combined_factor"})]}),_.some(ge=>ge.outputColumn)&&(()=>{const ge=_.filter(Le=>Le.outputColumn).map(Le=>Le.outputColumn),He=B||"?";let ae="";return I==="multiply"?ae=ge.join(" × "):I==="add"?ae=ge.join(" + "):I==="min"?ae=`min(${ge.join(", ")})`:I==="max"&&(ae=`max(${ge.join(", ")})`),E.jsxs("div",{className:"text-[10px] font-mono px-2 py-1.5 rounded flex items-center gap-1.5",style:{background:"var(--bg-elevated)",color:"var(--text-secondary)",border:"1px solid var(--border)"},children:[E.jsx("span",{style:{color:w,fontWeight:600},children:He}),E.jsx("span",{style:{color:"var(--text-muted)"},children:"="}),E.jsx("span",{children:ae}),!B&&E.jsx("span",{style:{color:"var(--text-muted)",fontStyle:"italic"},children:" — name the output above"})]})})()]}),E.jsxs("div",{className:"flex items-center gap-1 overflow-x-auto pb-1",children:[_.map((ge,He)=>{const ae=jhe(ge.entries||[]);return E.jsxs("button",{onClick:()=>{k(He),A(0)},className:"group flex items-center gap-1.5 px-2.5 py-1.5 rounded-lg text-[11px] font-medium whitespace-nowrap transition-colors",style:{background:He===U?zo(w,.12):"var(--bg-surface)",border:He===U?`1px solid ${zo(w,.4)}`:"1px solid var(--border)",color:He===U?w:"var(--text-secondary)"},children:[ge.name||`Table ${He+1}`,ae&&E.jsx("span",{className:"text-[9px] font-mono px-1 py-0.5 rounded",style:{background:He===U?zo(w,.15):"var(--bg-elevated)",color:"var(--text-muted)"},children:ae.count}),_.length>1&&E.jsx("span",{onClick:Le=>{Le.stopPropagation(),Re(He)},className:"ml-0.5 opacity-0 group-hover:opacity-100 transition-opacity cursor-pointer",style:{color:"var(--text-muted)"},children:E.jsx(jp,{size:10})})]},He)}),E.jsx("button",{onClick:me,className:"p-1.5 rounded-lg transition-colors",style:{color:"var(--text-muted)",border:"1px dashed var(--border)"},onMouseEnter:ge=>{ge.currentTarget.style.borderColor=w,ge.currentTarget.style.color=w},onMouseLeave:ge=>{ge.currentTarget.style.borderColor="var(--border)",ge.currentTarget.style.color="var(--text-muted)"},children:E.jsx(w8,{size:12})})]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em] block mb-1",style:{color:"var(--text-muted)"},children:"Table Name"}),E.jsx("input",{type:"text",defaultValue:K.name,onBlur:ge=>Z(U,{name:ge.target.value}),className:"w-full px-2 py-1.5 text-xs font-mono rounded-lg focus:outline-none focus:ring-2",style:sf,placeholder:"Age Factor"},`name-${U}`)]}),E.jsxs("div",{children:[E.jsxs("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em] block mb-1",style:{color:"var(--text-muted)"},children:["Factors (",Ke,"/3)"]}),E.jsxs("div",{className:"space-y-1.5",children:[K.factors.map((ge,He)=>E.jsxs("div",{className:"flex items-center gap-1.5",children:[E.jsx("span",{className:"text-[10px] font-bold w-4 text-center",style:{color:"var(--text-muted)"},children:He+1}),E.jsxs("select",{value:ge,onChange:ae=>{const Le=[...K.factors];Le[He]=ae.target.value,ee(U,Le)},className:"flex-1 px-2 py-1.5 text-xs font-mono rounded-lg focus:outline-none",style:sf,children:[E.jsx("option",{value:"",children:"Select column..."}),F.map(ae=>E.jsxs("option",{value:ae,children:[ae," (",(D[ae]||[]).length," levels)"]},ae))]},`fsel-${U}-${He}`),E.jsx("button",{onClick:()=>fe(U,He),className:"p-1 rounded transition-colors",style:{color:"var(--text-muted)"},onMouseEnter:ae=>{ae.currentTarget.style.color="#ef4444"},onMouseLeave:ae=>{ae.currentTarget.style.color="var(--text-muted)"},children:E.jsx(jp,{size:11})})]},He)),Ke<3&&E.jsxs("select",{value:"",onChange:ge=>{ge.target.value&&ce(U,ge.target.value)},className:"w-full px-2 py-1.5 text-xs rounded-lg focus:outline-none",style:{...sf,color:"var(--text-muted)"},children:[E.jsx("option",{value:"",children:"+ Add factor..."}),F.filter(ge=>!K.factors.includes(ge)).map(ge=>E.jsxs("option",{value:ge,children:[ge," (",(D[ge]||[]).length," levels)"]},ge))]})]})]}),E.jsxs("div",{className:"grid grid-cols-2 gap-2",children:[E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em] block mb-1",style:{color:"var(--text-muted)"},children:"Output Column"}),E.jsx("input",{type:"text",defaultValue:K.outputColumn,onBlur:ge=>Z(U,{outputColumn:ge.target.value}),className:"w-full px-2 py-1.5 text-xs font-mono rounded-lg focus:outline-none focus:ring-2",style:sf,placeholder:"age_factor"},`out-${U}`)]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em] block mb-1",style:{color:"var(--text-muted)"},children:"Default"}),E.jsx("input",{type:"number",step:"0.01",defaultValue:K.defaultValue??"1.0",onBlur:ge=>Z(U,{defaultValue:ge.target.value}),className:"w-full px-2 py-1.5 text-xs font-mono rounded-lg focus:outline-none focus:ring-2",style:sf,placeholder:"1.0"},`def-${U}`)]})]}),Ke>0&&E.jsx("button",{onClick:Te,className:"w-full px-2 py-1.5 text-[11px] font-medium rounded-lg transition-colors",style:{background:"var(--bg-surface)",border:"1px solid var(--border)",color:"var(--text-secondary)"},onMouseEnter:ge=>{ge.currentTarget.style.borderColor=w,ge.currentTarget.style.color=w},onMouseLeave:ge=>{ge.currentTarget.style.borderColor="var(--border)",ge.currentTarget.style.color="var(--text-secondary)"},children:"↻ Rebuild from banding levels"}),Ke===0&&E.jsx("div",{className:"px-2 py-4 text-center text-[11px]",style:{color:"var(--text-muted)"},children:"Select at least one factor to populate the rating table"}),Ke===1&&E.jsx(z2n,{table:K,bandingLevels:D,onUpdateEntries:ge=>be(U,ge)}),Ke===2&&E.jsx(e4t,{table:K,bandingLevels:D,onUpdateEntries:ge=>be(U,ge)}),Ke===3&&E.jsxs("div",{className:"space-y-2",children:[E.jsxs("div",{className:"flex items-center gap-2",children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:ze}),E.jsx("select",{value:te,onChange:ge=>A(Number(ge.target.value)),className:"flex-1 px-2 py-1.5 text-xs font-mono rounded-lg focus:outline-none",style:sf,children:je.map((ge,He)=>E.jsx("option",{value:He,children:ge},ge))})]}),je.length>0&&E.jsx(e4t,{table:K,bandingLevels:D,onUpdateEntries:ge=>be(U,ge),factorOverrides:{factors:[K.factors[0],K.factors[1]],sliceKey:{[K.factors[2]]:je[te]}}})]}),K.entries.length>0&&(()=>{const ge=jhe(K.entries);return E.jsxs("div",{className:"flex items-center justify-between text-[10px] font-mono px-1",style:{color:"var(--text-muted)"},children:[E.jsx("span",{children:K.outputColumn?E.jsx("span",{style:{color:"var(--text-secondary)"},children:K.outputColumn}):"untitled"}),E.jsxs("span",{children:[K.entries.length," entries",ge?` · range ${ge.min.toFixed(2)}–${ge.max.toFixed(2)}`:""]})]})})()]})}function q2n({config:l,onUpdate:s,nodeId:u,allNodes:h,edges:g}){var _;const w=ni(l,"fields",[]),p=g.find(D=>D.target===u),k=p?h.find(D=>D.id===p.source):null,j=((_=k==null?void 0:k.data)==null?void 0:_._columns)||[],A=D=>{const I=w.includes(D)?w.filter(B=>B!==D):[...w,D];s("fields",I)};return E.jsxs("div",{className:"px-4 py-3 space-y-3",children:[E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em] block mb-2",style:{color:"var(--text-muted)"},children:"Response Fields"}),j.length===0?E.jsx("div",{className:"text-xs py-3",style:{color:"var(--text-muted)"},children:"Preview or run the upstream node to see columns"}):E.jsx("div",{className:"rounded-lg overflow-hidden",style:{border:"1px solid var(--border)",background:"var(--bg-input)"},children:E.jsxs("table",{className:"w-full text-xs",children:[E.jsx("thead",{children:E.jsxs("tr",{style:{borderBottom:"1px solid var(--border)",background:"var(--bg-elevated)"},children:[E.jsx("th",{className:"text-left px-2.5 py-1.5 font-semibold",style:{color:"var(--text-muted)",width:28}}),E.jsx("th",{className:"text-left px-2.5 py-1.5 font-semibold",style:{color:"var(--text-muted)"},children:"Column"}),E.jsx("th",{className:"text-left px-2.5 py-1.5 font-semibold",style:{color:"var(--text-muted)"},children:"Type"})]})}),E.jsx("tbody",{children:j.map(D=>{const I=w.includes(D.name);return E.jsxs("tr",{style:{borderBottom:"1px solid var(--border)"},children:[E.jsx("td",{className:"px-2.5 py-1.5 text-center",children:E.jsx("input",{type:"checkbox",checked:I,onChange:()=>A(D.name),className:"accent-rose-500 rounded"})}),E.jsx("td",{className:"px-2.5 py-1.5 font-mono",style:{color:I?"var(--text-primary)":"var(--text-muted)"},children:D.name}),E.jsx("td",{className:"px-2.5 py-1.5",children:E.jsx("span",{className:`text-[11px] font-medium ${GMe(D.dtype)}`,children:D.dtype})})]},D.name)})})]})})]}),w.length>0&&E.jsxs("div",{className:"rounded-lg px-3 py-2",style:{background:"var(--bg-elevated)",border:"1px solid var(--border)"},children:[E.jsx("div",{className:"text-[11px] font-bold uppercase tracking-[0.08em] mb-1.5",style:{color:"var(--text-muted)"},children:"JSON Preview"}),E.jsx("pre",{className:"text-[11px] font-mono leading-relaxed",style:{color:"var(--text-secondary)"},children:`{
${w.map(D=>`  "${D}": ...`).join(`,
`)}
}`})]})]})}function H2n({config:l,onUpdate:s,inputSources:u,onDeleteInput:h,errorLine:g,accentColor:w}){const[p,k]=pe.useState(ni(l,"fileType","pickle")),[j,A]=pe.useState(ni(l,"modelClass","classifier")),_=ni(l,"code",""),D=u.length>0,I=u.length>0?u[0].varName:"df",B={pickle:D?`df = ${I}.with_columns(
    prediction=pl.Series(obj.predict(${I}.to_numpy()))
)`:`# obj is the loaded pickle
df = pl.DataFrame({"result": [obj]})`,json:D?`df = ${I}.with_columns(
    lookup=${I}["key"].map_elements(lambda k: obj.get(k))
)`:`# obj is the loaded JSON dict/list
df = pl.DataFrame(obj)`,joblib:D?`df = ${I}.with_columns(
    prediction=pl.Series(obj.predict(${I}.to_numpy()))
)`:`# obj is the loaded joblib object
df = pl.DataFrame({"result": [str(obj)]})`,catboost:D?`X = ${I}.select(obj.feature_names_).collect().to_numpy()
preds = obj.predict(X)
df = ${I}.select("id").with_columns(prediction=pl.Series(preds))`:`# obj is the loaded CatBoost model
df = pl.DataFrame({"prediction": obj.predict([[1, 2, 3]])})`};return E.jsxs("div",{className:"flex-1 flex flex-col min-h-0 px-3 py-2 gap-2",children:[E.jsx(CM,{inputSources:u,onDeleteInput:h}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"File Type"}),E.jsx("div",{className:"mt-1",children:E.jsx(TM,{value:p,onChange:F=>{k(F),s("fileType",F)},options:[{key:"pickle",label:"PICKLE"},{key:"json",label:"JSON"},{key:"joblib",label:"JOBLIB"},{key:"catboost",label:"CATBOOST"}],accentColor:w})})]}),p==="catboost"&&E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Model Type"}),E.jsx("div",{className:"mt-1",children:E.jsx(TM,{value:j,onChange:F=>{A(F),s("modelClass",F)},options:[{key:"classifier",label:"Classifier"},{key:"regressor",label:"Regressor"}],accentColor:w})})]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em] mb-1.5 block",style:{color:"var(--text-muted)"},children:"File Path"}),E.jsx(DAe,{currentPath:ni(l,"path","")||void 0,onSelect:F=>s("path",F),extensions:".pkl,.pickle,.json,.joblib,.cbm,.onnx,.pmml"})]}),E.jsxs("div",{className:"flex items-center justify-between shrink-0",children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Code"}),E.jsxs("span",{className:"text-[11px] font-medium",style:{color:"var(--text-muted)"},children:[E.jsx("code",{className:"px-0.5 rounded",style:{background:"var(--bg-hover)"},children:"obj"})," = loaded file, assign to ",E.jsx("code",{className:"px-0.5 rounded",style:{background:"var(--bg-hover)"},children:"df"})]})]}),E.jsx(RV,{defaultValue:_,onChange:F=>s("code",F),errorLine:g,placeholder:B[p]||B.pickle})]})}function Q2n({dataPath:l}){return E.jsx(LSt,{resourceKey:l,getStatus:s=>Yfn(s),startFetch:s=>Wfn({path:s}).then(u=>({cached:!0,...u})),getProgress:s=>Kfn(s),deleteCache:s=>Zfn(s),timestampField:"cached_at",labels:{fetchLabel:"Cache as Parquet",refreshLabel:"Refresh Cache",notCachedHint:"Not cached yet — click to flatten and cache as Parquet",pendingLabel:"Processing..."}})}function G2n({config:l,onUpdate:s,accentColor:u}){const h=ni(l,"path",void 0),{schema:g,loading:w,fetchForPath:p}=DSt(h),k=h&&(h.endsWith(".json")||h.endsWith(".jsonl"));return E.jsxs(E.Fragment,{children:[E.jsxs("div",{className:"px-4 py-3 space-y-3",children:[E.jsxs("div",{className:"flex items-center gap-2 px-2.5 py-2 rounded-lg text-xs font-medium",style:{background:zo(u,.1),border:`1px solid ${zo(u,.3)}`,color:u},children:[E.jsx(FMe,{size:14}),E.jsx("span",{children:"This node receives live API requests at deploy time"})]}),E.jsxs("div",{children:[E.jsxs("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em] mb-1.5 block",style:{color:"var(--text-muted)"},children:["Preview Data",E.jsx("span",{className:"ml-1.5 normal-case tracking-normal font-normal",children:".json or .jsonl"})]}),E.jsx(DAe,{currentPath:h,onSelect:j=>{s("path",j),p(j)},extensions:".json,.jsonl"})]}),k&&E.jsx(Q2n,{dataPath:h})]}),w&&E.jsx("div",{className:"px-4 py-3",style:{borderTop:"1px solid var(--border)"},children:E.jsx("span",{className:"text-xs",style:{color:"var(--text-muted)"},children:"Loading schema..."})}),E.jsx(_St,{schema:g})]})}function U2n({config:l,onUpdate:s,inputSources:u,accentColor:h}){const g=Kc(j=>j.scenarios),w=Kc(j=>j.activeScenario),p=ni(l,"input_scenario_map",{}),k=(j,A)=>{s("input_scenario_map",{...p,[j]:A})};return E.jsxs("div",{className:"px-4 py-3 space-y-3",children:[E.jsxs("div",{className:"flex items-center gap-2 px-2.5 py-2 rounded-lg text-xs font-medium",style:{background:zo(h,.1),border:`1px solid ${zo(h,.3)}`,color:h},children:[E.jsx(lkt,{size:14}),E.jsx("span",{children:"Routes inputs based on the active scenario"})]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em] mb-1 block",style:{color:"var(--text-muted)"},children:"Active Scenario"}),E.jsx("div",{className:"px-2.5 py-1.5 text-xs rounded-lg font-mono",style:{background:"var(--bg-input)",border:"1px solid var(--border)",color:"var(--text-primary)"},children:w==="live"?"● live":w}),E.jsx("div",{className:"mt-1 text-[10px]",style:{color:"var(--text-muted)"},children:"Change the active scenario in the toolbar dropdown"})]}),E.jsxs("div",{children:[E.jsxs("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em] mb-1.5 block",style:{color:"var(--text-muted)"},children:["Input → Scenario Mapping (",u.length,")"]}),E.jsx("div",{className:"space-y-1.5",children:u.map(j=>{const A=p[j.varName]||"",_=A===w;return E.jsxs("div",{className:"flex items-center gap-2 px-2 py-1.5 rounded-md text-xs",style:{background:_?zo(h,.1):"var(--bg-surface)",border:_?`1px solid ${zo(h,.3)}`:"1px solid var(--border)"},children:[E.jsx("span",{className:"w-1.5 h-1.5 rounded-full shrink-0",style:{background:_?h:"var(--text-muted)"}}),E.jsx("span",{className:"font-mono truncate min-w-0 flex-1",style:{color:"var(--text-primary)"},children:j.sourceLabel}),E.jsxs("select",{value:A,onChange:D=>k(j.varName,D.target.value),className:"px-1.5 py-0.5 text-[11px] font-mono rounded focus:outline-none",style:{background:"var(--bg-input)",border:"1px solid var(--border)",color:"var(--text-primary)"},children:[E.jsx("option",{value:"",children:"—"}),g.map(D=>E.jsx("option",{value:D,children:D},D))]}),_&&E.jsx("span",{className:"text-[10px] font-medium shrink-0",style:{color:h},children:"active"})]},j.varName)})})]})]})}function J2n({config:l,onUpdate:s,nodeId:u,allNodes:h,edges:g,submodels:w,preamble:p,accentColor:k}){const j=ni(l,"format","parquet"),[A,_]=pe.useState(!1),[D,I]=pe.useState(null),B=!!l.path,F=()=>{if(!B||A)return;_(!0),I(null);const U=ZX(h,g,w,p);jfn(U,u,Kc.getState().activeScenario).then(K=>{I({status:K.status||"ok",message:K.message||"Written successfully"}),_(!1)}).catch(K=>{I({status:"error",message:K.message}),_(!1)})};return E.jsxs("div",{className:"px-4 py-3 space-y-3",children:[E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Format"}),E.jsx("div",{className:"mt-1",children:E.jsx(TM,{value:j,onChange:U=>s("format",U),options:[{key:"parquet",label:"PARQUET"},{key:"csv",label:"CSV"}],accentColor:k})})]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em] mb-1.5 block",style:{color:"var(--text-muted)"},children:"Output Path"}),E.jsx("input",{type:"text",placeholder:j==="csv"?"output/results.csv":"output/results.parquet",defaultValue:ni(l,"path",""),onChange:U=>s("path",U.target.value),className:"w-full px-2.5 py-1.5 text-xs font-mono rounded-lg focus:outline-none focus:ring-2",style:{background:"var(--bg-input)",border:"1px solid var(--border)",color:"var(--text-primary)"},onFocus:U=>{U.currentTarget.style.borderColor=zo(k,.3),U.currentTarget.style.boxShadow=`0 0 0 2px ${zo(k,.1)}`},onBlur:U=>{U.currentTarget.style.borderColor="var(--border)",U.currentTarget.style.boxShadow="none"}})]}),E.jsxs("button",{onClick:F,disabled:!B||A,className:"w-full flex items-center justify-center gap-2 px-3 py-2 text-[12px] font-semibold rounded-lg transition-colors disabled:opacity-40",style:{background:k,color:"#000"},onMouseEnter:U=>{B&&!A&&(U.currentTarget.style.opacity="0.85")},onMouseLeave:U=>{U.currentTarget.style.opacity="1"},children:[E.jsx(Jfe,{size:14}),A?"Writing...":"Write"]}),D&&E.jsx("div",{className:"px-2.5 py-2 rounded-lg text-xs",style:{background:D.status==="ok"?"rgba(34,197,94,.1)":"rgba(239,68,68,.1)",border:D.status==="ok"?"1px solid rgba(34,197,94,.2)":"1px solid rgba(239,68,68,.2)",color:D.status==="ok"?"#4ade80":"#f87171"},children:D.message})]})}function X2n({config:l,onUpdate:s,inputSources:u,onDeleteInput:h,upstreamColumns:g,accentColor:w}){const p=ni(l,"quote_id",""),k=ni(l,"column_name","scenario_value"),j=ni(l,"min_value",.8),A=ni(l,"max_value",1.2),_=ni(l,"steps",21),D=ni(l,"step_column","scenario_index");return E.jsxs("div",{className:"px-4 py-3 space-y-4",children:[E.jsx(CM,{inputSources:u,onDeleteInput:h}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em] block mb-1.5",style:{color:"var(--text-muted)"},children:"Quote ID Column"}),g.length>0?E.jsxs("select",{className:"w-full px-2.5 py-1.5 rounded-md text-[12px] font-mono appearance-none cursor-pointer",style:sf,value:p,onChange:I=>s("quote_id",I.target.value),children:[E.jsx("option",{value:"",children:"-- select column --"}),g.map(I=>E.jsx("option",{value:I.name,children:I.name},I.name))]}):E.jsx("input",{type:"text",className:"w-full px-2.5 py-1.5 rounded-md text-[12px] font-mono",style:sf,value:p,onChange:I=>s("quote_id",I.target.value),placeholder:"quote_id"}),E.jsx("p",{className:"text-[10px] mt-1",style:{color:"var(--text-muted)"},children:"Column that identifies each quote / row-group"})]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em] block mb-1.5",style:{color:"var(--text-muted)"},children:"Value Column"}),E.jsx("input",{type:"text",className:"w-full px-2.5 py-1.5 rounded-md text-[12px] font-mono",style:sf,value:k,onChange:I=>s("column_name",I.target.value),placeholder:"scenario_value"}),E.jsx("p",{className:"text-[10px] mt-1",style:{color:"var(--text-muted)"},children:"Name of the new column with generated values"})]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em] block mb-1.5",style:{color:"var(--text-muted)"},children:"Range"}),E.jsxs("div",{className:"grid grid-cols-3 gap-2",children:[E.jsxs("div",{children:[E.jsx("label",{className:"text-[10px] block mb-0.5",style:{color:"var(--text-muted)"},children:"Min"}),E.jsx("input",{type:"number",step:"any",className:"w-full px-2 py-1.5 rounded-md text-[12px] font-mono",style:sf,value:j,onChange:I=>s("min_value",parseFloat(I.target.value)||0)})]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[10px] block mb-0.5",style:{color:"var(--text-muted)"},children:"Max"}),E.jsx("input",{type:"number",step:"any",className:"w-full px-2 py-1.5 rounded-md text-[12px] font-mono",style:sf,value:A,onChange:I=>s("max_value",parseFloat(I.target.value)||0)})]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[10px] block mb-0.5",style:{color:"var(--text-muted)"},children:"Steps"}),E.jsx("input",{type:"number",min:1,className:"w-full px-2 py-1.5 rounded-md text-[12px] font-mono",style:sf,value:_,onChange:I=>s("steps",Math.max(1,parseInt(I.target.value)||1))})]})]})]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em] block mb-1.5",style:{color:"var(--text-muted)"},children:"Step Column"}),E.jsx("input",{type:"text",className:"w-full px-2.5 py-1.5 rounded-md text-[12px] font-mono",style:sf,value:D,onChange:I=>s("step_column",I.target.value),placeholder:"scenario_index"}),E.jsx("p",{className:"text-[10px] mt-1",style:{color:"var(--text-muted)"},children:"Name of the 0-based step index column"})]}),E.jsxs("div",{className:"rounded-lg px-3 py-2",style:{background:"var(--bg-elevated)",border:"1px solid var(--border)"},children:[E.jsxs("div",{className:"text-[11px] font-mono",style:{color:"var(--text-secondary)"},children:["Each input row → ",E.jsx("span",{style:{color:w,fontWeight:600},children:_})," output rows"]}),E.jsxs("div",{className:"text-[10px] font-mono mt-0.5",style:{color:"var(--text-muted)"},children:[k||"value",": ",j," → ",A," (",_," steps)"]})]})]})}function V2n({config:l,onUpdate:s,inputSources:u,onDeleteInput:h,accentColor:g}){const w=ni(l,"sourceType","file"),p=ni(l,"artifact_path",""),k=ni(l,"version_column","__optimiser_version__"),j=ni(l,"registered_model",""),[A,_]=pe.useState(null),[D,I]=pe.useState(""),{experiments:B,runs:F,models:U,modelVersions:K,loadingExperiments:Y,loadingRuns:Z,loadingModels:ee,errorExperiments:ce,errorRuns:fe,errorModels:be,errorVersions:me,browseExpId:Re,setBrowseExpId:Te,setRuns:Ke,resetRunsGuard:ze,refreshExperiments:je,refreshRuns:te,refreshModels:ge,refreshVersions:He}=PSt({runTag:"optimiser",initialExpId:ni(l,"experiment_id","")});return pe.useEffect(()=>{if(w!=="file"||!p){w==="file"&&(_(null),I(""));return}fetch("/api/pipeline/read-json",{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({path:p})}).then(async ae=>{if(!ae.ok){I(`Could not read artifact: ${ae.statusText}`),_(null);return}const Le=await ae.json();_(Le),I("")}).catch(ae=>{console.warn("Artifact load failed:",ae),I("Could not load artifact file"),_(null)})},[p,w]),E.jsxs("div",{className:"flex-1 flex flex-col min-h-0 px-3 py-2 gap-3",children:[E.jsx(CM,{inputSources:u,onDeleteInput:h}),w!=="file"&&E.jsx(NSt,{}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Artifact Source"}),E.jsx("div",{className:"mt-1",children:E.jsx(TM,{value:w,onChange:ae=>s("sourceType",ae),options:[{key:"file",label:"File Path"},{key:"registered",label:"Registered"},{key:"run",label:"Experiment Run"}],accentColor:g})})]}),w==="file"&&E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em] block mb-1",style:{color:"var(--text-muted)"},children:"Artifact Path"}),E.jsx("input",{type:"text",className:"w-full px-2.5 py-1.5 rounded-lg text-[12px] font-mono focus:outline-none focus:ring-2",style:sf,value:p,onChange:ae=>s("artifact_path",ae.target.value),placeholder:"artifacts/optimiser_v1.json"}),E.jsx("p",{className:"text-[10px] mt-1",style:{color:"var(--text-muted)"},children:"Path to saved optimiser result (JSON from the Optimiser Save action)"})]}),w==="registered"&&E.jsxs("div",{className:"flex flex-col gap-2",children:[E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Model Name"}),E.jsxs("select",{className:"mt-1 w-full text-xs px-2.5 py-1.5 rounded-lg focus:outline-none focus:ring-2",style:Zb,value:j,onFocus:ge,onChange:ae=>s({registered_model:ae.target.value,version:"latest"}),children:[E.jsx("option",{value:"",children:ee?"Loading...":"Select a model..."}),j&&!U.some(ae=>ae.name===j)&&E.jsx("option",{value:j,children:j}),U.map(ae=>E.jsx("option",{value:ae.name,children:ae.name},ae.name))]}),be&&E.jsx("span",{className:"text-[10px] mt-0.5",style:{color:"#ef4444"},children:be})]}),j&&E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Version"}),E.jsxs("select",{className:"mt-1 w-full text-xs px-2.5 py-1.5 rounded-lg focus:outline-none focus:ring-2",style:Zb,value:ni(l,"version","latest"),onFocus:()=>He(j),onChange:ae=>s("version",ae.target.value),children:[E.jsx("option",{value:"latest",children:"latest"}),K.map(ae=>E.jsxs("option",{value:ae.version,children:["v",ae.version," — ",ae.status,ae.description?` (${ae.description})`:""]},ae.version))]}),me&&E.jsx("span",{className:"text-[10px] mt-0.5",style:{color:"#ef4444"},children:me})]})]}),w==="run"&&E.jsxs("div",{className:"flex flex-col gap-2",children:[E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Experiment"}),E.jsxs("select",{className:"mt-1 w-full text-xs px-2.5 py-1.5 rounded-lg focus:outline-none focus:ring-2",style:Zb,value:Re,onFocus:je,onChange:ae=>{const Le=ae.target.value,Oe=B.find(Qe=>Qe.experiment_id===Le);Te(Le),s({experiment_id:Le,experiment_name:(Oe==null?void 0:Oe.name)||Le}),Ke([]),ze(),Le&&te(Le)},children:[E.jsx("option",{value:"",children:Y?"Loading...":"Select an experiment..."}),Re&&!B.some(ae=>ae.experiment_id===Re)&&E.jsx("option",{value:Re,children:ni(l,"experiment_name","")||Re}),B.map(ae=>E.jsx("option",{value:ae.experiment_id,children:ae.name},ae.experiment_id))]}),ce&&E.jsx("span",{className:"text-[10px] mt-0.5",style:{color:"#ef4444"},children:ce})]}),Re&&E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Run"}),E.jsxs("select",{className:"mt-1 w-full text-xs px-2.5 py-1.5 rounded-lg focus:outline-none focus:ring-2",style:Zb,value:ni(l,"run_id",""),onFocus:()=>te(Re),onChange:ae=>{const Le=ae.target.value,Oe=F.find(Qe=>Qe.run_id===Le);s({run_id:Le,run_name:(Oe==null?void 0:Oe.run_name)||""})},children:[E.jsx("option",{value:"",children:Z?"Loading...":"Select a run..."}),ni(l,"run_id","")&&!F.some(ae=>ae.run_id===l.run_id)&&E.jsx("option",{value:ni(l,"run_id",""),children:ni(l,"run_name","")||ni(l,"run_id","")}),F.map(ae=>{const Le=ae.metrics.converged!==void 0?ae.metrics.cd_iterations!==void 0?"ratebook":"online":"";return E.jsxs("option",{value:ae.run_id,children:[ae.run_name||ae.run_id.slice(0,8),Le?` [${Le}]`:"",ae.metrics.total_objective!==void 0?` obj=${ae.metrics.total_objective.toFixed(2)}`:""]},ae.run_id)})]}),fe&&E.jsx("span",{className:"text-[10px] mt-0.5",style:{color:"#ef4444"},children:fe})]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Run ID"}),E.jsx("input",{type:"text",className:"mt-1 w-full text-xs px-2.5 py-1.5 rounded-lg font-mono focus:outline-none focus:ring-2",style:Zb,value:ni(l,"run_id",""),onChange:ae=>s("run_id",ae.target.value),placeholder:"e.g. a1b2c3d4e5f6..."})]})]}),E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em] block mb-1",style:{color:"var(--text-muted)"},children:"Version Column"}),E.jsx("input",{type:"text",className:"w-full px-2.5 py-1.5 rounded-lg text-[12px] font-mono focus:outline-none focus:ring-2",style:sf,value:k,onChange:ae=>s("version_column",ae.target.value),placeholder:"__optimiser_version__"}),E.jsx("p",{className:"text-[10px] mt-1",style:{color:"var(--text-muted)"},children:"Column added to output for monitoring / version tracking"})]}),w==="file"&&D&&E.jsx("div",{className:"rounded-lg px-3 py-2",style:{background:"var(--bg-elevated)",border:`1px solid ${g}`},children:E.jsx("div",{className:"text-[11px]",style:{color:g},children:D})}),w==="file"&&A&&E.jsx(W2n,{meta:A,accentColor:g})]})}function W2n({meta:l,accentColor:s}){return E.jsxs("div",{className:"rounded-lg px-3 py-2.5 space-y-2",style:{background:"var(--bg-elevated)",border:"1px solid var(--border)"},children:[E.jsx("div",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Loaded Artifact"}),E.jsxs("div",{className:"grid grid-cols-2 gap-x-4 gap-y-1 text-[11px] font-mono",children:[E.jsx("span",{style:{color:"var(--text-muted)"},children:"Mode"}),E.jsx("span",{style:{color:"var(--text-primary)",fontWeight:600},children:l.mode}),E.jsx("span",{style:{color:"var(--text-muted)"},children:"Version"}),E.jsx("span",{style:{color:"var(--text-primary)"},children:l.version||"—"}),E.jsx("span",{style:{color:"var(--text-muted)"},children:"Created"}),E.jsx("span",{style:{color:"var(--text-primary)"},children:l.created_at?new Date(l.created_at).toLocaleDateString():"—"}),E.jsx("span",{style:{color:"var(--text-muted)"},children:"Objective"}),E.jsx("span",{style:{color:"var(--text-primary)"},children:l.objective||"—"})]}),l.mode==="online"&&l.lambdas&&Object.keys(l.lambdas).length>0&&E.jsxs("div",{children:[E.jsx("div",{className:"text-[10px] font-bold uppercase tracking-[0.08em] mt-1 mb-0.5",style:{color:"var(--text-muted)"},children:"Lambdas"}),Object.entries(l.lambdas).map(([u,h])=>E.jsxs("div",{className:"flex justify-between text-[11px] font-mono px-1",children:[E.jsx("span",{style:{color:"var(--text-secondary)"},children:u}),E.jsx("span",{style:{color:s,fontWeight:600},children:typeof h=="number"?h.toFixed(4):String(h)})]},u))]}),l.mode==="ratebook"&&l.factor_tables&&Object.keys(l.factor_tables).length>0&&E.jsxs("div",{children:[E.jsx("div",{className:"text-[10px] font-bold uppercase tracking-[0.08em] mt-1 mb-0.5",style:{color:"var(--text-muted)"},children:"Factor Tables"}),Object.entries(l.factor_tables).map(([u,h])=>E.jsxs("div",{className:"flex justify-between text-[11px] font-mono px-1",children:[E.jsx("span",{style:{color:"var(--text-secondary)"},children:u}),E.jsxs("span",{style:{color:"var(--text-muted)"},children:[Array.isArray(h)?h.length:0," levels"]})]},u))]})]})}function K2n({config:l,onUpdate:s}){const u=ni(l,"values",[]),h=(p,k,j)=>{const A=u.map((_,D)=>D===p?{..._,[k]:j}:_);s("values",A)},g=()=>{s("values",[...u,{name:`constant_${u.length+1}`,value:"0"}])},w=p=>{s("values",u.filter((k,j)=>j!==p))};return E.jsxs("div",{className:"px-4 py-3 space-y-3",children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Values"}),E.jsx("div",{className:"space-y-1.5",children:u.map((p,k)=>E.jsxs("div",{className:"flex items-center gap-1.5",children:[E.jsx("input",{type:"text",value:p.name,onChange:j=>h(k,"name",j.target.value),placeholder:"name",className:"flex-1 min-w-0 px-2 py-1.5 text-xs font-mono rounded-lg",style:{background:"var(--input-bg)",color:"var(--text-primary)",border:"1px solid var(--border)"}}),E.jsx("input",{type:"text",value:p.value,onChange:j=>h(k,"value",j.target.value),placeholder:"value",className:"w-24 px-2 py-1.5 text-xs font-mono rounded-lg text-right",style:{background:"var(--input-bg)",color:"var(--text-primary)",border:"1px solid var(--border)"}}),E.jsx("button",{onClick:()=>w(k),className:"p-1 rounded transition-colors shrink-0",style:{color:"var(--text-muted)"},onMouseEnter:j=>j.currentTarget.style.color="#ef4444",onMouseLeave:j=>j.currentTarget.style.color="var(--text-muted)",title:"Remove",children:E.jsx(BI,{size:12})})]},k))}),E.jsxs("button",{onClick:g,className:"flex items-center gap-1.5 px-2.5 py-1.5 text-xs font-medium rounded-lg transition-colors w-full justify-center",style:{background:"var(--chrome-hover)",color:"var(--text-secondary)",border:"1px solid var(--border)"},onMouseEnter:p=>p.currentTarget.style.background="var(--chrome-active)",onMouseLeave:p=>p.currentTarget.style.background="var(--chrome-hover)",children:[E.jsx(w8,{size:12}),"Add value"]})]})}function Y2n({config:l,accentColor:s}){const u=ni(l,"file",""),h=ni(l,"childNodeIds",[]),g=ni(l,"inputPorts",[]),w=ni(l,"outputPorts",[]);return E.jsxs("div",{className:"px-4 py-3 space-y-3",children:[E.jsxs("div",{className:"flex items-center gap-2 px-2.5 py-2 rounded-lg",style:{background:zo(s,.08),border:`1px solid ${zo(s,.2)}`},children:[E.jsx(jV,{size:14,style:{color:s}}),E.jsx("span",{className:"text-xs font-medium",style:{color:s},children:"Submodel"}),E.jsxs("span",{className:"ml-auto text-[11px] font-mono",style:{color:"var(--text-muted)"},children:[h.length," nodes"]})]}),u&&E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"File"}),E.jsx("div",{className:"mt-1 text-xs font-mono px-2.5 py-1.5 rounded-lg",style:{background:"var(--bg-input)",border:"1px solid var(--border)",color:"var(--text-secondary)"},children:u})]}),g.length>0&&E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Inputs"}),E.jsx("div",{className:"mt-1 flex flex-wrap gap-1.5",children:g.map(p=>E.jsx("span",{className:"inline-flex items-center px-2 py-0.5 rounded text-[11px] font-mono",style:{background:"var(--accent-soft)",color:"var(--accent)"},children:p},p))})]}),w.length>0&&E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Outputs"}),E.jsx("div",{className:"mt-1 flex flex-wrap gap-1.5",children:w.map(p=>E.jsx("span",{className:"inline-flex items-center px-2 py-0.5 rounded text-[11px] font-mono",style:{background:zo(s,.1),color:s},children:p},p))})]}),E.jsx("div",{className:"text-[11px] pt-1",style:{color:"var(--text-muted)"},children:"Double-click to view internal nodes"})]})}const Da=Bhe()(l=>({paletteOpen:!0,setPaletteOpen:s=>l({paletteOpen:s}),utilityOpen:!1,setUtilityOpen:s=>l({utilityOpen:s,importsOpen:!1,gitOpen:!1}),importsOpen:!1,setImportsOpen:s=>l({importsOpen:s,utilityOpen:!1,gitOpen:!1}),gitOpen:!1,setGitOpen:s=>l({gitOpen:s,utilityOpen:!1,importsOpen:!1}),shortcutsOpen:!1,setShortcutsOpen:s=>{l(typeof s=="function"?u=>({shortcutsOpen:s(u.shortcutsOpen)}):{shortcutsOpen:s})},submodelDialog:null,setSubmodelDialog:s=>l({submodelDialog:s}),syncBanner:null,setSyncBanner:s=>l({syncBanner:s}),dirty:!1,setDirty:s=>l({dirty:s}),nodePanelWidth:900,setNodePanelWidth:s=>l({nodePanelWidth:s})})),Z2n=320,evn=900;function $V({children:l,style:s}){const u=Da(_=>_.nodePanelWidth),h=Da(_=>_.setNodePanelWidth),g=pe.useRef(!1),w=pe.useRef(0),p=pe.useRef(u),k=pe.useRef(u),j=pe.useRef(null);pe.useEffect(()=>{const _=I=>{if(!g.current)return;const B=w.current-I.clientX,F=Math.min(evn,Math.max(Z2n,p.current+B));k.current=F,j.current&&(j.current.style.width=`${F}px`)},D=()=>{g.current&&(g.current=!1,document.body.style.cursor="",document.body.style.userSelect="",h(k.current))};return window.addEventListener("mousemove",_),window.addEventListener("mouseup",D),()=>{window.removeEventListener("mousemove",_),window.removeEventListener("mouseup",D)}},[h]);const A=pe.useCallback(_=>{g.current=!0,w.current=_.clientX,p.current=u,k.current=u,document.body.style.cursor="col-resize",document.body.style.userSelect="none"},[u]);return E.jsxs("div",{ref:j,className:"h-full shrink-0 flex flex-row animate-slide-in",style:{width:u,background:"var(--bg-panel)",...s},children:[E.jsx("div",{onMouseDown:A,className:"shrink-0 h-full w-1 cursor-col-resize transition-colors",style:{background:"var(--chrome-border)"},onMouseEnter:_=>{_.currentTarget.style.background="var(--accent)"},onMouseLeave:_=>{g.current||(_.currentTarget.style.background="var(--chrome-border)")}}),E.jsx("div",{className:"flex-1 min-w-0 h-full flex flex-col overflow-hidden",children:l})]})}const tvn=new Set([Ln.CONSTANT,Ln.TRANSFORM,Ln.BANDING,Ln.SCENARIO_EXPANDER,Ln.RATING_STEP,Ln.MODEL_SCORE,Ln.OPTIMISER_APPLY]);function nvn({node:l,config:s,edges:u,allNodes:h,nodeMap:g,handleConfigUpdate:w}){return E.jsxs("div",{className:"px-4 py-3 flex flex-col gap-3",children:[E.jsxs("div",{className:"flex items-center gap-2 px-3 py-2 rounded-lg",style:{background:"var(--accent-soft)",border:"1px solid rgba(96,165,250,.15)"},children:[E.jsx(zMe,{size:13,style:{color:"var(--accent)"},className:"shrink-0"}),E.jsxs("div",{className:"min-w-0",children:[E.jsx("div",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--accent)"},children:"Instance of"}),E.jsx("div",{className:"text-[13px] font-semibold truncate",style:{color:"var(--text-primary)"},children:(()=>{const p=h.find(k=>k.id===s.instanceOf);return p?p.data.label:String(s.instanceOf)})()})]})]}),E.jsx("p",{className:"text-[11px] leading-relaxed",style:{color:"var(--text-muted)"},children:"This node uses the same logic as the original. To edit the code or config, select the original node. Changes will automatically apply to all instances."}),(()=>{const p=s.instanceOf,k=u.filter(Y=>Y.target===p).map(Y=>{const Z=g[Y.source];return Z?ECe(Z.data.label):Y.source}),j=u.filter(Y=>Y.target===l.id).map(Y=>{const Z=g[Y.source];return{varName:Z?ECe(Z.data.label):Y.source,label:Z?Z.data.label:Y.source}});if(k.length===0&&j.length===0)return null;const A=s.inputMapping||{},_={},D=new Set;for(const Y of k){const Z=j.find(ee=>ee.varName===Y&&!D.has(ee.varName));Z&&(_[Y]=Z.varName,D.add(Z.varName))}for(const Y of k){if(_[Y])continue;const Z=j.find(ee=>!D.has(ee.varName)&&ee.varName.includes(Y));Z&&(_[Y]=Z.varName,D.add(Z.varName))}const I=j.filter(Y=>!D.has(Y.varName));k.filter(Y=>!_[Y]).forEach((Y,Z)=>{Z<I.length&&(_[Y]=I[Z].varName)});const F={},U=new Set(j.map(Y=>Y.varName));for(const Y of k)A[Y]&&U.has(A[Y])?F[Y]=A[Y]:F[Y]=_[Y]||"";const K=(Y,Z)=>{const ee={...F,[Y]:Z};w("inputMapping",ee)};return E.jsxs("div",{className:"flex flex-col gap-2",children:[E.jsx("div",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Input Mapping"}),E.jsx("p",{className:"text-[10px] leading-relaxed",style:{color:"var(--text-muted)"},children:"Map each original input to a connected upstream node."}),E.jsx("div",{className:"flex flex-col gap-1.5",children:k.map(Y=>E.jsxs("div",{className:"flex items-center gap-2 px-2 py-1.5 rounded-md",style:{background:"var(--bg-surface)",border:"1px solid var(--border)"},children:[E.jsx("span",{className:"text-[11px] font-mono shrink-0 min-w-[90px] truncate",style:{color:"var(--text-secondary)"},title:Y,children:Y}),E.jsx("span",{className:"text-[10px] shrink-0",style:{color:"var(--text-muted)"},children:"→"}),E.jsxs("select",{className:"flex-1 min-w-0 text-[11px] font-mono px-1.5 py-1 rounded border bg-transparent appearance-none cursor-pointer truncate",style:{color:"var(--text-primary)",borderColor:"var(--border)",background:"var(--bg-panel)"},value:F[Y]||"",onChange:Z=>K(Y,Z.target.value),children:[E.jsx("option",{value:"",children:"— unmapped —"}),j.map(Z=>E.jsx("option",{value:Z.varName,children:Z.label},Z.varName))]})]},Y))})]})})(),(()=>{const p=l.data._schemaWarnings||[];return p.length===0?null:E.jsxs("div",{className:"flex flex-col gap-1.5 px-3 py-2 rounded-lg",style:{background:"rgba(245,158,11,.08)",border:"1px solid rgba(245,158,11,.2)"},children:[E.jsxs("div",{className:"flex items-center gap-1.5",children:[E.jsx(Oy,{size:11,style:{color:"#f59e0b"},className:"shrink-0"}),E.jsxs("span",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"#f59e0b"},children:["Missing columns (",p.length,")"]})]}),E.jsx("p",{className:"text-[10px] leading-relaxed",style:{color:"var(--text-muted)"},children:"The original node receives columns that are not available at this instance's position:"}),E.jsx("div",{className:"flex flex-wrap gap-1 mt-0.5",children:p.map(k=>E.jsx("span",{className:"px-1.5 py-0.5 rounded text-[10px] font-mono",style:{background:"rgba(245,158,11,.12)",color:"#fbbf24"},children:k.column},k.column))})]})})()]})}function bfe(l,s,u){const h=[],g=new Set;return s.filter(w=>w.target===l).forEach(w=>{var j;const p=u[w.source],k=(j=p==null?void 0:p.data)==null?void 0:j._columns;k&&k.forEach(A=>{g.has(A.name)||(g.add(A.name),h.push(A))})}),h}function ivn({node:l,edges:s,allNodes:u,submodels:h,preamble:g,onClose:w,onUpdateNode:p,onDeleteEdge:k,onRefreshPreview:j,dimmed:A,errorLine:_}){var ce;const D=(l==null?void 0:l.data.config)||{},I=pe.useCallback((fe,be)=>{if(!l||!p)return;const me=typeof fe=="string"?{...D,[fe]:be}:{...D,...fe};p(l.id,{...l.data,config:me})},[D,l,p]),B=pe.useMemo(()=>({...D,_nodeId:(l==null?void 0:l.id)??""}),[D,l==null?void 0:l.id]);if(!l)return null;const F=!!D.instanceOf,U=l.data.nodeType,K=Object.fromEntries(u.map(fe=>[fe.id,fe])),Y=s.filter(fe=>fe.target===l.id).map(fe=>{var be,me;return{varName:ECe(((be=K[fe.source])==null?void 0:be.data.label)||fe.source),sourceLabel:((me=K[fe.source])==null?void 0:me.data.label)||fe.source,edgeId:fe.id}}),Z=((ce=zI[U])==null?void 0:ce.color)??"var(--accent)",ee=()=>{var fe,be;if(F)return E.jsx(nvn,{node:l,config:D,edges:s,allNodes:u,nodeMap:K,handleConfigUpdate:I});switch(U){case Ln.API_INPUT:return E.jsx(G2n,{config:D,onUpdate:I,accentColor:Z});case Ln.LIVE_SWITCH:return E.jsx(U2n,{config:D,onUpdate:I,inputSources:Y,accentColor:Z});case Ln.DATA_SOURCE:return E.jsx(M2n,{config:D,onUpdate:I,onRefreshPreview:j,accentColor:Z});case Ln.DATA_SINK:return E.jsx(J2n,{config:D,onUpdate:I,nodeId:l.id,allNodes:u,edges:s,submodels:h,preamble:g,accentColor:Z});case Ln.EXTERNAL_FILE:return E.jsx(H2n,{config:D,onUpdate:I,inputSources:Y,onDeleteInput:k,errorLine:_,accentColor:Z});case Ln.OUTPUT:return E.jsx(q2n,{config:D,onUpdate:I,nodeId:l.id,allNodes:u,edges:s});case Ln.BANDING:return E.jsx($2n,{config:D,onUpdate:I,inputSources:Y,onDeleteInput:k,upstreamColumns:bfe(l.id,s,K),accentColor:Z});case Ln.SCENARIO_EXPANDER:return E.jsx(X2n,{config:D,onUpdate:I,inputSources:Y,onDeleteInput:k,upstreamColumns:bfe(l.id,s,K),accentColor:Z});case Ln.RATING_STEP:return E.jsx(F2n,{config:D,onUpdate:I,inputSources:Y,onDeleteInput:k,allNodes:u,accentColor:Z});case Ln.MODEL_SCORE:return E.jsx(N2n,{config:D,onUpdate:I,inputSources:Y,onDeleteInput:k,errorLine:_,accentColor:Z});case Ln.MODELLING:{const me=bfe(l.id,s,K),Re=me.length>0?me:((fe=l.data)==null?void 0:fe._columns)||[];return E.jsx(Hhn,{config:B,onUpdate:I,allNodes:u,edges:s,submodels:h,preamble:g,upstreamColumns:Re})}case Ln.OPTIMISER:{const me=bfe(l.id,s,K),Re=me.length>0?me:((be=l.data)==null?void 0:be._columns)||[];return E.jsx(Vhn,{config:B,onUpdate:I,allNodes:u,edges:s,submodels:h,upstreamColumns:Re,accentColor:Z})}case Ln.OPTIMISER_APPLY:return E.jsx(V2n,{config:D,onUpdate:I,inputSources:Y,onDeleteInput:k,accentColor:Z});case Ln.CONSTANT:return E.jsx(K2n,{config:D,onUpdate:I});case Ln.TRANSFORM:return E.jsx(A2n,{config:D,onUpdate:I,inputSources:Y,onDeleteInput:k,errorLine:_});case Ln.SUBMODEL:return E.jsx(Y2n,{config:D,accentColor:Z});default:return Object.keys(D).length>0?E.jsxs("div",{className:"px-4 py-3",children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Config"}),Object.entries(D).map(([me,Re])=>E.jsxs("div",{className:"mt-1.5 flex items-center gap-2",children:[E.jsxs("span",{className:"text-xs font-mono",style:{color:"var(--text-muted)"},children:[me,":"]}),E.jsx("span",{className:"text-xs font-mono truncate",style:{color:"var(--text-primary)"},children:String(Re)})]},me))]}):null}};return E.jsxs($V,{style:{opacity:A?.6:1,transition:"opacity 150ms"},children:[E.jsxs("div",{className:"px-3 py-2.5 flex items-center gap-2 shrink-0",style:{borderBottom:"1px solid var(--border)"},children:[E.jsx("input",{type:"text",value:l.data.label,onChange:fe=>{p&&p(l.id,{...l.data,label:fe.target.value})},className:"flex-1 min-w-0 px-2 py-1 text-[13px] font-semibold border border-transparent rounded-md focus:outline-none focus:ring-2 bg-transparent",style:{color:"var(--text-primary)",borderColor:"transparent"},onFocus:fe=>{fe.currentTarget.style.borderColor="var(--accent)",fe.currentTarget.style.boxShadow="0 0 0 2px var(--accent-soft)"},onBlur:fe=>{fe.currentTarget.style.borderColor="transparent",fe.currentTarget.style.boxShadow="none"}}),E.jsx("span",{className:"text-[11px] font-mono shrink-0",style:{color:"var(--text-muted)"},children:l.id}),j&&tvn.has(U)&&E.jsx("button",{onClick:j,className:"p-1 rounded shrink-0 transition-colors",style:{color:"var(--text-muted)"},onMouseEnter:fe=>{fe.currentTarget.style.background="var(--bg-hover)",fe.currentTarget.style.color="var(--accent)"},onMouseLeave:fe=>{fe.currentTarget.style.background="transparent",fe.currentTarget.style.color="var(--text-muted)"},title:"Refresh preview",children:E.jsx(qMe,{size:13})}),E.jsx("button",{onClick:w,className:"p-1 rounded shrink-0 transition-colors",style:{color:"var(--text-muted)"},onMouseEnter:fe=>fe.currentTarget.style.background="var(--bg-hover)",onMouseLeave:fe=>fe.currentTarget.style.background="transparent",title:"Close",children:E.jsx(jp,{size:14})})]}),ee()]})}function BSt(l){const{initialHeight:s,minHeight:u,maxHeight:h}=l,[g,w]=pe.useState(s),p=pe.useRef(null),k=pe.useRef(!1),j=pe.useRef(g);pe.useEffect(()=>{j.current=g},[g]);const A=pe.useRef(null);pe.useEffect(()=>()=>{var D;(D=A.current)==null||D.call(A)},[]);const _=pe.useCallback(D=>{D.preventDefault(),k.current=!0;const I=D.clientY,B=j.current,F=K=>{if(!k.current)return;const Y=Math.max(u,Math.min(h,B+(I-K.clientY)));p.current&&(p.current.style.height=`${Y}px`)},U=K=>{k.current=!1;const Y=Math.max(u,Math.min(h,B+(I-K.clientY)));w(Y),document.removeEventListener("mousemove",F),document.removeEventListener("mouseup",U),A.current=null};document.addEventListener("mousemove",F),document.addEventListener("mouseup",U),A.current=()=>{k.current=!1,document.removeEventListener("mousemove",F),document.removeEventListener("mouseup",U)}},[u,h]);return{height:g,containerRef:p,onDragStart:_}}const TX=28,rvn=50,t4t=10;function svn({data:l,onClose:s,onCellClick:u,tracedCell:h}){const[g,w]=pe.useState(!1),[p,k]=pe.useState(""),{height:j,containerRef:A,onDragStart:_}=BSt({initialHeight:256,minHeight:120,maxHeight:600}),D=l==null?void 0:l.nodeId;pe.useEffect(()=>{k("")},[D]);const I=pe.useMemo(()=>{if(!l||!p.trim())return(l==null?void 0:l.columns)??[];const ce=p.toLowerCase();return l.columns.filter(fe=>fe.name.toLowerCase().includes(ce))},[l,p]),B=pe.useRef(null),[F,U]=pe.useState(0),[K,Y]=pe.useState(0),Z=pe.useRef(0),ee=pe.useCallback(()=>{cancelAnimationFrame(Z.current),Z.current=requestAnimationFrame(()=>{B.current&&U(B.current.scrollTop)})},[]);return pe.useEffect(()=>{const ce=B.current;if(!ce)return;const fe=new ResizeObserver(([be])=>{Y(be.contentRect.height)});return fe.observe(ce),()=>fe.disconnect()},[l]),pe.useEffect(()=>{const ce=Z;return()=>cancelAnimationFrame(ce.current)},[]),l?g?E.jsx("div",{className:"h-8 flex items-center px-4 shrink-0",style:{borderTop:"1px solid var(--border)",background:"var(--bg-panel)"},children:E.jsxs("button",{onClick:()=>w(!1),className:"flex items-center gap-2 text-xs",style:{color:"var(--text-secondary)"},children:[E.jsx(Y5t,{size:14}),E.jsx(Xfe,{size:14}),E.jsx("span",{className:"font-medium",children:l.nodeLabel}),l.status==="ok"&&E.jsxs("span",{style:{color:"var(--text-muted)"},children:[l.row_count.toLocaleString()," rows · ",l.column_count," cols"]})]})}):E.jsxs("div",{ref:A,style:{height:j,borderTop:"1px solid var(--border)",background:"var(--bg-panel)"},className:"flex flex-col shrink-0 relative",children:[E.jsx("div",{onMouseDown:_,className:"absolute top-0 left-0 right-0 h-1 cursor-ns-resize z-10 transition-colors",style:{background:"var(--chrome-border)"},onMouseEnter:ce=>ce.currentTarget.style.background="var(--accent)",onMouseLeave:ce=>ce.currentTarget.style.background="var(--chrome-border)"}),E.jsxs("div",{className:"h-9 flex items-center px-4 shrink-0 gap-2",style:{borderBottom:"1px solid var(--border)",background:"var(--bg-elevated)"},children:[E.jsx(Xfe,{size:14,style:{color:"var(--text-muted)"}}),E.jsx("span",{className:"text-xs font-bold",style:{color:"var(--text-primary)"},children:l.nodeLabel}),l.status==="ok"&&E.jsxs(E.Fragment,{children:[E.jsx(Z5t,{size:13,className:"ml-1",style:{color:"#22c55e"}}),E.jsxs("span",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:[l.row_count.toLocaleString()," rows · ",l.column_count," cols"]})]}),l.status==="error"&&E.jsxs(E.Fragment,{children:[E.jsx(TCe,{size:13,className:"ml-1",style:{color:"#ef4444"}}),E.jsx("span",{className:"text-[11px] truncate",style:{color:"#ef4444"},children:l.error})]}),l.status==="loading"&&E.jsx("span",{className:"text-[11px] animate-pulse",style:{color:"var(--text-muted)"},children:"Running..."}),E.jsxs("div",{className:"ml-auto flex items-center gap-1.5",children:[E.jsxs("div",{className:"flex items-center gap-1 px-1.5 py-0.5 rounded-md",style:{background:"var(--chrome-hover)",border:"1px solid var(--chrome-border)"},children:[E.jsx(Jan,{size:11,style:{color:"var(--text-muted)"}}),E.jsx("input",{type:"text",value:p,onChange:ce=>k(ce.target.value),placeholder:"Search columns...",className:"w-28 text-[11px] font-mono bg-transparent focus:outline-none",style:{color:"var(--text-primary)"}}),p&&E.jsx("button",{onClick:()=>k(""),className:"shrink-0",style:{color:"var(--text-muted)"},children:E.jsx(jp,{size:10})})]}),E.jsx("button",{onClick:()=>w(!0),className:"p-1 rounded transition-colors",style:{color:"var(--text-muted)"},onMouseEnter:ce=>ce.currentTarget.style.background="var(--bg-hover)",onMouseLeave:ce=>ce.currentTarget.style.background="transparent",children:E.jsx(Vw,{size:14})}),E.jsx("button",{onClick:s,className:"p-1 rounded transition-colors",style:{color:"var(--text-muted)"},onMouseEnter:ce=>ce.currentTarget.style.background="var(--bg-hover)",onMouseLeave:ce=>ce.currentTarget.style.background="transparent",children:E.jsx(jp,{size:14})})]})]}),l.status==="loading"?E.jsx("div",{className:"flex-1 flex items-center justify-center",children:E.jsx("div",{className:"text-xs animate-pulse",style:{color:"var(--text-muted)"},children:"Executing pipeline..."})}):l.status==="error"?E.jsx("div",{className:"flex-1 flex items-center justify-center p-4",children:E.jsxs("div",{className:"text-center",children:[E.jsx(TCe,{size:24,className:"mx-auto mb-2",style:{color:"#ef4444",opacity:.5}}),E.jsx("div",{className:"text-xs max-w-md",style:{color:"#ef4444"},children:l.error})]})}):E.jsxs("div",{ref:B,className:"flex-1 overflow-auto",onScroll:ee,children:[(()=>{const ce=l.preview.length,fe=ce>rvn&&K>0;let be=0,me=ce;fe&&(be=Math.max(0,Math.floor(F/TX)-t4t),me=Math.min(ce,Math.ceil((F+K)/TX)+t4t));const Re=be*TX,Te=(ce-me)*TX;return E.jsxs("table",{className:"w-full text-xs",children:[E.jsx("thead",{className:"sticky top-0 z-10",style:{background:"var(--bg-elevated)"},children:E.jsxs("tr",{children:[E.jsx("th",{className:"px-3 py-1.5 text-left text-[11px] font-semibold uppercase tracking-wider w-10",style:{color:"var(--text-muted)",borderBottom:"1px solid var(--border)"},children:"#"}),I.map(Ke=>E.jsxs("th",{className:"px-3 py-1.5 text-left whitespace-nowrap",style:{borderBottom:"1px solid var(--border)"},children:[E.jsx("div",{className:"font-semibold",style:{color:"var(--text-primary)"},children:Ke.name}),E.jsx("div",{className:`text-[11px] font-normal ${GMe(Ke.dtype)}`,children:Ke.dtype})]},Ke.name))]})}),E.jsxs("tbody",{children:[Re>0&&E.jsx("tr",{style:{height:Re}}),l.preview.slice(be,me).map((Ke,ze)=>{const je=be+ze;return E.jsxs("tr",{style:{height:TX,background:je%2===0?"transparent":"rgba(255,255,255,.02)"},children:[E.jsx("td",{className:"px-3 py-1 font-mono",style:{color:"var(--text-muted)",borderRight:"1px solid var(--border)"},children:je+1}),I.map(te=>{const ge=(h==null?void 0:h.rowIndex)===je&&(h==null?void 0:h.column)===te.name;return E.jsx("td",{className:"px-3 py-1 font-mono whitespace-nowrap max-w-[200px] truncate transition-colors",style:{color:"var(--text-secondary)",cursor:u?"pointer":void 0,background:ge?"var(--accent-soft)":void 0,boxShadow:ge?"inset 0 0 0 1.5px var(--accent)":void 0,borderRadius:ge?"3px":void 0},onClick:()=>u==null?void 0:u(je,te.name),children:E.jsx("span",{style:Ke[te.name]===null?{color:"var(--text-muted)",fontStyle:"italic"}:void 0,children:HMe(Ke[te.name])})},te.name)})]},je)}),Te>0&&E.jsx("tr",{style:{height:Te}})]})]})})(),l.row_count>l.preview.length&&E.jsxs("div",{className:"px-3 py-1.5 text-[11px] text-center",style:{color:"var(--text-muted)",borderTop:"1px solid var(--border)",background:"var(--bg-elevated)"},children:["Showing ",l.preview.length," of ",l.row_count.toLocaleString()," rows"]})]})]}):null}function ovn({data:l,onClose:s}){const{result:u,jobId:h,constraints:g}=l,[w,p]=pe.useState(!1),{height:k,containerRef:j,onDragStart:A}=BSt({initialHeight:320,minHeight:160,maxHeight:600}),[_,D]=pe.useState("summary"),[I,B]=pe.useState(null),[F,U]=pe.useState(!1),[K,Y]=pe.useState(null),[Z,ee]=pe.useState(null),ce=pe.useCallback(async()=>{U(!0),Y(null),B(null),ee(null);try{const fe={};for(const me of Object.keys(g)){const Re=u.baseline_constraints[me];Re!=null&&(fe[me]=[Re*.85,Re*1.05])}const be=await Ffn({job_id:h,threshold_ranges:fe,n_points_per_dim:5});B(be.points)}catch(fe){Y(String(fe))}finally{U(!1)}},[h,u,g]);return w?E.jsx("div",{className:"h-8 flex items-center px-4 shrink-0",style:{borderTop:"1px solid var(--border)",background:"var(--bg-panel)"},children:E.jsxs("button",{onClick:()=>p(!1),className:"flex items-center gap-2 text-xs",style:{color:"var(--text-secondary)"},children:[E.jsx(Y5t,{size:14}),E.jsx(PX,{size:14}),E.jsx("span",{className:"font-medium",children:l.nodeLabel}),E.jsxs("span",{style:{color:"var(--text-muted)"},children:[u.converged?"Converged":"Not converged"," — ","Objective: ",yX(u.total_objective)]})]})}):E.jsxs("div",{ref:j,style:{height:k,borderTop:"1px solid var(--border)",background:"var(--bg-panel)"},className:"flex flex-col shrink-0 relative",children:[E.jsx("div",{onMouseDown:A,className:"absolute top-0 left-0 right-0 h-1 cursor-ns-resize z-10 transition-colors",style:{background:"var(--chrome-border)"},onMouseEnter:fe=>{fe.currentTarget.style.background="var(--accent)"},onMouseLeave:fe=>{fe.currentTarget.style.background="var(--chrome-border)"}}),E.jsxs("div",{className:"h-9 flex items-center px-4 shrink-0 gap-2",style:{borderBottom:"1px solid var(--border)",background:"var(--bg-elevated)"},children:[E.jsx(PX,{size:14,style:{color:"#f97316"}}),E.jsx("span",{className:"text-xs font-bold",style:{color:"var(--text-primary)"},children:l.nodeLabel}),E.jsxs("span",{className:"text-[11px]",style:{color:u.converged?"#22c55e":"#f59e0b"},children:[u.converged?"Converged":"Not converged",u.mode==="ratebook"?` · ${u.cd_iterations??"?"} CD iters`:` · ${u.iterations??"?"} iters`,u.n_quotes!=null&&E.jsxs(E.Fragment,{children:[" · ",u.n_quotes.toLocaleString()," quotes"]})]}),E.jsx("div",{className:"flex gap-1 ml-3",children:["summary","frontier","convergence"].filter(fe=>fe!=="convergence"||u.history).map(fe=>E.jsx("button",{onClick:()=>D(fe),className:"px-2 py-0.5 rounded text-[10px] font-medium",style:{background:_===fe?"var(--accent-soft)":"var(--chrome-hover)",color:_===fe?"var(--accent)":"var(--text-muted)"},children:fe==="summary"?"Summary":fe==="frontier"?"Frontier":"Convergence"},fe))}),E.jsxs("div",{className:"ml-auto flex items-center gap-1",children:[E.jsx("button",{onClick:()=>p(!0),className:"p-1 rounded transition-colors",style:{color:"var(--text-muted)"},onMouseEnter:fe=>{fe.currentTarget.style.background="var(--bg-hover)"},onMouseLeave:fe=>{fe.currentTarget.style.background="transparent"},children:E.jsx(Vw,{size:14})}),E.jsx("button",{onClick:s,className:"p-1 rounded transition-colors",style:{color:"var(--text-muted)"},onMouseEnter:fe=>{fe.currentTarget.style.background="var(--bg-hover)"},onMouseLeave:fe=>{fe.currentTarget.style.background="transparent"},children:E.jsx(jp,{size:14})})]})]}),E.jsxs("div",{className:"flex-1 overflow-auto px-4 py-3",children:[_==="summary"&&E.jsxs("div",{className:"flex gap-6 flex-wrap",children:[E.jsxs("div",{className:"space-y-3 min-w-[200px]",children:[E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Objective"}),E.jsxs("div",{className:"mt-1 space-y-0.5",children:[E.jsxs("div",{className:"flex justify-between text-xs font-mono gap-4",children:[E.jsx("span",{style:{color:"var(--text-secondary)"},children:"Optimised"}),E.jsx("span",{style:{color:"var(--text-primary)"},children:yX(u.total_objective)})]}),E.jsxs("div",{className:"flex justify-between text-xs font-mono gap-4",children:[E.jsx("span",{style:{color:"var(--text-secondary)"},children:"Baseline"}),E.jsx("span",{style:{color:"var(--text-muted)"},children:yX(u.baseline_objective)})]}),u.baseline_objective!==0&&E.jsxs("div",{className:"flex justify-between text-xs font-mono gap-4",children:[E.jsx("span",{style:{color:"var(--text-secondary)"},children:"Uplift"}),E.jsxs("span",{style:{color:"#f97316"},children:[((u.total_objective/u.baseline_objective-1)*100).toFixed(2),"%"]})]})]})]}),Object.keys(u.constraints).length>0&&E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Constraints"}),E.jsx("div",{className:"mt-1 space-y-0.5",children:Object.entries(u.constraints).map(([fe,be])=>{const me=u.baseline_constraints[fe],Re=me?be/me:0,Te=g[fe]||{},Ke=Object.keys(Te)[0],ze=Te[Ke]??0,je=Ke==="min"?Re>=ze:Ke==="max"?Re<=ze:Ke==="min_abs"?be>=ze:Ke==="max_abs"?be<=ze:!0;return E.jsxs("div",{className:"flex items-center justify-between text-xs font-mono gap-4",children:[E.jsxs("span",{className:"flex items-center gap-1.5",children:[E.jsx("span",{className:"inline-block w-1.5 h-1.5 rounded-full shrink-0",style:{background:je?"#22c55e":"#ef4444"}}),E.jsx("span",{style:{color:"var(--text-secondary)"},children:fe})]}),E.jsxs("span",{children:[E.jsx("span",{style:{color:"var(--text-primary)"},children:yX(be)}),me!==void 0&&E.jsxs("span",{style:{color:"var(--text-muted)"},children:[" (",(Re*100).toFixed(1),"%)"]})]})]},fe)})})]}),u.mode!=="ratebook"&&Object.keys(u.lambdas).length>0&&E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Lambdas"}),E.jsx("div",{className:"mt-1 space-y-0.5",children:Object.entries(u.lambdas).map(([fe,be])=>E.jsxs("div",{className:"flex justify-between text-xs font-mono gap-4",children:[E.jsx("span",{style:{color:"var(--text-secondary)"},children:fe}),E.jsx("span",{style:{color:"var(--text-primary)"},children:be.toFixed(6)})]},fe))})]}),u.mode==="ratebook"&&u.clamp_rate!=null&&E.jsxs("div",{className:"flex justify-between text-xs font-mono",children:[E.jsx("span",{style:{color:"var(--text-muted)"},children:"Clamp rate"}),E.jsxs("span",{style:{color:"#f59e0b"},children:[(u.clamp_rate*100).toFixed(1),"%"]})]})]}),u.scenario_value_histogram&&(()=>{const{counts:fe,edges:be}=u.scenario_value_histogram;if(!fe||fe.length===0)return null;const me=Math.max(...fe),Re=320,Te=100,Ke=2,ze=2,je=Re-Ke*2,te=Te-ze*2,ge=je/fe.length,He=be[0],ae=be[be.length-1],Le=ae>He?Ke+(1-He)/(ae-He)*je:null;return E.jsxs("div",{className:"min-w-[200px]",children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Scenario Value Distribution"}),E.jsxs("svg",{width:Re,height:Te,className:"mt-1",style:{background:"var(--input-bg)",borderRadius:6,border:"1px solid var(--border)"},children:[fe.map((Oe,Qe)=>{const kt=me>0?Oe/me*te:0;return E.jsx("rect",{x:Ke+Qe*ge+.5,y:ze+te-kt,width:Math.max(ge-1,1),height:kt,fill:"#f97316",opacity:.7},Qe)}),Le!=null&&Le>=Ke&&Le<=Ke+je&&E.jsx("line",{x1:Le,y1:ze,x2:Le,y2:ze+te,stroke:"#ef4444",strokeWidth:1,strokeDasharray:"3,2"})]}),E.jsxs("div",{className:"flex gap-3 mt-0.5 text-[10px]",style:{color:"var(--text-muted)"},children:[E.jsx("span",{children:He.toFixed(2)}),E.jsx("span",{className:"flex-1"}),Le!=null&&E.jsxs("span",{children:[E.jsx("span",{style:{color:"#ef4444"},children:"|"})," 1.0"]}),E.jsx("span",{className:"flex-1"}),E.jsx("span",{children:ae.toFixed(2)})]}),u.scenario_value_stats&&E.jsxs("div",{className:"mt-2 grid grid-cols-2 gap-x-6 gap-y-0.5 text-xs font-mono",children:[E.jsxs("div",{className:"flex justify-between",children:[E.jsx("span",{style:{color:"var(--text-muted)"},children:"Mean"}),E.jsx("span",{style:{color:"var(--text-primary)"},children:u.scenario_value_stats.mean.toFixed(4)})]}),E.jsxs("div",{className:"flex justify-between",children:[E.jsx("span",{style:{color:"var(--text-muted)"},children:"Std"}),E.jsx("span",{style:{color:"var(--text-primary)"},children:u.scenario_value_stats.std.toFixed(4)})]}),E.jsxs("div",{className:"flex justify-between",children:[E.jsx("span",{style:{color:"var(--text-muted)"},children:"P5–P95"}),E.jsxs("span",{style:{color:"var(--text-primary)"},children:[u.scenario_value_stats.p5.toFixed(3),"–",u.scenario_value_stats.p95.toFixed(3)]})]}),E.jsxs("div",{className:"flex justify-between",children:[E.jsx("span",{style:{color:"var(--text-muted)"},children:"Min–Max"}),E.jsxs("span",{style:{color:"var(--text-primary)"},children:[u.scenario_value_stats.min.toFixed(3),"–",u.scenario_value_stats.max.toFixed(3)]})]}),E.jsxs("div",{className:"flex justify-between",children:[E.jsx("span",{style:{color:"#22c55e"},children:"Increase"}),E.jsxs("span",{style:{color:"#22c55e"},children:[(u.scenario_value_stats.pct_increase*100).toFixed(1),"%"]})]}),E.jsxs("div",{className:"flex justify-between",children:[E.jsx("span",{style:{color:"#ef4444"},children:"Decrease"}),E.jsxs("span",{style:{color:"#ef4444"},children:[(u.scenario_value_stats.pct_decrease*100).toFixed(1),"%"]})]})]})]})})(),u.mode==="ratebook"&&u.factor_tables&&E.jsxs("div",{className:"min-w-[180px]",children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Factor Tables"}),Object.entries(u.factor_tables).map(([fe,be])=>E.jsxs("div",{className:"mt-1.5",children:[E.jsx("div",{className:"text-[11px] font-medium mb-1",style:{color:"var(--text-secondary)"},children:fe}),E.jsx("div",{className:"space-y-0.5",children:be.map((me,Re)=>{const Te=me.__factor_group__??me[Object.keys(me)[0]]??`Level ${Re}`,Ke=me.optimal_scenario_value;return E.jsxs("div",{className:"flex justify-between text-xs font-mono gap-4",children:[E.jsx("span",{style:{color:"var(--text-secondary)"},children:Te}),E.jsx("span",{style:{color:"var(--text-primary)"},children:typeof Ke=="number"?Ke.toFixed(2):"?"})]},Re)})})]},fe))]})]}),_==="frontier"&&E.jsxs("div",{className:"flex gap-6 flex-wrap",children:[E.jsxs("div",{className:"space-y-2",children:[E.jsxs("button",{onClick:ce,disabled:F,className:"flex items-center justify-center gap-2 px-3 py-1.5 rounded-lg text-xs font-medium transition-colors",style:{background:F?"var(--chrome-hover)":"rgba(168,85,247,.15)",color:F?"var(--text-muted)":"#a855f7",border:"1px solid rgba(168,85,247,.3)"},children:[F?E.jsx(Ey,{size:14,className:"animate-spin"}):E.jsx(PX,{size:14}),F?"Computing...":"Run Efficient Frontier"]}),K&&E.jsx("div",{className:"px-3 py-2 rounded-lg text-xs",style:{background:"rgba(239,68,68,.08)",border:"1px solid rgba(239,68,68,.2)",color:"#fca5a5"},children:K}),I&&I.length>0&&(()=>{const ze=Object.keys(g),je=ze.length>0?`total_${ze[0]}`:null,te="total_objective";if(!je)return null;const ge=I.map(rn=>rn[je]).filter(rn=>rn!=null),He=I.map(rn=>rn[te]).filter(rn=>rn!=null);if(ge.length<2)return null;const ae=Math.min(...ge),Le=Math.max(...ge),Oe=Math.min(...He),Qe=Math.max(...He),kt=Le-ae||1,Ae=Qe-Oe||1,Ye=rn=>35+(rn-ae)/kt*355,mt=rn=>176-(rn-Oe)/Ae*164,Pt=[...I].filter(rn=>rn[je]!=null&&rn[te]!=null).sort((rn,Cn)=>rn[je]-Cn[je]).map((rn,Cn)=>`${Cn===0?"M":"L"}${Ye(rn[je]).toFixed(1)},${mt(rn[te]).toFixed(1)}`).join(" ");return E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Efficient Frontier"}),E.jsxs("svg",{width:400,height:200,className:"mt-1",style:{background:"var(--input-bg)",borderRadius:6,border:"1px solid var(--border)"},children:[E.jsx("text",{x:35+355/2,y:199,textAnchor:"middle",fontSize:9,fill:"var(--text-muted)",children:ze[0]}),E.jsx("text",{x:4,y:12+164/2,textAnchor:"middle",fontSize:9,fill:"var(--text-muted)",transform:`rotate(-90,4,${12+164/2})`,children:"objective"}),E.jsx("path",{d:Pt,fill:"none",stroke:"#a855f7",strokeWidth:1.5,opacity:.6}),I.map((rn,Cn)=>{const Pn=Ye(rn[je]),mi=mt(rn[te]),er=Z===Cn;return E.jsx("circle",{cx:Pn,cy:mi,r:er?5:3.5,fill:er?"#f97316":"#a855f7",stroke:er?"#fff":"none",strokeWidth:1.5,style:{cursor:"pointer"},onClick:()=>ee(er?null:Cn)},Cn)})]}),E.jsxs("div",{className:"text-[10px] mt-0.5",style:{color:"var(--text-muted)"},children:[I.length," points. Click a point for details."]})]})})(),I&&I.length===0&&E.jsx("div",{className:"text-[11px] py-2",style:{color:"var(--text-muted)"},children:"No frontier points returned."})]}),I&&Z!=null&&I[Z]&&E.jsxs("div",{className:"min-w-[200px]",children:[E.jsxs("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:["Point ",Z+1]}),E.jsx("div",{className:"mt-1 space-y-0.5",children:Object.entries(I[Z]).map(([fe,be])=>E.jsxs("div",{className:"flex justify-between text-xs font-mono gap-4",children:[E.jsx("span",{style:{color:"var(--text-muted)"},children:fe}),E.jsx("span",{style:{color:"var(--text-primary)"},children:typeof be=="number"?be.toFixed(4):String(be)})]},fe))})]})]}),_==="convergence"&&u.history&&u.history.length>0&&(()=>{const fe=u.history,be=400,me=140,Re=6,Te=6,Ke=be-Re*2,ze=me-Te*2,je=fe.map(Pt=>Pt.total_objective),te=fe.map(Pt=>Pt.max_lambda_change),ge=Math.min(...je),He=Math.max(...je),ae=Math.min(...te),Le=Math.max(...te),Oe=He-ge||1,Qe=Le-ae||1,kt=Pt=>Re+Pt/Math.max(fe.length-1,1)*Ke,Ae=Pt=>Te+ze-(Pt-ge)/Oe*ze,Ye=Pt=>Te+ze-(Pt-ae)/Qe*ze,mt=fe.map((Pt,rn)=>`${rn===0?"M":"L"}${kt(rn).toFixed(1)},${Ae(Pt.total_objective).toFixed(1)}`).join(" "),Ue=fe.map((Pt,rn)=>`${rn===0?"M":"L"}${kt(rn).toFixed(1)},${Ye(Pt.max_lambda_change).toFixed(1)}`).join(" ");return E.jsxs("div",{className:"flex gap-6 flex-wrap",children:[E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Convergence"}),E.jsxs("svg",{width:be,height:me,className:"mt-1",style:{background:"var(--input-bg)",borderRadius:6,border:"1px solid var(--border)"},children:[E.jsx("path",{d:mt,fill:"none",stroke:"#f97316",strokeWidth:1.5}),E.jsx("path",{d:Ue,fill:"none",stroke:"#3b82f6",strokeWidth:1.5})]}),E.jsxs("div",{className:"flex gap-3 mt-0.5 text-[10px]",style:{color:"var(--text-muted)"},children:[E.jsxs("span",{children:[E.jsx("span",{style:{color:"#f97316"},children:"--"})," Objective"]}),E.jsxs("span",{children:[E.jsx("span",{style:{color:"#3b82f6"},children:"--"})," Lambda change"]})]})]}),E.jsxs("div",{className:"min-w-[280px]",children:[E.jsx("label",{className:"text-[11px] font-bold uppercase tracking-[0.08em]",style:{color:"var(--text-muted)"},children:"Iterations"}),E.jsxs("div",{className:"mt-1 max-h-48 overflow-y-auto",children:[E.jsxs("div",{className:"flex text-[10px] font-bold py-0.5 sticky top-0",style:{color:"var(--text-muted)",background:"var(--bg-panel)"},children:[E.jsx("span",{className:"w-8 text-center",children:"#"}),E.jsx("span",{className:"flex-1 text-right",children:"Objective"}),E.jsx("span",{className:"flex-1 text-right",children:"Max dLambda"}),E.jsx("span",{className:"w-10 text-center",children:"OK"})]}),fe.map(Pt=>E.jsxs("div",{className:"flex text-[10px] font-mono py-0.5",style:{color:"var(--text-secondary)"},children:[E.jsx("span",{className:"w-8 text-center",children:Pt.iteration}),E.jsx("span",{className:"flex-1 text-right",children:yX(Pt.total_objective)}),E.jsx("span",{className:"flex-1 text-right",children:Pt.max_lambda_change.toExponential(2)}),E.jsx("span",{className:"w-10 text-center",children:Pt.all_constraints_satisfied?"Y":"N"})]},Pt.iteration))]})]})]})})()]})]})}const QX=l=>HMe(l,6);function cvn({step:l,index:s,tracedColumn:u}){const[h,g]=pe.useState(!1),w=Vfe[l.node_type]||"#06b6d4",p=akt[l.node_type]||"NODE",k=l.column_relevant,{columns_added:j,columns_modified:A,columns_removed:_}=l.schema_diff,D=[];if(u&&l.output_values[u]!==void 0){const F=j.includes(u)?"added":A.includes(u)?"modified":"value";D.push({col:u,val:l.output_values[u],tag:F})}else{for(const F of j.slice(0,2))D.push({col:F,val:l.output_values[F],tag:"added"});for(const F of A.slice(0,2))D.push({col:F,val:l.output_values[F],tag:"modified"})}const I={added:{bg:"rgba(34,197,94,.12)",color:"#4ade80",label:"+"},modified:{bg:"rgba(251,191,36,.12)",color:"#fbbf24",label:"~"},value:{bg:"rgba(255,255,255,.06)",color:"var(--text-secondary)",label:"="}},B=Object.keys(l.output_values);return E.jsxs("div",{className:"rounded-lg overflow-hidden transition-opacity",style:{border:k?`1px solid ${w}40`:"1px solid var(--border)",background:"var(--bg-elevated)",opacity:k?1:.55},children:[E.jsxs("button",{onClick:()=>g(!h),className:"w-full flex items-center gap-2 px-3 py-2 text-left transition-colors",style:{background:"transparent"},onMouseEnter:F=>F.currentTarget.style.background="var(--bg-hover)",onMouseLeave:F=>F.currentTarget.style.background="transparent",children:[h?E.jsx(Vw,{size:12,style:{color:"var(--text-muted)"}}):E.jsx(NI,{size:12,style:{color:"var(--text-muted)"}}),E.jsx("span",{className:"text-[11px] font-mono font-bold shrink-0",style:{color:"var(--text-muted)",minWidth:"1.2em"},children:s+1}),E.jsx("span",{className:"text-[13px] font-semibold truncate",style:{color:"var(--text-primary)"},children:l.node_name}),E.jsx("span",{className:"text-[9px] font-bold uppercase tracking-wider shrink-0 px-1.5 py-0.5 rounded",style:{color:w,background:`${w}15`},children:p}),E.jsxs("span",{className:"ml-auto text-[10px] font-mono shrink-0",style:{color:"var(--text-muted)"},children:[l.execution_ms.toFixed(1),"ms"]})]}),D.length>0&&!h&&E.jsx("div",{className:"px-3 pb-2 flex flex-wrap gap-1.5",style:{paddingLeft:"2.8rem"},children:D.map(({col:F,val:U,tag:K})=>{const Y=I[K];return E.jsxs("span",{className:"inline-flex items-center gap-1 px-1.5 py-0.5 rounded text-[11px] font-mono",style:{background:Y.bg,color:Y.color},children:[E.jsx("span",{className:"font-bold",children:Y.label}),F,": ",QX(U)]},F)})}),h&&E.jsxs("div",{className:"px-3 pb-3",style:{borderTop:"1px solid var(--border)"},children:[E.jsxs("div",{className:"flex flex-wrap gap-2 py-2 text-[10px]",children:[j.length>0&&E.jsxs("span",{style:{color:"#4ade80"},children:["+",j.length," added"]}),A.length>0&&E.jsxs("span",{style:{color:"#fbbf24"},children:["~",A.length," modified"]}),_.length>0&&E.jsxs("span",{style:{color:"#f87171"},children:["-",_.length," removed"]}),E.jsxs("span",{style:{color:"var(--text-muted)"},children:[l.schema_diff.columns_passed.length," passed through"]})]}),E.jsx("div",{className:"space-y-0.5",children:B.map(F=>{const U=j.includes(F),K=A.includes(F),Y=_.includes(F),Z=l.input_values[F],ee=l.output_values[F],ce=F===u;let fe="var(--text-secondary)",be="";return U?(fe="#4ade80",be="+"):K?(fe="#fbbf24",be="~"):Y&&(fe="#f87171",be="-"),E.jsxs("div",{className:"flex items-center gap-2 px-2 py-0.5 rounded text-[11px] font-mono",style:{background:ce?"var(--accent-soft)":"transparent",borderLeft:ce?"2px solid var(--accent)":"2px solid transparent"},children:[E.jsx("span",{className:"font-bold w-3",style:{color:fe},children:be}),E.jsx("span",{className:"truncate",style:{color:fe,minWidth:"6em",maxWidth:"10em"},children:F}),K&&Z!==void 0&&E.jsxs(E.Fragment,{children:[E.jsx("span",{style:{color:"var(--text-muted)"},children:QX(Z)}),E.jsx("span",{style:{color:"var(--text-muted)"},children:"→"})]}),E.jsx("span",{style:{color:U||K?fe:"var(--text-secondary)"},children:QX(ee)})]},F)})})]})]})}function lvn({trace:l,onClose:s}){return E.jsxs($V,{children:[E.jsxs("div",{className:"px-4 py-3 flex items-center gap-2 shrink-0",style:{borderBottom:"1px solid var(--border)"},children:[E.jsx(Gan,{size:14,style:{color:"var(--accent)"}}),E.jsxs("div",{className:"flex-1 min-w-0",children:[E.jsxs("div",{className:"text-xs font-bold",style:{color:"var(--text-primary)"},children:["Trace",l.column?`: ${l.column}`:""]}),E.jsxs("div",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:[l.row_id_column&&l.row_id_value!=null?E.jsxs(E.Fragment,{children:[E.jsx("span",{className:"font-mono",children:l.row_id_column})," = ",E.jsx("span",{className:"font-mono font-medium",style:{color:"var(--text-secondary)"},children:QX(l.row_id_value)})]}):E.jsxs(E.Fragment,{children:["Row ",l.row_index]})," ","· ",l.nodes_in_trace," of ",l.total_nodes_in_pipeline," nodes"]})]}),E.jsx("button",{onClick:s,className:"p-1 rounded transition-colors",style:{color:"var(--text-muted)"},onMouseEnter:u=>u.currentTarget.style.background="var(--bg-hover)",onMouseLeave:u=>u.currentTarget.style.background="transparent",children:E.jsx(jp,{size:14})})]}),E.jsxs("div",{className:"px-4 py-2 shrink-0",style:{borderBottom:"1px solid var(--border)",background:"var(--bg-elevated)"},children:[E.jsxs("div",{className:"flex items-center gap-2",children:[E.jsx("span",{className:"text-[11px] font-medium",style:{color:"var(--text-muted)"},children:"Result"}),E.jsx("span",{className:"px-2 py-0.5 rounded text-[13px] font-mono font-bold",style:{background:"var(--accent-soft)",color:"var(--accent)"},children:QX(l.output_value)})]}),E.jsxs("div",{className:"flex items-center gap-3 mt-1.5 text-[10px]",style:{color:"var(--text-muted)"},children:[E.jsxs("span",{className:"inline-flex items-center gap-1",children:[E.jsx(ekt,{size:10}),l.execution_ms.toFixed(1),"ms"]}),E.jsxs("span",{className:"inline-flex items-center gap-1",children:[E.jsx(okt,{size:10}),l.steps.length," steps"]})]})]}),E.jsx("div",{className:"flex-1 overflow-y-auto p-3 space-y-2",children:l.steps.map((u,h)=>E.jsx(cvn,{step:u,index:h,tracedColumn:l.column},u.node_id))})]})}const sO=Bhe()((l,s)=>({toasts:[],_toastCounter:0,addToast:(u,h)=>{const g=String(s()._toastCounter+1);l(w=>({_toastCounter:w._toastCounter+1,toasts:[...w.toasts,{id:g,type:u,text:h}]}))},dismissToast:u=>l(h=>({toasts:h.toasts.filter(g=>g.id!==u)}))})),uvn={success:Z5t,error:TCe,info:yan,warning:Oy},avn={success:"#22c55e",error:"#ef4444",info:"#6366f1",warning:"#f59e0b"};function fvn({toast:l,onDismiss:s}){const u=uvn[l.type],h=avn[l.type];return pe.useEffect(()=>{const g=setTimeout(()=>s(l.id),3e3);return()=>clearTimeout(g)},[l.id,s]),E.jsxs("div",{role:"alert",className:"px-4 py-2.5 rounded-lg shadow-xl flex items-center gap-2.5 text-[12px] font-medium animate-slide-in min-w-[240px] max-w-[380px]",style:{background:"var(--bg-panel)",color:"var(--text-primary)",border:"1px solid var(--border-bright)"},children:[E.jsx(u,{size:14,style:{color:h},className:"shrink-0"}),E.jsx("span",{className:"flex-1",style:{color:"var(--text-primary)"},children:l.text}),E.jsx("button",{onClick:()=>s(l.id),"aria-label":"Dismiss notification",className:"p-0.5 rounded shrink-0 transition-colors",style:{color:"var(--text-muted)"},onMouseEnter:g=>{g.currentTarget.style.background="var(--bg-hover)"},onMouseLeave:g=>{g.currentTarget.style.background="transparent"},children:E.jsx(jp,{size:12})})]})}function hvn(){const l=sO(u=>u.toasts),s=sO(u=>u.dismissToast);return l.length===0?null:E.jsx("div",{className:"fixed bottom-4 right-4 z-50 flex flex-col gap-2 items-end","aria-live":"polite",children:l.map(u=>E.jsx(fvn,{toast:u,onDismiss:s},u.id))})}class EX extends pe.Component{constructor(s){super(s),this.state={hasError:!1,error:null}}static getDerivedStateFromError(s){return{hasError:!0,error:s}}componentDidCatch(s,u){console.error(`[ErrorBoundary${this.props.name?`: ${this.props.name}`:""}]`,s,u.componentStack)}render(){var s;return this.state.hasError?this.props.fallback?this.props.fallback:E.jsxs("div",{style:{padding:"16px",background:"var(--bg-secondary, #1e1e2e)",border:"1px solid var(--border, #333)",borderRadius:"8px",color:"var(--text-secondary, #999)",fontSize:"12px"},children:[E.jsx("p",{style:{margin:"0 0 8px",fontWeight:600,color:"var(--text-primary, #ccc)"},children:"Something went wrong"}),E.jsx("p",{style:{margin:"0 0 12px",fontFamily:"monospace",fontSize:"11px"},children:(s=this.state.error)==null?void 0:s.message}),E.jsx("button",{onClick:()=>this.setState({hasError:!1,error:null}),style:{padding:"4px 12px",fontSize:"11px",background:"var(--bg-input, #2a2a3e)",border:"1px solid var(--border, #333)",borderRadius:"4px",color:"var(--text-primary, #ccc)",cursor:"pointer"},children:"Try again"})]}):this.props.children}}function dvn({x:l,y:s,nodeLabel:u,onClose:h,onDelete:g,onDuplicate:w,onRename:p,onCreateInstance:k,onDissolveSubmodel:j,isSubmodel:A,nodeId:_}){const D=pe.useRef(null),[I,B]=pe.useState(0),F=pe.useRef([]),U=pe.useMemo(()=>{const K=[{label:"Rename",icon:ofn,action:()=>p(_)},{label:"Duplicate",icon:Kun,action:()=>w(_)}];if(k&&!A&&K.push({label:"Create Instance",icon:zMe,action:()=>k(_)}),A&&j){const Y=_.replace("submodel__","");K.push({label:"Dissolve Submodel",icon:afn,action:()=>j(Y),danger:!0})}return K.push({label:"Delete",icon:BI,action:()=>g(_),danger:!0}),K},[_,A,p,w,g,k,j]);return pe.useEffect(()=>{const K=Y=>{D.current&&!D.current.contains(Y.target)&&h()};return document.addEventListener("mousedown",K),()=>document.removeEventListener("mousedown",K)},[h]),pe.useEffect(()=>{var K;(K=F.current[0])==null||K.focus()},[]),pe.useEffect(()=>{const K=Y=>{if(Y.key==="Escape"){h();return}if(Y.key==="ArrowDown"){Y.preventDefault(),B(Z=>{var ce;const ee=(Z+1)%U.length;return(ce=F.current[ee])==null||ce.focus(),ee});return}Y.key==="ArrowUp"&&(Y.preventDefault(),B(Z=>{var ce;const ee=(Z-1+U.length)%U.length;return(ce=F.current[ee])==null||ce.focus(),ee}))};return document.addEventListener("keydown",K),()=>document.removeEventListener("keydown",K)},[h,U.length]),E.jsxs("div",{ref:D,role:"menu","aria-label":`Actions for ${u}`,className:"fixed z-50 rounded-lg shadow-2xl py-1 min-w-[160px] animate-fade-in",style:{left:l,top:s,background:"var(--bg-panel)",border:"1px solid var(--border-bright)"},children:[E.jsx("div",{className:"px-3 py-1.5 text-[9px] font-bold uppercase tracking-[0.1em] mb-0.5",style:{color:"var(--text-muted)",borderBottom:"1px solid var(--border)"},children:u}),U.map((K,Y)=>{const Z=K.icon;return E.jsxs("button",{ref:ee=>{F.current[Y]=ee},role:"menuitem",tabIndex:Y===I?0:-1,onClick:()=>{K.action(),h()},className:"w-full flex items-center gap-2.5 px-3 py-1.5 text-[12px] transition-colors",style:{color:K.danger?"#ef4444":"var(--text-secondary)"},onMouseEnter:ee=>{ee.currentTarget.style.background=K.danger?"rgba(239,68,68,.1)":"var(--chrome-hover)",K.danger||(ee.currentTarget.style.color="var(--text-primary)")},onMouseLeave:ee=>{ee.currentTarget.style.background="transparent",ee.currentTarget.style.color=K.danger?"#ef4444":"var(--text-secondary)"},children:[E.jsx(Z,{size:13,"aria-hidden":"true"}),K.label]},K.label)})]})}const gvn=typeof navigator<"u"&&/Mac/.test(navigator.userAgent),iM=gvn?"⌘":"Ctrl",pvn=[{keys:`${iM}+Z`,label:"Undo"},{keys:`${iM}+Shift+Z`,label:"Redo"},{keys:`${iM}+C`,label:"Copy selected nodes"},{keys:`${iM}+V`,label:"Paste nodes"},{keys:`${iM}+A`,label:"Select all nodes"},{keys:`${iM}+S`,label:"Save pipeline"},{keys:`${iM}+1`,label:"Fit view"},{keys:"Delete / Backspace",label:"Delete selected"},{keys:"?",label:"Show this help"}];function bvn({onClose:l}){return pe.useEffect(()=>{const s=u=>{(u.key==="Escape"||u.key==="?")&&(u.preventDefault(),l())};return window.addEventListener("keydown",s),()=>window.removeEventListener("keydown",s)},[l]),E.jsx("div",{className:"fixed inset-0 z-50 flex items-center justify-center",role:"dialog","aria-modal":"true","aria-label":"Keyboard shortcuts",style:{background:"rgba(0,0,0,.5)"},onClick:s=>{s.target===s.currentTarget&&l()},children:E.jsxs("div",{className:"w-[360px] rounded-xl overflow-hidden shadow-2xl",style:{background:"var(--bg-panel)",border:"1px solid var(--border)"},children:[E.jsxs("div",{className:"px-4 py-3 flex items-center justify-between",style:{borderBottom:"1px solid var(--border)"},children:[E.jsx("h2",{className:"text-sm font-semibold",style:{color:"var(--text-primary)"},children:"Keyboard Shortcuts"}),E.jsx("button",{onClick:l,"aria-label":"Close keyboard shortcuts",className:"p-1 rounded transition-colors",style:{color:"var(--text-muted)"},onMouseEnter:s=>s.currentTarget.style.background="var(--bg-hover)",onMouseLeave:s=>s.currentTarget.style.background="transparent",children:"✕"})]}),E.jsx("div",{className:"px-4 py-3 space-y-1.5",children:pvn.map(s=>E.jsxs("div",{className:"flex items-center justify-between py-1",children:[E.jsx("span",{className:"text-[12px]",style:{color:"var(--text-secondary)"},children:s.label}),E.jsx("kbd",{className:"text-[11px] font-mono px-2 py-0.5 rounded",style:{background:"var(--bg-input)",border:"1px solid var(--border)",color:"var(--text-muted)"},children:s.keys})]},s.keys))})]})})}function mvn({viewStack:l,onNavigate:s}){return l.length<=1?null:E.jsx("div",{className:"absolute top-2 left-1/2 -translate-x-1/2 z-10 flex items-center gap-1 px-3 py-1.5 rounded-lg",style:{background:"var(--chrome)",border:"1px solid var(--chrome-border)",boxShadow:"0 2px 8px rgba(0,0,0,.3)"},children:l.map((u,h)=>E.jsxs("span",{className:"flex items-center gap-1",children:[h>0&&E.jsx(NI,{size:12,style:{color:"var(--text-muted)"}}),E.jsx("button",{onClick:()=>s(h),className:"text-[12px] font-medium px-1.5 py-0.5 rounded transition-colors",style:{color:h===l.length-1?"var(--text-primary)":"var(--text-muted)",cursor:h===l.length-1?"default":"pointer"},onMouseEnter:g=>{h<l.length-1&&(g.currentTarget.style.background="var(--chrome-hover)",g.currentTarget.style.color="var(--text-primary)")},onMouseLeave:g=>{g.currentTarget.style.background="transparent",g.currentTarget.style.color=h===l.length-1?"var(--text-primary)":"var(--text-muted)"},disabled:h===l.length-1,children:u.name})]},h))})}function zSt(l,s,u){pe.useEffect(()=>{if(!u)return;const h=g=>{l.current&&!l.current.contains(g.target)&&s()};return document.addEventListener("mousedown",h),()=>document.removeEventListener("mousedown",h)},[u,l,s])}function n4t({icon:l,title:s,items:u,formatValue:h,valueWidth:g="w-12"}){const[w,p]=pe.useState(!1),k=pe.useRef(null),j=pe.useCallback(()=>p(!1),[]);zSt(k,j,w);const A=pe.useMemo(()=>{var F;if(!u.length)return null;const D=[...u].sort((U,K)=>K.value-U.value),I=((F=D[0])==null?void 0:F.value)||1,B=D.reduce((U,K)=>U+K.value,0);return{sorted:D,maxValue:I,total:B}},[u]),_=A!==null;return E.jsxs("div",{ref:k,className:"relative flex items-center gap-1",children:[E.jsxs("button",{onClick:()=>{_&&p(D=>!D)},className:"flex items-center gap-1 px-1 py-0.5 rounded transition-colors",style:{color:w?"var(--accent)":"var(--text-muted)",background:w?"var(--accent-soft)":"transparent",cursor:_?"pointer":"default",opacity:_?1:.35},onMouseEnter:D=>{!w&&_&&(D.currentTarget.style.color="var(--text-secondary)")},onMouseLeave:D=>{w||(D.currentTarget.style.color="var(--text-muted)")},title:_?`Toggle ${s.toLowerCase()} breakdown`:s,children:[E.jsx(l,{size:12}),E.jsx("span",{className:"text-[11px] font-mono",children:h((A==null?void 0:A.total)??0)})]}),w&&A&&E.jsx("div",{className:"absolute top-full left-0 mt-1 rounded-lg shadow-2xl z-50 w-[320px] overflow-hidden",style:{background:"var(--bg-panel)",border:"1px solid var(--border)"},children:E.jsxs("div",{className:"px-3 py-2 overflow-y-auto",style:{maxHeight:240},children:[E.jsxs("div",{className:"flex items-center justify-between mb-1.5",children:[E.jsx("span",{className:"text-[10px] font-semibold uppercase tracking-wider",style:{color:"var(--text-muted)"},children:s}),E.jsxs("span",{className:"text-[10px] font-mono",style:{color:"var(--text-muted)"},children:[h(A.total)," total"]})]}),A.sorted.map(D=>{const I=D.value/A.maxValue,B=I>.7?"#ef4444":I>.3?"#eab308":"#22c55e";return E.jsxs("div",{className:"flex items-center gap-2 py-0.5",children:[E.jsx("span",{className:"text-[11px] truncate shrink-0",style:{width:100,color:"var(--text-secondary)"},title:D.label,children:D.label}),E.jsx("div",{className:"flex-1 h-3 rounded-sm overflow-hidden",style:{background:"rgba(255,255,255,.05)"},children:E.jsx("div",{className:"h-full rounded-sm transition-all",style:{width:`${Math.max(2,I*100)}%`,background:B,opacity:.8}})}),E.jsx("span",{className:`text-[10px] font-mono shrink-0 ${g} text-right`,style:{color:"var(--text-muted)"},children:h(D.value)})]},D.node_id)})]})})]})}function wvn(l){return l<1e3?`${l.toFixed(1)}ms`:`${(l/1e3).toFixed(2)}s`}function vvn(l){return l<1024?`${l} B`:l<1024*1024?`${(l/1024).toFixed(1)} KB`:l<1024*1024*1024?`${(l/(1024*1024)).toFixed(1)} MB`:`${(l/(1024*1024*1024)).toFixed(1)} GB`}const yvn={connected:{color:"#22c55e",title:"Live sync connected"},reconnecting:{color:"#f59e0b",title:"Reconnecting to server…"},disconnected:{color:"#ef4444",title:"Server unreachable — restart haute serve"}};function xvn({nodeCount:l,dirty:s,canUndo:u,canRedo:h,onUndo:g,onRedo:w,onShowShortcuts:p,onOpenUtility:k,onOpenImports:j,onOpenGit:A,onCentre:_,onAutoLayout:D,onSave:I,wsStatus:B,timings:F,memory:U}){const K=Kc(Oe=>Oe.rowLimit),Y=Kc(Oe=>Oe.setRowLimit),Z=Kc(Oe=>Oe.scenarios),ee=Kc(Oe=>Oe.activeScenario),ce=Kc(Oe=>Oe.setActiveScenario),fe=Kc(Oe=>Oe.addScenario),be=Kc(Oe=>Oe.removeScenario),[me,Re]=pe.useState(!1),[Te,Ke]=pe.useState(""),[ze,je]=pe.useState(!1),te=pe.useRef(null),ge=pe.useCallback(()=>je(!1),[]);zSt(te,ge,ze);const He=yvn[B],ae=pe.useMemo(()=>(F??[]).map(Oe=>({node_id:Oe.node_id,label:Oe.label,value:Oe.timing_ms})),[F]),Le=pe.useMemo(()=>(U??[]).map(Oe=>({node_id:Oe.node_id,label:Oe.label,value:Oe.memory_bytes})),[U]);return E.jsxs("header",{role:"toolbar","aria-label":"Pipeline toolbar",className:"h-11 flex items-center px-4 shrink-0",style:{background:"var(--chrome)",borderBottom:"1px solid var(--chrome-border)"},children:[E.jsxs("div",{className:"flex items-center gap-2.5",children:[E.jsx("h1",{className:"text-sm font-bold tracking-tight",style:{color:"var(--text-primary)"},children:"Haute"}),E.jsx("span",{className:"text-[11px] font-mono",style:{color:"var(--text-muted)"},children:"v0.1.0"}),s&&E.jsx("span",{className:"w-1.5 h-1.5 rounded-full bg-amber-400 animate-pulse-dot",title:"Unsaved changes"}),E.jsx("span",{className:`w-2 h-2 rounded-full shrink-0${B==="reconnecting"?" animate-pulse-dot":""}`,style:{background:He.color},title:He.title})]}),E.jsxs("div",{ref:te,className:"relative flex items-center gap-1 ml-12",children:[E.jsx("label",{className:"text-[11px] font-medium",style:{color:"var(--text-muted)"},children:"Source"}),me?E.jsx("form",{className:"flex items-center gap-0.5",onSubmit:Oe=>{Oe.preventDefault(),Te.trim()&&(fe(Te),ce(Te.trim().toLowerCase().replace(/\s+/g,"_"))),Re(!1),Ke("")},children:E.jsx("input",{autoFocus:!0,value:Te,onChange:Oe=>Ke(Oe.target.value),onBlur:()=>{Re(!1),Ke("")},placeholder:"name",className:"w-20 px-1.5 py-1 text-[11px] font-mono rounded focus:outline-none",style:{background:"var(--chrome-hover)",border:"1px solid var(--accent)",color:"var(--text-primary)"}})}):E.jsxs("button",{onClick:()=>je(Oe=>!Oe),className:"flex items-center gap-1.5 px-2 py-1 text-[12px] font-mono rounded-md transition-colors",style:{background:ze?"var(--accent-soft)":"var(--chrome-hover)",border:`1px solid ${ze?"var(--accent)":"var(--chrome-border)"}`,color:"var(--text-primary)"},title:"Data source",children:[ee==="live"&&E.jsx("span",{className:"w-1.5 h-1.5 rounded-full bg-green-400 shrink-0"}),E.jsx("span",{children:ee}),E.jsx(Vw,{size:11,style:{color:"var(--text-muted)",transition:"transform 150ms",transform:ze?"rotate(180deg)":void 0}})]}),ze&&E.jsxs("div",{className:"absolute top-full left-0 mt-1 rounded-lg shadow-2xl z-50 min-w-[160px] overflow-hidden",style:{background:"var(--bg-panel)",border:"1px solid var(--border)"},children:[E.jsx("div",{className:"py-1",children:Z.map(Oe=>E.jsxs("button",{onClick:()=>{ce(Oe),je(!1)},className:"w-full flex items-center gap-2 px-3 py-1.5 text-[12px] font-mono text-left transition-colors",style:{color:Oe===ee?"var(--accent)":"var(--text-secondary)",background:Oe===ee?"var(--accent-soft)":"transparent"},onMouseEnter:Qe=>{Oe!==ee&&(Qe.currentTarget.style.background="var(--chrome-hover)")},onMouseLeave:Qe=>{Oe!==ee&&(Qe.currentTarget.style.background="transparent")},children:[Oe==="live"?E.jsx("span",{className:"w-1.5 h-1.5 rounded-full bg-green-400 shrink-0"}):E.jsx("span",{className:"w-1.5 shrink-0"}),Oe]},Oe))}),E.jsxs("div",{className:"py-1",style:{borderTop:"1px solid var(--border)"},children:[E.jsxs("button",{onClick:()=>{Re(!0),je(!1)},className:"w-full flex items-center gap-2 px-3 py-1.5 text-[12px] text-left transition-colors",style:{color:"var(--text-muted)"},onMouseEnter:Oe=>{Oe.currentTarget.style.background="var(--chrome-hover)",Oe.currentTarget.style.color="var(--text-secondary)"},onMouseLeave:Oe=>{Oe.currentTarget.style.background="transparent",Oe.currentTarget.style.color="var(--text-muted)"},children:[E.jsx(w8,{size:12}),"Add scenario"]}),ee!=="live"&&E.jsxs("button",{onClick:()=>{be(ee),je(!1)},className:"w-full flex items-center gap-2 px-3 py-1.5 text-[12px] text-left transition-colors",style:{color:"#ef4444"},onMouseEnter:Oe=>Oe.currentTarget.style.background="rgba(239,68,68,.1)",onMouseLeave:Oe=>Oe.currentTarget.style.background="transparent",children:[E.jsx(BI,{size:12}),'Remove "',ee,'"']})]})]})]}),E.jsxs("div",{className:"flex items-center gap-1 ml-3",title:"Row limit for preview (0 = no limit)",children:[E.jsx("label",{className:"text-[11px] font-medium",style:{color:"var(--text-muted)"},children:"Rows"}),E.jsx("input",{type:"number",min:0,step:100,value:K,onChange:Oe=>Y(Math.max(0,parseInt(Oe.target.value)||0)),className:"w-16 px-1.5 py-0.5 text-[12px] font-mono rounded text-center focus:outline-none",style:{background:"var(--chrome-hover)",border:"1px solid var(--chrome-border)",color:"var(--text-primary)"}})]}),E.jsx("button",{onClick:g,disabled:!u,className:"p-1.5 rounded-md transition-colors disabled:opacity-20 ml-3",style:{color:"var(--text-secondary)"},onMouseEnter:Oe=>{Oe.currentTarget.style.background="var(--chrome-hover)",Oe.currentTarget.style.color="var(--text-primary)"},onMouseLeave:Oe=>{Oe.currentTarget.style.background="transparent",Oe.currentTarget.style.color="var(--text-secondary)"},title:"Undo (Ctrl+Z)",children:E.jsx(lfn,{size:14,"aria-hidden":"true"})}),E.jsx("button",{onClick:w,disabled:!h,"aria-label":"Redo",className:"p-1.5 rounded-md transition-colors disabled:opacity-20",style:{color:"var(--text-secondary)"},onMouseEnter:Oe=>{Oe.currentTarget.style.background="var(--chrome-hover)",Oe.currentTarget.style.color="var(--text-primary)"},onMouseLeave:Oe=>{Oe.currentTarget.style.background="transparent",Oe.currentTarget.style.color="var(--text-secondary)"},title:"Redo (Ctrl+Shift+Z)",children:E.jsx(Ian,{size:14,"aria-hidden":"true"})}),E.jsx("div",{className:"ml-3",children:E.jsx(n4t,{icon:efn,title:"Pipeline Timing",items:ae,formatValue:wvn})}),E.jsx(n4t,{icon:ban,title:"Pipeline Memory",items:Le,formatValue:vvn,valueWidth:"w-14"}),E.jsxs("div",{className:"ml-auto flex items-center gap-1.5",children:[E.jsxs("button",{onClick:k,className:"px-2.5 py-1 text-[12px] font-medium rounded-md transition-colors flex items-center gap-1",style:{color:"var(--text-secondary)"},onMouseEnter:Oe=>{Oe.currentTarget.style.background="var(--chrome-hover)",Oe.currentTarget.style.color="var(--text-primary)"},onMouseLeave:Oe=>{Oe.currentTarget.style.background="transparent",Oe.currentTarget.style.color="var(--text-secondary)"},title:"Utility scripts — reusable functions",children:[E.jsx(nkt,{size:13}),"Utility"]}),E.jsxs("button",{onClick:j,className:"px-2.5 py-1 text-[12px] font-medium rounded-md transition-colors flex items-center gap-1",style:{color:"var(--text-secondary)"},onMouseEnter:Oe=>{Oe.currentTarget.style.background="var(--chrome-hover)",Oe.currentTarget.style.color="var(--text-primary)"},onMouseLeave:Oe=>{Oe.currentTarget.style.background="transparent",Oe.currentTarget.style.color="var(--text-secondary)"},title:"Pipeline imports — utility and library imports",children:[E.jsx(jV,{size:13}),"Imports"]}),E.jsx("button",{onClick:p,"aria-label":"Keyboard shortcuts",className:"p-1.5 rounded-md transition-colors",style:{color:"var(--text-secondary)"},onMouseEnter:Oe=>{Oe.currentTarget.style.background="var(--chrome-hover)",Oe.currentTarget.style.color="var(--text-primary)"},onMouseLeave:Oe=>{Oe.currentTarget.style.background="transparent",Oe.currentTarget.style.color="var(--text-secondary)"},title:"Keyboard shortcuts (?)",children:E.jsx(kan,{size:14,"aria-hidden":"true"})}),E.jsx("div",{className:"w-px h-4 mx-0.5",style:{background:"var(--chrome-border)"}}),E.jsx("button",{onClick:_,disabled:l===0,className:"px-2.5 py-1 text-[12px] font-medium rounded-md transition-colors disabled:opacity-30",style:{color:"var(--text-secondary)"},onMouseEnter:Oe=>{Oe.currentTarget.style.background="var(--chrome-hover)",Oe.currentTarget.style.color="var(--text-primary)"},onMouseLeave:Oe=>{Oe.currentTarget.style.background="transparent",Oe.currentTarget.style.color="var(--text-secondary)"},title:"Fit all nodes in view",children:"Centre"}),E.jsx("button",{onClick:D,disabled:l===0,className:"px-2.5 py-1 text-[12px] font-medium rounded-md transition-colors disabled:opacity-30",style:{color:"var(--text-secondary)"},onMouseEnter:Oe=>{Oe.currentTarget.style.background="var(--chrome-hover)",Oe.currentTarget.style.color="var(--text-primary)"},onMouseLeave:Oe=>{Oe.currentTarget.style.background="transparent",Oe.currentTarget.style.color="var(--text-secondary)"},title:"Auto-arrange nodes",children:"Layout"}),E.jsx("button",{onClick:I,className:"px-3 py-1 text-[12px] font-semibold text-white rounded-md transition-colors",style:{background:"var(--accent)"},onMouseEnter:Oe=>Oe.currentTarget.style.background="#60a5fa",onMouseLeave:Oe=>Oe.currentTarget.style.background="var(--accent)",title:"Ctrl+S",children:"Save"}),E.jsxs("button",{onClick:A,className:"px-3 py-1 text-[12px] font-semibold text-white rounded-md transition-colors flex items-center gap-1",style:{background:"#22c55e"},onMouseEnter:Oe=>Oe.currentTarget.style.background="#4ade80",onMouseLeave:Oe=>Oe.currentTarget.style.background="#22c55e",title:"Git — branch management and version control",children:[E.jsx(skt,{size:13}),"Git"]})]})]})}function kvn({nodeCount:l,onClose:s,onSubmit:u}){return E.jsx("div",{className:"fixed inset-0 z-50 flex items-center justify-center",role:"dialog","aria-modal":"true","aria-label":"Create submodel",style:{background:"rgba(0,0,0,.5)"},onClick:h=>{h.target===h.currentTarget&&s()},children:E.jsxs("div",{className:"w-[400px] flex flex-col rounded-xl overflow-hidden shadow-2xl",style:{background:"var(--bg-panel)",border:"1px solid var(--border)"},children:[E.jsxs("div",{className:"px-4 py-3",style:{borderBottom:"1px solid var(--border)"},children:[E.jsx("h2",{className:"text-sm font-semibold",style:{color:"var(--text-primary)"},children:"Create Submodel"}),E.jsxs("p",{className:"text-[11px] mt-0.5",style:{color:"var(--text-muted)"},children:["Group ",l," selected nodes into a submodel"]})]}),E.jsxs("form",{className:"p-4 flex flex-col gap-3",onSubmit:h=>{h.preventDefault();const w=(new FormData(h.currentTarget).get("name")||"").trim();w&&u(w)},children:[E.jsxs("div",{children:[E.jsx("label",{className:"text-[11px] font-medium block mb-1",style:{color:"var(--text-muted)"},children:"Submodel name"}),E.jsx("input",{name:"name",type:"text",autoFocus:!0,placeholder:"e.g. model_scoring",className:"w-full px-3 py-1.5 text-[13px] rounded-md focus:outline-none focus:ring-2",style:{background:"var(--bg-input)",border:"1px solid var(--border)",color:"var(--text-primary)",caretColor:"var(--accent)"}})]}),E.jsxs("div",{className:"flex justify-end gap-2",children:[E.jsx("button",{type:"button",onClick:s,className:"px-3 py-1.5 text-[12px] font-medium rounded-md transition-colors",style:{color:"var(--text-secondary)"},children:"Cancel"}),E.jsx("button",{type:"submit",className:"px-4 py-1.5 text-[12px] font-semibold text-white rounded-md transition-colors",style:{background:"#f97316"},onMouseEnter:h=>h.currentTarget.style.background="#fb923c",onMouseLeave:h=>h.currentTarget.style.background="#f97316",children:"Create"})]})]})]})})}function Ovn({onClose:l,onImportAdded:s}){const[u,h]=pe.useState([]),[g,w]=pe.useState(null),[p,k]=pe.useState(""),[j,A]=pe.useState(null),[_,D]=pe.useState(null),[I,B]=pe.useState(!1),[F,U]=pe.useState(!1),[K,Y]=pe.useState(""),Z=pe.useRef(void 0),ee=pe.useRef(g);ee.current=g;const ce=pe.useCallback((Te,Ke)=>{clearTimeout(Z.current),Z.current=setTimeout(async()=>{if(ee.current===Te)try{const ze=await chn(Te,Ke);if(ee.current!==Te)return;ze.status==="error"?(A(ze.error_line??null),D(ze.error??"Syntax error")):(A(null),D(null))}catch(ze){console.warn("Failed to save utility file",Te,ze),ee.current===Te&&D("Failed to save")}},500)},[]);pe.useEffect(()=>()=>clearTimeout(Z.current),[]);const fe=pe.useCallback(async()=>{try{const Te=await rhn();h(Te.files)}catch(Te){console.warn("Failed to list utility files",Te),h([])}},[]);pe.useEffect(()=>{fe()},[fe]);const be=pe.useCallback(async Te=>{clearTimeout(Z.current);try{const Ke=await shn(Te);k(Ke.content),w(Te),A(null),D(null)}catch(Ke){console.warn("Failed to load utility file",Te,Ke),D(`Failed to load ${Te}`)}},[]);pe.useEffect(()=>{u.length>0&&g===null&&be(u[0].module)},[u,g,be]);const me=pe.useCallback(async()=>{const Te=K.trim().replace(/\.py$/,"");if(Te){U(!1),Y("");try{const Ke=await ohn({name:Te});if(Ke.status==="error"){D(Ke.error??"Failed to create");return}Ke.import_line&&s(Ke.import_line),await fe(),be(Ke.module)}catch(Ke){D(Ke instanceof Error?Ke.message:"Failed to create")}}},[K,fe,be,s]),Re=pe.useCallback(async()=>{if(g&&confirm(`Delete ${g}?`)){clearTimeout(Z.current);try{await lhn(g),w(null),k(""),await fe()}catch(Te){console.warn("Failed to delete utility file",g,Te),D("Failed to delete")}}},[g,fe]);return E.jsxs($V,{children:[E.jsxs("div",{className:"px-3 py-2.5 flex items-center gap-2 shrink-0",style:{borderBottom:"1px solid var(--border)"},children:[E.jsx(nkt,{size:14,style:{color:"var(--accent)"}}),E.jsx("span",{className:"text-[13px] font-semibold flex-1",style:{color:"var(--text-primary)"},children:"Utility Scripts"}),E.jsx("button",{onClick:l,className:"p-1 rounded shrink-0 transition-colors",style:{color:"var(--text-muted)"},onMouseEnter:Te=>Te.currentTarget.style.background="var(--bg-hover)",onMouseLeave:Te=>Te.currentTarget.style.background="transparent",title:"Close",children:E.jsx(jp,{size:14})})]}),E.jsx("div",{className:"px-3 py-2 flex items-center gap-2 shrink-0",style:{borderBottom:"1px solid var(--border)"},children:F?E.jsxs("form",{className:"flex items-center gap-1 flex-1",onSubmit:Te=>{Te.preventDefault(),me()},children:[E.jsx("input",{autoFocus:!0,value:K,onChange:Te=>Y(Te.target.value),onBlur:()=>{U(!1),Y("")},placeholder:"module_name",className:"flex-1 px-2 py-1 text-[12px] font-mono rounded focus:outline-none",style:{background:"var(--bg-input)",border:"1px solid var(--accent)",color:"var(--text-primary)"}}),E.jsx("span",{className:"text-[11px] font-mono",style:{color:"var(--text-muted)"},children:".py"})]}):E.jsxs(E.Fragment,{children:[E.jsxs("div",{className:"relative flex-1",children:[E.jsxs("button",{onClick:()=>B(Te=>!Te),className:"w-full flex items-center gap-1.5 px-2 py-1 text-[12px] font-mono rounded-md transition-colors",style:{background:I?"var(--accent-soft)":"var(--bg-input)",border:`1px solid ${I?"var(--accent)":"var(--border)"}`,color:"var(--text-primary)"},children:[E.jsx("span",{className:"flex-1 text-left truncate",children:g??"No files"}),E.jsx(Vw,{size:11,style:{color:"var(--text-muted)",transition:"transform 150ms",transform:I?"rotate(180deg)":void 0}})]}),I&&u.length>0&&E.jsx("div",{className:"absolute top-full left-0 right-0 mt-1 rounded-lg shadow-2xl z-50 overflow-hidden",style:{background:"var(--bg-panel)",border:"1px solid var(--border)"},children:E.jsx("div",{className:"py-1",children:u.map(Te=>E.jsx("button",{onClick:()=>{B(!1),Te.module!==g&&be(Te.module)},className:"w-full flex items-center px-3 py-1.5 text-[12px] font-mono text-left transition-colors",style:{color:Te.module===g?"var(--accent)":"var(--text-secondary)",background:Te.module===g?"var(--accent-soft)":"transparent"},onMouseEnter:Ke=>{Te.module!==g&&(Ke.currentTarget.style.background="var(--bg-hover)")},onMouseLeave:Ke=>{Te.module!==g&&(Ke.currentTarget.style.background="transparent")},children:Te.module},Te.module))})})]}),E.jsx("button",{onClick:()=>U(!0),className:"p-1.5 rounded-md transition-colors",style:{color:"var(--text-muted)"},onMouseEnter:Te=>{Te.currentTarget.style.background="var(--bg-hover)",Te.currentTarget.style.color="var(--accent)"},onMouseLeave:Te=>{Te.currentTarget.style.background="transparent",Te.currentTarget.style.color="var(--text-muted)"},title:"New utility file",children:E.jsx(w8,{size:14})}),g&&E.jsx("button",{onClick:Re,className:"p-1.5 rounded-md transition-colors",style:{color:"var(--text-muted)"},onMouseEnter:Te=>{Te.currentTarget.style.background="rgba(239,68,68,.1)",Te.currentTarget.style.color="#ef4444"},onMouseLeave:Te=>{Te.currentTarget.style.background="transparent",Te.currentTarget.style.color="var(--text-muted)"},title:`Delete ${g}`,children:E.jsx(BI,{size:14})})]})}),E.jsx("div",{className:"flex-1 min-h-0 overflow-y-auto",children:g?E.jsxs("div",{className:"h-full flex flex-col",children:[E.jsx("div",{className:"flex-1 min-h-0",children:E.jsx(RV,{defaultValue:p,onChange:Te=>{k(Te),A(null),D(null),g&&ce(g,Te)},errorLine:j,placeholder:"# Write reusable helper functions here\\n\\nimport polars as pl\\n\\ndef my_helper(df):\\n    return df"})}),_&&E.jsx("div",{className:"px-3 py-2 text-[11px] shrink-0",style:{color:"#ef4444",borderTop:"1px solid var(--border)"},children:_})]}):E.jsx("div",{className:"flex items-center justify-center h-full text-[12px]",style:{color:"var(--text-muted)"},children:u.length===0?E.jsxs("div",{className:"text-center",children:[E.jsx("p",{children:"No utility files yet."}),E.jsx("button",{onClick:()=>U(!0),className:"mt-2 px-3 py-1 text-[12px] font-medium rounded-md transition-colors",style:{color:"var(--accent)",background:"var(--accent-soft)"},onMouseEnter:Te=>Te.currentTarget.style.background="rgba(59,130,246,.2)",onMouseLeave:Te=>Te.currentTarget.style.background="var(--accent-soft)",children:"Create one"})]}):"Select a file"})})]})}function Svn({preamble:l,onPreambleChange:s,onClose:u}){return E.jsxs($V,{children:[E.jsxs("div",{className:"px-3 py-2.5 flex items-center gap-2 shrink-0",style:{borderBottom:"1px solid var(--border)"},children:[E.jsx(jV,{size:14,style:{color:"var(--accent)"}}),E.jsxs("div",{className:"flex-1 min-w-0",children:[E.jsx("span",{className:"text-[13px] font-semibold block",style:{color:"var(--text-primary)"},children:"Pipeline Imports"}),E.jsx("span",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:"Import statements for utility modules and third-party libraries."})]}),E.jsx("button",{onClick:u,className:"p-1 rounded shrink-0 transition-colors",style:{color:"var(--text-muted)"},onMouseEnter:h=>h.currentTarget.style.background="var(--bg-hover)",onMouseLeave:h=>h.currentTarget.style.background="transparent",title:"Close",children:E.jsx(jp,{size:14})})]}),E.jsx("div",{className:"px-3 py-2 shrink-0",style:{borderBottom:"1px solid var(--border)"},children:E.jsxs("p",{className:"text-[11px] font-mono",style:{color:"var(--text-muted)"},children:[E.jsx("span",{style:{color:"rgba(96,165,250,.5)"},children:"import polars as pl"})," and ",E.jsx("span",{style:{color:"rgba(96,165,250,.5)"},children:"import haute"})," are always included"]})}),E.jsx("div",{className:"flex-1 min-h-0",children:E.jsx(RV,{defaultValue:l,onChange:s,placeholder:`from utility.features import *
import numpy as np
from catboost import CatBoostRegressor`})})]})}function jvn({onClose:l}){const[s,u]=pe.useState(null),[h,g]=pe.useState([]),[w,p]=pe.useState([]),[k,j]=pe.useState("main"),[A,_]=pe.useState(null),[D,I]=pe.useState(!1),[B,F]=pe.useState(!1),[U,K]=pe.useState(""),[Y,Z]=pe.useState(!1),[ee,ce]=pe.useState(null),fe=pe.useCallback(async()=>{try{const[Ue,Pt]=await Promise.all([ahn(),fhn()]);u(Ue),g(Pt.branches)}catch(Ue){_(Ue instanceof Error?Ue.message:"Failed to load git status")}},[]);pe.useEffect(()=>{fe()},[fe]);const be=pe.useCallback(async()=>{try{const Ue=await bhn(30);p(Ue.entries)}catch(Ue){console.warn("Failed to load git history",Ue),p([])}},[]);pe.useEffect(()=>{k==="history"&&be()},[k,be]);const me=pe.useCallback(async()=>{const Ue=U.trim();if(Ue){I(!0),_(null);try{await hhn(Ue),F(!1),K(""),await fe()}catch(Pt){_(Pt instanceof Error?Pt.message:"Failed to create branch")}finally{I(!1)}}},[U,fe]),Re=pe.useCallback(async Ue=>{I(!0),_(null),Z(!1);try{await dhn(Ue),await fe()}catch(Pt){_(Pt instanceof Error?Pt.message:"Failed to switch branch")}finally{I(!1)}},[fe]),Te=pe.useCallback(async()=>{I(!0),_(null);try{await ghn(),await fe(),k==="history"&&await be()}catch(Ue){_(Ue instanceof Error?Ue.message:"Failed to save")}finally{I(!1)}},[fe,be,k]),Ke=pe.useCallback(async()=>{I(!0),_(null);try{const Ue=await phn();Ue.compare_url&&window.open(Ue.compare_url,"_blank"),await fe()}catch(Ue){_(Ue instanceof Error?Ue.message:"Failed to submit")}finally{I(!1)}},[fe]),ze=pe.useCallback(async()=>{I(!0),_(null);try{const Ue=await whn();Ue.conflict&&_(Ue.conflict_message??"Merge conflict detected"),await fe()}catch(Ue){_(Ue instanceof Error?Ue.message:"Failed to pull")}finally{I(!1)}},[fe]),je=pe.useCallback(async Ue=>{I(!0),_(null),ce(null);try{await mhn(Ue),await fe(),await be()}catch(Pt){_(Pt instanceof Error?Pt.message:"Failed to revert")}finally{I(!1)}},[fe,be]),te=pe.useCallback(async Ue=>{I(!0),_(null),ce(null);try{await vhn(Ue),await fe()}catch(Pt){_(Pt instanceof Error?Pt.message:"Failed to archive")}finally{I(!1)}},[fe]),ge=pe.useCallback(async Ue=>{I(!0),_(null),ce(null);try{await yhn(Ue),await fe()}catch(Pt){_(Pt instanceof Error?Pt.message:"Failed to delete")}finally{I(!1)}},[fe]),He=(s==null?void 0:s.is_main)??!0,ae=(s==null?void 0:s.is_read_only)??!0,Le=(s==null?void 0:s.branch)??"main",Oe=(s==null?void 0:s.changed_files)??[],Qe=h.filter(Ue=>Ue.is_yours&&!Ue.is_archived),kt=h.filter(Ue=>!Ue.is_yours&&!Ue.is_archived&&!["main","master","develop"].includes(Ue.name)),Ae=h.filter(Ue=>Ue.is_archived),Ye=h.filter(Ue=>["main","master","develop"].includes(Ue.name));function mt(Ue){const Pt=Date.now()-new Date(Ue).getTime(),rn=Math.floor(Pt/6e4);if(rn<1)return"just now";if(rn<60)return`${rn}m ago`;const Cn=Math.floor(rn/60);return Cn<24?`${Cn}h ago`:`${Math.floor(Cn/24)}d ago`}return E.jsxs($V,{children:[E.jsxs("div",{className:"px-3 py-2.5 flex items-center gap-2 shrink-0",style:{borderBottom:"1px solid var(--border)"},children:[E.jsx(skt,{size:14,style:{color:"#22c55e"}}),E.jsx("span",{className:"text-[13px] font-semibold flex-1",style:{color:"var(--text-primary)"},children:"Git"}),E.jsx("button",{onClick:l,className:"p-1 rounded shrink-0 transition-colors",style:{color:"var(--text-muted)"},onMouseEnter:Ue=>Ue.currentTarget.style.background="var(--bg-hover)",onMouseLeave:Ue=>Ue.currentTarget.style.background="transparent",title:"Close",children:E.jsx(jp,{size:14})})]}),A&&E.jsxs("div",{className:"px-3 py-2 text-[11px] flex items-start gap-2 shrink-0",style:{color:"#ef4444",background:"rgba(239,68,68,.08)",borderBottom:"1px solid var(--border)"},children:[E.jsx(Oy,{size:12,className:"shrink-0 mt-0.5"}),E.jsx("span",{className:"flex-1",children:A}),E.jsx("button",{onClick:()=>_(null),className:"opacity-60 hover:opacity-100 shrink-0",children:"✕"})]}),ee&&E.jsxs("div",{className:"px-3 py-3 shrink-0",style:{background:"rgba(239,68,68,.06)",borderBottom:"1px solid var(--border)"},children:[E.jsx("p",{className:"text-[12px] mb-2",style:{color:"var(--text-primary)"},children:ee.type==="delete"?`Permanently delete "${ee.label}"? This cannot be undone.`:ee.type==="archive"?`Archive "${ee.label}"? You can restore it later.`:"Revert to this version? A backup will be created."}),E.jsxs("div",{className:"flex gap-2",children:[E.jsx("button",{onClick:()=>{ee.type==="delete"?ge(ee.target):ee.type==="archive"?te(ee.target):je(ee.target)},className:"px-3 py-1 text-[12px] font-medium rounded-md",style:{background:ee.type==="delete"?"#ef4444":"var(--accent)",color:"#fff"},children:ee.type==="delete"?"Delete":ee.type==="archive"?"Archive":"Revert"}),E.jsx("button",{onClick:()=>ce(null),className:"px-3 py-1 text-[12px] font-medium rounded-md",style:{color:"var(--text-secondary)",background:"var(--bg-input)"},children:"Cancel"})]})]}),E.jsxs("div",{className:"flex-1 min-h-0 overflow-y-auto",children:[E.jsxs("div",{className:"px-3 py-3",style:{borderBottom:"1px solid var(--border)"},children:[E.jsxs("div",{className:"flex items-center gap-2 mb-2",children:[E.jsx("span",{className:"text-[11px] font-medium",style:{color:"var(--text-muted)"},children:"Branch"}),He&&E.jsx("span",{className:"text-[10px] px-1.5 py-0.5 rounded font-mono",style:{background:"rgba(239,68,68,.15)",color:"#f87171"},children:"read-only"}),!He&&ae&&E.jsx("span",{className:"text-[10px] px-1.5 py-0.5 rounded font-mono",style:{background:"rgba(245,158,11,.15)",color:"#fbbf24"},children:"read-only"})]}),E.jsxs("div",{className:"relative",children:[E.jsxs("button",{onClick:()=>Z(Ue=>!Ue),className:"w-full flex items-center gap-1.5 px-2.5 py-1.5 text-[12px] font-mono rounded-md transition-colors",style:{background:Y?"var(--accent-soft)":"var(--bg-input)",border:`1px solid ${Y?"var(--accent)":"var(--border)"}`,color:"var(--text-primary)"},children:[E.jsx(rkt,{size:12,style:{color:"var(--accent)"}}),E.jsx("span",{className:"flex-1 text-left truncate",children:Le}),E.jsx(Vw,{size:11,style:{color:"var(--text-muted)",transition:"transform 150ms",transform:Y?"rotate(180deg)":void 0}})]}),Y&&E.jsxs("div",{className:"absolute top-full left-0 right-0 mt-1 rounded-lg shadow-2xl z-50 overflow-hidden max-h-[300px] overflow-y-auto",style:{background:"var(--bg-panel)",border:"1px solid var(--border)"},children:[Ye.length>0&&E.jsx("div",{className:"py-1",children:Ye.map(Ue=>E.jsx(mfe,{branch:Ue,currentBranch:Le,onSwitch:Re},Ue.name))}),Qe.length>0&&E.jsxs(E.Fragment,{children:[E.jsx("div",{className:"px-3 pt-2 pb-1",style:{borderTop:"1px solid var(--border)"},children:E.jsx("span",{className:"text-[10px] font-medium uppercase tracking-wider",style:{color:"var(--text-muted)"},children:"Your branches"})}),E.jsx("div",{className:"py-1",children:Qe.map(Ue=>E.jsx(mfe,{branch:Ue,currentBranch:Le,onSwitch:Re},Ue.name))})]}),kt.length>0&&E.jsxs(E.Fragment,{children:[E.jsx("div",{className:"px-3 pt-2 pb-1",style:{borderTop:"1px solid var(--border)"},children:E.jsx("span",{className:"text-[10px] font-medium uppercase tracking-wider",style:{color:"var(--text-muted)"},children:"Other branches"})}),E.jsx("div",{className:"py-1",children:kt.map(Ue=>E.jsx(mfe,{branch:Ue,currentBranch:Le,onSwitch:Re},Ue.name))})]}),Ae.length>0&&E.jsxs(E.Fragment,{children:[E.jsx("div",{className:"px-3 pt-2 pb-1",style:{borderTop:"1px solid var(--border)"},children:E.jsx("span",{className:"text-[10px] font-medium uppercase tracking-wider",style:{color:"var(--text-muted)"},children:"Archived"})}),E.jsx("div",{className:"py-1",children:Ae.map(Ue=>E.jsx(mfe,{branch:Ue,currentBranch:Le,onSwitch:Re},Ue.name))})]})]})]})]}),He&&E.jsx("div",{className:"px-3 py-3",style:{borderBottom:"1px solid var(--border)"},children:B?E.jsxs("form",{onSubmit:Ue=>{Ue.preventDefault(),me()},className:"flex flex-col gap-2",children:[E.jsx("label",{className:"text-[11px] font-medium",style:{color:"var(--text-muted)"},children:"What are you working on?"}),E.jsx("input",{autoFocus:!0,value:U,onChange:Ue=>K(Ue.target.value),placeholder:"Update area factors",className:"w-full px-2.5 py-1.5 text-[12px] rounded-md focus:outline-none",style:{background:"var(--bg-input)",border:"1px solid var(--accent)",color:"var(--text-primary)"},disabled:D}),E.jsxs("div",{className:"flex gap-2",children:[E.jsx("button",{type:"submit",disabled:!U.trim()||D,className:"px-3 py-1 text-[12px] font-medium text-white rounded-md transition-colors disabled:opacity-40",style:{background:"var(--accent)"},children:"Create branch"}),E.jsx("button",{type:"button",onClick:()=>{F(!1),K("")},className:"px-3 py-1 text-[12px] font-medium rounded-md",style:{color:"var(--text-secondary)"},children:"Cancel"})]})]}):E.jsxs("button",{onClick:()=>F(!0),className:"w-full flex items-center justify-center gap-2 px-3 py-2 text-[12px] font-medium rounded-md transition-colors",style:{color:"var(--accent)",background:"var(--accent-soft)"},onMouseEnter:Ue=>Ue.currentTarget.style.background="rgba(59,130,246,.2)",onMouseLeave:Ue=>Ue.currentTarget.style.background="var(--accent-soft)",children:[E.jsx(w8,{size:13}),"Start editing (create branch)"]})}),!He&&!ae&&E.jsxs(E.Fragment,{children:[Oe.length>0&&E.jsxs("div",{className:"px-3 py-2.5",style:{borderBottom:"1px solid var(--border)"},children:[E.jsx("span",{className:"text-[11px] font-medium block mb-1.5",style:{color:"var(--text-muted)"},children:"Unsaved changes"}),E.jsxs("div",{className:"flex flex-col gap-0.5",children:[Oe.slice(0,8).map(Ue=>E.jsx("span",{className:"text-[11px] font-mono truncate",style:{color:"var(--text-secondary)"},children:Ue},Ue)),Oe.length>8&&E.jsxs("span",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:["+",Oe.length-8," more"]})]})]}),E.jsxs("div",{className:"px-3 py-3 flex flex-col gap-2",style:{borderBottom:"1px solid var(--border)"},children:[Oe.length>0&&E.jsx("button",{onClick:Te,disabled:D,className:"w-full px-3 py-2 text-[12px] font-medium rounded-md transition-colors disabled:opacity-40",style:{background:"var(--bg-input)",color:"var(--text-primary)",border:"1px solid var(--border)"},onMouseEnter:Ue=>Ue.currentTarget.style.background="var(--bg-hover)",onMouseLeave:Ue=>Ue.currentTarget.style.background="var(--bg-input)",children:"Save progress"}),E.jsxs("button",{onClick:Ke,disabled:D,className:"w-full flex items-center justify-center gap-2 px-3 py-2 text-[12px] font-semibold text-white rounded-md transition-colors disabled:opacity-40",style:{background:"var(--accent)"},onMouseEnter:Ue=>Ue.currentTarget.style.background="#60a5fa",onMouseLeave:Ue=>Ue.currentTarget.style.background="var(--accent)",children:[E.jsx(ran,{size:12}),"Submit for review"]})]}),(s==null?void 0:s.main_ahead)&&E.jsxs("div",{className:"px-3 py-2.5",style:{borderBottom:"1px solid var(--border)"},children:[E.jsxs("div",{className:"flex items-center gap-2 mb-2",children:[E.jsx(Oy,{size:12,style:{color:"#fbbf24"}}),E.jsxs("span",{className:"text-[11px]",style:{color:"#fbbf24"},children:["Main updated (",s.main_ahead_by," commit",s.main_ahead_by!==1?"s":""," ahead)"]})]}),E.jsxs("button",{onClick:ze,disabled:D,className:"w-full flex items-center justify-center gap-2 px-3 py-1.5 text-[12px] font-medium rounded-md transition-colors disabled:opacity-40",style:{background:"var(--bg-input)",color:"var(--text-primary)",border:"1px solid var(--border)"},onMouseEnter:Ue=>Ue.currentTarget.style.background="var(--bg-hover)",onMouseLeave:Ue=>Ue.currentTarget.style.background="var(--bg-input)",children:[E.jsx(Dun,{size:12}),"Pull latest"]})]}),E.jsx("div",{className:"px-3 py-2.5",style:{borderBottom:"1px solid var(--border)"},children:E.jsxs("button",{onClick:()=>j(k==="history"?"main":"history"),className:"flex items-center gap-2 text-[12px] font-medium transition-colors",style:{color:k==="history"?"var(--accent)":"var(--text-secondary)"},onMouseEnter:Ue=>Ue.currentTarget.style.color="var(--accent)",onMouseLeave:Ue=>Ue.currentTarget.style.color=k==="history"?"var(--accent)":"var(--text-secondary)",children:[E.jsx(ekt,{size:12}),k==="history"?"Hide version history":"Version history"]})}),k==="history"&&E.jsx("div",{className:"px-3 py-2",children:w.length===0?E.jsx("span",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:"No commits yet on this branch."}):E.jsx("div",{className:"flex flex-col gap-1",children:w.map(Ue=>E.jsxs("div",{className:"flex items-start gap-2 py-1.5 group",children:[E.jsxs("div",{className:"flex-1 min-w-0",children:[E.jsx("span",{className:"text-[11px] block truncate",style:{color:"var(--text-primary)"},children:Ue.message}),E.jsxs("span",{className:"text-[10px] font-mono",style:{color:"var(--text-muted)"},children:[Ue.short_sha," · ",mt(Ue.timestamp)]})]}),E.jsx("button",{onClick:()=>ce({type:"revert",target:Ue.sha,label:Ue.message}),className:"p-1 rounded opacity-0 group-hover:opacity-100 transition-opacity shrink-0",style:{color:"var(--text-muted)"},onMouseEnter:Pt=>{Pt.currentTarget.style.background="var(--bg-hover)",Pt.currentTarget.style.color="var(--accent)"},onMouseLeave:Pt=>{Pt.currentTarget.style.background="transparent",Pt.currentTarget.style.color="var(--text-muted)"},title:"Revert to this version",children:E.jsx(Ban,{size:12})})]},Ue.sha))})}),E.jsxs("div",{className:"px-3 py-2.5 flex gap-2",style:{borderTop:"1px solid var(--border)"},children:[E.jsxs("button",{onClick:()=>ce({type:"archive",target:Le,label:Le.split("/").pop()??Le}),disabled:D,className:"flex items-center gap-1.5 px-2.5 py-1 text-[11px] font-medium rounded-md transition-colors disabled:opacity-40",style:{color:"var(--text-muted)"},onMouseEnter:Ue=>{Ue.currentTarget.style.background="var(--bg-hover)",Ue.currentTarget.style.color="var(--text-secondary)"},onMouseLeave:Ue=>{Ue.currentTarget.style.background="transparent",Ue.currentTarget.style.color="var(--text-muted)"},children:[E.jsx(Nun,{size:11}),"Archive"]}),E.jsxs("button",{onClick:()=>ce({type:"delete",target:Le,label:Le.split("/").pop()??Le}),disabled:D,className:"flex items-center gap-1.5 px-2.5 py-1 text-[11px] font-medium rounded-md transition-colors disabled:opacity-40",style:{color:"var(--text-muted)"},onMouseEnter:Ue=>{Ue.currentTarget.style.background="rgba(239,68,68,.1)",Ue.currentTarget.style.color="#ef4444"},onMouseLeave:Ue=>{Ue.currentTarget.style.background="transparent",Ue.currentTarget.style.color="var(--text-muted)"},children:[E.jsx(BI,{size:11}),"Delete"]})]})]}),!He&&ae&&E.jsxs("div",{className:"px-3 py-4 text-center",children:[E.jsx("p",{className:"text-[12px] mb-1",style:{color:"var(--text-secondary)"},children:"Viewing someone else's branch."}),E.jsx("p",{className:"text-[11px]",style:{color:"var(--text-muted)"},children:"Switch to your own branch to make changes."})]})]})]})}function mfe({branch:l,currentBranch:s,onSwitch:u}){const h=l.name===s,g=l.name.split("/"),w=g.length>=3?g.slice(2).join("/"):l.name;return E.jsxs("button",{onClick:()=>{h||u(l.name)},className:"w-full flex items-center gap-2 px-3 py-1.5 text-[12px] font-mono text-left transition-colors",style:{color:h?"var(--accent)":"var(--text-secondary)",background:h?"var(--accent-soft)":"transparent"},onMouseEnter:p=>{h||(p.currentTarget.style.background="var(--bg-hover)")},onMouseLeave:p=>{h||(p.currentTarget.style.background="transparent")},children:[E.jsx(rkt,{size:11,style:{color:h?"var(--accent)":"var(--text-muted)",flexShrink:0}}),E.jsx("span",{className:"flex-1 truncate",children:w}),l.commit_count>0&&E.jsx("span",{className:"text-[10px] shrink-0",style:{color:"var(--text-muted)"},children:l.commit_count})]})}function Tvn(l=[],s=[]){const[u,h,g]=Kln(l),[w,p,k]=Yln(s),j=pe.useRef([]),A=pe.useRef([]),_=pe.useRef(u),D=pe.useRef(w);pe.useEffect(()=>{_.current=u,D.current=w},[u,w]);const[I,B]=pe.useState(!1),[F,U]=pe.useState(!1),K=pe.useCallback(()=>{j.current=[...j.current.slice(-99),{nodes:_.current,edges:D.current}],A.current=[],B(!0),U(!1)},[]),Y=pe.useRef(!1),Z=pe.useCallback(Re=>{const Te=Re.some(je=>je.type==="add"||je.type==="remove"||je.type==="replace"),Ke=Re.some(je=>je.type==="position"&&je.dragging===!0),ze=Re.some(je=>je.type==="position"&&je.dragging===!1);Te&&K(),Ke&&!Y.current&&(Y.current=!0,K()),ze&&(Y.current=!1),g(Re)},[g,K]),ee=pe.useCallback(Re=>{Re.some(Ke=>Ke.type==="add"||Ke.type==="remove"||Ke.type==="replace")&&K(),k(Re)},[k,K]),ce=pe.useCallback(Re=>{K(),h(Re)},[h,K]),fe=pe.useCallback(Re=>{K(),p(Re)},[p,K]),be=pe.useCallback(()=>{const Re=j.current.pop();Re&&(A.current.push({nodes:_.current,edges:D.current}),h(Re.nodes),p(Re.edges),B(j.current.length>0),U(!0))},[h,p]),me=pe.useCallback(()=>{const Re=A.current.pop();Re&&(j.current.push({nodes:_.current,edges:D.current}),h(Re.nodes),p(Re.edges),B(!0),U(A.current.length>0))},[h,p]);return{nodes:u,edges:w,setNodes:ce,setEdges:fe,setNodesRaw:h,setEdgesRaw:p,onNodesChange:Z,onEdgesChange:ee,undo:be,redo:me,canUndo:I,canRedo:F,pushSnapshot:K}}function wfe(l){throw new Error('Could not dynamically require "'+l+'". Please configure the dynamicRequireTargets or/and ignoreDynamicRequires option of @rollup/plugin-commonjs appropriately for this require call to work.')}var aCe={exports:{}},i4t;function Evn(){return i4t||(i4t=1,(function(l,s){(function(u){l.exports=u()})(function(){return(function(){function u(h,g,w){function p(A,_){if(!g[A]){if(!h[A]){var D=typeof wfe=="function"&&wfe;if(!_&&D)return D(A,!0);if(k)return k(A,!0);var I=new Error("Cannot find module '"+A+"'");throw I.code="MODULE_NOT_FOUND",I}var B=g[A]={exports:{}};h[A][0].call(B.exports,function(F){var U=h[A][1][F];return p(U||F)},B,B.exports,u,h,g,w)}return g[A].exports}for(var k=typeof wfe=="function"&&wfe,j=0;j<w.length;j++)p(w[j]);return p}return u})()({1:[function(u,h,g){Object.defineProperty(g,"__esModule",{value:!0}),g.default=void 0;function w(I){"@babel/helpers - typeof";return w=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(B){return typeof B}:function(B){return B&&typeof Symbol=="function"&&B.constructor===Symbol&&B!==Symbol.prototype?"symbol":typeof B},w(I)}function p(I,B){if(!(I instanceof B))throw new TypeError("Cannot call a class as a function")}function k(I,B){for(var F=0;F<B.length;F++){var U=B[F];U.enumerable=U.enumerable||!1,U.configurable=!0,"value"in U&&(U.writable=!0),Object.defineProperty(I,A(U.key),U)}}function j(I,B,F){return B&&k(I.prototype,B),Object.defineProperty(I,"prototype",{writable:!1}),I}function A(I){var B=_(I,"string");return w(B)=="symbol"?B:B+""}function _(I,B){if(w(I)!="object"||!I)return I;var F=I[Symbol.toPrimitive];if(F!==void 0){var U=F.call(I,B);if(w(U)!="object")return U;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(I)}g.default=(function(){function I(){var B=this,F=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{},U=F.defaultLayoutOptions,K=U===void 0?{}:U,Y=F.algorithms,Z=Y===void 0?["layered","stress","mrtree","radial","force","disco","sporeOverlap","sporeCompaction","rectpacking","vertiflex"]:Y,ee=F.workerFactory,ce=F.workerUrl;if(p(this,I),this.defaultLayoutOptions=K,this.initialized=!1,typeof ce>"u"&&typeof ee>"u")throw new Error("Cannot construct an ELK without both 'workerUrl' and 'workerFactory'.");var fe=ee;typeof ce<"u"&&typeof ee>"u"&&(fe=function(Re){return new Worker(Re)});var be=fe(ce);if(typeof be.postMessage!="function")throw new TypeError("Created worker does not provide the required 'postMessage' function.");this.worker=new D(be),this.worker.postMessage({cmd:"register",algorithms:Z}).then(function(me){return B.initialized=!0}).catch(console.err)}return j(I,[{key:"layout",value:function(F){var U=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},K=U.layoutOptions,Y=K===void 0?this.defaultLayoutOptions:K,Z=U.logging,ee=Z===void 0?!1:Z,ce=U.measureExecutionTime,fe=ce===void 0?!1:ce;return F?this.worker.postMessage({cmd:"layout",graph:F,layoutOptions:Y,options:{logging:ee,measureExecutionTime:fe}}):Promise.reject(new Error("Missing mandatory parameter 'graph'."))}},{key:"knownLayoutAlgorithms",value:function(){return this.worker.postMessage({cmd:"algorithms"})}},{key:"knownLayoutOptions",value:function(){return this.worker.postMessage({cmd:"options"})}},{key:"knownLayoutCategories",value:function(){return this.worker.postMessage({cmd:"categories"})}},{key:"terminateWorker",value:function(){this.worker&&this.worker.terminate()}}])})();var D=(function(){function I(B){var F=this;if(p(this,I),B===void 0)throw new Error("Missing mandatory parameter 'worker'.");this.resolvers={},this.worker=B,this.worker.onmessage=function(U){setTimeout(function(){F.receive(F,U)},0)}}return j(I,[{key:"postMessage",value:function(F){var U=this.id||0;this.id=U+1,F.id=U;var K=this;return new Promise(function(Y,Z){K.resolvers[U]=function(ee,ce){ee?(K.convertGwtStyleError(ee),Z(ee)):Y(ce)},K.worker.postMessage(F)})}},{key:"receive",value:function(F,U){var K=U.data,Y=F.resolvers[K.id];Y&&(delete F.resolvers[K.id],K.error?Y(K.error):Y(null,K.data))}},{key:"terminate",value:function(){this.worker&&this.worker.terminate()}},{key:"convertGwtStyleError",value:function(F){if(F){var U=F.__java$exception;U&&(U.cause&&U.cause.backingJsObject&&(F.cause=U.cause.backingJsObject,this.convertGwtStyleError(F.cause)),delete F.__java$exception)}}}])})()},{}],2:[function(u,h,g){(function(w){(function(){var p;typeof window<"u"?p=window:typeof w<"u"?p=w:typeof self<"u"&&(p=self);var k;function j(){}function A(){}function _(){}function D(){}function I(){}function B(){}function F(){}function U(){}function K(){}function Y(){}function Z(){}function ee(){}function ce(){}function fe(){}function be(){}function me(){}function Re(){}function Te(){}function Ke(){}function ze(){}function je(){}function te(){}function ge(){}function He(){}function ae(){}function Le(){}function Oe(){}function Qe(){}function kt(){}function Ae(){}function Ye(){}function mt(){}function Ue(){}function Pt(){}function rn(){}function Cn(){}function Pn(){}function mi(){}function er(){}function Mr(){}function hr(){}function Gn(){}function Ir(){}function is(){}function bs(){}function bo(){}function Bl(){}function Zl(){}function rs(){}function Ls(){}function f1(){}function mo(){}function eu(){}function Un(){}function Rc(){}function io(){}function zf(){}function tu(){}function Kw(){}function uO(){}function aO(){}function Cp(){}function Ff(){}function lg(){}function qf(){}function fO(){}function hO(){}function dO(){}function Yw(){}function Zw(){}function e2(){}function f0(){}function t2(){}function im(){}function gO(){}function _y(){}function Ti(){}function gu(){}function gh(){}function h0(){}function pO(){}function M8(){}function Dy(){}function bO(){}function A8(){}function mO(){}function Mp(){}function Pa(){}function ph(){}function rm(){}function e4(){}function N8(){}function MM(){}function _8(){}function Ly(){}function wO(){}function Ap(){}function n2(){}function i2(){}function r2(){}function ra(){}function D8(){}function L8(){}function sm(){}function s2(){}function AM(){}function vO(){}function P8(){}function I8(){}function Py(){}function t4(){}function d0(){}function Ed(){}function R8(){}function NM(){}function o2(){}function $8(){}function Iy(){}function _M(){}function Cd(){}function Ry(){}function B8(){}function yO(){}function om(){}function QI(){}function GI(){}function n4(){}function BV(){}function UI(){}function JI(){}function DM(){}function zV(){}function FV(){}function z8(){}function cm(){}function LM(){}function PM(){}function i4(){}function r4(){}function XI(){}function IM(){}function VI(){}function xO(){}function lm(){}function RM(){}function kO(){}function c2(){}function $M(){}function F8(){}function WI(){}function q8(){}function H8(){}function KI(){}function Md(){}function $y(){}function Q8(){}function OO(){}function qV(){}function BM(){}function zM(){}function SO(){}function G8(){}function YI(){}function HV(){}function QV(){}function GV(){}function FM(){}function UV(){}function JV(){}function XV(){}function VV(){}function WV(){}function ZI(){}function KV(){}function YV(){}function ZV(){}function eW(){}function qM(){}function tW(){}function nW(){}function iW(){}function eR(){}function rW(){}function sW(){}function oW(){}function cW(){}function lW(){}function uW(){}function aW(){}function fW(){}function hW(){}function HM(){}function jO(){}function dW(){}function tR(){}function nR(){}function iR(){}function rR(){}function sR(){}function s4(){}function gW(){}function pW(){}function bW(){}function oR(){}function cR(){}function TO(){}function EO(){}function mW(){}function U8(){}function lR(){}function QM(){}function GM(){}function UM(){}function uR(){}function aR(){}function fR(){}function wW(){}function vW(){}function yW(){}function xW(){}function kW(){}function h1(){}function CO(){}function hR(){}function dR(){}function gR(){}function pR(){}function JM(){}function OW(){}function o4(){}function XM(){}function MO(){}function VM(){}function bR(){}function By(){}function c4(){}function WM(){}function mR(){}function zy(){}function wR(){}function vR(){}function yR(){}function SW(){}function jW(){}function TW(){}function xR(){}function kR(){}function KM(){}function g0(){}function J8(){}function ug(){}function l4(){}function YM(){}function X8(){}function V8(){}function ZM(){}function Fy(){}function OR(){}function W8(){}function u4(){}function EW(){}function d1(){}function eA(){}function um(){}function SR(){}function K8(){}function qy(){}function tA(){}function jR(){}function nA(){}function TR(){}function ag(){}function a4(){}function f4(){}function Y8(){}function AO(){}function fg(){}function hg(){}function l2(){}function Np(){}function _p(){}function am(){}function ER(){}function iA(){}function rA(){}function CR(){}function cf(){}function Sl(){}function ko(){}function u2(){}function dg(){}function sA(){}function a2(){}function MR(){}function AR(){}function h4(){}function Hy(){}function d4(){}function f2(){}function oA(){}function Qy(){}function Dp(){}function h2(){}function fm(){}function cA(){}function lA(){}function g4(){}function NO(){}function d2(){}function Hf(){}function _O(){}function uA(){}function CW(){}function MW(){}function DO(){}function sa(){}function aA(){}function LO(){}function PO(){}function fA(){}function p4(){}function b4(){}function AW(){}function NR(){}function NW(){}function _R(){}function Gy(){}function hA(){}function Z8(){}function DR(){}function m4(){}function dA(){}function ej(){}function tj(){}function gA(){}function LR(){}function Uy(){}function Jy(){}function PR(){}function IR(){}function w4(){}function IO(){}function nj(){}function RO(){}function ij(){}function RR(){}function Xy(){}function $R(){}function g2(){}function pA(){}function bA(){}function p2(){}function b2(){}function $O(){}function mA(){}function wA(){}function BO(){}function zO(){}function BR(){}function zR(){}function v4(){}function rj(){}function FR(){}function vA(){}function yA(){}function g1(){}function gg(){}function m2(){}function xA(){}function qR(){}function w2(){}function p1(){}function Nu(){}function sj(){}function hm(){}function Ts(){}function $c(){}function oa(){}function oj(){}function y4(){}function Vy(){}function cj(){}function FO(){}function x4(){}function _W(){}function pu(){}function kA(){}function OA(){}function HR(){}function QR(){}function DW(){}function SA(){}function jA(){}function TA(){}function Vh(){}function _u(){}function lj(){}function qO(){}function uj(){}function EA(){}function dm(){}function aj(){}function CA(){}function GR(){}function UR(){}function JR(){}function XR(){}function VR(){}function WR(){}function KR(){}function MA(){}function YR(){}function LW(){}function ZR(){}function e$(){}function t$(){}function AA(){}function n$(){}function i$(){}function r$(){}function s$(){}function o$(){}function PW(){}function c$(){}function k4(){}function l$(){}function fj(){}function hj(){}function u$(){}function NA(){}function IW(){}function a$(){}function f$(){}function h$(){}function d$(){}function g$(){}function _A(){}function p$(){}function b$(){}function DA(){}function m$(){}function w$(){}function LA(){}function HO(){}function v$(){}function dj(){}function PA(){}function y$(){}function x$(){}function RW(){}function $W(){}function k$(){}function QO(){}function IA(){}function gj(){}function O$(){}function S$(){}function GO(){}function j$(){}function RA(){}function BW(){}function $A(){}function pj(){}function T$(){}function E$(){}function Wy(){}function C$(){}function M$(){}function A$(){}function bj(){}function N$(){}function BA(){}function _$(){}function b1(){}function zW(){}function Lp(){}function Du(){}function Qf(){}function D$(){}function L$(){}function P$(){}function I$(){}function UO(){}function R$(){}function mj(){}function $$(){}function FW(){}function wj(){}function zA(){}function B$(){}function z$(){}function F$(){}function FA(){}function qA(){}function HA(){}function q$(){}function QA(){}function tt(){}function GA(){}function H$(){}function UA(){}function Q$(){}function gm(){}function JA(){}function qW(){}function G$(){}function pm(){}function XA(){}function U$(){}function O4(){}function JO(){}function jl(){}function VA(){}function HW(){}function J$(){}function XO(){}function v2(){}function vj(){}function VO(){}function y2(){}function Pp(){}function WA(){}function KA(){}function X$(){}function S4(){}function YA(){}function yj(){}function V$(){}function pg(){}function ca(){}function ZA(){}function W$(){}function lf(){}function xj(){}function K$(){}function eN(){}function zl(){}function bh(){}function Ip(){}function Y$(){}function Z$(){}function eB(){}function QW(){}function tN(){}function Ad(){}function p0(){}function tB(){}function Nd(){}function nB(){}function bm(){}function Ky(){}function mm(){}function nN(){}function iN(){}function Gf(){}function kj(){}function j4(){}function WO(){}function KO(){}function T4(){}function iB(){}function rB(){}function YO(){}function sB(){}function Oj(){}function oB(){}function GW(){}function UW(){}function rc(){}function Yc(){}function ro(){}function wo(){}function kc(){}function m1(){}function x2(){}function E4(){}function rN(){}function wm(){}function bu(){}function k2(){}function Yy(){}function sN(){}function w1(){}function C4(){}function ZO(){}function _d(){}function oN(){}function Sj(){}function cB(){}function jj(){}function Tj(){}function O2(){}function Ia(){}function S2(){}function M4(){}function vm(){}function cN(){}function lN(){}function lB(){}function e6(){}function uN(){}function v1(){}function uB(){}function Dd(){}function aB(){}function fB(){}function JW(){}function j2(){}function Ej(){}function aN(){}function A4(){}function hB(){}function dB(){}function gB(){}function pB(){}function Cj(){}function fN(){}function XW(){}function VW(){}function WW(){}function bB(){}function mB(){}function N4(){}function Mj(){}function wB(){}function vB(){}function yB(){}function xB(){}function kB(){}function OB(){}function Aj(){}function SB(){}function jB(){}function Oc(){}function hN(){}function KW(){}function TB(){}function YW(){}function ZW(){}function eK(){}function Nj(){}function _4(){}function dN(){}function _j(){}function gN(){}function T2(){}function Rp(){}function t6(){}function tK(){}function EB(){}function CB(){}function MB(){}function AB(){}function nK(){}function pN(){}function NB(){}function _B(){}function DB(){}function bN(){}function mN(){}function wN(){Kj()}function iK(){U2e()}function n6(){t_()}function rK(){Sf()}function LB(){n2e()}function so(){DD()}function vN(){C_()}function Dj(){e_()}function yN(){_Ie()}function PB(){_5()}function xN(){hUe()}function i6(){aS()}function Lj(){z0()}function sK(){ime()}function IB(){RXe()}function oK(){$Xe()}function cK(){Pz()}function RB(){Kye()}function $B(){tQe()}function Bc(){JUe()}function kN(){nme()}function Uf(){ZHe()}function lK(){YHe()}function BB(){eQe()}function uK(){iQe()}function ON(){Ge()}function SN(){BXe()}function Pj(){HQe()}function zB(){zXe()}function FB(){rQe()}function jN(){A5()}function TN(){fVe()}function aK(){lye()}function qB(){F0()}function fK(){nQe()}function HB(){QYe()}function hK(){xit()}function dK(){Ove()}function E2(){Uo()}function QB(){Ah()}function GB(){vye()}function EN(){KWe()}function gK(){L1()}function pK(){$D()}function UB(){sie()}function CN(){pne()}function MN(){xwe()}function bK(){q5()}function bg(){Hq()}function AN(){fQ()}function NN(){Dn()}function JB(){SH()}function XB(){_we()}function D4(){_Q()}function y1(){dte()}function la(){Lze()}function Ij(){kye()}function $p(e){zt(e)}function mK(e){this.a=e}function Rj(e){this.a=e}function L4(e){this.a=e}function VB(e){this.a=e}function wK(e){this.a=e}function WB(e){this.a=e}function KB(e){this.a=e}function vK(e){this.a=e}function _N(e){this.a=e}function yK(e){this.a=e}function xK(e){this.a=e}function YB(e){this.a=e}function P4(e){this.a=e}function r6(e){this.c=e}function ZB(e){this.a=e}function DN(e){this.a=e}function I4(e){this.a=e}function s6(e){this.a=e}function ez(e){this.a=e}function R4(e){this.a=e}function LN(e){this.a=e}function PN(e){this.a=e}function $4(e){this.a=e}function tz(e){this.a=e}function $j(e){this.a=e}function kK(e){this.a=e}function nz(e){this.a=e}function OK(e){this.a=e}function IN(e){this.a=e}function SK(e){this.a=e}function Bj(e){this.a=e}function zj(e){this.a=e}function Fj(e){this.a=e}function jK(e){this.a=e}function o6(e){this.a=e}function TK(e){this.a=e}function iz(e){this.a=e}function rz(e){this.a=e}function sz(e){this.a=e}function RN(e){this.a=e}function qj(e){this.a=e}function c6(e){this.a=e}function B4(e){this.a=e}function l6(e){this.b=e}function mg(){this.a=[]}function EK(e,t){e.a=t}function oz(e,t){e.a=t}function cz(e,t){e.b=t}function $N(e,t){e.c=t}function lz(e,t){e.c=t}function CK(e,t){e.d=t}function uz(e,t){e.d=t}function mu(e,t){e.k=t}function ym(e,t){e.j=t}function Zy(e,t){e.c=t}function z4(e,t){e.c=t}function F4(e,t){e.a=t}function ex(e,t){e.a=t}function ode(e,t){e.f=t}function MK(e,t){e.a=t}function Hj(e,t){e.b=t}function BN(e,t){e.d=t}function u6(e,t){e.i=t}function a6(e,t){e.o=t}function AK(e,t){e.r=t}function cde(e,t){e.a=t}function zN(e,t){e.b=t}function Qj(e,t){e.e=t}function NK(e,t){e.f=t}function tx(e,t){e.g=t}function _K(e,t){e.e=t}function az(e,t){e.f=t}function FN(e,t){e.f=t}function q4(e,t){e.b=t}function qN(e,t){e.b=t}function H4(e,t){e.a=t}function m(e,t){e.n=t}function y(e,t){e.a=t}function O(e,t){e.c=t}function N(e,t){e.c=t}function $(e,t){e.c=t}function q(e,t){e.a=t}function le(e,t){e.a=t}function Ce(e,t){e.d=t}function dt(e,t){e.d=t}function Ft(e,t){e.e=t}function gn(e,t){e.e=t}function xn(e,t){e.g=t}function Zt(e,t){e.f=t}function on(e,t){e.j=t}function Wi(e,t){e.a=t}function qr(e,t){e.a=t}function Zc(e,t){e.b=t}function At(e){e.b=e.a}function yt(e){e.c=e.d.d}function $t(e){this.a=e}function an(e){this.a=e}function mr(e){this.a=e}function Fo(e){this.a=e}function rr(e){this.a=e}function ds(e){this.a=e}function Fs(e){this.a=e}function qo(e){this.a=e}function xm(e){this.a=e}function Bp(e){this.a=e}function DK(e){this.a=e}function x1(e){this.a=e}function C2(e){this.a=e}function PAe(e){this.a=e}function IAe(e){this.a=e}function lde(e){this.a=e}function RAe(e){this.a=e}function Xn(e){this.a=e}function Gj(e){this.d=e}function LK(e){this.b=e}function f6(e){this.b=e}function nx(e){this.b=e}function PK(e){this.c=e}function G(e){this.c=e}function $Ae(e){this.c=e}function BAe(e){this.a=e}function ude(e){this.a=e}function ade(e){this.a=e}function fde(e){this.a=e}function hde(e){this.a=e}function dde(e){this.a=e}function gde(e){this.a=e}function h6(e){this.a=e}function zAe(e){this.a=e}function FAe(e){this.a=e}function d6(e){this.a=e}function qAe(e){this.a=e}function HAe(e){this.a=e}function QAe(e){this.a=e}function GAe(e){this.a=e}function UAe(e){this.a=e}function JAe(e){this.a=e}function XAe(e){this.a=e}function VAe(e){this.a=e}function WAe(e){this.a=e}function g6(e){this.a=e}function KAe(e){this.a=e}function YAe(e){this.a=e}function ZAe(e){this.a=e}function eNe(e){this.a=e}function fz(e){this.a=e}function tNe(e){this.a=e}function nNe(e){this.a=e}function pde(e){this.a=e}function iNe(e){this.a=e}function rNe(e){this.a=e}function sNe(e){this.a=e}function bde(e){this.a=e}function mde(e){this.a=e}function wde(e){this.a=e}function Uj(e){this.a=e}function hz(e){this.e=e}function p6(e){this.a=e}function oNe(e){this.a=e}function Q4(e){this.a=e}function vde(e){this.a=e}function cNe(e){this.a=e}function lNe(e){this.a=e}function uNe(e){this.a=e}function aNe(e){this.a=e}function fNe(e){this.a=e}function hNe(e){this.a=e}function dNe(e){this.a=e}function gNe(e){this.a=e}function pNe(e){this.a=e}function bNe(e){this.a=e}function mNe(e){this.a=e}function yde(e){this.a=e}function wNe(e){this.a=e}function vNe(e){this.a=e}function yNe(e){this.a=e}function xNe(e){this.a=e}function kNe(e){this.a=e}function ONe(e){this.a=e}function SNe(e){this.a=e}function jNe(e){this.a=e}function TNe(e){this.a=e}function ENe(e){this.a=e}function CNe(e){this.a=e}function MNe(e){this.a=e}function ANe(e){this.a=e}function NNe(e){this.a=e}function _Ne(e){this.a=e}function DNe(e){this.a=e}function LNe(e){this.a=e}function PNe(e){this.a=e}function INe(e){this.a=e}function RNe(e){this.a=e}function $Ne(e){this.a=e}function BNe(e){this.a=e}function zNe(e){this.a=e}function FNe(e){this.a=e}function qNe(e){this.a=e}function HNe(e){this.a=e}function QNe(e){this.a=e}function GNe(e){this.a=e}function UNe(e){this.a=e}function JNe(e){this.a=e}function XNe(e){this.a=e}function VNe(e){this.a=e}function WNe(e){this.a=e}function KNe(e){this.a=e}function YNe(e){this.a=e}function ZNe(e){this.a=e}function e_e(e){this.a=e}function t_e(e){this.a=e}function n_e(e){this.a=e}function i_e(e){this.a=e}function r_e(e){this.a=e}function s_e(e){this.a=e}function o_e(e){this.c=e}function c_e(e){this.b=e}function l_e(e){this.a=e}function u_e(e){this.a=e}function a_e(e){this.a=e}function f_e(e){this.a=e}function h_e(e){this.a=e}function d_e(e){this.a=e}function g_e(e){this.a=e}function p_e(e){this.a=e}function b_e(e){this.a=e}function m_e(e){this.a=e}function w_e(e){this.a=e}function v_e(e){this.a=e}function y_e(e){this.a=e}function x_e(e){this.a=e}function k_e(e){this.a=e}function O_e(e){this.a=e}function S_e(e){this.a=e}function j_e(e){this.a=e}function T_e(e){this.a=e}function E_e(e){this.a=e}function C_e(e){this.a=e}function M_e(e){this.a=e}function A_e(e){this.a=e}function N_e(e){this.a=e}function __e(e){this.a=e}function D_e(e){this.a=e}function L_e(e){this.a=e}function k1(e){this.a=e}function ix(e){this.a=e}function P_e(e){this.a=e}function I_e(e){this.a=e}function R_e(e){this.a=e}function $_e(e){this.a=e}function B_e(e){this.a=e}function z_e(e){this.a=e}function F_e(e){this.a=e}function q_e(e){this.a=e}function H_e(e){this.a=e}function Q_e(e){this.a=e}function G_e(e){this.a=e}function U_e(e){this.a=e}function J_e(e){this.a=e}function X_e(e){this.a=e}function V_e(e){this.a=e}function W_e(e){this.a=e}function K_e(e){this.a=e}function Y_e(e){this.a=e}function xde(e){this.a=e}function Z_e(e){this.a=e}function eDe(e){this.a=e}function tDe(e){this.a=e}function nDe(e){this.a=e}function iDe(e){this.a=e}function rDe(e){this.a=e}function sDe(e){this.a=e}function oDe(e){this.a=e}function dz(e){this.a=e}function cDe(e){this.f=e}function lDe(e){this.a=e}function uDe(e){this.a=e}function aDe(e){this.a=e}function fDe(e){this.a=e}function hDe(e){this.a=e}function dDe(e){this.a=e}function gDe(e){this.a=e}function pDe(e){this.a=e}function bDe(e){this.a=e}function mDe(e){this.a=e}function wDe(e){this.a=e}function vDe(e){this.a=e}function yDe(e){this.a=e}function xDe(e){this.a=e}function kDe(e){this.a=e}function ODe(e){this.a=e}function SDe(e){this.a=e}function jDe(e){this.a=e}function TDe(e){this.a=e}function EDe(e){this.a=e}function CDe(e){this.a=e}function MDe(e){this.a=e}function ADe(e){this.a=e}function NDe(e){this.a=e}function _De(e){this.a=e}function DDe(e){this.a=e}function LDe(e){this.a=e}function IK(e){this.a=e}function kde(e){this.a=e}function gi(e){this.b=e}function PDe(e){this.a=e}function IDe(e){this.a=e}function RDe(e){this.a=e}function $De(e){this.a=e}function BDe(e){this.a=e}function zDe(e){this.a=e}function FDe(e){this.a=e}function qDe(e){this.a=e}function HN(e){this.a=e}function HDe(e){this.a=e}function QDe(e){this.b=e}function Ode(e){this.c=e}function gz(e){this.e=e}function GDe(e){this.a=e}function pz(e){this.a=e}function bz(e){this.a=e}function RK(e){this.a=e}function UDe(e){this.d=e}function JDe(e){this.a=e}function Sde(e){this.a=e}function jde(e){this.a=e}function km(e){this.e=e}function FSt(){this.a=0}function Fe(){ZY(this)}function wn(){sc(this)}function $K(){Dqe(this)}function XDe(){}function Om(){this.c=MTe}function VDe(e,t){e.b+=t}function qSt(e,t){t.Wb(e)}function HSt(e){return e.a}function QSt(e){return e.a}function GSt(e){return e.a}function USt(e){return e.a}function JSt(e){return e.a}function J(e){return e.e}function XSt(){return null}function VSt(){return null}function WSt(e){throw J(e)}function G4(e){this.a=Rn(e)}function WDe(){this.a=this}function zp(){wBe.call(this)}function KSt(e){e.b.Mf(e.e)}function KDe(e){e.b=new tY}function Jj(e,t){e.b=t-e.b}function Xj(e,t){e.a=t-e.a}function YDe(e,t){t.gd(e.a)}function YSt(e,t){$r(t,e)}function It(e,t){e.push(t)}function ZDe(e,t){e.sort(t)}function ZSt(e,t,n){e.Wd(n,t)}function QN(e,t){e.e=t,t.b=e}function e9t(){r1e(),Uen()}function eLe(e){U6(),Aoe.je(e)}function Tde(){wBe.call(this)}function Ede(){zp.call(this)}function BK(){zp.call(this)}function tLe(){zp.call(this)}function GN(){zp.call(this)}function Tl(){zp.call(this)}function U4(){zp.call(this)}function $n(){zp.call(this)}function ua(){zp.call(this)}function nLe(){zp.call(this)}function Co(){zp.call(this)}function iLe(){zp.call(this)}function mz(){this.Bb|=256}function rLe(){this.b=new g$e}function Cde(){Cde=te,new wn}function sLe(){Ede.call(this)}function M2(e,t){e.length=t}function wz(e,t){qe(e.a,t)}function t9t(e,t){X2e(e.c,t)}function n9t(e,t){Sr(e.b,t)}function i9t(e,t){WH(e.a,t)}function r9t(e,t){Fte(e.a,t)}function b6(e,t){vi(e.e,t)}function J4(e){pQ(e.c,e.b)}function s9t(e,t){e.kc().Nb(t)}function Mde(e){this.a=C$t(e)}function Or(){this.a=new wn}function oLe(){this.a=new wn}function vz(){this.a=new Fe}function zK(){this.a=new Fe}function Ade(){this.a=new Fe}function Ra(){this.a=new aO}function Fp(){this.a=new aUe}function FK(){this.a=new jIe}function Nde(){this.a=new GHe}function _de(){this.a=new cze}function Dde(){this.a=new pO}function cLe(){this.a=new xQe}function lLe(){this.a=new Fe}function uLe(){this.a=new Fe}function aLe(){this.a=new Fe}function Lde(){this.a=new Fe}function fLe(){this.d=new Fe}function hLe(){this.a=new Or}function dLe(){this.a=new wn}function gLe(){this.b=new wn}function pLe(){this.b=new Fe}function Pde(){this.e=new Fe}function bLe(){this.d=new Fe}function mLe(){this.a=new Lj}function wLe(){xHe.call(this)}function vLe(){xHe.call(this)}function yLe(){zde.call(this)}function xLe(){zde.call(this)}function kLe(){zde.call(this)}function OLe(){Fe.call(this)}function SLe(){Lde.call(this)}function yz(){vz.call(this)}function jLe(){NF.call(this)}function Vj(){XDe.call(this)}function qK(){Vj.call(this)}function X4(){XDe.call(this)}function Ide(){X4.call(this)}function nu(){Ai.call(this)}function TLe(){Fde.call(this)}function Wj(){v2.call(this)}function Rde(){v2.call(this)}function ELe(){FLe.call(this)}function CLe(){FLe.call(this)}function MLe(){wn.call(this)}function ALe(){wn.call(this)}function NLe(){wn.call(this)}function HK(){DXe.call(this)}function _Le(){Or.call(this)}function DLe(){mz.call(this)}function QK(){Sge.call(this)}function $de(){wn.call(this)}function GK(){Sge.call(this)}function UK(){wn.call(this)}function LLe(){wn.call(this)}function Bde(){xj.call(this)}function PLe(){Bde.call(this)}function ILe(){xj.call(this)}function RLe(){DB.call(this)}function zde(){this.a=new Or}function $Le(){this.a=new wn}function Fde(){this.a=new wn}function V4(){this.a=new Ai}function BLe(){this.a=new Fe}function zLe(){this.j=new Fe}function FLe(){this.a=new ca}function qde(){this.a=new d$}function qLe(){this.a=new $Pe}function Kj(){Kj=te,koe=new A}function JK(){JK=te,Ooe=new QLe}function XK(){XK=te,Soe=new HLe}function HLe(){$4.call(this,"")}function QLe(){$4.call(this,"")}function GLe(e){sXe.call(this,e)}function ULe(e){sXe.call(this,e)}function Hde(e){WB.call(this,e)}function Qde(e){bIe.call(this,e)}function o9t(e){bIe.call(this,e)}function c9t(e){Qde.call(this,e)}function l9t(e){Qde.call(this,e)}function u9t(e){Qde.call(this,e)}function JLe(e){Nee.call(this,e)}function XLe(e){Nee.call(this,e)}function VLe(e){Y$e.call(this,e)}function WLe(e){a1e.call(this,e)}function Yj(e){Nz.call(this,e)}function Gde(e){Nz.call(this,e)}function KLe(e){Nz.call(this,e)}function Mo(e){JFe.call(this,e)}function YLe(e){Mo.call(this,e)}function W4(){B4.call(this,{})}function VK(e){C6(),this.a=e}function ZLe(e){e.b=null,e.c=0}function a9t(e,t){e.e=t,vnt(e,t)}function f9t(e,t){e.a=t,FQt(e)}function WK(e,t,n){e.a[t.g]=n}function h9t(e,t,n){cqt(n,e,t)}function d9t(e,t){tTt(t.i,e.n)}function ePe(e,t){wRt(e).Ad(t)}function g9t(e,t){return e*e/t}function tPe(e,t){return e.g-t.g}function p9t(e,t){e.a.ec().Kc(t)}function b9t(e){return new c6(e)}function m9t(e){return new J2(e)}function nPe(){nPe=te,Q5e=new j}function Ude(){Ude=te,G5e=new fe}function xz(){xz=te,EE=new Re}function kz(){kz=te,Toe=new K$e}function iPe(){iPe=te,Pat=new Ke}function Oz(e){xme(),this.a=e}function rPe(e){Dze(),this.a=e}function wg(e){LZ(),this.f=e}function KK(e){LZ(),this.f=e}function Sz(e){Mo.call(this,e)}function zc(e){Mo.call(this,e)}function sPe(e){Mo.call(this,e)}function YK(e){JFe.call(this,e)}function m6(e){Mo.call(this,e)}function qt(e){Mo.call(this,e)}function oo(e){Mo.call(this,e)}function oPe(e){Mo.call(this,e)}function K4(e){Mo.call(this,e)}function vg(e){Mo.call(this,e)}function Ho(e){zt(e),this.a=e}function Zj(e){npe(e,e.length)}function Jde(e){return fb(e),e}function A2(e){return!!e&&e.b}function w9t(e){return!!e&&e.k}function v9t(e){return!!e&&e.j}function e7(e){return e.b==e.c}function et(e){return zt(e),e}function ue(e){return zt(e),e}function UN(e){return zt(e),e}function Xde(e){return zt(e),e}function y9t(e){return zt(e),e}function Wh(e){Mo.call(this,e)}function Y4(e){Mo.call(this,e)}function Kh(e){Mo.call(this,e)}function Qn(e){Mo.call(this,e)}function ZK(e){Mo.call(this,e)}function eY(e){_ge.call(this,e,0)}function tY(){qpe.call(this,12,3)}function nY(){this.a=zn(Rn(Jc))}function cPe(){throw J(new $n)}function Vde(){throw J(new $n)}function lPe(){throw J(new $n)}function x9t(){throw J(new $n)}function k9t(){throw J(new $n)}function O9t(){throw J(new $n)}function jz(){jz=te,U6()}function yg(){ds.call(this,"")}function t7(){ds.call(this,"")}function b0(){ds.call(this,"")}function Z4(){ds.call(this,"")}function Wde(e){zc.call(this,e)}function Kde(e){zc.call(this,e)}function Yh(e){qt.call(this,e)}function w6(e){f6.call(this,e)}function uPe(e){w6.call(this,e)}function iY(e){TF.call(this,e)}function S9t(e,t,n){e.c.Cf(t,n)}function j9t(e,t,n){t.Ad(e.a[n])}function T9t(e,t,n){t.Ne(e.a[n])}function E9t(e,t){return e.a-t.a}function C9t(e,t){return e.a-t.a}function M9t(e,t){return e.a-t.a}function Tz(e,t){return Uee(e,t)}function V(e,t){return WHe(e,t)}function A9t(e,t){return t in e.a}function aPe(e){return e.a?e.b:0}function N9t(e){return e.a?e.b:0}function fPe(e,t){return e.f=t,e}function _9t(e,t){return e.b=t,e}function hPe(e,t){return e.c=t,e}function D9t(e,t){return e.g=t,e}function Yde(e,t){return e.a=t,e}function Zde(e,t){return e.f=t,e}function L9t(e,t){return e.k=t,e}function e1e(e,t){return e.e=t,e}function P9t(e,t){return e.e=t,e}function t1e(e,t){return e.a=t,e}function I9t(e,t){return e.f=t,e}function R9t(e,t){e.b=new Cs(t)}function dPe(e,t){e._d(t),t.$d(e)}function $9t(e,t){Pu(),t.n.a+=e}function B9t(e,t){z0(),_o(t,e)}function n1e(e){Zqe.call(this,e)}function gPe(e){Zqe.call(this,e)}function pPe(){age.call(this,"")}function bPe(){this.b=0,this.a=0}function mPe(){mPe=te,Xat=Lqt()}function Sm(e,t){return e.b=t,e}function JN(e,t){return e.a=t,e}function jm(e,t){return e.c=t,e}function Tm(e,t){return e.d=t,e}function Em(e,t){return e.e=t,e}function rY(e,t){return e.f=t,e}function n7(e,t){return e.a=t,e}function v6(e,t){return e.b=t,e}function y6(e,t){return e.c=t,e}function rt(e,t){return e.c=t,e}function vt(e,t){return e.b=t,e}function st(e,t){return e.d=t,e}function ot(e,t){return e.e=t,e}function z9t(e,t){return e.f=t,e}function ct(e,t){return e.g=t,e}function lt(e,t){return e.a=t,e}function ut(e,t){return e.i=t,e}function at(e,t){return e.j=t,e}function F9t(e,t){return e.g-t.g}function q9t(e,t){return e.b-t.b}function H9t(e,t){return e.s-t.s}function Q9t(e,t){return e?0:t-1}function wPe(e,t){return e?0:t-1}function G9t(e,t){return e?t-1:0}function U9t(e,t){return t.pg(e)}function vPe(e,t){return e.k=t,e}function J9t(e,t){return e.j=t,e}function as(){this.a=0,this.b=0}function Ez(e){wZ.call(this,e)}function m0(e){Um.call(this,e)}function yPe(e){lee.call(this,e)}function xPe(e){lee.call(this,e)}function kPe(e,t){e.b=0,iv(e,t)}function X9t(e,t){e.c=t,e.b=!0}function V9t(e,t,n){iMt(e.a,t,n)}function OPe(e,t){return e.c._b(t)}function Jf(e){return e.e&&e.e()}function sY(e){return e?e.d:null}function SPe(e,t){return QWe(e.b,t)}function W9t(e){return e?e.g:null}function K9t(e){return e?e.i:null}function jPe(e,t){return y8t(e.a,t)}function i1e(e,t){for(;e.zd(t););}function TPe(){throw J(new $n)}function w0(){w0=te,x2t=GFt()}function EPe(){EPe=te,Wr=tHt()}function r1e(){r1e=te,gp=rT()}function x6(){x6=te,CTe=UFt()}function CPe(){CPe=te,svt=JFt()}function s1e(){s1e=te,ic=$Qt()}function qp(e){return j1(e),e.o}function rx(e,t){return e.a+=t,e}function oY(e,t){return e.a+=t,e}function xg(e,t){return e.a+=t,e}function Cm(e,t){return e.a+=t,e}function o1e(e){nst(),stn(this,e)}function Cz(e){this.a=new e5(e)}function kg(e){this.a=new zZ(e)}function MPe(){throw J(new $n)}function APe(){throw J(new $n)}function NPe(){throw J(new $n)}function _Pe(){throw J(new $n)}function DPe(){throw J(new $n)}function LPe(){this.b=new DS(C9e)}function PPe(){this.a=new DS(u8e)}function Mz(e){this.a=0,this.b=e}function IPe(){this.a=new DS(D8e)}function RPe(){this.b=new DS(jue)}function $Pe(){this.b=new DS(jue)}function BPe(){this.a=new DS(Dje)}function zPe(e,t){return vXt(e,t)}function Y9t(e,t){return eYt(t,e)}function c1e(e,t){return e.d[t.p]}function XN(e){return e.b!=e.d.c}function FPe(e){return e.l|e.m<<22}function k6(e){return T0(e),e.a}function qPe(e){e.c?Pnt(e):Int(e)}function sx(e,t){for(;e.Pe(t););}function l1e(e,t,n){e.splice(t,n)}function HPe(){throw J(new $n)}function QPe(){throw J(new $n)}function GPe(){throw J(new $n)}function UPe(){throw J(new $n)}function JPe(){throw J(new $n)}function XPe(){throw J(new $n)}function VPe(){throw J(new $n)}function WPe(){throw J(new $n)}function KPe(){throw J(new $n)}function YPe(){throw J(new $n)}function Z9t(){throw J(new Co)}function e8t(){throw J(new Co)}function VN(e){this.a=new ZPe(e)}function ZPe(e){UPt(this,e,iQt())}function WN(e){return!e||Aqe(e)}function KN(e){return Uh[e]!=-1}function t8t(){VG!=0&&(VG=0),WG=-1}function eIe(){xoe==null&&(xoe=[])}function YN(e,t){wx.call(this,e,t)}function O6(e,t){YN.call(this,e,t)}function tIe(e,t){this.a=e,this.b=t}function nIe(e,t){this.a=e,this.b=t}function iIe(e,t){this.a=e,this.b=t}function rIe(e,t){this.a=e,this.b=t}function sIe(e,t){this.a=e,this.b=t}function oIe(e,t){this.a=e,this.b=t}function cIe(e,t){this.a=e,this.b=t}function S6(e,t){this.e=e,this.d=t}function u1e(e,t){this.b=e,this.c=t}function lIe(e,t){this.b=e,this.a=t}function uIe(e,t){this.b=e,this.a=t}function aIe(e,t){this.b=e,this.a=t}function fIe(e,t){this.b=e,this.a=t}function hIe(e,t){this.a=e,this.b=t}function dIe(e,t){this.a=e,this.b=t}function cY(e,t){this.a=e,this.b=t}function gIe(e,t){this.a=e,this.f=t}function Mm(e,t){this.g=e,this.i=t}function Sn(e,t){this.f=e,this.g=t}function pIe(e,t){this.b=e,this.c=t}function bIe(e){yge(e.dc()),this.c=e}function n8t(e,t){this.a=e,this.b=t}function mIe(e,t){this.a=e,this.b=t}function wIe(e){this.a=c(Rn(e),16)}function a1e(e){this.a=c(Rn(e),16)}function vIe(e){this.a=c(Rn(e),93)}function Az(e){this.b=c(Rn(e),93)}function Nz(e){this.b=c(Rn(e),51)}function _z(){this.q=new p.Date}function lY(e,t){this.a=e,this.b=t}function yIe(e,t){return jc(e.b,t)}function i7(e,t){return e.b.Gc(t)}function f1e(e,t){return e.b.Hc(t)}function h1e(e,t){return e.b.Oc(t)}function xIe(e,t){return e.b.Gc(t)}function kIe(e,t){return e.c.uc(t)}function OIe(e,t){return yi(e.c,t)}function $a(e,t){return e.a._b(t)}function SIe(e,t){return e>t&&t<KT}function r7(e){return e.f.c+e.i.c}function i8t(e){return mqe(),e?Lat:Dat}function e5(e){rWe.call(this,e,0)}function jIe(){zZ.call(this,null)}function t5(e){this.c=e,QJe(this)}function Ai(){B$e(this),Ou(this)}function Og(){Og=te,Bat=new ge}function j6(){j6=te,S9=new Oe}function N2(){N2=te,Ioe=new p$e}function Dz(){Dz=te,Wat=new b$e}function T6(){T6=te,wke=new hr}function Hp(){Hp=te,hk=new bo}function d1e(){Fee.call(this,null)}function lr(e,t){T0(e),e.a.Nb(t)}function r8t(e,t){return e.a.Vc(t)}function s8t(e,t){return e.a.Wc(t)}function uY(e,t){return e.a.Yc(t)}function aY(e,t){return e.a.Zc(t)}function o8t(e,t){return e.Fc(t),e}function c8t(e,t){Wne(Ne(e.a),t)}function l8t(e,t){Wne(Ne(e.a),t)}function uf(e,t){return e.a.e=t,e}function af(e,t){return e.a.a=t,e}function ff(e,t){return e.a.d=t,e}function TIe(e,t){return e.a.d=t,e}function u8t(e,t){return e.a.f=t,e}function EIe(e,t){return e.a.g=t,e}function CIe(e,t){return e.a.j=t,e}function hf(e,t){return e.a.g=t,e}function ZN(e,t){return e.a.f=t,e}function a8t(e){return e.b=!1,e}function MIe(){MIe=te,Cht=new i2}function g1e(){g1e=te,Mht=new BFe}function AIe(){AIe=te,oft=new Rc}function p1e(){p1e=te,Eht=new Pa}function e_(){e_=te,Qht=new PM}function b1e(){b1e=te,Hke=new MM}function NIe(){NIe=te,$ht=new vO}function s7(){s7=te,zht=new P8}function _Ie(){_Ie=te,Xht=new KV}function t_(){t_=te,Hht=new as}function Lz(){Lz=te,x0t=new G$}function o7(){o7=te,ndt=new qy}function Pz(){Pz=te,s3=new sA}function Iz(){Iz=te,Tue=new LIe}function Rz(){Rz=te,Eue=new ABe}function c7(){c7=te,SP=new Pqe}function $z(){$z=te,que=new DFe}function Bz(){Bz=te,Hue=new _Fe}function zz(){zz=te,Que=new sqe}function DIe(){IXe(),this.c=new tY}function LIe(){Sn.call(this,nct,0)}function f8t(e,t,n,i){mzt(e,i,t,n)}function h8t(e,t,n,i){MJt(i,e,t,n)}function d8t(e,t,n,i){cen(i,e,t,n)}function g8t(e,t,n){lo(e.d,t.f,n)}function Am(e,t){gb(e.c.b,t.c,t)}function l7(e,t){gb(e.c.c,t.b,t)}function u7(e,t){return e.a=t.g,e}function p8t(e){return e.e.a+e.f.a}function b8t(e){return e.e.b+e.f.b}function m8t(e){return(e.c+e.a)/2}function w8t(e){return e.b?e.b:e.a}function PIe(e,t){return OFt(e.a,t)}function m1e(){m1e=te,ETe=new LLe}function a7(){a7=te,Eae=new V$e}function Sg(){Sg=te,ZP=new W$e}function v0(){v0=te,v2t=new XO}function IIe(){IIe=te,E2t=new lf}function RIe(){RIe=te,z2t=new ALe}function $Ie(){$Ie=te,F2t=new NLe}function y0(){y0=te,nf=new $de}function Fz(){Fz=te,cX=new wn}function w1e(){w1e=te,$Te=new Fe}function x0(){x0=te,wp=new mN}function fY(){fY=te,tvt=new v1}function qs(){qs=te,ivt=new uB}function v1e(e){nee(),ZHt.call(this,e)}function y1e(e){nee(),v1e.call(this,e)}function x1e(e){AZ(),Y$e.call(this,e)}function v8t(e,t){UHe.call(this,e,t)}function qz(e,t){this.d=e,this.e=t}function hY(e,t){return Mc(e,t)>0}function dY(e,t){return Mc(e,t)<0}function BIe(e,t){return _Z(e.a,t)}function y8t(e,t){return e.a.a.cc(t)}function gY(e){return e.b<e.d.gc()}function f7(e,t){return e.a.get(t)}function x8t(e,t){return t.split(e)}function zIe(e,t){return jc(e.e,t)}function Hz(e){return c(e,45).jd()}function k1e(e){return zt(e),!1}function O1e(e){this.a=c(Rn(e),231)}function Qz(e){Tt.call(this,e,21)}function Gz(e,t){Sn.call(this,e,t)}function pY(e,t){Sn.call(this,e,t)}function FIe(e,t){this.b=e,this.a=t}function qIe(e,t){this.a=e,this.b=t}function HIe(e,t){this.a=e,this.b=t}function QIe(e,t){this.a=e,this.b=t}function GIe(e,t){this.a=e,this.b=t}function UIe(e,t){this.b=e,this.a=t}function S1e(e,t){IFe(e,e.length,t)}function n_(e,t){gqe(e,e.length,t)}function k8t(e,t,n){t.Ne(e.a.We(n))}function O8t(e,t,n){t.Bd(e.a.Xe(n))}function S8t(e,t,n){t.Ad(e.a.Kb(n))}function j8t(e,t,n){e.Mb(n)&&t.Ad(n)}function h7(e,t,n){e.splice(t,0,n)}function bY(e,t){Sn.call(this,e,t)}function mY(e,t){Sn.call(this,e,t)}function wY(e,t){Sn.call(this,e,t)}function Uz(e,t){Sn.call(this,e,t)}function j1e(e,t){Sn.call(this,e,t)}function vY(e,t){Sn.call(this,e,t)}function i_(e,t){Sn.call(this,e,t)}function n5(e,t){this.a=e,this.b=t}function T1e(e,t){this.b=e,this.a=t}function E1e(e,t){this.b=e,this.a=t}function JIe(e,t){this.b=e,this.a=t}function C1e(e,t){this.b=e,this.a=t}function E6(e,t){this.c=e,this.d=t}function XIe(e,t){this.e=e,this.d=t}function VIe(e,t){this.a=e,this.b=t}function i5(e,t){Sn.call(this,e,t)}function Jz(e,t){Sn.call(this,e,t)}function Er(e,t){Sn.call(this,e,t)}function Xz(e,t){Sn.call(this,e,t)}function M1e(e,t){Sn.call(this,e,t)}function Vz(e,t){Sn.call(this,e,t)}function WIe(e,t){this.a=e,this.b=t}function KIe(e,t){this.a=e,this.b=t}function YIe(e,t){this.a=e,this.b=t}function ZIe(e,t){this.a=e,this.b=t}function eRe(e,t){this.a=e,this.b=t}function tRe(e,t){this.a=e,this.b=t}function nRe(e,t){this.a=e,this.b=t}function iRe(e,t){this.a=e,this.b=t}function rRe(e,t){this.b=e,this.a=t}function sRe(e,t){this.b=e,this.a=t}function oRe(e,t){this.b=t,this.c=e}function Wz(e,t){Sn.call(this,e,t)}function r_(e,t){Sn.call(this,e,t)}function yY(e,t){Sn.call(this,e,t)}function d7(e,t){Sn.call(this,e,t)}function A1e(e,t){Sn.call(this,e,t)}function Kz(e,t){Sn.call(this,e,t)}function xY(e,t){Sn.call(this,e,t)}function ox(e,t){Sn.call(this,e,t)}function N1e(e,t){Sn.call(this,e,t)}function kY(e,t){Sn.call(this,e,t)}function g7(e,t){Sn.call(this,e,t)}function _1e(e,t){Sn.call(this,e,t)}function p7(e,t){Sn.call(this,e,t)}function b7(e,t){Sn.call(this,e,t)}function _2(e,t){Sn.call(this,e,t)}function OY(e,t){Sn.call(this,e,t)}function SY(e,t){Sn.call(this,e,t)}function jY(e,t){Sn.call(this,e,t)}function D1e(e,t){Sn.call(this,e,t)}function s_(e,t){Sn.call(this,e,t)}function L1e(e,t){Sn.call(this,e,t)}function cx(e,t){Sn.call(this,e,t)}function TY(e,t){Sn.call(this,e,t)}function Yz(e,t){Sn.call(this,e,t)}function o_(e,t){Sn.call(this,e,t)}function D2(e,t){Sn.call(this,e,t)}function Zz(e,t){Sn.call(this,e,t)}function P1e(e,t){Sn.call(this,e,t)}function EY(e,t){Sn.call(this,e,t)}function CY(e,t){Sn.call(this,e,t)}function MY(e,t){Sn.call(this,e,t)}function AY(e,t){Sn.call(this,e,t)}function NY(e,t){Sn.call(this,e,t)}function _Y(e,t){Sn.call(this,e,t)}function cRe(e,t){this.b=e,this.a=t}function T8t(e,t){return Cl(e.e,t)}function E8t(e,t){return Cl(e.c,t)}function C8t(e,t){return Cl(t.b,e)}function M8t(e,t){return L6(),t!=e}function c_(e){return dn(e.a),e.b}function DY(e){return UGt(e,e.c),e}function lRe(){return mPe(),new Xat}function uRe(){IF(),this.a=new n0e}function aRe(e,t){this.a=e,this.b=t}function fRe(e,t){this.a=e,this.b=t}function hRe(e,t){this.a=e,this.b=t}function dRe(e,t){this.b=e,this.a=t}function gRe(e,t){this.a=e,this.b=t}function I1e(e,t){Sn.call(this,e,t)}function R1e(e,t){Sn.call(this,e,t)}function eF(e,t){Sn.call(this,e,t)}function $1e(e,t){Sn.call(this,e,t)}function B1e(e,t){Sn.call(this,e,t)}function z1e(e,t){Sn.call(this,e,t)}function pRe(e,t){this.a=e,this.b=t}function bRe(e,t){this.a=e,this.b=t}function mRe(e,t){this.a=e,this.b=t}function wRe(e,t){this.b=e,this.d=t}function vRe(e,t){this.b=e,this.a=t}function tF(e,t){Sn.call(this,e,t)}function Nm(e,t){Sn.call(this,e,t)}function LY(e,t){Sn.call(this,e,t)}function nF(e,t){Sn.call(this,e,t)}function F1e(e,t){Sn.call(this,e,t)}function yRe(e,t){this.b=e,this.a=t}function xRe(e,t){this.b=e,this.a=t}function kRe(e,t){this.b=e,this.a=t}function ORe(e,t){this.b=e,this.a=t}function q1e(e,t){Sn.call(this,e,t)}function l_(e,t){Sn.call(this,e,t)}function H1e(e,t){Sn.call(this,e,t)}function PY(e,t){Sn.call(this,e,t)}function iF(e,t){Sn.call(this,e,t)}function IY(e,t){Sn.call(this,e,t)}function RY(e,t){Sn.call(this,e,t)}function rF(e,t){Sn.call(this,e,t)}function $Y(e,t){Sn.call(this,e,t)}function Q1e(e,t){Sn.call(this,e,t)}function BY(e,t){Sn.call(this,e,t)}function zY(e,t){Sn.call(this,e,t)}function u_(e,t){Sn.call(this,e,t)}function FY(e,t){Sn.call(this,e,t)}function G1e(e,t){Sn.call(this,e,t)}function a_(e,t){Sn.call(this,e,t)}function U1e(e,t){Sn.call(this,e,t)}function J1e(e,t){Sn.call(this,e,t)}function sF(e,t){Sn.call(this,e,t)}function X1e(e,t){Sn.call(this,e,t)}function SRe(e,t){this.a=e,this.b=t}function jRe(e,t){this.a=e,this.b=t}function V1e(e,t){this.a=e,this.b=t}function f_(e,t){Sn.call(this,e,t)}function r5(e,t){Sn.call(this,e,t)}function $e(e,t){this.a=e,this.b=t}function m7(e,t){Sn.call(this,e,t)}function w7(e,t){Sn.call(this,e,t)}function h_(e,t){Sn.call(this,e,t)}function oF(e,t){Sn.call(this,e,t)}function qY(e,t){Sn.call(this,e,t)}function cF(e,t){Sn.call(this,e,t)}function v7(e,t){Sn.call(this,e,t)}function HY(e,t){Sn.call(this,e,t)}function lF(e,t){Sn.call(this,e,t)}function lx(e,t){Sn.call(this,e,t)}function d_(e,t){Sn.call(this,e,t)}function y7(e,t){Sn.call(this,e,t)}function x7(e,t){Sn.call(this,e,t)}function g_(e,t){Sn.call(this,e,t)}function QY(e,t){Sn.call(this,e,t)}function uF(e,t){Sn.call(this,e,t)}function ux(e,t){Sn.call(this,e,t)}function GY(e,t){Sn.call(this,e,t)}function UY(e,t){Sn.call(this,e,t)}function aF(e,t){Sn.call(this,e,t)}function TRe(e,t){this.a=e,this.b=t}function ERe(e,t){this.a=e,this.b=t}function CRe(e,t){this.a=e,this.b=t}function MRe(e,t){this.a=e,this.b=t}function ARe(e,t){this.a=e,this.b=t}function NRe(e,t){this.a=e,this.b=t}function fF(e,t){Sn.call(this,e,t)}function Ps(e,t){this.a=e,this.b=t}function _Re(){jQ(),this.a=new Or}function DRe(){mee(),this.b=new Or}function LRe(){Bpe(),Q0e.call(this)}function PRe(){zpe(),yHe.call(this)}function IRe(){zpe(),yHe.call(this)}function RRe(e,t){VLt(e.a,c(t,12))}function A8t(e,t,n){aZe(t,Gne(e,n))}function N8t(e,t,n){aZe(t,Gne(e,n))}function W1e(e,t){return Cl(e.g,t)}function _8t(e,t){return-e.b.$e(t)}function $Re(e,t){this.a=e,this.b=t}function BRe(e,t){this.a=e,this.b=t}function zRe(e,t){this.a=e,this.b=t}function FRe(e,t){this.a=e,this.b=t}function qRe(e,t){this.a=e,this.b=t}function HRe(e,t){this.a=e,this.b=t}function QRe(e,t){this.a=e,this.b=t}function GRe(e,t){this.a=e,this.b=t}function URe(e,t){this.a=e,this.b=t}function JRe(e,t){this.a=e,this.b=t}function XRe(e,t){this.b=e,this.a=t}function VRe(e,t){this.b=e,this.a=t}function WRe(e,t){this.b=e,this.a=t}function KRe(e,t){this.b=e,this.a=t}function YRe(e,t){this.f=e,this.c=t}function K1e(e,t){this.i=e,this.g=t}function hF(e,t){this.a=e,this.b=t}function ZRe(e,t){this.a=e,this.b=t}function e$e(e,t){this.a=e,this.b=t}function t$e(e,t){this.a=e,this.b=t}function Y1e(e,t){this.d=e,this.e=t}function n$e(e,t){this.d=e,this.b=t}function i$e(e,t){this.a=e,this.b=t}function r$e(e,t){this.e=e,this.a=t}function p_(e,t){this.b=e,this.c=t}function s5(e,t){Sn.call(this,e,t)}function D8t(e,t){e&&oi(WP,e,t)}function Z1e(e,t){e.i=null,aH(e,t)}function s$e(e,t){return Wte(e.a,t)}function dF(e){return ED(e.c,e.b)}function Ao(e){return e?e.kd():null}function ve(e){return e??null}function L2(e){return typeof e===K5}function P2(e){return typeof e===Zye}function Kr(e){return typeof e===Iie}function k7(e,t){return Mc(e,t)==0}function gF(e,t){return Mc(e,t)>=0}function O7(e,t){return Mc(e,t)!=0}function k0(e,t){return e.Pd().Xb(t)}function pF(e,t){return vIt(e.Jc(),t)}function L8t(e){return""+(zt(e),e)}function ege(e,t){return e.a+=""+t,e}function S7(e,t){return e.a+=""+t,e}function Ys(e,t){return e.a+=""+t,e}function j7(e,t){return e.a+=""+t,e}function Sc(e,t){return e.a+=""+t,e}function Zn(e,t){return e.a+=""+t,e}function bF(e){return L7(e==null),e}function tge(e){return ht(e,0),null}function o$e(e){return cu(e),e.d.gc()}function P8t(e){p.clearTimeout(e)}function c$e(e,t){e.q.setTime(ib(t))}function I8t(e,t){cPt(new cn(e),t)}function l$e(e,t){Y0e.call(this,e,t)}function u$e(e,t){Y0e.call(this,e,t)}function mF(e,t){Y0e.call(this,e,t)}function Es(e,t){tr(e,t,e.c.b,e.c)}function ax(e,t){tr(e,t,e.a,e.a.a)}function R8t(e,t){return e.j[t.p]==2}function a$e(e,t){return e.a=t.g+1,e}function Xf(e){return e.a=0,e.b=0,e}function f$e(){f$e=te,Bft=Tn(sne())}function h$e(){h$e=te,Jht=Tn(ant())}function d$e(){d$e=te,Bpt=Tn(bVe())}function g$e(){this.b=new e5(ov(12))}function p$e(){this.b=0,this.a=!1}function b$e(){this.b=0,this.a=!1}function T7(e){this.a=e,wN.call(this)}function m$e(e){this.a=e,wN.call(this)}function wt(e,t){qi.call(this,e,t)}function JY(e,t){F2.call(this,e,t)}function fx(e,t){K1e.call(this,e,t)}function w$e(e,t){y_.call(this,e,t)}function XY(e,t){oS.call(this,e,t)}function li(e,t){Fz(),oi(cX,e,t)}function VY(e,t){return Fa(e.a,0,t)}function v$e(e,t){return ve(e)===ve(t)}function $8t(e,t){return ji(e.a,t.a)}function nge(e,t){return fc(e.a,t.a)}function B8t(e,t){return fqe(e.a,t.a)}function o5(e){return xs((zt(e),e))}function z8t(e){return xs((zt(e),e))}function y$e(e){return el(e.l,e.m,e.h)}function F8t(e){return Rn(e),new T7(e)}function Zh(e,t){return e.indexOf(t)}function Oo(e){return typeof e===Zye}function wF(e){return e<10?"0"+e:""+e}function q8t(e){return e==jw||e==Dv}function H8t(e){return e==jw||e==_v}function x$e(e,t){return fc(e.g,t.g)}function ige(e){return Do(e.b.b,e,0)}function k$e(e){sc(this),lT(this,e)}function O$e(e){this.a=lRe(),this.b=e}function S$e(e){this.a=lRe(),this.b=e}function j$e(e,t){return qe(e.a,t),t}function rge(e,t){K6(e,0,e.length,t)}function Q8t(e,t){return fc(e.g,t.g)}function G8t(e,t){return ji(t.f,e.f)}function U8t(e,t){return Pu(),t.a+=e}function J8t(e,t){return Pu(),t.a+=e}function X8t(e,t){return Pu(),t.c+=e}function sge(e,t){return Fu(e.a,t),e}function V8t(e,t){return qe(e.c,t),e}function vF(e){return Fu(new wr,e)}function O1(e){return e==go||e==yo}function hx(e){return e==Ca||e==Fh}function T$e(e){return e==v3||e==w3}function dx(e){return e!=Hh&&e!=fp}function wu(e){return e.sh()&&e.th()}function E$e(e){return tee(c(e,127))}function c5(){pf.call(this,0,0,0,0)}function C$e(){XF.call(this,0,0,0,0)}function Ld(){ude.call(this,new M0)}function WY(e){YRe.call(this,e,!0)}function Cs(e){this.a=e.a,this.b=e.b}function KY(e,t){hS(e,t),tS(e,e.D)}function YY(e,t,n){nH(e,t),tH(e,n)}function _m(e,t,n){ob(e,t),sb(e,n)}function aa(e,t,n){Cc(e,t),Nl(e,n)}function b_(e,t,n){Jm(e,t),Xm(e,n)}function m_(e,t,n){Vm(e,t),Wm(e,n)}function M$e(e,t,n){zge.call(this,e,t,n)}function A$e(){Gz.call(this,"Head",1)}function N$e(){Gz.call(this,"Tail",3)}function O0(e){ld(),kIt.call(this,e)}function gx(e){return e!=null?Ri(e):0}function _$e(e,t){return new oS(t,e)}function W8t(e,t){return new oS(t,e)}function K8t(e,t){return nv(t,yh(e))}function Y8t(e,t){return nv(t,yh(e))}function Z8t(e,t){return e[e.length]=t}function ejt(e,t){return e[e.length]=t}function oge(e){return mCt(e.b.Jc(),e.a)}function tjt(e,t){return cH(KZ(e.f),t)}function njt(e,t){return cH(KZ(e.n),t)}function ijt(e,t){return cH(KZ(e.p),t)}function Gr(e,t){qi.call(this,e.b,t)}function Qp(e){XF.call(this,e,e,e,e)}function ZY(e){e.c=ye(Br,Lt,1,0,5,1)}function D$e(e,t,n){dr(e.c[t.g],t.g,n)}function rjt(e,t,n){c(e.c,72).Ei(t,n)}function sjt(e,t,n){aa(n,n.i+e,n.j+t)}function ojt(e,t){Nn(gc(e.a),aQe(t))}function cjt(e,t){Nn(ou(e.a),fQe(t))}function ljt(e,t){Ph||(e.b=t)}function eZ(e,t,n){return dr(e,t,n),n}function L$e(e){Qc(e.Qf(),new eNe(e))}function P$e(){P$e=te,$le=new yT(hae)}function cge(){cge=te,Cde(),U5e=new wn}function Bn(){Bn=te,new I$e,new Fe}function I$e(){new wn,new wn,new wn}function ujt(){throw J(new vg(vat))}function ajt(){throw J(new vg(vat))}function fjt(){throw J(new vg(yat))}function hjt(){throw J(new vg(yat))}function E7(e){wi(),km.call(this,e)}function R$e(e){this.a=e,S0e.call(this,e)}function tZ(e){this.a=e,Az.call(this,e)}function nZ(e){this.a=e,Az.call(this,e)}function djt(e){return e==null?0:Ri(e)}function No(e){return e.a<e.c.c.length}function lge(e){return e.a<e.c.a.length}function uge(e,t){return Mc(e,t)>0?e:t}function fc(e,t){return e<t?-1:e>t?1:0}function $$e(e,t){return e.a?e.b:t.Ue()}function el(e,t,n){return{l:e,m:t,h:n}}function gjt(e,t){e.a!=null&&RRe(t,e.a)}function pjt(e,t){Rn(t),yx(e).Ic(new Z)}function Rr(e,t){NZ(e.c,e.c.length,t)}function B$e(e){e.a=new Pt,e.c=new Pt}function yF(e){this.b=e,this.a=new Fe}function z$e(e){this.b=new gh,this.a=e}function age(e){t0e.call(this),this.a=e}function F$e(e){Npe.call(this),this.b=e}function q$e(){Gz.call(this,"Range",2)}function H$e(){d2e(),this.a=new DS(qke)}function mh(){mh=te,p.Math.log(2)}function fa(){fa=te,o1=(IIe(),E2t)}function xF(e){e.j=ye(ske,Be,325,0,0,1)}function Q$e(e){e.a=new wn,e.e=new wn}function fge(e){return new $e(e.c,e.d)}function bjt(e){return new $e(e.c,e.d)}function Ms(e){return new $e(e.a,e.b)}function mjt(e,t){return oi(e.a,t.a,t)}function wjt(e,t,n){return oi(e.g,n,t)}function vjt(e,t,n){return oi(e.k,n,t)}function px(e,t,n){return Dwe(t,n,e.c)}function G$e(e,t){return SZt(e.a,t,null)}function hge(e,t){return he(Ut(e.i,t))}function dge(e,t){return he(Ut(e.j,t))}function U$e(e,t){En(e),e.Fc(c(t,16))}function yjt(e,t,n){e.c._c(t,c(n,138))}function xjt(e,t,n){e.c.Si(t,c(n,138))}function kjt(e,t,n){return kZt(e,t,n),n}function Ojt(e,t){return Ru(),t.n.b+=e}function C7(e,t){return _Yt(e.c,e.b,t)}function iZ(e,t){return ZIt(e.Jc(),t)!=-1}function oe(e,t){return e!=null&&une(e,t)}function Sjt(e,t){return new pBe(e.Jc(),t)}function kF(e){return e.Ob()?e.Pb():null}function J$e(e){return od(e,0,e.length)}function jjt(e){ks(e,null),ss(e,null)}function X$e(e){vee(e,null),yee(e,null)}function V$e(){y_.call(this,null,null)}function W$e(){CF.call(this,null,null)}function K$e(){Sn.call(this,"INSTANCE",0)}function bx(){this.a=ye(Br,Lt,1,8,5,1)}function gge(e){this.a=e,wn.call(this)}function Y$e(e){this.a=(Ct(),new w6(e))}function Tjt(e){this.b=(Ct(),new PK(e))}function C6(){C6=te,pke=new VK(null)}function pge(){pge=te,pge(),Kat=new Pn}function qe(e,t){return It(e.c,t),!0}function Z$e(e,t){e.c&&(L0e(t),_He(t))}function Ejt(e,t){e.q.setHours(t),HT(e,t)}function bge(e,t){return e.a.Ac(t)!=null}function rZ(e,t){return e.a.Ac(t)!=null}function wh(e,t){return e.a[t.c.p][t.p]}function Cjt(e,t){return e.c[t.c.p][t.p]}function Mjt(e,t){return e.e[t.c.p][t.p]}function sZ(e,t,n){return e.a[t.g][n.g]}function Ajt(e,t){return e.j[t.p]=iJt(t)}function l5(e,t){return e.a*t.a+e.b*t.b}function Njt(e,t){return e.a<mZ(t)?-1:1}function _jt(e,t){return mbe(e.b,t.Og())}function Djt(e,t){return mbe(e.f,t.Og())}function Ljt(e,t){return ue(he(t.a))<=e}function Pjt(e,t){return ue(he(t.a))>=e}function Ijt(e,t,n){return n?t!=0:t!=e-1}function eBe(e,t,n){e.a=t^1502,e.b=n^dre}function Rjt(e,t,n){return e.a=t,e.b=n,e}function S1(e,t){return e.a*=t,e.b*=t,e}function M7(e,t,n){return dr(e.g,t,n),n}function $jt(e,t,n,i){dr(e.a[t.g],n.g,i)}function Ar(e,t,n){__.call(this,e,t,n)}function OF(e,t,n){Ar.call(this,e,t,n)}function El(e,t,n){Ar.call(this,e,t,n)}function tBe(e,t,n){OF.call(this,e,t,n)}function mge(e,t,n){__.call(this,e,t,n)}function mx(e,t,n){__.call(this,e,t,n)}function nBe(e,t,n){wge.call(this,e,t,n)}function iBe(e,t,n){mge.call(this,e,t,n)}function wge(e,t,n){BF.call(this,e,t,n)}function rBe(e,t,n){BF.call(this,e,t,n)}function S0(e){this.c=e,this.a=this.c.a}function cn(e){this.i=e,this.f=this.i.j}function wx(e,t){this.a=e,Az.call(this,t)}function sBe(e,t){this.a=e,eY.call(this,t)}function oBe(e,t){this.a=e,eY.call(this,t)}function cBe(e,t){this.a=e,eY.call(this,t)}function vge(e){this.a=e,r6.call(this,e.d)}function lBe(e){e.b.Qb(),--e.d.f.d,YF(e.d)}function uBe(e){e.a=c(Wt(e.b.a,4),131)}function aBe(e){e.a=c(Wt(e.b.a,4),131)}function Bjt(e){$_(e,Ult),xQ(e,ven(e))}function fBe(e){$4.call(this,c(Rn(e),34))}function hBe(e){$4.call(this,c(Rn(e),34))}function yge(e){if(!e)throw J(new GN)}function xge(e){if(!e)throw J(new Tl)}function kge(e,t){return P$t(e,new b0,t).a}function dBe(e,t){return new wet(e.a,e.b,t)}function Vt(e,t){return Rn(t),new gBe(e,t)}function gBe(e,t){this.a=t,Nz.call(this,e)}function pBe(e,t){this.a=t,Nz.call(this,e)}function Oge(e,t){this.a=t,eY.call(this,e)}function bBe(e,t){this.a=t,Nee.call(this,e)}function mBe(e,t){this.a=e,Nee.call(this,t)}function wBe(){xF(this),dq(this),this.he()}function Sge(){this.Bb|=256,this.Bb|=512}function Bt(){Bt=te,K0=!1,k9=!0}function vBe(){vBe=te,fY(),nvt=new Ij}function zjt(e){return XN(e.a)?hQe(e):null}function Fjt(e){return e.l+e.m*tk+e.h*yb}function qjt(e){return e==null?null:e.name}function A7(e){return e==null?pl:jo(e)}function SF(e,t){return e.lastIndexOf(t)}function jge(e,t,n){return e.indexOf(t,n)}function Cl(e,t){return!!t&&e.b[t.g]==t}function u5(e){return e.a!=null?e.a:null}function vu(e){return dn(e.a!=null),e.a}function w_(e,t,n){return mte(e,t,t,n),e}function yBe(e,t){return qe(t.a,e.a),e.a}function xBe(e,t){return qe(t.b,e.a),e.a}function jF(e,t){return++e.b,qe(e.a,t)}function Tge(e,t){return++e.b,fl(e.a,t)}function Dm(e,t){return qe(t.a,e.a),e.a}function TF(e){f6.call(this,e),this.a=e}function Ege(e){nx.call(this,e),this.a=e}function Cge(e){w6.call(this,e),this.a=e}function Mge(e){FK.call(this),Os(this,e)}function Ba(e){ds.call(this,(zt(e),e))}function Lu(e){ds.call(this,(zt(e),e))}function oZ(e){ude.call(this,new Ebe(e))}function Age(e,t){qwe.call(this,e,t,null)}function Hjt(e,t){return ji(e.n.a,t.n.a)}function Qjt(e,t){return ji(e.c.d,t.c.d)}function Gjt(e,t){return ji(e.c.c,t.c.c)}function ul(e,t){return c(Si(e.b,t),16)}function Ujt(e,t){return e.n.b=(zt(t),t)}function Jjt(e,t){return e.n.b=(zt(t),t)}function Xjt(e,t){return ji(e.e.b,t.e.b)}function Vjt(e,t){return ji(e.e.a,t.e.a)}function Wjt(e,t,n){return dGe(e,t,n,e.b)}function Nge(e,t,n){return dGe(e,t,n,e.c)}function Kjt(e){return Pu(),!!e&&!e.dc()}function kBe(){o7(),this.b=new INe(this)}function OBe(e){this.a=e,LK.call(this,e)}function v_(e){this.c=e,f5.call(this,e)}function a5(e){this.c=e,cn.call(this,e)}function f5(e){this.d=e,cn.call(this,e)}function EF(e,t){LZ(),this.f=t,this.d=e}function y_(e,t){a7(),this.a=e,this.b=t}function CF(e,t){Sg(),this.b=e,this.c=t}function _ge(e,t){vbe(t,e),this.c=e,this.b=t}function jg(e){var t;t=e.a,e.a=e.b,e.b=t}function N7(e){return No(e.a)||No(e.b)}function Lm(e){return e.$H||(e.$H=++qtn)}function cZ(e,t){return new Eze(e,e.gc(),t)}function Yjt(e,t){return $Z(e.c).Kd().Xb(t)}function M6(e,t,n){var i;i=e.dd(t),i.Rb(n)}function Dge(e,t,n){c(tD(e,t),24).Ec(n)}function Zjt(e,t,n){Fte(e.a,n),WH(e.a,t)}function SBe(e,t,n,i){W0e.call(this,e,t,n,i)}function A6(e,t,n){return jge(e,dl(t),n)}function e7t(e){return kz(),jn((KHe(),Cat),e)}function t7t(e){return new Z2(3,e)}function Pd(e){return zu(e,Sv),new Hc(e)}function N6(e){return dn(e.b!=0),e.a.a.c}function df(e){return dn(e.b!=0),e.c.b.c}function n7t(e,t){return mte(e,t,t+1,""),e}function jBe(e){if(!e)throw J(new ua)}function TBe(e){e.d=new MBe(e),e.e=new wn}function Lge(e){if(!e)throw J(new GN)}function i7t(e){if(!e)throw J(new BK)}function dn(e){if(!e)throw J(new Co)}function I2(e){if(!e)throw J(new Tl)}function EBe(e){return e.b=c(Tpe(e.a),45)}function xi(e,t){return!!e.q&&jc(e.q,t)}function r7t(e,t){return e>0?t*t/e:t*t*100}function s7t(e,t){return e>0?t/(e*e):t*100}function R2(e,t){return c(Oh(e.a,t),34)}function o7t(e){return e.f!=null?e.f:""+e.g}function lZ(e){return e.f!=null?e.f:""+e.g}function CBe(e){return U6(),parseInt(e)||-1}function c7t(e){return L1(),e.e.a+e.f.a/2}function l7t(e,t,n){return L1(),n.e.a-e*t}function u7t(e,t,n){return Lz(),n.Lg(e,t)}function a7t(e,t,n){return L1(),n.e.b-e*t}function f7t(e){return L1(),e.e.b+e.f.b/2}function h7t(e,t){return z0(),St(e,t.e,t)}function x_(e){oe(e,162)&&c(e,162).mi()}function MBe(e){j0e.call(this,e,null,null)}function ABe(){Sn.call(this,"GROW_TREE",0)}function NBe(e){this.c=e,this.a=1,this.b=1}function uZ(e){N2(),this.b=e,this.a=!0}function _Be(e){Dz(),this.b=e,this.a=!0}function DBe(e){Lie(),KDe(this),this.Df(e)}function LBe(e){Ai.call(this),sT(this,e)}function PBe(e){this.c=e,Cc(e,0),Nl(e,0)}function MF(e){return e.a=-e.a,e.b=-e.b,e}function Pge(e,t){return e.a=t.a,e.b=t.b,e}function $2(e,t,n){return e.a+=t,e.b+=n,e}function IBe(e,t,n){return e.a-=t,e.b-=n,e}function d7t(e,t,n){Hq(),e.nf(t)&&n.Ad(e)}function g7t(e,t,n){wT(gc(e.a),t,aQe(n))}function p7t(e,t,n){return qe(t,fKe(e,n))}function b7t(e,t){return c(Ut(e.e,t),19)}function m7t(e,t){return c(Ut(e.e,t),19)}function w7t(e,t){return e.c.Ec(c(t,138))}function RBe(e,t){a7(),y_.call(this,e,t)}function Ige(e,t){Sg(),CF.call(this,e,t)}function $Be(e,t){Sg(),CF.call(this,e,t)}function BBe(e,t){Sg(),Ige.call(this,e,t)}function aZ(e,t){fa(),WF.call(this,e,t)}function zBe(e,t){fa(),aZ.call(this,e,t)}function Rge(e,t){fa(),aZ.call(this,e,t)}function FBe(e,t){fa(),Rge.call(this,e,t)}function $ge(e,t){fa(),WF.call(this,e,t)}function qBe(e,t){fa(),WF.call(this,e,t)}function HBe(e,t){fa(),$ge.call(this,e,t)}function yu(e,t,n){Al.call(this,e,t,n,2)}function v7t(e,t,n){wT(ou(e.a),t,fQe(n))}function fZ(e,t){return I0(e.e,c(t,52))}function y7t(e,t,n){return t.xl(e.e,e.c,n)}function x7t(e,t,n){return t.yl(e.e,e.c,n)}function Bge(e,t,n){return IQ(nD(e,t),n)}function QBe(e,t){return zt(e),e+mZ(t)}function k7t(e){return e==null?null:jo(e)}function O7t(e){return e==null?null:jo(e)}function S7t(e){return e==null?null:aen(e)}function j7t(e){return e==null?null:uQt(e)}function j1(e){e.o==null&&AUt(e)}function Ze(e){return L7(e==null||L2(e)),e}function he(e){return L7(e==null||P2(e)),e}function zn(e){return L7(e==null||Kr(e)),e}function GBe(){this.a=new Qm,this.b=new Qm}function T7t(e,t){this.d=e,yt(this),this.b=t}function k_(e,t){this.c=e,S6.call(this,e,t)}function _7(e,t){this.a=e,k_.call(this,e,t)}function zge(e,t,n){Fq.call(this,e,t,n,null)}function UBe(e,t,n){Fq.call(this,e,t,n,null)}function Fge(){DXe.call(this),this.Bb|=Is}function qge(e,t){Fee.call(this,e),this.a=t}function Hge(e,t){Fee.call(this,e),this.a=t}function JBe(e,t){Ph||qe(e.a,t)}function E7t(e,t){return mne(e,t),new qqe(e,t)}function C7t(e,t,n){return e.Le(t,n)<=0?n:t}function M7t(e,t,n){return e.Le(t,n)<=0?t:n}function XBe(e){return zt(e),e?1231:1237}function hZ(e){return c(Xe(e.a,e.b),296)}function VBe(e){return Ru(),T$e(c(e,205))}function A7t(e,t){return c(Oh(e.b,t),144)}function N7t(e,t){return c(Oh(e.c,t),236)}function WBe(e){return new $e(e.c,e.d+e.a)}function _7t(e,t){return _5(),new oit(t,e)}function D7t(e,t){return t_(),sS(t.d.i,e)}function L7t(e,t){t.a?WGt(e,t):rZ(e.a,t.b)}function Qge(e,t){return c(Ut(e.b,t),280)}function qi(e,t){gi.call(this,e),this.a=t}function Gge(e,t,n){return n=Qu(e,t,3,n),n}function Uge(e,t,n){return n=Qu(e,t,6,n),n}function Jge(e,t,n){return n=Qu(e,t,9,n),n}function ed(e,t){return $_(t,wxe),e.f=t,e}function Xge(e,t){return(t&di)%e.d.length}function KBe(e,t,n){++e.j,e.oj(t,e.Xi(t,n))}function O_(e,t,n){++e.j,e.rj(),zee(e,t,n)}function YBe(e,t,n){var i;i=e.dd(t),i.Rb(n)}function ZBe(e,t){this.c=e,Um.call(this,t)}function eze(e,t){this.a=e,QDe.call(this,t)}function S_(e,t){this.a=e,QDe.call(this,t)}function Vge(e){this.q=new p.Date(ib(e))}function tze(e){this.a=(zu(e,Sv),new Hc(e))}function nze(e){this.a=(zu(e,Sv),new Hc(e))}function dZ(e){this.a=(Ct(),new DK(Rn(e)))}function AF(){AF=te,rU=new qi(Cot,0)}function vx(){vx=te,k3=new gi("root")}function _6(){_6=te,YP=new ELe,new CLe}function B2(){B2=te,kke=gt((Cu(),Qb))}function P7t(e){return Hn(Vp(e,32))^Hn(e)}function gZ(e){return String.fromCharCode(e)}function I7t(e){return e==null?null:e.message}function R7t(e,t,n){return e.apply(t,n)}function ize(e,t,n){return _ye(e.c,e.b,t,n)}function Wge(e,t,n){return v5(e,c(t,23),n)}function Gp(e,t){return Bt(),e==t?0:e?1:-1}function Kge(e,t){var n;return n=t,!!e.De(n)}function Yge(e,t){var n;return n=e.e,e.e=t,n}function $7t(e,t){var n;n=e[hre],n.call(e,t)}function B7t(e,t){var n;n=e[hre],n.call(e,t)}function z2(e,t){e.a._c(e.b,t),++e.b,e.c=-1}function rze(e){sc(e.e),e.d.b=e.d,e.d.a=e.d}function j_(e){e.b?j_(e.b):e.f.c.yc(e.e,e.d)}function T_(e){return!e.a&&(e.a=new ze),e.a}function sze(e,t,n){return e.a+=od(t,0,n),e}function z7t(e,t,n){Hp(),EK(e,t.Te(e.a,n))}function Zge(e,t,n,i){XF.call(this,e,t,n,i)}function e0e(e,t){Ode.call(this,e),this.a=t}function pZ(e,t){Ode.call(this,e),this.a=t}function oze(){NF.call(this),this.a=new as}function t0e(){this.n=new as,this.o=new as}function cze(){this.b=new as,this.c=new Fe}function lze(){this.a=new Fe,this.b=new Fe}function uze(){this.a=new pO,this.b=new rLe}function n0e(){this.b=new M0,this.a=new M0}function aze(){this.b=new Or,this.a=new Or}function fze(){this.b=new wn,this.a=new wn}function hze(){this.a=new Fe,this.d=new Fe}function dze(){this.a=new cK,this.b=new AR}function gze(){this.b=new LPe,this.a=new xA}function NF(){this.n=new X4,this.i=new c5}function ki(e,t){return e.a+=t.a,e.b+=t.b,e}function Hr(e,t){return e.a-=t.a,e.b-=t.b,e}function F7t(e){return M2(e.j.c,0),e.a=-1,e}function i0e(e,t,n){return n=Qu(e,t,11,n),n}function pze(e,t,n){n!=null&&lH(t,yne(e,n))}function bze(e,t,n){n!=null&&uH(t,yne(e,n))}function h5(e,t,n,i){Me.call(this,e,t,n,i)}function F2(e,t){zc.call(this,wE+e+Tb+t)}function r0e(e,t,n,i){Me.call(this,e,t,n,i)}function mze(e,t,n,i){r0e.call(this,e,t,n,i)}function wze(e,t,n,i){rq.call(this,e,t,n,i)}function bZ(e,t,n,i){rq.call(this,e,t,n,i)}function vze(e,t,n,i){bZ.call(this,e,t,n,i)}function s0e(e,t,n,i){rq.call(this,e,t,n,i)}function Et(e,t,n,i){s0e.call(this,e,t,n,i)}function o0e(e,t,n,i){bZ.call(this,e,t,n,i)}function yze(e,t,n,i){o0e.call(this,e,t,n,i)}function xze(e,t,n,i){epe.call(this,e,t,n,i)}function c0e(e,t){return e.hk().ti().oi(e,t)}function l0e(e,t){return e.hk().ti().qi(e,t)}function q7t(e,t){return e.n.a=(zt(t),t+10)}function H7t(e,t){return e.n.a=(zt(t),t+10)}function Q7t(e,t){return e.e=c(e.d.Kb(t),163)}function G7t(e,t){return t==e||ES(yQ(t),e)}function gf(e,t){return Tz(new Array(t),e)}function kze(e,t){return zt(e),ve(e)===ve(t)}function Ot(e,t){return zt(e),ve(e)===ve(t)}function Oze(e,t){return oi(e.a,t,"")==null}function u0e(e,t,n){return e.lastIndexOf(t,n)}function U7t(e,t){return e.b.zd(new HIe(e,t))}function J7t(e,t){return e.b.zd(new QIe(e,t))}function Sze(e,t){return e.b.zd(new GIe(e,t))}function X7t(e){return e<100?null:new m0(e)}function V7t(e,t){return Ee(t,(Ge(),oP),e)}function W7t(e,t,n){return ji(e[t.a],e[n.a])}function K7t(e,t){return fc(e.a.d.p,t.a.d.p)}function Y7t(e,t){return fc(t.a.d.p,e.a.d.p)}function Z7t(e,t){return t_(),!sS(t.d.i,e)}function eTt(e,t){Ph||t&&(e.d=t)}function tTt(e,t){O1(e.f)?kUt(e,t):hHt(e,t)}function jze(e,t){wCt.call(this,e,e.length,t)}function Tze(e){this.c=e,mF.call(this,cL,0)}function a0e(e,t){this.c=e,UZ.call(this,e,t)}function Eze(e,t,n){this.a=e,_ge.call(this,t,n)}function Cze(e,t,n){this.c=t,this.b=n,this.a=e}function E_(e){L6(),this.d=e,this.a=new bx}function nTt(e,t){var n;return n=t.ni(e.a),n}function iTt(e,t){return ji(e.c-e.s,t.c-t.s)}function rTt(e,t){return ji(e.c.e.a,t.c.e.a)}function sTt(e,t){return ji(e.b.e.a,t.b.e.a)}function Mze(e,t){return oe(t,16)&&znt(e.c,t)}function oTt(e,t,n){return c(e.c,72).Uk(t,n)}function _F(e,t,n){return c(e.c,72).Vk(t,n)}function cTt(e,t,n){return y7t(e,c(t,345),n)}function f0e(e,t,n){return x7t(e,c(t,345),n)}function lTt(e,t,n){return yZe(e,c(t,345),n)}function Aze(e,t,n){return SHt(e,c(t,345),n)}function D7(e,t){return t==null?null:lv(e.b,t)}function d5(e){return e==Hb||e==r1||e==xc}function Nze(e){return e.c?Do(e.c.a,e,0):-1}function mZ(e){return P2(e)?(zt(e),e):e.se()}function DF(e){return!isNaN(e)&&!isFinite(e)}function wZ(e){B$e(this),Ou(this),Os(this,e)}function Fl(e){ZY(this),D0e(this.c,0,e.Nc())}function _ze(e){iu(e.a),jbe(e.c,e.b),e.b=null}function vZ(){vZ=te,gke=new rn,Vat=new Cn}function Dze(){Dze=te,_2t=ye(Br,Lt,1,0,5,1)}function Lze(){Lze=te,W2t=ye(Br,Lt,1,0,5,1)}function h0e(){h0e=te,K2t=ye(Br,Lt,1,0,5,1)}function uTt(e){return Y6(),jn((nJe(),Yat),e)}function aTt(e){return va(),jn((bUe(),rft),e)}function fTt(e){return Yf(),jn((mUe(),hft),e)}function hTt(e){return Hl(),jn((wUe(),gft),e)}function dTt(e){return hl(),jn((vUe(),bft),e)}function gTt(e){return FQ(),jn((f$e(),Bft),e)}function d0e(e,t){if(!e)throw J(new qt(t))}function D6(e){if(!e)throw J(new oo(exe))}function yZ(e,t){if(e!=t)throw J(new ua)}function ha(e,t,n){this.a=e,this.b=t,this.c=n}function Pze(e,t,n){this.a=e,this.b=t,this.c=n}function Ize(e,t,n){this.a=e,this.b=t,this.c=n}function g0e(e,t,n){this.b=e,this.c=t,this.a=n}function Rze(e,t,n){this.d=e,this.b=n,this.a=t}function pTt(e,t,n){return Hp(),e.a.Wd(t,n),t}function xZ(e){var t;return t=new dO,t.e=e,t}function p0e(e){var t;return t=new fLe,t.b=e,t}function LF(e,t,n){this.e=t,this.b=e,this.d=n}function PF(e,t,n){this.b=e,this.a=t,this.c=n}function $ze(e){this.a=e,Og(),Zo(Date.now())}function Bze(e,t,n){this.a=e,this.b=t,this.c=n}function kZ(e){XF.call(this,e.d,e.c,e.a,e.b)}function b0e(e){XF.call(this,e.d,e.c,e.a,e.b)}function bTt(e){return Jt(),jn((hVe(),Fht),e)}function mTt(e){return Ym(),jn((iJe(),Fft),e)}function wTt(e){return lS(),jn((rJe(),Nht),e)}function vTt(e){return Wq(),jn((TGe(),Wft),e)}function yTt(e){return tT(),jn((yUe(),kht),e)}function xTt(e){return es(),jn((FJe(),Tht),e)}function kTt(e){return $5(),jn((sJe(),Rht),e)}function OTt(e){return iS(),jn((EGe(),Uht),e)}function STt(e){return cs(),jn((h$e(),Jht),e)}function jTt(e){return kH(),jn((oJe(),Wht),e)}function TTt(e){return xf(),jn((cJe(),cdt),e)}function ETt(e){return dv(),jn((ZJe(),udt),e)}function CTt(e){return qq(),jn((MGe(),mdt),e)}function MTt(e){return H5(),jn((wXe(),bdt),e)}function ATt(e){return Km(),jn(($Ue(),gdt),e)}function NTt(e){return EQ(),jn((dVe(),pdt),e)}function _Tt(e){return xT(),jn((fJe(),wdt),e)}function DTt(e){return rH(),jn((SUe(),vdt),e)}function LTt(e){return QD(),jn((CVe(),ydt),e)}function PTt(e){return oD(),jn((CGe(),xdt),e)}function ITt(e){return ab(),jn((jUe(),Odt),e)}function RTt(e){return hQ(),jn((mXe(),Sdt),e)}function $Tt(e){return Z_(),jn((AGe(),jdt),e)}function BTt(e){return RD(),jn((pXe(),Tdt),e)}function zTt(e){return MS(),jn((bXe(),Edt),e)}function FTt(e){return Gs(),jn((qVe(),Cdt),e)}function qTt(e){return cS(),jn((OUe(),Mdt),e)}function HTt(e){return D0(),jn((xUe(),Adt),e)}function QTt(e){return D1(),jn((kUe(),_dt),e)}function GTt(e){return Cq(),jn((NGe(),Ddt),e)}function UTt(e){return Tu(),jn((tXe(),Pdt),e)}function JTt(e){return Nq(),jn((_Ge(),Idt),e)}function XTt(e){return hv(),jn((uJe(),j0t),e)}function VTt(e){return gT(),jn((_Ue(),S0t),e)}function WTt(e){return ST(),jn((nXe(),T0t),e)}function KTt(e){return H0(),jn((FVe(),E0t),e)}function YTt(e){return UD(),jn((MVe(),O0t),e)}function ZTt(e){return B1(),jn((aJe(),C0t),e)}function eEt(e){return rD(),jn((DGe(),M0t),e)}function tEt(e){return Qs(),jn((TUe(),N0t),e)}function nEt(e){return vH(),jn((EUe(),_0t),e)}function iEt(e){return dT(),jn((CUe(),D0t),e)}function rEt(e){return dS(),jn((MUe(),L0t),e)}function sEt(e){return iH(),jn((AUe(),P0t),e)}function oEt(e){return yH(),jn((NUe(),I0t),e)}function cEt(e){return hb(),jn((lJe(),tpt),e)}function lEt(e){return Z7(),jn((LGe(),opt),e)}function uEt(e){return td(),jn((PGe(),dpt),e)}function aEt(e){return vh(),jn((IGe(),ppt),e)}function fEt(e){return Wf(),jn((RGe(),Apt),e)}function hEt(e,t){return zt(e),e+(zt(t),t)}function dEt(e){return Hm(),jn(($Ge(),Rpt),e)}function gEt(e){return B5(),jn((pJe(),$pt),e)}function pEt(e){return FT(),jn((d$e(),Bpt),e)}function bEt(e){return fT(),jn((BUe(),zpt),e)}function mEt(e){return hT(),jn((hJe(),ubt),e)}function wEt(e){return jq(),jn((BGe(),abt),e)}function vEt(e){return hH(),jn((zGe(),pbt),e)}function yEt(e){return cQ(),jn((eXe(),mbt),e)}function xEt(e){return Qq(),jn((FGe(),wbt),e)}function kEt(e){return yD(),jn((zUe(),vbt),e)}function OEt(e){return YH(),jn((dJe(),Bbt),e)}function SEt(e){return mH(),jn((DUe(),zbt),e)}function jEt(e){return BH(),jn((LUe(),Fbt),e)}function TEt(e){return uQ(),jn((gJe(),Hbt),e)}function EEt(e){return LH(),jn((FUe(),Ubt),e)}function L6(){L6=te,T9e=(Je(),Yt),wJ=nn}function Pu(){Pu=te,idt=new J8,rdt=new ug}function C_(){C_=te,aU=new qV,fU=new BM}function IF(){IF=te,Yht=new cW,Kht=new lW}function CEt(e){return!e.e&&(e.e=new Fe),e.e}function MEt(e){return RT(),jn((iXe(),wmt),e)}function AEt(e){return Iz(),jn((eGe(),ymt),e)}function NEt(e){return SD(),jn((PUe(),vmt),e)}function _Et(e){return Rz(),jn((tGe(),kmt),e)}function DEt(e){return X_(),jn((HGe(),Omt),e)}function LEt(e){return BD(),jn((rXe(),Smt),e)}function PEt(e){return Pq(),jn((qGe(),gmt),e)}function IEt(e){return Gq(),jn((IUe(),pmt),e)}function REt(e){return CH(),jn((RUe(),bmt),e)}function $Et(e){return c7(),jn((nGe(),zmt),e)}function BEt(e){return pD(),jn((QGe(),Fmt),e)}function zEt(e){return Aq(),jn((GGe(),qmt),e)}function FEt(e){return nQ(),jn((bJe(),Qmt),e)}function qEt(e){return $z(),jn((iGe(),Zmt),e)}function HEt(e){return Bz(),jn((rGe(),twt),e)}function QEt(e){return zz(),jn((sGe(),iwt),e)}function GEt(e){return cD(),jn((UGe(),swt),e)}function UEt(e){return Th(),jn((YJe(),fwt),e)}function JEt(e){return q0(),jn((gVe(),dwt),e)}function XEt(e){return Hd(),jn((xXe(),gwt),e)}function VEt(e){return bb(),jn((yXe(),ywt),e)}function WEt(e){return Nr(),jn((zJe(),Uwt),e)}function KEt(e){return gS(),jn((mJe(),Jwt),e)}function YEt(e){return Sh(),jn((HUe(),Xwt),e)}function ZEt(e){return $1(),jn((wJe(),Vwt),e)}function eCt(e){return aQ(),jn((vXe(),Wwt),e)}function tCt(e){return R1(),jn((qUe(),Ywt),e)}function nCt(e){return qu(),jn((vJe(),e2t),e)}function iCt(e){return mv(),jn((EVe(),t2t),e)}function rCt(e){return _x(),jn((KJe(),n2t),e)}function sCt(e){return Zr(),jn((kXe(),i2t),e)}function oCt(e){return Ql(),jn((OXe(),r2t),e)}function cCt(e){return iT(),jn((GUe(),a2t),e)}function lCt(e){return Je(),jn((BJe(),s2t),e)}function uCt(e){return Cu(),jn((xJe(),f2t),e)}function aCt(e){return uu(),jn((TVe(),h2t),e)}function fCt(e){return P5(),jn((QUe(),d2t),e)}function hCt(e){return _q(),jn((yJe(),g2t),e)}function dCt(e){return PH(),jn((kJe(),p2t),e)}function gCt(e){return OH(),jn((OJe(),w2t),e)}function OZ(e,t){this.c=e,this.a=t,this.b=t-e}function xu(e,t,n){this.c=e,this.a=t,this.b=n}function zze(e,t,n){this.a=e,this.c=t,this.b=n}function Fze(e,t,n){this.a=e,this.c=t,this.b=n}function qze(e,t,n){this.a=e,this.b=t,this.c=n}function m0e(e,t,n){this.a=e,this.b=t,this.c=n}function w0e(e,t,n){this.a=e,this.b=t,this.c=n}function SZ(e,t,n){this.a=e,this.b=t,this.c=n}function Hze(e,t,n){this.a=e,this.b=t,this.c=n}function v0e(e,t,n){this.a=e,this.b=t,this.c=n}function Qze(e,t,n){this.a=e,this.b=t,this.c=n}function Gze(e,t,n){this.b=e,this.a=t,this.c=n}function Tg(e,t,n){this.e=e,this.a=t,this.c=n}function Uze(e,t,n){fa(),Lpe.call(this,e,t,n)}function jZ(e,t,n){fa(),ppe.call(this,e,t,n)}function y0e(e,t,n){fa(),ppe.call(this,e,t,n)}function x0e(e,t,n){fa(),ppe.call(this,e,t,n)}function Jze(e,t,n){fa(),jZ.call(this,e,t,n)}function k0e(e,t,n){fa(),jZ.call(this,e,t,n)}function Xze(e,t,n){fa(),k0e.call(this,e,t,n)}function Vze(e,t,n){fa(),y0e.call(this,e,t,n)}function Wze(e,t,n){fa(),x0e.call(this,e,t,n)}function pCt(e){return V5(),jn((pVe(),N2t),e)}function M_(e,t){return Rn(e),Rn(t),new nIe(e,t)}function g5(e,t){return Rn(e),Rn(t),new rFe(e,t)}function bCt(e,t){return Rn(e),Rn(t),new sFe(e,t)}function mCt(e,t){return Rn(e),Rn(t),new fIe(e,t)}function O0e(e,t){n8t.call(this,e,_H(new Ho(t)))}function Kze(e,t){this.c=e,this.b=t,this.a=!1}function S0e(e){this.d=e,yt(this),this.b=lMt(e.d)}function j0e(e,t,n){this.c=e,qz.call(this,t,n)}function wCt(e,t,n){WFe.call(this,t,n),this.a=e}function Yze(){this.a=";,;",this.b="",this.c=""}function Zze(e,t,n){this.b=e,l$e.call(this,t,n)}function vCt(e,t){t&&(e.b=t,e.a=(T0(t),t.a))}function TZ(e){return dn(e.b!=0),ba(e,e.a.a)}function yCt(e){return dn(e.b!=0),ba(e,e.c.b)}function xCt(e){return!e.c&&(e.c=new Gf),e.c}function eFe(e){var t;return t=new FK,fte(t,e),t}function A_(e){var t;return t=new Ai,fte(t,e),t}function P6(e){var t;return t=new Fe,Yee(t,e),t}function kCt(e){var t;return t=new Or,Yee(t,e),t}function c(e,t){return L7(e==null||une(e,t)),e}function RF(e,t){return t&&uq(e,t.d)?t:null}function N_(e,t){if(!e)throw J(new qt(t))}function T0e(e,t){if(!e)throw J(new sPe(t))}function p5(e,t){if(!e)throw J(new oo(t))}function OCt(e,t){return Pz(),fc(e.d.p,t.d.p)}function SCt(e,t){return L1(),ji(e.e.b,t.e.b)}function jCt(e,t){return L1(),ji(e.e.a,t.e.a)}function TCt(e,t){return fc(gFe(e.d),gFe(t.d))}function ECt(e,t){return t==(Je(),Yt)?e.c:e.d}function CCt(e){return new $e(e.c+e.b,e.d+e.a)}function E0e(e){var t,n;n=e.d,t=e.a,e.d=t,e.a=n}function C0e(e){var t,n;t=e.b,n=e.c,e.b=n,e.c=t}function Id(e,t,n,i,r){e.b=t,e.c=n,e.d=i,e.a=r}function M0e(e,t,n,i,r){e.d=t,e.c=n,e.a=i,e.b=r}function tFe(e,t,n,i,r){e.c=t,e.d=n,e.b=i,e.a=r}function $F(e,t){return EPt(e),e.a*=t,e.b*=t,e}function A0e(e,t){return t<0?e.g=-1:e.g=t,e}function __(e,t,n){Y1e.call(this,e,t),this.c=n}function N0e(e,t,n){E6.call(this,e,t),this.b=n}function _0e(e){h0e(),xj.call(this),this._h(e)}function BF(e,t,n){Y1e.call(this,e,t),this.c=n}function nFe(e,t,n){this.a=e,fx.call(this,t,n)}function iFe(e,t,n){this.a=e,fx.call(this,t,n)}function EZ(e){this.b=e,this.a=Jp(this.b.a).Md()}function rFe(e,t){this.b=e,this.a=t,wN.call(this)}function sFe(e,t){this.a=e,this.b=t,wN.call(this)}function oFe(e){_ge.call(this,e.length,0),this.a=e}function D0e(e,t,n){wve(n,0,e,t,n.length,!1)}function I6(e,t,n){var i;i=new J2(n),wf(e,t,i)}function MCt(e,t){var n;return n=e.c,ome(e,t),n}function ACt(e,t){return(XWe(e)<<4|XWe(t))&_r}function cFe(e){return e!=null&&!Xte(e,HC,QC)}function D_(e){return e==0||isNaN(e)?e:e<0?-1:1}function L0e(e){e.a.b=e.b,e.b.a=e.a,e.a=e.b=null}function ei(e,t){return tr(e,t,e.c.b,e.c),!0}function zF(e){var t;return t=e.slice(),Uee(t,e)}function FF(e){var t;return t=e.n,e.a.b+t.d+t.a}function lFe(e){var t;return t=e.n,e.e.b+t.d+t.a}function P0e(e){var t;return t=e.n,e.e.a+t.b+t.c}function uFe(e){return wi(),new Rd(0,e)}function aFe(){aFe=te,Mae=(Ct(),new DK(hoe))}function qF(){qF=te,new Gwe((XK(),Soe),(JK(),Ooe))}function fFe(){V6(),qMt.call(this,(y0(),nf))}function hFe(e,t){WFe.call(this,t,1040),this.a=e}function Pm(e,t){return CT(e,new E6(t.a,t.b))}function NCt(e){return!vs(e)&&e.c.i.c==e.d.i.c}function _Ct(e,t){return e.c<t.c?-1:e.c==t.c?0:1}function dFe(e){return e.b.c.length-e.e.c.length}function gFe(e){return e.e.c.length-e.g.c.length}function CZ(e){return e.e.c.length+e.g.c.length}function pFe(e){return A5(),ye(kJ,xG,41,e,0,1)}function bFe(){bFe=te,eke=ye(Lr,Be,15,256,0,1)}function mFe(){this.b=ue(he(Ve((Sf(),Voe))))}function DCt(e){return Ru(),(Je(),ol).Gc(e.j)}function LCt(e,t,n){return L1(),n.e.a+n.f.a+e*t}function PCt(e,t,n){return L1(),n.e.b+n.f.b+e*t}function ICt(e,t,n){return oi(e.b,c(n.b,17),t)}function RCt(e,t,n){return oi(e.b,c(n.b,17),t)}function $Ct(e,t){return qe(e,new $e(t.a,t.b))}function BCt(e,t){cme(e,t==null?null:(zt(t),t))}function zCt(e,t){ume(e,t==null?null:(zt(t),t))}function FCt(e,t){ume(e,t==null?null:(zt(t),t))}function I0e(e,t,n,i){Rwe.call(this,e,t,n,i,0,0)}function HF(e,t){p_.call(this,e,t),this.a=this}function wFe(e){h0e(),_0e.call(this,e),this.a=-1}function vFe(){UY.call(this,"COUNT_CHILDREN",0)}function R0e(e){this.c=e,this.b=this.c.d.vc().Jc()}function yFe(e){return e.e.Pd().gc()*e.c.Pd().gc()}function MZ(e,t,n){return new Cze(UMt(e).Ze(),n,t)}function Wn(e,t,n){return e.a=-1,Dge(e,t.g,n),e}function $0e(e,t,n){var i;return i=e[t],e[t]=n,i}function Ki(e,t){var n;return n=YZ(e,t),n.i=2,n}function QF(e,t){var n;return++e.j,n=e.Aj(t),n}function qCt(e){return e.a?e.a:cee(e)}function L7(e){if(!e)throw J(new m6(null))}function B0e(e){if(e.c.e!=e.a)throw J(new ua)}function z0e(e){if(e.e.c!=e.b)throw J(new ua)}function GF(e){for(Rn(e);e.Ob();)e.Pb(),e.Qb()}function HCt(e){e.a.jd(),c(e.a.kd(),18).gc(),Vde()}function UF(){UF=te,Eoe=new kee((Ct(),Ct(),Rs))}function AZ(){AZ=te,H5e=new x1e((Ct(),Ct(),eU))}function xFe(){xFe=te,K5e=ye(ak,Be,224,256,0,1)}function kFe(){kFe=te,Z5e=ye(CE,Be,183,128,0,1)}function OFe(){OFe=te,tke=ye(Ow,Be,192,256,0,1)}function SFe(){SFe=te,rke=ye(Sw,Be,193,256,0,1)}function F0e(){Id(this,!1,!1,!1,!1)}function q0e(e){ude.call(this,new M0),Os(this,e)}function q2(e){this.a=new e5(e.gc()),Os(this,e)}function jFe(e){this.c=e,this.a=new t5(this.c.a)}function jt(e,t){Hp(),Fee.call(this,e),this.a=t}function Xe(e,t){return ht(t,e.c.length),e.c[t]}function TFe(e,t){return ht(t,e.a.length),e.a[t]}function EFe(e,t){return e.a+=od(t,0,t.length),e}function QCt(e,t){return e.a==null&&Xnt(e),e.a[t]}function GCt(e,t,n){return fc(t.d[e.g],n.d[e.g])}function UCt(e,t,n){return fc(e.d[t.p],e.d[n.p])}function JCt(e,t,n){return fc(e.d[t.p],e.d[n.p])}function XCt(e,t,n){return fc(e.d[t.p],e.d[n.p])}function VCt(e,t,n){return fc(e.d[t.p],e.d[n.p])}function WCt(e,t){return zt(e),aD(e,(zt(t),t))}function KCt(e,t){return zt(t),aD(t,(zt(e),e))}function CFe(e){return e.q?e.q:(Ct(),Ct(),Yd)}function MFe(e){return e.c-c(Xe(e.a,e.b),296).b}function AFe(e,t){return e?0:p.Math.max(0,t-1)}function JF(e,t,n){return p.Math.min(n/e,1/t)}function H2(e,t,n,i,r,o){return fZe(e,t,n,i,r,0,o)}function XF(e,t,n,i){M0e(this,e,t,n,i)}function YCt(e,t){var n;for(n=0;n<t;++n)e[n]=-1}function NFe(e){var t;return t=hZe(e),t?NFe(t):e}function ku(e){return e.c?e.c.f:e.e.b}function Ml(e){return e.c?e.c.g:e.e.a}function VF(e){Um.call(this,e.gc()),ur(this,e)}function _Fe(){Sn.call(this,"SIMPLE_X_PLACING",0)}function DFe(){Sn.call(this,"SIMPLE_Y_PLACING",0)}function LFe(e){this.a=e,this.c=new wn,nRt(this)}function PFe(e){this.b=new Ai,this.a=e,this.c=-1}function Rd(e,t){wi(),km.call(this,e),this.a=t}function WF(e,t){fa(),gz.call(this,t),this.a=e}function P7(e,t,n){this.a=e,Ar.call(this,t,n,2)}function Up(e,t,n){K2(t,e.c.length),h7(e.c,t,n)}function ZCt(e,t){return!e&&(e=[]),e[e.length]=t,e}function NZ(e,t,n){mWe(0,t,e.length),K6(e,0,t,n)}function IFe(e,t,n){var i;for(i=0;i<t;++i)e[i]=n}function _i(e,t){var n;return n=gt(e),Rme(n,t),n}function _Z(e,t){return oe(t,23)&&Cl(e,c(t,23))}function RFe(e,t){return oe(t,23)&&kPt(e,c(t,23))}function co(e,t){return jWe(e,t,HDt(e,e.b.Ae(t)))}function eMt(e,t){return e.a.get(t)!==void 0}function DZ(e,t){return e==null?t==null:Ot(e,t)}function tMt(e,t){return e==null?t==null:FH(e,t)}function KF(e,t){return wi(),new spe(e,t)}function Hn(e){return Oo(e)?e|0:FPe(e)}function LZ(){LZ=te,y2t=new Gr((Dn(),fu),0)}function $Fe(){$Fe=te,Tat=new oFe(ye(Br,Lt,1,0,5,1))}function BFe(){this.b=new D8,this.c=new OHe(this)}function H0e(){this.d=new Kw,this.e=new kHe(this)}function PZ(e,t){this.b=new Ai,this.a=e,this.c=t}function Q0e(){Bpe(),this.g=new Ai,this.f=new Ai}function nMt(e,t){IZ(e,Hr(new $e(t.a,t.b),e.c))}function IZ(e,t){ki(e.c,t),e.b.c+=t.a,e.b.d+=t.b}function YF(e){e.b?YF(e.b):e.d.dc()&&e.f.c.Ac(e.e)}function G0e(e){return Array.isArray(e)&&e.Rm===je}function RZ(e){return lu(e,26)*YT+lu(e,27)*ZT}function iMt(e,t,n){return Sr(e,new n5(t.a,n.a))}function rMt(e,t,n){return-fc(e.f[t.p],e.f[n.p])}function ZF(e,t,n){var i;e&&(i=e.i,i.c=t,i.b=n)}function eq(e,t,n){var i;e&&(i=e.i,i.d=t,i.a=n)}function Fc(e,t,n){return e.a=-1,Dge(e,t.g+1,n),e}function U0e(e,t,n){return n=Qu(e,c(t,52),7,n),n}function J0e(e,t,n){return n=Qu(e,c(t,52),3,n),n}function sMt(e,t,n){_tt(n,e,1),qe(t,new ZIe(n,e))}function oMt(e,t,n){ET(n,e,1),qe(t,new sRe(n,e))}function zFe(e,t,n){this.a=e,OF.call(this,t,n,22)}function FFe(e,t,n){this.a=e,OF.call(this,t,n,14)}function qFe(e,t,n,i){fa(),DQe.call(this,e,t,n,i)}function HFe(e,t,n,i){fa(),DQe.call(this,e,t,n,i)}function cMt(e,t){(t.Bb&nc)!=0&&!e.a.o&&(e.a.o=t)}function QFe(e){return e!=null&&HZ(e)&&e.Rm!==je}function X0e(e){return!Array.isArray(e)&&e.Rm===je}function lMt(e){return oe(e,16)?c(e,16).cd():e.Jc()}function V0e(e){return e.Oc(ye(Br,Lt,1,e.gc(),5,1))}function I7(e,t){return MBt(nD(e,t))?t.wi():null}function Jp(e){return e.c?e.c:e.c=e.Qd()}function $Z(e){return e.d?e.d:e.d=e.Rd()}function b5(e){var t;return t=e.i,t||(e.i=e.bc())}function GFe(e){var t;return t=e.f,t||(e.f=e.Cc())}function UFe(e){return wi(),new gee(10,e,0)}function Xp(e){x0(),this.a=0,this.b=e-1,this.c=1}function JFe(e){xF(this),this.g=e,dq(this),this.he()}function XFe(){Ru(),this.k=new wn,this.d=new Or}function W0e(e,t,n,i){this.a=e,Fq.call(this,e,t,n,i)}function Ht(e){this.a=($Fe(),Tat),this.d=c(Rn(e),51)}function tq(e){if(e.e.j!=e.d)throw J(new ua)}function R7(e){return Oo(e)?""+e:Bnt(e)}function $d(e,t){return _0(VZe(Oo(e)?qa(e):e,t))}function Im(e,t){return _0(Eve(Oo(e)?qa(e):e,t))}function Vp(e,t){return _0(vQt(Oo(e)?qa(e):e,t))}function uMt(e,t){return Gp((zt(e),e),(zt(t),t))}function BZ(e,t){return ji((zt(e),e),(zt(t),t))}function VFe(e,t){return Rn(t),e.a.Hd(t)&&!e.b.Hd(t)}function aMt(e,t){return el(e.l&t.l,e.m&t.m,e.h&t.h)}function fMt(e,t){return el(e.l|t.l,e.m|t.m,e.h|t.h)}function hMt(e,t){return el(e.l^t.l,e.m^t.m,e.h^t.h)}function Q2(e,t){return OD(e,(zt(t),new zAe(t)))}function m5(e,t){return OD(e,(zt(t),new FAe(t)))}function dMt(e,t,n){e.a.Mb(n)&&(e.b=!0,t.Ad(n))}function K0e(e){e.d||(e.d=e.b.Jc(),e.c=e.b.gc())}function R6(e,t){if(e<0||e>=t)throw J(new sLe)}function sc(e){e.f=new O$e(e),e.i=new S$e(e),++e.g}function nq(e){this.b=new Hc(11),this.a=(Fm(),e)}function zZ(e){this.b=null,this.a=(Fm(),e||hke)}function Y0e(e,t){this.e=e,this.d=(t&64)!=0?t|ad:t}function WFe(e,t){this.c=0,this.d=e,this.b=t|64|ad}function KFe(e){this.a=uYe(e.a),this.b=new Fl(e.b)}function Eg(e,t,n,i){var r;r=e.i,r.i=t,r.a=n,r.b=i}function Z0e(e){var t;for(t=e;t.f;)t=t.f;return t}function gMt(e){return e.e?xbe(e.e):null}function pMt(e,t){return _5(),ji(t.a.o.a,e.a.o.a)}function YFe(e,t,n){return LS(),bte(e,t)&&bte(e,n)}function $7(e){return Ql(),!e.Gc(eg)&&!e.Gc(hp)}function ZFe(e,t,n){return Lst(e,c(t,12),c(n,12))}function eqe(e){return _l(),c(e,12).g.c.length!=0}function tqe(e){return _l(),c(e,12).e.c.length!=0}function iq(e){return new $e(e.c+e.b/2,e.d+e.a/2)}function FZ(e,t){return t.Sh()?I0(e.b,c(t,52)):t}function bMt(e,t,n){t.of(n,ue(he(Ut(e.b,n)))*e.a)}function mMt(e,t){t.Tg("General 'Rotator",1),WZt(e)}function Ur(e,t,n,i,r){Hee.call(this,e,t,n,i,r,-1)}function B7(e,t,n,i,r){W_.call(this,e,t,n,i,r,-1)}function Me(e,t,n,i){Ar.call(this,e,t,n),this.b=i}function rq(e,t,n,i){__.call(this,e,t,n),this.b=i}function nqe(e){YRe.call(this,e,!1),this.a=!1}function iqe(){UY.call(this,"LOOKAHEAD_LAYOUT",1)}function rqe(){UY.call(this,"LAYOUT_NEXT_LEVEL",3)}function sqe(){Sn.call(this,"ABSOLUTE_XPLACING",0)}function oqe(e){this.b=e,f5.call(this,e),uBe(this)}function cqe(e){this.b=e,v_.call(this,e),aBe(this)}function lqe(e,t){this.b=e,r6.call(this,e.b),this.a=t}function G2(e,t,n){this.a=e,h5.call(this,t,n,5,6)}function epe(e,t,n,i){this.b=e,Ar.call(this,t,n,i)}function Wp(e,t,n){ld(),this.e=e,this.d=t,this.a=n}function gs(e,t){for(zt(t);e.Ob();)t.Ad(e.Pb())}function sq(e,t){return wi(),new gpe(e,t,0)}function qZ(e,t){return wi(),new gpe(6,e,t)}function wMt(e,t){return Ot(e.substr(0,t.length),t)}function jc(e,t){return Kr(t)?fee(e,t):!!co(e.f,t)}function vMt(e){return el(~e.l&au,~e.m&au,~e.h&Q1)}function HZ(e){return typeof e===iL||typeof e===Rie}function Bd(e){return new Ht(new Oge(e.a.length,e.a))}function QZ(e){return new jt(null,EMt(e,e.length))}function uqe(e){if(!e)throw J(new Co);return e.d}function w5(e){var t;return t=aT(e),dn(t!=null),t}function yMt(e){var t;return t=g$t(e),dn(t!=null),t}function $6(e,t){var n;return n=e.a.gc(),vbe(t,n),n-t}function Sr(e,t){var n;return n=e.a.yc(t,e),n==null}function L_(e,t){return e.a.yc(t,(Bt(),K0))==null}function xMt(e,t){return e>0?p.Math.log(e/t):-100}function tpe(e,t){return t?Os(e,t):!1}function v5(e,t,n){return yf(e.a,t),$0e(e.b,t.g,n)}function kMt(e,t,n){R6(n,e.a.c.length),Su(e.a,n,t)}function we(e,t,n,i){mWe(t,n,e.length),OMt(e,t,n,i)}function OMt(e,t,n,i){var r;for(r=t;r<n;++r)e[r]=i}function npe(e,t){var n;for(n=0;n<t;++n)e[n]=!1}function ipe(e,t){if(e==null)throw J(new K4(t))}function P_(e,t){U$e(e,oe(t,164)?t:c(t,2015).Pl())}function SMt(e,t,n){ten(e.a,e.b,e.d,e.c,c(t,171),n)}function Iu(e,t,n){return MRt(e,t.g,n),yf(e.c,t),e}function jMt(e){return Hx(e,(Nr(),go)),e.d=!0,e}function GZ(e){return!e.j&&on(e,UVt(e.g,e.b)),e.j}function TMt(e,t,n){var i;return i=tv(e,t),Eee(e,t,n),i}function rpe(e,t,n){this.c=e,this.a=t,Ct(),this.b=n}function UZ(e,t){this.d=e,cn.call(this,e),this.e=t}function spe(e,t){km.call(this,1),this.a=e,this.b=t}function z7(e){I2(e.b!=-1),Mg(e.c,e.a=e.b),e.b=-1}function aqe(e){e.a=null,e.e=null,sc(e.b),e.d=0,++e.c}function F7(e){return e.e==0?e:new Wp(-e.e,e.d,e.a)}function EMt(e,t){return wPt(t,e.length),new hFe(e,t)}function fqe(e,t){return Mc(e,t)<0?-1:Mc(e,t)>0?1:0}function CMt(e,t){return ji(e.c.c+e.c.b,t.c.c+t.c.b)}function oq(e,t){tr(e.d,t,e.b.b,e.b),++e.a,e.c=null}function hqe(e,t){return e.c?hqe(e.c,t):qe(e.b,t),e}function Rm(e,t){lr(qc(e.Mc(),new a4),new JNe(t))}function B6(e,t,n,i,r){Lne(e,c(Si(t.k,n),16),n,i,r)}function dqe(e,t,n,i,r){for(;t<n;)i[r++]=ms(e,t++)}function gqe(e,t,n){var i;for(i=0;i<t;++i)dr(e,i,n)}function cq(e){e.s=NaN,e.c=NaN,xtt(e,e.e),xtt(e,e.j)}function JZ(e){return p.Math.abs(e.d.e-e.e.e)-e.a}function MMt(e,t){return ji(e.e.a+e.f.a,t.e.a+t.f.a)}function AMt(e,t){return ji(e.e.b+e.f.b,t.e.b+t.f.b)}function XZ(e,t){this.d=p$t(e),this.c=t,this.a=.5*t}function U2(e){this.d=(zt(e),e),this.a=0,this.c=cL}function pqe(e){Npe.call(this),this.a=e,qe(e.a,this)}function ope(e){e?D2e(e,(Og(),Bat)):hNt((Og(),e))}function NMt(e,t){y5(e,new J2(t.f!=null?t.f:""+t.g))}function _Mt(e,t){y5(e,new J2(t.f!=null?t.f:""+t.g))}function ur(e,t){return e.Qi()&&(t=JHe(e,t)),e.Di(t)}function VZ(e,t){return t=e.Wk(null,t),MZe(e,null,t)}function bqe(e,t,n){return wi(),new bQe(e,t,n)}function DMt(e,t,n){return c(e.c.fd(t,c(n,138)),45)}function LMt(){return kz(),W(V(Eat,1),_e,541,0,[Toe])}function PMt(e){return e==nr?BL:e==Qr?"-INF":""+e}function IMt(e){return e==nr?BL:e==Qr?"-INF":""+e}function pn(e){return(e.i==null&&ud(e),e.i).length}function j0(){j0=te,Gt=MGt(),Mt(),hy&&FFt()}function mqe(){mqe=te,Dat=new qj(!1),Lat=new qj(!0)}function q7(e){var t;return t=e.g,t||(e.g=new WB(e))}function lq(e){var t;return t=e.k,t||(e.k=new KB(e))}function cpe(e){var t;return t=e.k,t||(e.k=new KB(e))}function RMt(e){var t;return t=e.i,t||(e.i=new yK(e))}function WZ(e){var t;return t=e.j,t||(e.j=new o6(e))}function wqe(e){var t;return t=e.f,t||(e.f=new vge(e))}function KZ(e){var t;return t=e.d,t||(e.d=new $j(e))}function lpe(e){return oe(e,613)?e:new IHe(e)}function vqe(e,t){return Q_(t,e.c.b.c.gc()),new tIe(e,t)}function upe(e,t){var n;return n=e.a.gc(),Q_(t,n),n-1-t}function C(e,t,n){var i;return i=YZ(e,t),EXe(n,i),i}function YZ(e,t){var n;return n=new Dme,n.j=e,n.d=t,n}function z6(e,t){return e.a+=String.fromCharCode(t),e}function Kp(e,t){return e.a+=String.fromCharCode(t),e}function Rn(e){if(e==null)throw J(new U4);return e}function J2(e){if(e==null)throw J(new U4);this.a=e}function yqe(e){Cde(),this.b=new Fe,this.a=e,ZYt(this,e)}function ape(e){this.b=e,this.a=c(za(this.b.a.e),229)}function fpe(e){this.d=e,this.c=e.a.d.a,this.b=e.a.e.g}function xqe(e){this.b=new Fe,this.a=new Fe,this.c=e}function hc(e){this.c=new as,this.a=new Fe,this.b=e}function kqe(){M0.call(this),this.a=!0,this.b=!0}function hpe(e,t){return en(t,e.length+1),e.substr(t)}function dr(e,t,n){return i7t(n==null||AWt(e,n)),e[t]=n}function ZZ(e,t,n){var i;return i=ute(e,t,n),rye(e,i)}function Oqe(e,t){var n;n=console[e],n.call(console,t)}function Ut(e,t){return Kr(t)?Tc(e,t):Ao(co(e.f,t))}function Sqe(e,t){return c(Jp(e.a).Kd().Xb(t),45).jd()}function $Mt(e,t){return c(R(t,(Ge(),Hv)),15).a<e}function BMt(e,t){return _5(),c(Zs(e,t.d),16).Ec(t)}function zMt(e,t,n,i){return n==0||(n-i)/n<e.e||t>=e.g}function H7(e){return p.Math.sqrt(e.a*e.a+e.b*e.b)}function jqe(e){return oe(e,104)&&(c(e,20).Bb&nc)!=0}function $m(e){return!e.d&&(e.d=new Ar(Ks,e,1)),e.d}function FMt(e){return!e.a&&(e.a=new Ar(dp,e,4)),e.a}function Tqe(e){this.c=e,this.a=new Ai,this.b=new Ai}function qMt(e){this.a=(zt(Kn),Kn),this.b=e,new $de}function Eqe(e,t,n){this.a=e,Ype.call(this,8,t,null,n)}function dpe(e,t,n){this.a=e,Ode.call(this,t),this.b=n}function gpe(e,t,n){km.call(this,e),this.a=t,this.b=n}function ppe(e,t,n){gz.call(this,t),this.a=e,this.b=n}function HMt(e,t,n){c(t.b,68),Qc(t.a,new m0e(e,n,t))}function eee(e,t){for(zt(t);e.c<e.d;)e.Qe(t,e.c++)}function QMt(e,t){++e.j,Dne(e,e.i,t),AGt(e,c(t,345))}function Cqe(e,t){var n;++e.j,n=e.Cj(),e.pj(e.Xi(n,t))}function y5(e,t){var n;n=e.a.length,tv(e,n),Eee(e,n,t)}function Bm(e,t){return R6(t,e.a.c.length),Xe(e.a,t)}function uq(e,t){return Tne(e.c,e.f,t,e.b,e.a,e.e,e.d)}function T1(e,t){return ve(e)===ve(t)||e!=null&&yi(e,t)}function Mqe(e){return za(e),oe(e,475)?c(e,475):jo(e)}function Aqe(e){return e?e.dc():!e.Jc().Ob()}function GMt(e){return gy?fee(gy,e):!1}function UMt(e){return 0>=e?new d1e:JPt(e-1)}function za(e){if(e==null)throw J(new U4);return e}function zt(e){if(e==null)throw J(new U4);return e}function Jr(e){return!e.a&&e.c?e.c.b:e.a}function Nqe(e){var t,n;return t=e.c.i.c,n=e.d.i.c,t==n}function JMt(e,t){return fc(t.j.c.length,e.j.c.length)}function _qe(e){kpe(e.a),e.b=ye(Br,Lt,1,e.b.length,5,1)}function Q7(e){e.c?e.c.Ye():(e.d=!0,$Jt(e))}function T0(e){e.c?T0(e.c):(R0(e),e.d=!0)}function iu(e){I2(e.c!=-1),e.d.ed(e.c),e.b=e.c,e.c=-1}function Dqe(e){e.b=!1,e.c=!1,e.d=!1,e.a=!1}function Lqe(e){this.c=e,this.b=this.c.a,this.a=this.c.e}function wr(){zLe.call(this),M2(this.j.c,0),this.a=-1}function Pqe(){Sn.call(this,"DELAUNAY_TRIANGULATION",0)}function bpe(e){for(;e.a.b!=0;)LZt(e,c(DHe(e.a),9))}function XMt(e,t){Nn((!e.a&&(e.a=new S_(e,e)),e.a),t)}function mpe(e,t){e.c<0||e.b.b<e.c?Es(e.b,t):e.a.vf(t)}function VMt(e,t){var n;n=e.Fh(t),n>=0?e.hi(n):uve(e,t)}function Iqe(e,t){this.b=e,UZ.call(this,e,t),uBe(this)}function Rqe(e,t){this.b=e,a0e.call(this,e,t),aBe(this)}function $qe(){z2e.call(this,Ja,(x6(),CTe)),UKt(this)}function wpe(e){return!e.b&&(e.b=new pz(new UK)),e.b}function WMt(e){if(e.p!=3)throw J(new Tl);return e.e}function KMt(e){if(e.p!=4)throw J(new Tl);return e.e}function YMt(e){if(e.p!=4)throw J(new Tl);return e.j}function ZMt(e){if(e.p!=3)throw J(new Tl);return e.j}function eAt(e){if(e.p!=6)throw J(new Tl);return e.f}function tAt(e){if(e.p!=6)throw J(new Tl);return e.k}function zm(e){return e.c==-2&&$(e,EHt(e.g,e.b)),e.c}function F6(e,t){var n;return n=YZ("",e),n.n=t,n.i=1,n}function zd(e,t){for(;t-- >0;)e=e<<1|(e<0?1:0);return e}function nAt(e,t){IZ(c(t.b,68),e),Qc(t.a,new pde(e))}function Bqe(e,t){return qF(),new Gwe(new hBe(e),new fBe(t))}function iAt(e,t,n){return L5(),n.Kg(e,c(t.jd(),149))}function rAt(e){return zu(e,Fie),Kq(As(As(5,e),e/10|0))}function vpe(e){return Ct(),e?e.Me():(Fm(),Fm(),dke)}function oi(e,t,n){return Kr(t)?lo(e,t,n):gl(e.f,t,n)}function sAt(e){return String.fromCharCode.apply(null,e)}function zqe(e){return!e.d&&(e.d=new f6(e.c.Bc())),e.d}function q6(e){return!e.a&&(e.a=new uPe(e.c.vc())),e.a}function Fqe(e){return!e.b&&(e.b=new w6(e.c.ec())),e.b}function qqe(e,t){Tjt.call(this,XPt(Rn(e),Rn(t))),this.a=t}function ype(e,t,n,i){Mm.call(this,e,t),this.d=n,this.a=i}function aq(e,t,n,i){Mm.call(this,e,n),this.a=t,this.f=i}function G7(e){this.d=e,this.a=this.d.b,this.b=this.d.c}function Hqe(){z2e.call(this,Cb,(CPe(),svt)),RYt(this)}function Qqe(){Mo.call(this,"There is no more element.")}function ms(e,t){return en(t,e.length),e.charCodeAt(t)}function Gqe(e,t){e.u.Gc((Ql(),eg))&&SGt(e,t),dLt(e,t)}function dc(e,t){return ve(e)===ve(t)||e!=null&&yi(e,t)}function Zs(e,t){return _Z(e.a,t)?e.b[c(t,23).g]:null}function Uqe(e,t){var n;return n=new hc(e),It(t.c,n),n}function U7(e){return e.j.c.length=0,kpe(e.c),F7t(e.a),e}function oAt(e){return!e.b&&(e.b=new Et(vn,e,4,7)),e.b}function H6(e){return!e.c&&(e.c=new Et(vn,e,5,8)),e.c}function xpe(e){return!e.c&&(e.c=new Me(hu,e,9,9)),e.c}function tee(e){return!e.n&&(e.n=new Me(Bo,e,1,7)),e.n}function ai(e,t,n,i){return aVe(e,t,n,!1),MH(e,i),e}function Jqe(e,t){Qte(e,ue(P1(t,"x")),ue(P1(t,"y")))}function Xqe(e,t){Qte(e,ue(P1(t,"x")),ue(P1(t,"y")))}function cAt(){return $z(),W(V(Ymt,1),_e,557,0,[que])}function lAt(){return Bz(),W(V(ewt,1),_e,558,0,[Hue])}function uAt(){return zz(),W(V(nwt,1),_e,559,0,[Que])}function aAt(){return Rz(),W(V(xmt,1),_e,550,0,[Eue])}function fAt(){return Iz(),W(V(cje,1),_e,480,0,[Tue])}function hAt(){return c7(),W(V(Cje,1),_e,531,0,[SP])}function nee(){nee=te,Aat=new y1e(W(V(Mb,1),qQ,45,0,[]))}function dAt(e,t){return new wHe(c(Rn(e),50),c(Rn(t),50))}function gAt(e){return e!=null&&i7(lX,e.toLowerCase())}function Q6(e){return e.e==v9&&gn(e,DBt(e.g,e.b)),e.e}function I_(e){return e.f==v9&&Zt(e,MFt(e.g,e.b)),e.f}function yx(e){var t;return t=e.b,!t&&(e.b=t=new vK(e)),t}function kpe(e){var t;for(t=e.Jc();t.Ob();)t.Pb(),t.Qb()}function pAt(e,t,n){var i;i=c(e.d.Kb(n),163),i&&i.Nb(t)}function bAt(e,t){return ji(e.d.c+e.d.b/2,t.d.c+t.d.b/2)}function mAt(e,t){return ji(e.g.c+e.g.b/2,t.g.c+t.g.b/2)}function wAt(e,t){return b1e(),ji((zt(e),e),(zt(t),t))}function qc(e,t){return R0(e),new jt(e,new ybe(t,e.a))}function pi(e,t){return R0(e),new jt(e,new Dbe(t,e.a))}function X2(e,t){return R0(e),new qge(e,new sUe(t,e.a))}function fq(e,t){return R0(e),new Hge(e,new oUe(t,e.a))}function Ope(e,t){this.b=e,this.c=t,this.a=new t5(this.b)}function iee(e,t,n,i){this.a=e,this.e=t,this.d=n,this.c=i}function ree(e,t,n){this.a=oxe,this.d=e,this.b=t,this.c=n}function hq(e,t,n,i){this.a=e,this.c=t,this.b=n,this.d=i}function Spe(e,t,n,i){this.c=e,this.b=t,this.a=n,this.d=i}function Vqe(e,t,n,i){this.c=e,this.b=t,this.d=n,this.a=i}function Wqe(e,t,n,i){this.a=e,this.d=t,this.c=n,this.b=i}function pf(e,t,n,i){this.c=e,this.d=t,this.b=n,this.a=i}function x5(e,t,n,i){Sn.call(this,e,t),this.a=n,this.b=i}function Kqe(e,t,n,i){tWe.call(this,e,n,i,!1),this.f=t}function Yqe(e,t){this.d=(zt(e),e),this.a=16449,this.c=t}function Zqe(e){this.a=new Fe,this.e=ye(Fn,Be,54,e,0,2)}function vAt(e){e.Tg("No crossing minimization",1),e.Ug()}function E1(e){var t,n;return n=(t=new Om,t),eS(n,e),n}function see(e){var t,n;return n=(t=new Om,t),H2e(n,e),n}function oee(e,t,n){var i,r;return i=Jye(e),r=t.qi(n,i),r}function cee(e){var t;return t=WPt(e),t||null}function eHe(e){return!e.b&&(e.b=new Me(Ii,e,12,3)),e.b}function G6(e){if(cu(e.d),e.d.d!=e.c)throw J(new ua)}function tHe(e,t,n,i){this.a=e,this.c=t,this.d=n,this.b=i}function nHe(e,t,n,i){this.a=e,this.b=t,this.d=n,this.c=i}function iHe(e,t,n,i){this.a=e,this.b=t,this.c=n,this.d=i}function rHe(e,t,n,i){this.a=e,this.b=t,this.c=n,this.d=i}function Yp(e,t,n,i){this.e=e,this.a=t,this.c=n,this.d=i}function sHe(e,t,n,i){fa(),cUe.call(this,t,n,i),this.a=e}function oHe(e,t,n,i){fa(),cUe.call(this,t,n,i),this.a=e}function cHe(e,t){this.a=e,T7t.call(this,e,c(e.d,16).dd(t))}function lee(e){this.f=e,this.c=this.f.e,e.f>0&&rZe(this)}function dq(e){return e.n&&(e.e!==Xst&&e.he(),e.j=null),e}function lHe(e){return L7(e==null||HZ(e)&&e.Rm!==je),e}function yAt(e,t,n){return qe(e.a,(mne(t,n),new Mm(t,n))),e}function xAt(e,t,n){zKt(e.a,n),UIt(n),lUt(e.b,n),cYt(t,n)}function kAt(e,t){return ji(Ml(e)*ku(e),Ml(t)*ku(t))}function OAt(e,t){return ji(Ml(e)*ku(e),Ml(t)*ku(t))}function SAt(e){Pu();var t;t=c(e.g,9),t.n.a=e.d.c+t.d.b}function Ou(e){e.a.a=e.c,e.c.b=e.a,e.a.b=e.c.a=null,e.b=0}function jpe(e,t){return e.b=t.b,e.c=t.c,e.d=t.d,e.a=t.a,e}function Tpe(e){return dn(e.b<e.d.gc()),e.d.Xb(e.c=e.b++)}function jAt(e){return e.length>0?mf(e):new Fe}function TAt(e,t){return c(R(e,(De(),yk)),16).Ec(t),t}function EAt(e,t){return St(e,c(R(t,(Ge(),Hv)),15),t)}function CAt(e){return sw(e)&&et(Ze(ke(e,(Ge(),Lb))))}function k5(e){var t;return t=e.f,t||(e.f=new S6(e,e.c))}function MAt(e,t,n){return o7(),z$t(c(Ut(e.e,t),520),n)}function AAt(e,t,n){e.i=0,e.e=0,t!=n&&nWe(e,t,n)}function NAt(e,t,n){e.i=0,e.e=0,t!=n&&iWe(e,t,n)}function uHe(e,t,n,i){this.b=e,this.c=i,mF.call(this,t,n)}function aHe(e,t){this.g=e,this.d=W(V(e1,1),Hg,9,0,[t])}function fHe(e,t){e.d&&!e.d.a&&(VDe(e.d,t),fHe(e.d,t))}function hHe(e,t){e.e&&!e.e.a&&(VDe(e.e,t),hHe(e.e,t))}function dHe(e,t){return Nx(e.j,t.s,t.c)+Nx(t.e,e.s,e.c)}function _At(e){return c(e.jd(),149).Og()+":"+jo(e.kd())}function DAt(e,t){return-ji(Ml(e)*ku(e),Ml(t)*ku(t))}function LAt(e,t){return ju(e),ju(t),tPe(c(e,23),c(t,23))}function Zp(e,t,n){var i,r;i=mZ(n),r=new c6(i),wf(e,t,r)}function PAt(e){jz(),p.setTimeout(function(){throw e},0)}function gHe(e){this.b=new Fe,yr(this.b,this.b),this.a=e}function pHe(e){this.b=new AW,this.a=e,p.Math.random()}function Epe(e,t){new Ai,this.a=new nu,this.b=e,this.c=t}function bHe(e,t,n,i){Y1e.call(this,t,n),this.b=e,this.a=i}function uee(e,t,n,i,r,o){W_.call(this,e,t,n,i,r,o?-2:-1)}function mHe(){zne(this,new D4),this.wb=(j0(),Gt),x6()}function Cpe(){Cpe=te,cft=new io,uft=new H0e,lft=new zf}function Ct(){Ct=te,Rs=new Le,Yd=new Qe,eU=new ae}function Fm(){Fm=te,hke=new Ae,Poe=new Ae,dke=new Ye}function Ei(e){return!e.q&&(e.q=new Me(tf,e,11,10)),e.q}function Ne(e){return!e.s&&(e.s=new Me(xl,e,21,17)),e.s}function gq(e){return!e.a&&(e.a=new Me(Mn,e,10,11)),e.a}function pq(e,t){if(e==null)throw J(new K4(t));return e}function wHe(e,t){c9t.call(this,new zZ(e)),this.a=e,this.b=t}function Mpe(e){this.b=e,this.c=e,e.e=null,e.c=null,this.a=1}function Ape(e){return e&&e.hashCode?e.hashCode():Lm(e)}function IAt(e){return new sBe(e,e.e.Pd().gc()*e.c.Pd().gc())}function RAt(e){return new oBe(e,e.e.Pd().gc()*e.c.Pd().gc())}function aee(e){return oe(e,18)?new q2(c(e,18)):kCt(e.Jc())}function bq(e){return Ct(),oe(e,59)?new iY(e):new TF(e)}function $At(e){return Rn(e),yYe(new Ht(Vt(e.a.Jc(),new U)))}function fee(e,t){return t==null?!!co(e.f,null):eMt(e.i,t)}function BAt(e,t){var n;return n=bge(e.a,t),n&&(t.d=null),n}function vHe(e,t,n){return e.f?e.f.cf(t,n):!1}function R_(e,t,n,i){dr(e.c[t.g],n.g,i),dr(e.c[n.g],t.g,i)}function hee(e,t,n,i){dr(e.c[t.g],t.g,n),dr(e.b[t.g],t.g,i)}function zAt(e,t,n){return ue(he(n.a))<=e&&ue(he(n.b))>=t}function yHe(){this.d=new Ai,this.b=new wn,this.c=new Fe}function xHe(){this.b=new Or,this.d=new Ai,this.e=new yz}function Npe(){this.c=new as,this.d=new as,this.e=new as}function qm(){this.a=new nu,this.b=(zu(3,Sv),new Hc(3))}function kHe(e){this.c=e,this.b=new kg(c(Rn(new tu),50))}function OHe(e){this.c=e,this.b=new kg(c(Rn(new ra),50))}function SHe(e){this.b=e,this.a=new kg(c(Rn(new gu),50))}function Cg(e,t){this.e=e,this.a=Br,this.b=nit(t),this.c=t}function mq(e){this.c=e.c,this.d=e.d,this.b=e.b,this.a=e.a}function jHe(e,t,n,i,r,o){this.a=e,rte.call(this,t,n,i,r,o)}function THe(e,t,n,i,r,o){this.a=e,rte.call(this,t,n,i,r,o)}function E0(e,t,n,i,r,o,a){return new Aee(e.e,t,n,i,r,o,a)}function FAt(e,t,n){return n>=0&&Ot(e.substr(n,t.length),t)}function EHe(e,t){return oe(t,149)&&Ot(e.b,c(t,149).Og())}function qAt(e,t){return e.a?t.Dh().Jc():c(t.Dh(),72).Gi()}function CHe(e,t){var n;return n=e.b.Oc(t),xGe(n,e.b.gc()),n}function $_(e,t){if(e==null)throw J(new K4(t));return e}function vo(e){return e.u||(ru(e),e.u=new eze(e,e)),e.u}function U6(){U6=te;var e,t;t=!yBt(),e=new me,Aoe=t?new be:e}function al(e){var t;return t=c(Wt(e,16),29),t||e.fi()}function wq(e,t){var n;return n=qp(e.Pm),t==null?n:n+": "+t}function Fa(e,t,n){return fs(t,n,e.length),e.substr(t,n-t)}function MHe(e,t){NF.call(this),Qbe(this),this.a=e,this.c=t}function AHe(){UY.call(this,"FIXED_INTEGER_RATIO_BOXES",2)}function HAt(){return Cq(),W(V(h6e,1),_e,425,0,[qce,f6e])}function QAt(){return Nq(),W(V(T6e,1),_e,428,0,[Yce,Kce])}function GAt(){return rD(),W(V(d9e,1),_e,426,0,[Ale,Nle])}function UAt(){return qq(),W(V(zOe,1),_e,427,0,[BOe,xce])}function JAt(){return oD(),W(V(VOe,1),_e,424,0,[PU,XOe])}function XAt(){return Z_(),W(V(YOe,1),_e,479,0,[KOe,RU])}function VAt(){return vh(),W(V(gpt,1),_e,512,0,[Bb,Rh])}function WAt(){return td(),W(V(hpt,1),_e,513,0,[Pw,Wg])}function KAt(){return Wf(),W(V(Mpt,1),_e,519,0,[Kv,sp])}function YAt(){return Z7(),W(V(spt,1),_e,522,0,[aC,uC])}function ZAt(){return Hm(),W(V(Ipt,1),_e,457,0,[op,y3])}function eNt(){return jq(),W(V(l8e,1),_e,430,0,[Zle,c8e])}function tNt(){return hH(),W(V(u8e,1),_e,490,0,[EJ,O3])}function nNt(){return Qq(),W(V(f8e,1),_e,431,0,[a8e,sue])}function iNt(){return X_(),W(V(lje,1),_e,433,0,[Cue,$J])}function rNt(){return Pq(),W(V(eje,1),_e,481,0,[kue,Z8e])}function sNt(){return pD(),W(V(Aje,1),_e,432,0,[zJ,Mje])}function oNt(){return cD(),W(V(rwt,1),_e,498,0,[Uue,Gue])}function cNt(){return Aq(),W(V(_je,1),_e,389,0,[Lue,Nje])}function lNt(){return Wq(),W(V(Tke,1),_e,429,0,[Joe,sU])}function uNt(){return iS(),W(V(Ght,1),_e,506,0,[JL,oce])}function vq(e,t,n,i){return n>=0?e.Rh(t,n,i):e.zh(null,n,i)}function B_(e){return e.b.b==0?e.a.uf():TZ(e.b)}function aNt(e){if(e.p!=5)throw J(new Tl);return Hn(e.f)}function fNt(e){if(e.p!=5)throw J(new Tl);return Hn(e.k)}function _pe(e){return ve(e.a)===ve((dte(),Tae))&&NYt(e),e.a}function hNt(e){e&&wq(e,e.ge())}function NHe(e,t){cde(this,new $e(e.a,e.b)),zN(this,A_(t))}function Hm(){Hm=te,op=new z1e(nk,0),y3=new z1e(ik,1)}function td(){td=te,Pw=new I1e(ik,0),Wg=new I1e(nk,1)}function dNt(e,t){e.c=t,e.c>0&&e.b>0&&(e.g=JF(e.c,e.b,e.a))}function gNt(e,t){e.b=t,e.c>0&&e.b>0&&(e.g=JF(e.c,e.b,e.a))}function _He(e){var t;t=e.c.d.b,e.b=t,e.a=e.c.d,t.a=e.c.d.b=e}function DHe(e){return e.b==0?null:(dn(e.b!=0),ba(e,e.a.a))}function Tc(e,t){return t==null?Ao(co(e.f,null)):f7(e.i,t)}function LHe(e,t,n,i,r){return new qne(e,(Y6(),Boe),t,n,i,r)}function yq(e,t){return OGe(t),PPt(e,ye(Fn,ci,30,t,15,1),t)}function xq(e,t){return pq(e,"set1"),pq(t,"set2"),new mIe(e,t)}function pNt(e,t){var n=Moe[e.charCodeAt(0)];return n??e}function PHe(e,t){var n,i;return n=t,i=new mi,qrt(e,n,i),i.d}function dee(e,t,n,i){var r;r=new oze,t.a[n.g]=r,v5(e.b,i,r)}function bNt(e,t){var n;return n=NPt(e.f,t),ki(MF(n),e.f.d)}function J7(e){var t;HPt(e.a),L$e(e.a),t=new fz(e.a),jwe(t)}function mNt(e,t){Gnt(e,!0),Qc(e.e.Pf(),new g0e(e,!0,t))}function IHe(e){this.a=c(Rn(e),279),this.b=(Ct(),new Cge(e))}function RHe(e,t,n){this.i=new Fe,this.b=e,this.g=t,this.a=n}function kq(e,t,n){this.c=new Fe,this.e=e,this.f=t,this.b=n}function Dpe(e,t,n){this.a=new Fe,this.e=e,this.f=t,this.c=n}function gee(e,t,n){wi(),km.call(this,e),this.b=t,this.a=n}function Lpe(e,t,n){fa(),gz.call(this,t),this.a=e,this.b=n}function $He(e){NF.call(this),Qbe(this),this.a=e,this.c=!0}function Qm(){l9t.call(this,new e5(ov(12))),yge(!0),this.a=2}function vh(){vh=te,Bb=new R1e(vre,0),Rh=new R1e("UP",1)}function V2(e){return e.Db>>16!=3?null:c(e.Cb,19)}function yh(e){return e.Db>>16!=9?null:c(e.Cb,19)}function BHe(e){return e.Db>>16!=6?null:c(e.Cb,74)}function wNt(e){if(e.ye())return null;var t=e.n;return XG[t]}function vNt(e){function t(){}return t.prototype=e||{},new t}function zHe(e){var t;return t=new Cz(ov(e.length)),Rme(t,e),t}function z_(e,t){var n;n=e.q.getHours(),e.q.setDate(t),HT(e,n)}function Ppe(e,t,n){var i;i=e.Fh(t),i>=0?e.$h(i,n):$ve(e,t,n)}function xx(e,t,n){Oq(),e&&oi(Oae,e,t),e&&oi(WP,e,n)}function yNt(e,t){return L1(),c(R(t,(Uo(),xd)),15).a==e}function xNt(e,t){return IF(),Bt(),c(t.b,15).a<e}function kNt(e,t){return IF(),Bt(),c(t.a,15).a<e}function ONt(e,t){return _Ve(e,t)?(NXe(e),!0):!1}function C1(e,t){if(t==null)throw J(new U4);return kBt(e,t)}function FHe(e,t){return e.b+=t.b,e.c+=t.c,e.d+=t.d,e.a+=t.a,e}function qHe(e,t){var n;for(Rn(t),n=e.a;n;n=n.c)t.Wd(n.g,n.i)}function HHe(e,t){var n;return n=e.Fh(t),n>=0?e.Th(n):Xne(e,t)}function pee(e,t,n){var i;i=YVe(e,t,n),e.b=new pH(i.c.length)}function QHe(e){this.a=e,this.b=ye(npt,Be,2022,e.e.length,0,2)}function GHe(){this.a=new Ld,this.e=new Or,this.g=0,this.i=0}function UHe(e,t){xF(this),this.f=t,this.g=e,dq(this),this.he()}function bee(e,t){return p.Math.abs(e)<p.Math.abs(t)?e:t}function xs(e){return Math.max(Math.min(e,di),-2147483648)|0}function SNt(e){return!e.a&&(e.a=new Me(Mn,e,10,11)),e.a.i>0}function Ipe(e){var t;return t=e.d,t=e._i(e.f),Nn(e,t),t.Ob()}function JHe(e,t){var n;return n=new q0e(t),DZe(n,e),new Fl(n)}function jNt(e){if(e.p!=0)throw J(new Tl);return O7(e.f,0)}function TNt(e){if(e.p!=0)throw J(new Tl);return O7(e.k,0)}function XHe(e){return e.Db>>16!=7?null:c(e.Cb,244)}function J6(e){return e.Db>>16!=6?null:c(e.Cb,244)}function Rpe(e){return e.Db>>16!=7?null:c(e.Cb,176)}function Xi(e){return e.Db>>16!=11?null:c(e.Cb,19)}function W2(e){return e.Db>>16!=17?null:c(e.Cb,29)}function VHe(e){return e.Db>>16!=3?null:c(e.Cb,159)}function $pe(e){var t;return R0(e),t=new Or,pi(e,new JAe(t))}function WHe(e,t){var n=e.a=e.a||[];return n[t]||(n[t]=e.te(t))}function ENt(e,t){var n;n=e.q.getHours(),e.q.setMonth(t),HT(e,n)}function ks(e,t){e.c&&fl(e.c.g,e),e.c=t,e.c&&qe(e.c.g,e)}function ss(e,t){e.d&&fl(e.d.e,e),e.d=t,e.d&&qe(e.d.e,e)}function zr(e,t){e.c&&fl(e.c.a,e),e.c=t,e.c&&qe(e.c.a,e)}function _o(e,t){e.i&&fl(e.i.j,e),e.i=t,e.i&&qe(e.i.j,e)}function lo(e,t,n){return t==null?gl(e.f,null,n):Zm(e.i,t,n)}function X7(e,t,n,i,r,o){return new _1(e.e,t,e.Jj(),n,i,r,o)}function CNt(e){return Dte(),Bt(),c(e.a,84).d.e!=0}function KHe(){KHe=te,Cat=Tn((kz(),W(V(Eat,1),_e,541,0,[Toe])))}function YHe(){YHe=te,R0t=Fc(new wr,(es(),Vs),(cs(),pk))}function ZHe(){ZHe=te,$0t=Fc(new wr,(es(),Vs),(cs(),pk))}function eQe(){eQe=te,B0t=Fc(new wr,(es(),Vs),(cs(),pk))}function Bpe(){Bpe=te,z0t=Fc(new wr,(es(),Vs),(cs(),pk))}function tQe(){tQe=te,q0t=Fc(new wr,(es(),Vs),(cs(),pk))}function zpe(){zpe=te,H0t=Fc(new wr,(es(),Vs),(cs(),pk))}function nQe(){nQe=te,cpt=Wn(new wr,(es(),Vs),(cs(),IE))}function Ru(){Ru=te,apt=Wn(new wr,(es(),Vs),(cs(),IE))}function iQe(){iQe=te,fpt=Wn(new wr,(es(),Vs),(cs(),IE))}function mee(){mee=te,bpt=Wn(new wr,(es(),Vs),(cs(),IE))}function rQe(){rQe=te,fbt=Fc(new wr,(B5(),hC),(FT(),A9e))}function Oq(){Oq=te,Oae=new wn,WP=new wn,D8t(Jat,new yj)}function sQe(e,t,n){this.a=t,this.c=e,this.b=(Rn(n),new Fl(n))}function oQe(e,t,n){this.a=t,this.c=e,this.b=(Rn(n),new Fl(n))}function cQe(e,t){this.a=e,this.c=Ms(this.a),this.b=new mq(t)}function eb(e,t,n,i){this.c=e,this.d=i,vee(this,t),yee(this,n)}function O5(e){this.c=new Ai,this.b=e.b,this.d=e.c,this.a=e.a}function wee(e){this.a=p.Math.cos(e),this.b=p.Math.sin(e)}function vee(e,t){e.a&&fl(e.a.k,e),e.a=t,e.a&&qe(e.a.k,e)}function yee(e,t){e.b&&fl(e.b.f,e),e.b=t,e.b&&qe(e.b.f,e)}function lQe(e,t){HMt(e,e.b,e.c),c(e.b.b,68),t&&c(t.b,68).b}function MNt(e,t){pwe(e,t),oe(e.Cb,89)&&bv(ru(c(e.Cb,89)),2)}function xee(e,t){oe(e.Cb,89)&&bv(ru(c(e.Cb,89)),4),Gc(e,t)}function Sq(e,t){oe(e.Cb,187)&&(c(e.Cb,187).tb=null),Gc(e,t)}function uQe(e,t){var n;return n=c(lv(k5(e.a),t),18),n?n.gc():0}function ANt(e,t){var n,i;n=t.c,i=n!=null,i&&y5(e,new J2(t.c))}function aQe(e){var t,n;return n=(x6(),t=new Om,t),eS(n,e),n}function fQe(e){var t,n;return n=(x6(),t=new Om,t),eS(n,e),n}function hQe(e){for(var t;;)if(t=e.Pb(),!e.Ob())return t}function Ec(e,t){return qs(),Kee(t)?new HF(t,e):new p_(t,e)}function NNt(e,t){return ji(c(e.c,65).c.e.b,c(t.c,65).c.e.b)}function _Nt(e,t){return ji(c(e.c,65).c.e.a,c(t.c,65).c.e.a)}function dQe(e,t,n){return new qne(e,(Y6(),zoe),t,n,null,!1)}function gQe(e,t,n){return new qne(e,(Y6(),$oe),null,!1,t,n)}function F_(e){return ld(),Mc(e,0)>=0?$0(e):F7($0(Ng(e)))}function DNt(){return va(),W(V(ml,1),_e,132,0,[vke,bl,yke])}function LNt(){return Yf(),W(V(Nv,1),_e,240,0,[Vo,Vc,Wo])}function PNt(){return Hl(),W(V(dft,1),_e,464,0,[wd,Y0,Tf])}function INt(){return hl(),W(V(pft,1),_e,465,0,[rh,Z0,Ef])}function RNt(e,t){eBe(e,Hn(Yr(Im(t,24),UQ)),Hn(Yr(t,UQ)))}function K2(e,t){if(e<0||e>t)throw J(new zc(pxe+e+bxe+t))}function ht(e,t){if(e<0||e>=t)throw J(new zc(pxe+e+bxe+t))}function en(e,t){if(e<0||e>=t)throw J(new Wde(pxe+e+bxe+t))}function Tt(e,t){this.b=(zt(e),e),this.a=(t&jv)==0?t|64|ad:t}function nd(e,t,n){GWe(t,n,e.gc()),this.c=e,this.a=t,this.b=n-t}function pQe(e,t,n){var i;GWe(t,n,e.c.length),i=n-t,l1e(e.c,t,i)}function $Nt(e,t,n){var i;i=new Cs(n.d),ki(i,e),Qte(t,i.a,i.b)}function Fpe(e){var t;return R0(e),t=(Fm(),Fm(),Poe),Yq(e,t)}function kx(e){return o7(),oe(e.g,9)?c(e.g,9):null}function xh(e){return Lo(W(V(Vr,1),Be,8,0,[e.i.n,e.n,e.a]))}function BNt(){return tT(),W(V(Fke,1),_e,385,0,[Koe,Woe,Yoe])}function zNt(){return D0(),W(V(Fce,1),_e,330,0,[ZL,a6e,$v])}function FNt(){return D1(),W(V(Ndt,1),_e,316,0,[eP,a3,bk])}function qNt(){return cS(),W(V(zce,1),_e,303,0,[$ce,Bce,YL])}function HNt(){return rH(),W(V(GOe,1),_e,351,0,[QOe,LU,kce])}function QNt(){return ab(),W(V(kdt,1),_e,452,0,[Ace,_9,l3])}function GNt(){return Qs(),W(V(A0t,1),_e,455,0,[oC,Jl,Wc])}function UNt(){return vH(),W(V(b9e,1),_e,382,0,[g9e,_le,p9e])}function JNt(){return dT(),W(V(m9e,1),_e,349,0,[Lle,Dle,dP])}function XNt(){return dS(),W(V(v9e,1),_e,350,0,[Ple,w9e,cC])}function VNt(){return gT(),W(V(i9e,1),_e,353,0,[Ole,n9e,hJ])}function WNt(){return iH(),W(V(k9e,1),_e,352,0,[x9e,Ile,y9e])}function KNt(){return yH(),W(V(O9e,1),_e,383,0,[Rle,Q9,Wv])}function YNt(){return fT(),W(V(z9e,1),_e,386,0,[B9e,zle,bP])}function ZNt(){return yD(),W(V(g8e,1),_e,387,0,[CJ,h8e,d8e])}function e_t(){return LH(),W(V(I8e,1),_e,388,0,[P8e,wue,L8e])}function t_t(){return Km(),W(V(hce,1),_e,369,0,[Ew,ep,Tw])}function n_t(){return CH(),W(V(oje,1),_e,435,0,[rje,sje,Sue])}function i_t(){return Gq(),W(V(ije,1),_e,434,0,[Oue,nje,tje])}function r_t(){return SD(),W(V(jue,1),_e,440,0,[PJ,IJ,RJ])}function s_t(){return BH(),W(V(D8e,1),_e,441,0,[mC,NJ,fue])}function o_t(){return mH(),W(V(_8e,1),_e,304,0,[aue,N8e,A8e])}function c_t(){return iT(),W(V(Y7e,1),_e,301,0,[$P,gae,K7e])}function l_t(){return Sh(),W(V(L7e,1),_e,281,0,[t8,oy,n8])}function u_t(){return P5(),W(V(tTe,1),_e,283,0,[eTe,ly,nX])}function a_t(){return R1(),W(V(U7e,1),_e,348,0,[WJ,Zg,LC])}function $u(e){wi(),km.call(this,e),this.c=!1,this.a=!1}function bQe(e,t,n){km.call(this,25),this.b=e,this.a=t,this.c=n}function qpe(e,t){o9t.call(this,new e5(ov(e))),zu(t,qst),this.a=t}function f_t(e,t){var n;return n=(zt(e),e).g,Lge(!!n),zt(t),n(t)}function mQe(e,t){var n,i;return i=$6(e,t),n=e.a.dd(i),new pIe(e,n)}function h_t(e,t,n){var i;return i=UT(e,t,!1),i.b<=t&&i.a<=n}function wQe(e,t,n){var i;i=new pA,i.b=t,i.a=n,++t.b,qe(e.d,i)}function jq(){jq=te,Zle=new F1e("DFS",0),c8e=new F1e("BFS",1)}function d_t(e){if(e.p!=2)throw J(new Tl);return Hn(e.f)&_r}function g_t(e){if(e.p!=2)throw J(new Tl);return Hn(e.k)&_r}function p_t(e){return e.Db>>16!=6?null:c(Kne(e),244)}function Q(e){return dn(e.a<e.c.c.length),e.b=e.a++,e.c.c[e.b]}function b_t(e){return e.a==(V6(),hX)&&le(e,nVt(e.g,e.b)),e.a}function S5(e){return e.d==(V6(),hX)&&dt(e,eKt(e.g,e.b)),e.d}function kee(e){UF(),this.a=(Ct(),oe(e,59)?new iY(e):new TF(e))}function tb(e){return Rn(e),oe(e,18)?new Fl(c(e,18)):P6(e.Jc())}function Hpe(e,t){return RFe(e.a,t)?$0e(e.b,c(t,23).g,null):null}function Yr(e,t){return _0(aMt(Oo(e)?qa(e):e,Oo(t)?qa(t):t))}function id(e,t){return _0(fMt(Oo(e)?qa(e):e,Oo(t)?qa(t):t))}function Oee(e,t){return _0(hMt(Oo(e)?qa(e):e,Oo(t)?qa(t):t))}function m_t(e){return As($d(Zo(lu(e,32)),32),Zo(lu(e,32)))}function w_t(e){var t;return t=c(zF(e.b),10),new ha(e.a,t,e.c)}function v_t(e,t){var n;n=ue(he(e.a.mf((Dn(),UJ)))),hst(e,t,n)}function y_t(e,t){return nT(),e.c==t.c?ji(t.d,e.d):ji(e.c,t.c)}function x_t(e,t){return nT(),e.c==t.c?ji(e.d,t.d):ji(e.c,t.c)}function k_t(e,t){return nT(),e.c==t.c?ji(e.d,t.d):ji(t.c,e.c)}function O_t(e,t){return nT(),e.c==t.c?ji(t.d,e.d):ji(t.c,e.c)}function S_t(e,t){e.b=e.b|t.b,e.c=e.c|t.c,e.d=e.d|t.d,e.a=e.a|t.a}function See(e,t,n){var i;i=e.d[t.p],e.d[t.p]=e.d[n.p],e.d[n.p]=i}function vQe(e,t){var n,i;return n=Jee(t),i=n,c(Ut(e.c,i),15).a}function j_t(e,t){var n,i;return n=AYe(e),i=AYe(t),n<i?-1:n>i?1:0}function T_t(e,t){var n;n=c(Ut(e.g,t),60),Qc(t.d,new nRe(e,n))}function yQe(e,t){var n;for(n=e+"";n.length<t;)n="0"+n;return n}function nb(e){return e.c==null||e.c.length==0?"n_"+e.g:"n_"+e.c}function Qpe(e){return e.b==null||e.b.length==0?"n_"+e.a:"n_"+e.b}function q_(e){return c(jh(e,ye(e1,Hg,9,e.c.length,0,1)),201)}function Gpe(e,t){return e&&e.equals?e.equals(t):ve(e)===ve(t)}function Upe(e,t){return t==0?!!e.o&&e.o.f!=0:cne(e,t)}function E_t(e){return!!e.u&&gc(e.u.a).i!=0&&!(e.n&&dne(e.n))}function C_t(e,t,n){var i;e.n&&t&&n&&(i=new jl,qe(e.e,i))}function jee(e,t){if(Sr(e.a,t),t.d)throw J(new Mo(hot));t.d=e}function Jpe(e,t){this.a=new Fe,this.d=new Fe,this.f=e,this.c=t}function xQe(){this.c=new H$e,this.a=new fUe,this.b=new gLe,NIe()}function kQe(){L5(),this.b=new wn,this.a=new wn,this.c=new Fe}function OQe(e,t,n){this.d=e,this.j=t,this.e=n,this.o=-1,this.p=3}function SQe(e,t,n){this.d=e,this.k=t,this.f=n,this.o=-1,this.p=5}function jQe(e,t,n,i,r,o){Jbe.call(this,e,t,n,i,r),o&&(this.o=-2)}function TQe(e,t,n,i,r,o){Xbe.call(this,e,t,n,i,r),o&&(this.o=-2)}function EQe(e,t,n,i,r,o){hbe.call(this,e,t,n,i,r),o&&(this.o=-2)}function CQe(e,t,n,i,r,o){Kbe.call(this,e,t,n,i,r),o&&(this.o=-2)}function MQe(e,t,n,i,r,o){dbe.call(this,e,t,n,i,r),o&&(this.o=-2)}function AQe(e,t,n,i,r,o){Vbe.call(this,e,t,n,i,r),o&&(this.o=-2)}function NQe(e,t,n,i,r,o){Wbe.call(this,e,t,n,i,r),o&&(this.o=-2)}function _Qe(e,t,n,i,r,o){gbe.call(this,e,t,n,i,r),o&&(this.o=-2)}function DQe(e,t,n,i){gz.call(this,n),this.b=e,this.c=t,this.d=i}function LQe(e,t){this.f=e,this.a=(V6(),fX),this.c=fX,this.b=t}function PQe(e,t){this.g=e,this.d=(V6(),hX),this.a=hX,this.b=t}function Xpe(e,t){!e.c&&(e.c=new ar(e,0)),PQ(e.c,(Ci(),UC),t)}function M_t(e,t){return _Ut(e,t,oe(t,104)&&(c(t,20).Bb&Is)!=0)}function A_t(e,t){return fqe(Zo(e.q.getTime()),Zo(t.q.getTime()))}function IQe(e){return MZ(e.e.Pd().gc()*e.c.Pd().gc(),16,new YB(e))}function N_t(e){return!!e.a&&ou(e.a.a).i!=0&&!(e.b&&gne(e.b))}function V7(e){for(;e.d>0&&e.a[--e.d]==0;);e.a[e.d++]==0&&(e.e=0)}function RQe(e){return e.a?e.e.length==0?e.a.a:e.a.a+(""+e.e):e.c}function $Qe(e){return dn(e.b.b!=e.d.a),e.c=e.b=e.b.b,--e.a,e.c.c}function BQe(e,t){var n;return n=1-t,e.a[n]=fH(e.a[n],n),fH(e,t)}function zQe(e,t){var n,i;return i=Yr(e,Us),n=$d(t,32),id(n,i)}function __t(e,t,n){var i;return i=c(e.Zb().xc(t),18),!!i&&i.Gc(n)}function FQe(e,t,n){var i;return i=c(e.Zb().xc(t),18),!!i&&i.Kc(n)}function qQe(e,t,n){var i;i=(Rn(e),new Fl(e)),bFt(new sQe(i,t,n))}function H_(e,t,n){var i;i=(Rn(e),new Fl(e)),mFt(new oQe(i,t,n))}function HQe(){HQe=te,j9e=Bqe(Pe(1),Pe(4)),S9e=Bqe(Pe(1),Pe(2))}function QQe(e){hte.call(this,e,(Y6(),Roe),null,!1,null,!1)}function GQe(e,t){Wp.call(this,1,2,W(V(Fn,1),ci,30,15,[e,t]))}function os(e,t){this.a=e,Gj.call(this,e),K2(t,e.gc()),this.b=t}function UQe(e,t){var n;e.e=new qde,n=wv(t),Rr(n,e.c),Dnt(e,n,0)}function D_t(e,t,n){e.a=t,e.c=n,e.b.a.$b(),Ou(e.d),M2(e.e.a.c,0)}function Yi(e,t,n,i){var r;r=new Du,r.a=t,r.b=n,r.c=i,ei(e.a,r)}function Ie(e,t,n,i){var r;r=new Du,r.a=t,r.b=n,r.c=i,ei(e.b,r)}function JQe(e,t,n,i){return e.a+=""+Fa(t==null?pl:jo(t),n,i),e}function Qo(e,t,n,i,r,o){return aVe(e,t,n,o),cwe(e,i),lwe(e,r),e}function Vpe(){var e,t,n;return t=(n=(e=new Om,e),n),qe($Te,t),t}function Q_(e,t){if(e<0||e>=t)throw J(new zc(iGt(e,t)));return e}function XQe(e,t,n){if(e<0||t<e||t>n)throw J(new zc(SQt(e,t,n)))}function L_t(e){if(!("stack"in e))try{throw e}catch{}return e}function P_t(e){return yx(e).dc()?!1:(pjt(e,new ee),!0)}function ib(e){var t;return Oo(e)?(t=e,t==-0?0:t):ZLt(e)}function VQe(e,t){return oe(t,45)?vne(e.a,c(t,45)):!1}function WQe(e,t){return oe(t,45)?vne(e.a,c(t,45)):!1}function KQe(e,t){return oe(t,45)?vne(e.a,c(t,45)):!1}function I_t(e,t){return A5(),c(R(t,(Uo(),x3)),15).a>=e.gc()}function R_t(e){return Ru(),!vs(e)&&!(!vs(e)&&e.c.i.c==e.d.i.c)}function rd(e){return c(jh(e,ye(j9,s9,17,e.c.length,0,1)),324)}function Tq(e){return new Hc((zu(e,Fie),Kq(As(As(5,e),e/10|0))))}function $_t(e,t){return new SZ(t,IBe(Ms(t.e),e,e),(Bt(),!0))}function B_t(e){return MZ(e.e.Pd().gc()*e.c.Pd().gc(),273,new xK(e))}function YQe(e){return c(jh(e,ye(qht,zot,12,e.c.length,0,1)),2021)}function ZQe(e){this.a=ye(Br,Lt,1,Pme(p.Math.max(8,e))<<1,5,1)}function Wpe(e){var t;return T0(e),t=new mt,sx(e.a,new QAe(t)),t}function Eq(e){var t;return T0(e),t=new Ue,sx(e.a,new GAe(t)),t}function z_t(e,t){return e.a<=e.b?(t.Bd(e.a++),!0):!1}function F_t(e,t,n){e.d&&fl(e.d.e,e),e.d=t,e.d&&Up(e.d.e,n,e)}function Kpe(e,t,n){this.d=new r_e(this),this.e=e,this.i=t,this.f=n}function Cq(){Cq=te,qce=new D1e(WS,0),f6e=new D1e("TOP_LEFT",1)}function eGe(){eGe=te,ymt=Tn((Iz(),W(V(cje,1),_e,480,0,[Tue])))}function tGe(){tGe=te,kmt=Tn((Rz(),W(V(xmt,1),_e,550,0,[Eue])))}function nGe(){nGe=te,zmt=Tn((c7(),W(V(Cje,1),_e,531,0,[SP])))}function iGe(){iGe=te,Zmt=Tn(($z(),W(V(Ymt,1),_e,557,0,[que])))}function rGe(){rGe=te,twt=Tn((Bz(),W(V(ewt,1),_e,558,0,[Hue])))}function sGe(){sGe=te,iwt=Tn((zz(),W(V(nwt,1),_e,559,0,[Que])))}function q_t(e){lKe((!e.a&&(e.a=new Me(Mn,e,10,11)),e.a),new DA)}function W7(e,t){Xen(t,e),C0e(e.d),C0e(c(R(e,(Ge(),sJ)),216))}function Tee(e,t){Ven(t,e),E0e(e.d),E0e(c(R(e,(Ge(),sJ)),216))}function Gm(e,t){var n,i;return n=C1(e,t),i=null,n&&(i=n.ne()),i}function K7(e,t){var n,i;return n=C1(e,t),i=null,n&&(i=n.qe()),i}function X6(e,t){var n,i;return n=tv(e,t),i=null,n&&(i=n.qe()),i}function M1(e,t){var n,i;return n=C1(e,t),i=null,n&&(i=W2e(n)),i}function H_t(e,t,n){var i;return i=kS(n),MQ(e.n,i,t),MQ(e.o,t,n),t}function Q_t(e,t,n){var i;i=zBt();try{return R7t(e,t,n)}finally{QDt(i)}}function oGe(e,t,n,i){return oe(n,59)?new SBe(e,t,n,i):new W0e(e,t,n,i)}function Ype(e,t,n,i){this.d=e,this.n=t,this.g=n,this.o=i,this.p=-1}function cGe(e,t,n,i){this.e=null,this.c=e,this.d=t,this.a=n,this.b=i}function lGe(e){var t;t=e.Dh(),this.a=oe(t,72)?c(t,72).Gi():t.Jc()}function G_t(e){return new Tt(MPt(c(e.a.kd(),18).gc(),e.a.jd()),16)}function Y2(e){return oe(e,18)?c(e,18).dc():!e.Jc().Ob()}function uGe(e){if(e.e.g!=e.b)throw J(new ua);return!!e.c&&e.d>0}function An(e){return dn(e.b!=e.d.c),e.c=e.b,e.b=e.b.a,++e.a,e.c.c}function Zpe(e,t){zt(t),dr(e.a,e.c,t),e.c=e.c+1&e.a.length-1,RYe(e)}function C0(e,t){zt(t),e.b=e.b-1&e.a.length-1,dr(e.a,e.b,t),RYe(e)}function ebe(e,t){var n;return n=c(Oh(e.b,t),66),!n&&(n=new Ai),n}function U_t(e,t){var n;n=t.a,ks(n,t.c.d),ss(n,t.d.d),rv(n.a,e.n)}function aGe(e,t){return c(vu(Q2(c(Si(e.k,t),16).Mc(),s3)),114)}function fGe(e,t){return c(vu(m5(c(Si(e.k,t),16).Mc(),s3)),114)}function J_t(){return lS(),W(V(Aht,1),_e,413,0,[jw,Dv,_v,i3])}function X_t(){return Ym(),W(V(zft,1),_e,414,0,[HL,qL,Goe,Uoe])}function V_t(){return Y6(),W(V(tU,1),_e,310,0,[Roe,$oe,Boe,zoe])}function W_t(){return $5(),W(V(Gke,1),_e,384,0,[LE,Qke,ice,rce])}function K_t(){return kH(),W(V(Vht,1),_e,368,0,[ace,CU,MU,XL])}function Y_t(){return xf(),W(V(odt,1),_e,418,0,[Iv,E9,C9,fce])}function Z_t(){return hb(),W(V(ept,1),_e,409,0,[gP,lC,mJ,bJ])}function eDt(){return hv(),W(V(jle,1),_e,205,0,[dJ,Sle,v3,w3])}function tDt(){return B1(),W(V(h9e,1),_e,270,0,[rp,f9e,Cle,Mle])}function nDt(){return xT(),W(V(HOe,1),_e,302,0,[$E,FOe,WL,qOe])}function iDt(){return hT(),W(V(o8e,1),_e,354,0,[Yle,TJ,Kle,Wle])}function rDt(){return YH(),W(V(M8e,1),_e,355,0,[uue,E8e,C8e,T8e])}function sDt(){return uQ(),W(V(qbt,1),_e,406,0,[pue,hue,gue,due])}function oDt(){return B5(),W(V(C9e,1),_e,402,0,[xJ,fC,hC,dC])}function cDt(){return nQ(),W(V(Dje,1),_e,396,0,[Iue,Rue,$ue,Bue])}function lDt(){return gS(),W(V(D7e,1),_e,280,0,[_P,VJ,N7e,_7e])}function uDt(){return $1(),W(V(hae,1),_e,225,0,[fae,DP,i8,Ik])}function aDt(){return qu(),W(V(Zwt,1),_e,293,0,[PP,n1,up,LP])}function fDt(){return Cu(),W(V(BC,1),_e,381,0,[zP,Qb,BP,cy])}function hDt(){return _q(),W(V(HP,1),_e,290,0,[nTe,rTe,bae,iTe])}function dDt(){return PH(),W(V(lTe,1),_e,327,0,[mae,sTe,cTe,oTe])}function gDt(){return OH(),W(V(m2t,1),_e,412,0,[wae,aTe,uTe,fTe])}function pDt(e){var t;return e.j==(Je(),bn)&&(t=ytt(e),Cl(t,nn))}function hGe(e,t){var n;for(n=e.j.c.length;n<t;n++)qe(e.j,e.Mg())}function dGe(e,t,n,i){var r;return r=i[t.g][n.g],ue(he(R(e.a,r)))}function bDt(e,t,n){var i;return i=kS(n),MQ(e.f,i,t),oi(e.g,t,n),t}function mDt(e,t,n){var i;return i=kS(n),MQ(e.p,i,t),oi(e.q,t,n),t}function gGe(e){var t,n;return t=(w0(),n=new vj,n),e&&xQ(t,e),t}function tbe(e){var t;return t=e.$i(e.i),e.i>0&&mc(e.g,0,t,0,e.i),t}function j5(e){return o7(),oe(e.g,157)?c(e.g,157):null}function wDt(e){return Oq(),jc(Oae,e)?c(Ut(Oae,e),343).Pg():null}function da(e,t,n){return t<0?Xne(e,n):c(n,69).uk().zk(e,e.ei(),t)}function vDt(e,t){return l5(new $e(t.e.a+t.f.a/2,t.e.b+t.f.b/2),e)}function pGe(e,t){return ve(t)===ve(e)?"(this Map)":t==null?pl:jo(t)}function bGe(e,t){Fz();var n;return n=c(Ut(cX,e),58),!n||n.dk(t)}function yDt(e){if(e.p!=1)throw J(new Tl);return Hn(e.f)<<24>>24}function xDt(e){if(e.p!=1)throw J(new Tl);return Hn(e.k)<<24>>24}function kDt(e){if(e.p!=7)throw J(new Tl);return Hn(e.k)<<16>>16}function ODt(e){if(e.p!=7)throw J(new Tl);return Hn(e.f)<<16>>16}function Ox(e,t){return t.e==0||e.e==0?ME:(PS(),eie(e,t))}function SDt(e,t,n){if(n){var i=n.me();e.a[t]=i(n)}else delete e.a[t]}function mGe(e,t){var n;return n=new Z4,e.Ed(n),n.a+="..",t.Fd(n),n.a}function Vf(e){var t;for(t=0;e.Ob();)e.Pb(),t=As(t,1);return Kq(t)}function jDt(e,t,n){var i;i=c(Ut(e.g,n),60),qe(e.a.c,new Ps(t,i))}function TDt(e,t,n,i,r){var o;o=JUt(r,n,i),qe(t,VQt(r,o)),qHt(e,r,t)}function wGe(e,t,n){e.i=0,e.e=0,t!=n&&(iWe(e,t,n),nWe(e,t,n))}function EDt(e){e.a=null,e.e=null,M2(e.b.c,0),M2(e.f.c,0),e.c=null}function CDt(e,t){return c(t==null?Ao(co(e.f,null)):f7(e.i,t),291)}function MDt(e,t,n){return BZ(he(Ao(co(e.f,t))),he(Ao(co(e.f,n))))}function Mq(e,t,n){return NQ(e,t,n,oe(t,104)&&(c(t,20).Bb&Is)!=0)}function ADt(e,t,n){return $S(e,t,n,oe(t,104)&&(c(t,20).Bb&Is)!=0)}function NDt(e,t,n){return $Ut(e,t,n,oe(t,104)&&(c(t,20).Bb&Is)!=0)}function nbe(e,t){return e==(Jt(),or)&&t==or?4:e==or||t==or?8:32}function vGe(e,t){Npe.call(this),this.a=e,this.b=t,qe(this.a.b,this)}function Z2(e,t){wi(),km.call(this,e),this.a=t,this.c=-1,this.b=-1}function ibe(e,t,n,i,r){this.i=e,this.a=t,this.e=n,this.j=i,this.f=r}function A1(e,t){ld(),Wp.call(this,e,1,W(V(Fn,1),ci,30,15,[t]))}function Fd(e,t){qs();var n;return n=c(e,69).tk(),tQt(n,t),n.vl(t)}function yGe(e,t){var n;for(n=t;n;)$2(e,n.i,n.j),n=Xi(n);return e}function xGe(e,t){var n;for(n=0;n<t;++n)dr(e,n,new lde(c(e[n],45)))}function rbe(e,t){var n;n=e.q.getHours(),e.q.setFullYear(t+G0),HT(e,n)}function kGe(e,t){aS();var n;return n=e.j.g-t.j.g,n!=0?n:0}function Y7(e){return dn(e.a<e.c.a.length),e.b=e.a,QJe(e),e.c.b[e.b]}function gc(e){return e.n||(ru(e),e.n=new zFe(e,Ks,e),vo(e)),e.n}function OGe(e){if(e<0)throw J(new oPe("Negative array size: "+e))}function Eee(e,t,n){if(n){var i=n.me();n=i(n)}else n=void 0;e.a[t]=n}function _Dt(e,t){var n;return n=t!=null?Tc(e,t):Ao(co(e.f,t)),bF(n)}function DDt(e,t){var n;return n=t!=null?Tc(e,t):Ao(co(e.f,t)),bF(n)}function Cee(e){return e.c&&e.d?Qpe(e.c)+"->"+Qpe(e.d):"e_"+Lm(e)}function SGe(e){oe(e,209)&&!et(Ze(e.mf((Dn(),GJ))))&&WWt(c(e,19))}function sbe(e){e.b!=e.c&&(e.a=ye(Br,Lt,1,8,5,1),e.b=0,e.c=0)}function rb(e,t,n){this.e=e,this.a=Br,this.b=nit(t),this.c=t,this.d=n}function ev(e,t,n,i){OQe.call(this,1,n,i),this.c=e,this.b=t}function Mee(e,t,n,i){SQe.call(this,1,n,i),this.c=e,this.b=t}function Aee(e,t,n,i,r,o,a){rte.call(this,t,i,r,o,a),this.c=e,this.a=n}function Nee(e){this.e=e,this.c=this.e.a,this.b=this.e.g,this.d=this.e.i}function jGe(e){this.c=e,this.a=c(Qa(e),160),this.b=this.a.hk().ti()}function LDt(e,t){return Og(),Nn(Ne(e.a),t)}function PDt(e,t){return Og(),Nn(Ne(e.a),t)}function Aq(){Aq=te,Lue=new J1e("STRAIGHT",0),Nje=new J1e("BEND",1)}function Z7(){Z7=te,aC=new $1e("UPPER",0),uC=new $1e("LOWER",1)}function Nq(){Nq=te,Yce=new L1e(th,0),Kce=new L1e("ALTERNATING",1)}function _q(){_q=te,nTe=new vFe,rTe=new iqe,bae=new AHe,iTe=new rqe}function Dq(e){var t;return e?new q0e(e):(t=new Ld,fte(t,e),t)}function IDt(e,t){var n;for(n=e.d-1;n>=0&&e.a[n]===t[n];n--);return n<0}function RDt(e,t){var n;return OGe(t),n=e.slice(0,t),n.length=t,Uee(n,e)}function ql(e,t){var n;return t.b.Kb(TJe(e,t.c.Ve(),(n=new VAe(t),n)))}function Lq(e){L2e(),eBe(this,Hn(Yr(Im(e,24),UQ)),Hn(Yr(e,UQ)))}function TGe(){TGe=te,Wft=Tn((Wq(),W(V(Tke,1),_e,429,0,[Joe,sU])))}function EGe(){EGe=te,Uht=Tn((iS(),W(V(Ght,1),_e,506,0,[JL,oce])))}function CGe(){CGe=te,xdt=Tn((oD(),W(V(VOe,1),_e,424,0,[PU,XOe])))}function MGe(){MGe=te,mdt=Tn((qq(),W(V(zOe,1),_e,427,0,[BOe,xce])))}function AGe(){AGe=te,jdt=Tn((Z_(),W(V(YOe,1),_e,479,0,[KOe,RU])))}function NGe(){NGe=te,Ddt=Tn((Cq(),W(V(h6e,1),_e,425,0,[qce,f6e])))}function _Ge(){_Ge=te,Idt=Tn((Nq(),W(V(T6e,1),_e,428,0,[Yce,Kce])))}function DGe(){DGe=te,M0t=Tn((rD(),W(V(d9e,1),_e,426,0,[Ale,Nle])))}function LGe(){LGe=te,opt=Tn((Z7(),W(V(spt,1),_e,522,0,[aC,uC])))}function PGe(){PGe=te,dpt=Tn((td(),W(V(hpt,1),_e,513,0,[Pw,Wg])))}function IGe(){IGe=te,ppt=Tn((vh(),W(V(gpt,1),_e,512,0,[Bb,Rh])))}function RGe(){RGe=te,Apt=Tn((Wf(),W(V(Mpt,1),_e,519,0,[Kv,sp])))}function $Ge(){$Ge=te,Rpt=Tn((Hm(),W(V(Ipt,1),_e,457,0,[op,y3])))}function BGe(){BGe=te,abt=Tn((jq(),W(V(l8e,1),_e,430,0,[Zle,c8e])))}function zGe(){zGe=te,pbt=Tn((hH(),W(V(u8e,1),_e,490,0,[EJ,O3])))}function FGe(){FGe=te,wbt=Tn((Qq(),W(V(f8e,1),_e,431,0,[a8e,sue])))}function Pq(){Pq=te,kue=new Q1e(_xe,0),Z8e=new Q1e("TARGET_WIDTH",1)}function qGe(){qGe=te,gmt=Tn((Pq(),W(V(eje,1),_e,481,0,[kue,Z8e])))}function HGe(){HGe=te,Omt=Tn((X_(),W(V(lje,1),_e,433,0,[Cue,$J])))}function QGe(){QGe=te,Fmt=Tn((pD(),W(V(Aje,1),_e,432,0,[zJ,Mje])))}function GGe(){GGe=te,qmt=Tn((Aq(),W(V(_je,1),_e,389,0,[Lue,Nje])))}function UGe(){UGe=te,swt=Tn((cD(),W(V(rwt,1),_e,498,0,[Uue,Gue])))}function $Dt(){return Nr(),W(V(_C,1),_e,87,0,[qh,yo,go,Fh,Ca])}function BDt(){return Je(),W(V($s,1),cc,64,0,[$o,Kt,nn,bn,Yt])}function zDt(e){return(e.k==(Jt(),or)||e.k==Cr)&&xi(e,(De(),qE))}function FDt(e,t,n){return c(t==null?gl(e.f,null,n):Zm(e.i,t,n),291)}function obe(e,t,n){e.a.c.length=0,IYt(e,t,n),e.a.c.length==0||cWt(e,t)}function tr(e,t,n,i){var r;r=new Pt,r.c=t,r.b=n,r.a=i,i.b=n.a=r,++e.b}function cbe(e,t){var n,i;for(n=t,i=0;n>0;)i+=e.a[n],n-=n&-n;return i}function JGe(e,t){var n;for(n=t;n;)$2(e,-n.i,-n.j),n=Xi(n);return e}function qDt(e,t){var n,i;i=!1;do n=QVe(e,t),i=i|n;while(n);return i}function ws(e,t){var n,i;for(zt(t),i=e.Jc();i.Ob();)n=i.Pb(),t.Ad(n)}function XGe(e,t){var n,i;return n=t.jd(),i=e.De(n),!!i&&dc(i.e,t.kd())}function VGe(e,t){var n;return n=t.jd(),new Mm(n,e.e.pc(n,c(t.kd(),18)))}function HDt(e,t){var n;return n=e.a.get(t),n??ye(Br,Lt,1,0,5,1)}function Su(e,t,n){var i;return i=(ht(t,e.c.length),e.c[t]),e.c[t]=n,i}function WGe(e,t){this.c=0,this.b=t,u$e.call(this,e,17493),this.a=this.c}function lbe(e){this.d=e,this.b=this.d.a.entries(),this.a=this.b.next()}function M0(){wn.call(this),TBe(this),this.d.b=this.d,this.d.a=this.d}function _ee(e){Iq(),!Ph&&(this.c=e,this.e=!0,this.a=new Fe)}function KGe(e){Mst(),KDe(this),this.a=new Ai,Hme(this,e),ei(this.a,e)}function YGe(){ZY(this),this.b=new $e(nr,nr),this.a=new $e(Qr,Qr)}function ube(e){v8t.call(this,e==null?pl:jo(e),oe(e,81)?c(e,81):null)}function QDt(e){e&&oPt((Ude(),G5e)),--VG,e&&WG!=-1&&(P8t(WG),WG=-1)}function G_(e){e.i=0,n_(e.b,null),n_(e.c,null),e.a=null,e.e=null,++e.g}function Iq(){Iq=te,Ph=!0,eft=!1,tft=!1,ift=!1,nft=!1}function vs(e){return!e.c||!e.d?!1:!!e.c.i&&e.c.i==e.d.i}function abe(e,t){return oe(t,144)?Ot(e.c,c(t,144).c):!1}function Dee(e,t){var n;return n=c(Oh(e.d,t),21),n||c(Oh(e.e,t),21)}function Sx(e,t){return(R0(e),k6(new jt(e,new Dbe(t,e.a)))).zd(hk)}function GDt(){return es(),W(V(qke,1),_e,364,0,[Cf,Zd,vc,yc,Vs])}function UDt(){return cQ(),W(V(bbt,1),_e,365,0,[iue,eue,rue,tue,nue])}function JDt(){return dv(),W(V(ldt,1),_e,372,0,[VL,_U,DU,NU,AU])}function XDt(){return RT(),W(V(mmt,1),_e,370,0,[S3,Mk,OC,kC,OP])}function VDt(){return BD(),W(V(hje,1),_e,331,0,[uje,Mue,fje,Aue,aje])}function WDt(){return ST(),W(V(s9e,1),_e,329,0,[r9e,Tle,Ele,iC,rC])}function KDt(){return Tu(),W(V(j6e,1),_e,166,0,[rP,GE,V1,UE,Db])}function YDt(){return Th(),W(V($h,1),_e,161,0,[Nt,fr,ch,Yg,K1])}function ZDt(){return _x(),W(V(IC,1),_e,260,0,[ap,IP,J7e,PC,X7e])}function eLt(e){return jz(),function(){return Q_t(e,this,arguments)}}function ru(e){return e.t||(e.t=new zDe(e),wT(new rPe(e),0,e.t)),e.t}function ZGe(e){var t;return e.c||(t=e.r,oe(t,89)&&(e.c=c(t,29))),e.c}function tLt(e){return e.e=3,e.d=e.Yb(),e.e!=2?(e.e=0,!0):!1}function Lee(e){var t,n,i;return t=e&au,n=e>>22&au,i=e<0?Q1:0,el(t,n,i)}function eUe(e){var t;return t=e.length,Ot(Qt.substr(Qt.length-t,t),e)}function sn(e){if(hn(e))return e.c=e.a,e.a.Pb();throw J(new Co)}function T5(e,t){return t==0||e.e==0?e:t>0?EKe(e,t):ynt(e,-t)}function fbe(e,t){return t==0||e.e==0?e:t>0?ynt(e,t):EKe(e,-t)}function tUe(e){this.b=e,cn.call(this,e),this.a=c(Wt(this.b.a,4),131)}function nUe(e){this.b=e,a5.call(this,e),this.a=c(Wt(this.b.a,4),131)}function bf(e,t,n,i,r){lUe.call(this,t,i,r),this.c=e,this.b=n}function hbe(e,t,n,i,r){OQe.call(this,t,i,r),this.c=e,this.a=n}function dbe(e,t,n,i,r){SQe.call(this,t,i,r),this.c=e,this.a=n}function gbe(e,t,n,i,r){lUe.call(this,t,i,r),this.c=e,this.a=n}function nLt(e,t,n){return ji(l5(OS(e),Ms(t.b)),l5(OS(e),Ms(n.b)))}function iLt(e,t,n){return ji(l5(OS(e),Ms(t.e)),l5(OS(e),Ms(n.e)))}function rLt(e,t){return p.Math.min(A0(t.a,e.d.d.c),A0(t.b,e.d.d.c))}function Pee(e,t,n){var i;return i=e.Fh(t),i>=0?e.Ih(i,n,!0):ow(e,t,n)}function sLt(e,t){var n,i;n=c(HRt(e.c,t),18),n&&(i=n.gc(),n.$b(),e.d-=i)}function iUe(e){var t,n;return t=e.c.i,n=e.d.i,t.k==(Jt(),Cr)&&n.k==Cr}function eT(e){var t,n;++e.j,t=e.g,n=e.i,e.g=null,e.i=0,e.Mi(n,t),e.Li()}function U_(e,t){e.Zi(e.i+1),M7(e,e.i,e.Xi(e.i,t)),e.Ki(e.i++,t),e.Li()}function rUe(e,t,n){var i;i=new gge(e.a),lT(i,e.a.a),gl(i.f,t,n),e.a.a=i}function pbe(e,t,n,i){var r;for(r=0;r<iU;r++)ZF(e.a[r][t.g],n,i[t.g])}function bbe(e,t,n,i){var r;for(r=0;r<Hoe;r++)eq(e.a[t.g][r],n,i[t.g])}function Si(e,t){var n;return n=c(e.c.xc(t),18),!n&&(n=e.ic(t)),e.pc(t,n)}function oLt(e){var t;return t=(Rn(e),e?new Fl(e):P6(e.Jc())),NT(t),_H(t)}function Iee(e){var t;return t=new qm,ec(t,e),Ee(t,(Ge(),ho),null),t}function mf(e){var t,n;return Rn(e),t=rAt(e.length),n=new Hc(t),Rme(n,e),n}function Ree(e,t,n,i){var r;return r=ye(Fn,ci,30,t,15,1),cHt(r,e,t,n,i),r}function Mg(e,t){var n;return n=(ht(t,e.c.length),e.c[t]),l1e(e.c,t,1),n}function mbe(e,t){var n,i;return n=(zt(e),e),i=(zt(t),t),n==i?0:n<i?-1:1}function wbe(e){var t;return t=e.e+e.f,isNaN(t)&&DF(e.d)?e.d:t}function N1(e,t){return e.a?Zn(e.a,e.b):e.a=new Lu(e.d),j7(e.a,t),e}function vbe(e,t){if(e<0||e>t)throw J(new zc(sve(e,t,"index")));return e}function cLt(e,t){var n;n=e.q.getHours()+(t/60|0),e.q.setMinutes(t),HT(e,n)}function E5(e,t){return Kr(t)?t==null?kve(e.f,null):OVe(e.i,t):kve(e.f,t)}function sUe(e,t){l$e.call(this,t.xd(),t.wd()&-6),zt(e),this.a=e,this.b=t}function oUe(e,t){u$e.call(this,t.xd(),t.wd()&-6),zt(e),this.a=e,this.b=t}function ybe(e,t){mF.call(this,t.xd(),t.wd()&-6),zt(e),this.a=e,this.b=t}function cUe(e,t,n){gz.call(this,n),this.b=e,this.c=t,this.d=(Yte(),Cae)}function lUe(e,t,n){this.d=e,this.k=t?1:0,this.f=n?1:0,this.o=-1,this.p=0}function uUe(e,t,n){this.a=e,this.c=t,this.d=n,qe(t.e,this),qe(n.b,this)}function kh(e){this.c=e,this.a=new G(this.c.a),this.b=new G(this.c.b)}function Rq(){this.e=new Fe,this.c=new Fe,this.d=new Fe,this.b=new Fe}function aUe(){this.g=new Ade,this.b=new Ade,this.a=new Fe,this.k=new Fe}function fUe(){this.a=new Lde,this.b=new SLe,this.d=new s2,this.e=new sm}function $q(e,t,n){this.a=e,this.b=t,this.c=n,qe(e.t,this),qe(t.i,this)}function J_(){this.b=new Ai,this.a=new Ai,this.b=new Ai,this.a=new Ai}function V6(){V6=te;var e,t;fX=(x6(),t=new mz,t),hX=(e=new HK,e)}function Bq(){Bq=te,jC=new gi("org.eclipse.elk.labels.labelManager")}function hUe(){hUe=te,LOe=new qi("separateLayerConnections",(kH(),ace))}function X_(){X_=te,Cue=new G1e("FIXED",0),$J=new G1e("CENTER_NODE",1)}function Wf(){Wf=te,Kv=new B1e("REGULAR",0),sp=new B1e("CRITICAL",1)}function lLt(e,t){var n;return n=YYt(e,t),e.b=new pH(n.c.length),bYt(e,n)}function uLt(e,t,n){var i;return++e.e,--e.f,i=c(e.d[t].ed(n),138),i.kd()}function aLt(e){var t,n;return t=e.jd(),n=c(e.kd(),18),M_(n.Lc(),new wK(t))}function $ee(e){var t;return t=e.b,t.b==0?null:c(pc(t,0),65).b}function xbe(e){if(e.a){if(e.e)return xbe(e.e)}else return e;return null}function fLt(e,t){return e.p<t.p?1:e.p>t.p?-1:0}function zq(e,t){return zt(t),e.c<e.d?(e.Qe(t,e.c++),!0):!1}function dUe(e,t){return jc(e.a,t)?(E5(e.a,t),!0):!1}function C5(e,t,n){return Q_(t,e.e.Pd().gc()),Q_(n,e.c.Pd().gc()),e.a[t][n]}function gUe(e){var t;return e.a||(t=e.r,oe(t,160)&&(e.a=c(t,160))),e.a}function pUe(e){var t;for(T0(e),t=0;e.a.zd(new Bl);)t=As(t,1);return t}function hLt(e){var t;return R0(e),t=new Zze(e,e.a.e,e.a.d|4),new qge(e,t)}function dLt(e,t){var n;e.C&&(n=c(Zs(e.b,t),129).n,n.d=e.C.d,n.a=e.C.a)}function kbe(e){var t,n,i,r;r=e.d,t=e.a,n=e.b,i=e.c,e.d=n,e.a=i,e.b=r,e.c=t}function Obe(e,t,n){var i,r;for(i=0,r=0;r<t.length;r++)i+=e.sg(t[r],i,n)}function Fq(e,t,n,i){this.f=e,this.e=t,this.d=n,this.b=i,this.c=i?i.d:null}function gLt(e,t){t.Tg("Label management",1),bF(R(e,(Bq(),jC))),t.Ug()}function bUe(){bUe=te,rft=Tn((va(),W(V(ml,1),_e,132,0,[vke,bl,yke])))}function mUe(){mUe=te,hft=Tn((Yf(),W(V(Nv,1),_e,240,0,[Vo,Vc,Wo])))}function wUe(){wUe=te,gft=Tn((Hl(),W(V(dft,1),_e,464,0,[wd,Y0,Tf])))}function vUe(){vUe=te,bft=Tn((hl(),W(V(pft,1),_e,465,0,[rh,Z0,Ef])))}function yUe(){yUe=te,kht=Tn((tT(),W(V(Fke,1),_e,385,0,[Koe,Woe,Yoe])))}function xUe(){xUe=te,Adt=Tn((D0(),W(V(Fce,1),_e,330,0,[ZL,a6e,$v])))}function kUe(){kUe=te,_dt=Tn((D1(),W(V(Ndt,1),_e,316,0,[eP,a3,bk])))}function OUe(){OUe=te,Mdt=Tn((cS(),W(V(zce,1),_e,303,0,[$ce,Bce,YL])))}function SUe(){SUe=te,vdt=Tn((rH(),W(V(GOe,1),_e,351,0,[QOe,LU,kce])))}function jUe(){jUe=te,Odt=Tn((ab(),W(V(kdt,1),_e,452,0,[Ace,_9,l3])))}function TUe(){TUe=te,N0t=Tn((Qs(),W(V(A0t,1),_e,455,0,[oC,Jl,Wc])))}function EUe(){EUe=te,_0t=Tn((vH(),W(V(b9e,1),_e,382,0,[g9e,_le,p9e])))}function CUe(){CUe=te,D0t=Tn((dT(),W(V(m9e,1),_e,349,0,[Lle,Dle,dP])))}function MUe(){MUe=te,L0t=Tn((dS(),W(V(v9e,1),_e,350,0,[Ple,w9e,cC])))}function AUe(){AUe=te,P0t=Tn((iH(),W(V(k9e,1),_e,352,0,[x9e,Ile,y9e])))}function NUe(){NUe=te,I0t=Tn((yH(),W(V(O9e,1),_e,383,0,[Rle,Q9,Wv])))}function _Ue(){_Ue=te,S0t=Tn((gT(),W(V(i9e,1),_e,353,0,[Ole,n9e,hJ])))}function DUe(){DUe=te,zbt=Tn((mH(),W(V(_8e,1),_e,304,0,[aue,N8e,A8e])))}function LUe(){LUe=te,Fbt=Tn((BH(),W(V(D8e,1),_e,441,0,[mC,NJ,fue])))}function PUe(){PUe=te,vmt=Tn((SD(),W(V(jue,1),_e,440,0,[PJ,IJ,RJ])))}function IUe(){IUe=te,pmt=Tn((Gq(),W(V(ije,1),_e,434,0,[Oue,nje,tje])))}function RUe(){RUe=te,bmt=Tn((CH(),W(V(oje,1),_e,435,0,[rje,sje,Sue])))}function $Ue(){$Ue=te,gdt=Tn((Km(),W(V(hce,1),_e,369,0,[Ew,ep,Tw])))}function BUe(){BUe=te,zpt=Tn((fT(),W(V(z9e,1),_e,386,0,[B9e,zle,bP])))}function zUe(){zUe=te,vbt=Tn((yD(),W(V(g8e,1),_e,387,0,[CJ,h8e,d8e])))}function FUe(){FUe=te,Ubt=Tn((LH(),W(V(I8e,1),_e,388,0,[P8e,wue,L8e])))}function qUe(){qUe=te,Ywt=Tn((R1(),W(V(U7e,1),_e,348,0,[WJ,Zg,LC])))}function HUe(){HUe=te,Xwt=Tn((Sh(),W(V(L7e,1),_e,281,0,[t8,oy,n8])))}function QUe(){QUe=te,d2t=Tn((P5(),W(V(tTe,1),_e,283,0,[eTe,ly,nX])))}function GUe(){GUe=te,a2t=Tn((iT(),W(V(Y7e,1),_e,301,0,[$P,gae,K7e])))}function qq(){qq=te,BOe=new A1e("QUADRATIC",0),xce=new A1e("SCANLINE",1)}function V_(e){return!e.g&&(e.g=new pg),!e.g.c&&(e.g.c=new BDe(e)),e.g.c}function pLt(e){return!e.g&&(e.g=new pg),!e.g.b&&(e.g.b=new IDe(e)),e.g.b}function bLt(e){return!e.g&&(e.g=new pg),!e.g.d&&(e.g.d=new RDe(e)),e.g.d}function mLt(e){return!e.g&&(e.g=new pg),!e.g.a&&(e.g.a=new $De(e)),e.g.a}function Sbe(e,t){var n,i;return n=t,i=bq(P6(new Xee(e,n))),GF(new Xee(e,n)),i}function wLt(e,t,n,i){return n&&(i=n.Oh(t,Vi(n.Ah(),e.c.sk()),null,i)),i}function vLt(e,t,n,i){return n&&(i=n.Qh(t,Vi(n.Ah(),e.c.sk()),null,i)),i}function Bee(e,t,n,i){var r;return r=ye(Fn,ci,30,t+1,15,1),qWt(r,e,t,n,i),r}function ye(e,t,n,i,r,o){var a;return a=CYe(r,i),r!=10&&W(V(e,o),t,n,r,a),a}function yLt(e,t,n){var i,r;for(r=new oS(t,e),i=0;i<n;++i)XH(r);return r}function zee(e,t,n){var i,r;if(n!=null)for(i=0;i<t;++i)r=n[i],e.Oi(i,r)}function jbe(e,t){var n;return n=new mi,n.c=!0,n.d=t.kd(),qrt(e,t.jd(),n)}function xLt(e,t){var n;n=e.q.getHours()+(t/3600|0),e.q.setSeconds(t),HT(e,n)}function ga(e,t){return!e.o&&(e.o=new Al((oc(),s1),e0,e,0)),Wte(e.o,t)}function Tbe(e,t,n){c(e.b,68),c(e.b,68),c(e.b,68),Qc(e.a,new Ize(n,t,e))}function kLt(e,t,n,i){zit(e,t,n,$S(e,t,i,oe(t,104)&&(c(t,20).Bb&Is)!=0))}function fs(e,t,n){if(e<0||t>n||t<e)throw J(new Wde(JQ+e+gxe+t+fxe+n))}function UUe(e,t,n){this.d=new yz,this.c=new wn,this.a=e,this.e=t,this.c=n}function Fee(e){e?(this.c=e,this.b=null):(this.c=null,this.b=new Fe)}function qee(e,t){qz.call(this,e,t),this.a=ye(Btn,qQ,443,2,0,1),this.b=!0}function Ebe(e){rWe.call(this,e,0),TBe(this),this.d.b=this.d,this.d.a=this.d}function Cbe(e){this.e=e,this.b=this.e.a.entries(),this.a=ye(Br,Lt,1,0,5,1)}function JUe(){JUe=te,F0t=Fc(Wn(new wr,(es(),Cf),(cs(),cce)),Vs,pk)}function OLt(){return hQ(),W(V(WOe,1),_e,286,0,[_ce,Nce,Lce,Dce,Pce,IU])}function SLt(){return RD(),W(V(i6e,1),_e,284,0,[$U,e6e,n6e,ZOe,t6e,Ice])}function jLt(){return MS(),W(V(u6e,1),_e,285,0,[BE,s6e,l6e,c6e,o6e,r6e])}function TLt(){return H5(),W(V(N9,1),_e,233,0,[A9,RE,M9,Rv,c3,o3])}function ELt(){return aQ(),W(V(z7e,1),_e,328,0,[dae,R7e,B7e,P7e,$7e,I7e])}function CLt(){return bb(),W(V(Zue,1),_e,300,0,[Yue,MC,CC,Kue,TC,EC])}function MLt(){return Hd(),W(V(qje,1),_e,259,0,[Vue,TP,EP,HJ,FJ,qJ])}function ALt(){return Zr(),W(V(V7e,1),_e,103,0,[fp,Hh,r8,Hb,r1,xc])}function NLt(){return Ql(),W(V(KJ,1),_e,282,0,[hp,eg,RP,$C,RC,Rk])}function Mbe(e){var t;return!e.a&&e.b!=-1&&(t=e.c.Ah(),e.a=_t(t,e.b)),e.a}function Nn(e,t){return e.Qi()&&e.Gc(t)?!1:(e.Fi(t),!0)}function Kf(e,t){return $_(t,"Horizontal alignment cannot be null"),e.b=t,e}function XUe(e,t,n){wi();var i;return i=Q0(e,t),n&&i&&GMt(e)&&(i=null),i}function Abe(e,t,n){var i;i=e.b[n.c.p][n.p],i.b+=t.b,i.c+=t.c,i.a+=t.a,++i.a}function Nbe(e,t,n){var i;e.d[t.g]=n,i=e.g.c,i[t.g]=p.Math.max(i[t.g],n+1)}function A0(e,t){var n,i;return n=e.a-t.a,i=e.b-t.b,p.Math.sqrt(n*n+i*i)}function _be(e,t){var n,i;for(i=t.Jc();i.Ob();)n=c(i.Pb(),37),dit(e,n,0,0)}function Ag(e,t,n){var i,r;for(r=e.Jc();r.Ob();)i=c(r.Pb(),37),IS(i,t,n)}function _Lt(e){var t,n;for(n=_n(e.a,0);n.b!=n.d.c;)t=c(An(n),65),hve(t)}function VUe(e,t){return zIe(e.e,t)||gb(e.e,t,new YKe(t)),c(Oh(e.e,t),114)}function su(e,t,n,i){return zt(e),zt(t),zt(n),zt(i),new rpe(e,t,new Mr)}function Al(e,t,n,i){this.$j(),this.a=t,this.b=e,this.c=new epe(this,t,n,i)}function Hee(e,t,n,i,r,o){Ype.call(this,t,i,r,o),this.c=e,this.b=n}function W_(e,t,n,i,r,o){Ype.call(this,t,i,r,o),this.c=e,this.a=n}function K_(e,t){var n,i,r;return r=e.r,i=e.d,n=UT(e,t,!0),n.b!=r||n.a!=i}function Y_(e,t,n){var i,r;return r=(i=NS(e.b,t),i),r?IQ(nD(e,r),n):null}function DLt(e,t,n){var i,r,o;i=C1(e,n),r=null,i&&(r=W2e(i)),o=r,XKe(t,n,o)}function LLt(e,t,n){var i,r,o;i=C1(e,n),r=null,i&&(r=W2e(i)),o=r,XKe(t,n,o)}function PLt(e,t){var n;return n=Ut(e.k,t),qve(e,t),lie(e,t),_ve(e,t,n),null}function W6(e,t){var n;return n=e.Fh(t),n>=0?e.Ih(n,!0,!0):ow(e,t,!0)}function ILt(e,t){return ji(ue(he(R(e,(De(),Aw)))),ue(he(R(t,Aw))))}function Dbe(e,t){mF.call(this,t.xd(),t.wd()&-16449),zt(e),this.a=e,this.c=t}function Lbe(e,t,n,i,r){Q$e(this),this.b=e,this.d=t,this.f=n,this.g=i,this.c=r}function Hc(e){ZY(this),N_(e>=0,"Initial capacity must not be negative")}function M5(e){var t;return Rn(e),oe(e,206)?(t=c(e,206),t):new nz(e)}function RLt(e){for(;!e.a;)if(!Sze(e.c,new UAe(e)))return!1;return!0}function $Lt(e){var t;if(!e.a)throw J(new Qqe);return t=e.a,e.a=Xi(e.a),t}function BLt(e){if(e.b<=0)throw J(new Co);return--e.b,e.a-=e.c.c,Pe(e.a)}function Pbe(e,t){if(e.g==null||t>=e.i)throw J(new JY(t,e.i));return e.g[t]}function WUe(e,t,n){if(fS(e,n),n!=null&&!e.dk(n))throw J(new BK);return n}function zLt(e,t,n){var i;return i=YVe(e,t,n),e.b=new pH(i.c.length),Wve(e,i)}function KUe(e){var t;if(e.ll())for(t=e.i-1;t>=0;--t)re(e,t);return tbe(e)}function FLt(e){Hq(),c(e.mf((Dn(),iy)),185).Ec((Ql(),RP)),e.of(lae,null)}function Hq(){Hq=te,lwt=new BA,awt=new _$,uwt=tRt((Dn(),lae),lwt,lp,awt)}function YUe(){YUe=te,_Q(),UTe=nr,yvt=Qr,JTe=new Fs(nr),xvt=new Fs(Qr)}function Qq(){Qq=te,a8e=new H1e("LEAF_NUMBER",0),sue=new H1e("NODE_SIZE",1)}function Qee(e){e.a=ye(Fn,ci,30,e.b+1,15,1),e.c=ye(Fn,ci,30,e.b,15,1),e.d=0}function qLt(e,t){e.a.Le(t.d,e.b)>0&&(qe(e.c,new N0e(t.c,t.d,e.d)),e.b=t.d)}function K6(e,t,n,i){var r;i=(Fm(),i||hke),r=e.slice(t,n),ove(r,e,t,n,-t,i)}function pa(e,t,n,i,r){return t<0?ow(e,n,i):c(n,69).uk().wk(e,e.ei(),t,i,r)}function ZUe(e,t){var n,i;return i=t/e.c.Pd().gc()|0,n=t%e.c.Pd().gc(),C5(e,i,n)}function Ibe(e){var t,n;if(!e.b)return null;for(n=e.b;t=n.a[0];)n=t;return n}function eJe(e){var t,n;if(!e.b)return null;for(n=e.b;t=n.a[1];)n=t;return n}function HLt(e){return oe(e,183)?""+c(e,183).a:e==null?null:jo(e)}function QLt(e){return oe(e,183)?""+c(e,183).a:e==null?null:jo(e)}function tJe(e,t){if(t.a)throw J(new Mo(hot));Sr(e.a,t),t.a=e,!e.j&&(e.j=t)}function Hl(){Hl=te,wd=new mY(nk,0),Y0=new mY(WS,1),Tf=new mY(ik,2)}function Y6(){Y6=te,Roe=new Gz("All",0),$oe=new A$e,Boe=new q$e,zoe=new N$e}function nJe(){nJe=te,Yat=Tn((Y6(),W(V(tU,1),_e,310,0,[Roe,$oe,Boe,zoe])))}function iJe(){iJe=te,Fft=Tn((Ym(),W(V(zft,1),_e,414,0,[HL,qL,Goe,Uoe])))}function rJe(){rJe=te,Nht=Tn((lS(),W(V(Aht,1),_e,413,0,[jw,Dv,_v,i3])))}function sJe(){sJe=te,Rht=Tn(($5(),W(V(Gke,1),_e,384,0,[LE,Qke,ice,rce])))}function oJe(){oJe=te,Wht=Tn((kH(),W(V(Vht,1),_e,368,0,[ace,CU,MU,XL])))}function cJe(){cJe=te,cdt=Tn((xf(),W(V(odt,1),_e,418,0,[Iv,E9,C9,fce])))}function lJe(){lJe=te,tpt=Tn((hb(),W(V(ept,1),_e,409,0,[gP,lC,mJ,bJ])))}function uJe(){uJe=te,j0t=Tn((hv(),W(V(jle,1),_e,205,0,[dJ,Sle,v3,w3])))}function aJe(){aJe=te,C0t=Tn((B1(),W(V(h9e,1),_e,270,0,[rp,f9e,Cle,Mle])))}function fJe(){fJe=te,wdt=Tn((xT(),W(V(HOe,1),_e,302,0,[$E,FOe,WL,qOe])))}function hJe(){hJe=te,ubt=Tn((hT(),W(V(o8e,1),_e,354,0,[Yle,TJ,Kle,Wle])))}function dJe(){dJe=te,Bbt=Tn((YH(),W(V(M8e,1),_e,355,0,[uue,E8e,C8e,T8e])))}function gJe(){gJe=te,Hbt=Tn((uQ(),W(V(qbt,1),_e,406,0,[pue,hue,gue,due])))}function pJe(){pJe=te,$pt=Tn((B5(),W(V(C9e,1),_e,402,0,[xJ,fC,hC,dC])))}function bJe(){bJe=te,Qmt=Tn((nQ(),W(V(Dje,1),_e,396,0,[Iue,Rue,$ue,Bue])))}function mJe(){mJe=te,Jwt=Tn((gS(),W(V(D7e,1),_e,280,0,[_P,VJ,N7e,_7e])))}function wJe(){wJe=te,Vwt=Tn(($1(),W(V(hae,1),_e,225,0,[fae,DP,i8,Ik])))}function vJe(){vJe=te,e2t=Tn((qu(),W(V(Zwt,1),_e,293,0,[PP,n1,up,LP])))}function yJe(){yJe=te,g2t=Tn((_q(),W(V(HP,1),_e,290,0,[nTe,rTe,bae,iTe])))}function xJe(){xJe=te,f2t=Tn((Cu(),W(V(BC,1),_e,381,0,[zP,Qb,BP,cy])))}function kJe(){kJe=te,p2t=Tn((PH(),W(V(lTe,1),_e,327,0,[mae,sTe,cTe,oTe])))}function OJe(){OJe=te,w2t=Tn((OH(),W(V(m2t,1),_e,412,0,[wae,aTe,uTe,fTe])))}function Z_(){Z_=te,KOe=new _1e(th,0),RU=new _1e("IMPROVE_STRAIGHTNESS",1)}function Gq(){Gq=te,Oue=new BY(Nct,0),nje=new BY(t4e,1),tje=new BY(th,2)}function Rbe(e){var t;if(!cte(e))throw J(new Co);return e.e=1,t=e.d,e.d=null,t}function Ng(e){var t;return Oo(e)&&(t=0-e,!isNaN(t))?t:_0(uS(e))}function Do(e,t,n){for(;n<e.c.length;++n)if(dc(t,e.c[n]))return n;return-1}function fl(e,t){var n;return n=Do(e,t,0),n==-1?!1:(Mg(e,n),!0)}function SJe(e,t){var n;return n=c(E5(e.e,t),395),n?(L0e(n),n.e):null}function GLt(e,t,n,i,r){return zt(e),zt(t),zt(n),zt(i),zt(r),new rpe(e,t,i)}function jJe(e){I2(!!e.c),yZ(e.f.g,e.d),e.c.Qb(),e.c=null,e.b=jme(e),e.d=e.f.g}function eD(e){var t;for(t=e.p+1;t<e.c.a.c.length;++t)--c(Xe(e.c.a,t),9).p}function Gee(e){var t;t=e.hj(),t!=null&&e.d!=-1&&c(t,95).uh(e),e.i&&e.i.mj()}function ULt(e){var t;return T0(e),t=ye(ns,no,30,0,15,1),sx(e.a,new HAe(t)),t}function TJe(e,t,n){var i;return T0(e),i=new bs,i.a=t,e.a.Nb(new UIe(i,n)),i.a}function Uee(e,t){return sD(t)!=10&&W(ju(t),t.Qm,t.__elementTypeId$,sD(t),e),e}function Jee(e){var t,n;return n=c(Xe(e.j,0),12),t=c(R(n,(De(),Oi)),12),t}function Xee(e,t){var n;this.f=e,this.b=t,n=c(Ut(e.b,t),263),this.c=n?n.b:null}function EJe(){Pu(),this.b=new wn,this.f=new wn,this.g=new wn,this.e=new wn}function Uq(e){xF(this),this.g=e?wq(e,e.ge()):null,this.f=e,dq(this),this.he()}function _1(e,t,n,i,r,o,a){rte.call(this,t,i,r,o,a),this.c=e,this.b=n}function tD(e,t){if(t<0)throw J(new zc(Wct+t));return hGe(e,t+1),Xe(e.j,t)}function Jq(e,t){return dc(t,Xe(e.f,0))||dc(t,Xe(e.f,1))||dc(t,Xe(e.f,2))}function JLt(e,t){return new SZ(t,$2(Ms(t.e),t.f.a+e,t.f.b+e),(Bt(),!1))}function XLt(e,t){return L6(),qe(e,new Ps(t,Pe(t.e.c.length+t.g.c.length)))}function VLt(e,t){return L6(),qe(e,new Ps(t,Pe(t.e.c.length+t.g.c.length)))}function $be(e,t){o7();var n,i;return n=j5(e),i=j5(t),!!n&&!!i&&!iYe(n.k,i.k)}function nD(e,t){var n,i;return n=c(t,687),i=n.ui(),!i&&n.xi(i=new r$e(e,t)),i}function uo(e,t){var n,i;return n=c(t,689),i=n.Yk(),!i&&n.al(i=new PQe(e,t)),i}function iD(e){xFe();var t,n;return t=e+128,n=K5e[t],!n&&(n=K5e[t]=new rr(e)),n}function ou(e){return e.b||(e.b=new FFe(e,Ks,e),!e.a&&(e.a=new S_(e,e))),e.b}function CJe(e){return yZ(e.d.a.e.g,e.b),dn(e.c!=e.d.a.d),e.a=e.c,e.c=e.c.a,e.a}function Xq(e){var t,n;return n=e.length,t=ye(Na,fd,30,n,15,1),dqe(e,0,n,t,0),t}function MJe(e,t){for(;t[0]<e.length&&Zh(` 	\r
`,dl(ms(e,t[0])))>=0;)++t[0]}function AJe(e,t){Oke=new h0,qft=t,NE=e,c(NE.b,68),Tbe(NE,Oke,null),vrt(NE)}function tT(){tT=te,Koe=new vY("XY",0),Woe=new vY("X",1),Yoe=new vY("Y",2)}function hl(){hl=te,rh=new wY("TOP",0),Z0=new wY(WS,1),Ef=new wY(vxe,2)}function D1(){D1=te,eP=new jY(th,0),a3=new jY("TOP",1),bk=new jY(vxe,2)}function rD(){rD=te,Ale=new P1e("INPUT_ORDER",0),Nle=new P1e("PORT_DEGREE",1)}function Z6(){Z6=te,J5e=el(au,au,524287),Iat=el(0,0,aL),X5e=Lee(1),Lee(2),V5e=Lee(0)}function Bbe(e){var t;return t=N5(Wt(e,32)),t==null&&(tl(e),t=N5(Wt(e,32))),t}function zbe(e){var t;return e.Lh()||(t=pn(e.Ah())-e.gi(),e.Xh().Kk(t)),e.wh()}function NJe(e){(this.q?this.q:(Ct(),Ct(),Yd)).zc(e.q?e.q:(Ct(),Ct(),Yd))}function _Je(e,t){Cc(e,t==null||DF((zt(t),t))||isNaN((zt(t),t))?0:(zt(t),t))}function DJe(e,t){Nl(e,t==null||DF((zt(t),t))||isNaN((zt(t),t))?0:(zt(t),t))}function LJe(e,t){ob(e,t==null||DF((zt(t),t))||isNaN((zt(t),t))?0:(zt(t),t))}function PJe(e,t){sb(e,t==null||DF((zt(t),t))||isNaN((zt(t),t))?0:(zt(t),t))}function WLt(e,t){d5(c(c(e.f,19).mf((Dn(),Y9)),103))&&lKe(xpe(c(e.f,19)),t)}function Vee(e,t){var n;return n=Vi(e.d,t),n>=0?JH(e,n,!0,!0):ow(e,t,!0)}function Vq(e,t){var n;return n=e.bd(t),n>=0?(e.ed(n),!0):!1}function Wee(e,t,n){var i;return i=e.g[t],M7(e,t,e.Xi(t,n)),e.Pi(t,n,i),e.Li(),i}function Kee(e){var t;return e.d!=e.r&&(t=Qa(e),e.e=!!t&&t.jk()==Iut,e.d=t),e.e}function Yee(e,t){var n;for(Rn(e),Rn(t),n=!1;t.Ob();)n=n|e.Ec(t.Pb());return n}function So(e,t){var n,i;return R0(e),i=new ybe(t,e.a),n=new Tze(i),new jt(e,n)}function Oh(e,t){var n;return n=c(Ut(e.e,t),395),n?(Z$e(e,n),n.e):null}function KLt(e,t){var n,i,r;r=t.c.i,n=c(Ut(e.f,r),60),i=n.d.c-n.e.c,wme(t.a,i,0)}function qd(e,t,n){var i,r;for(i=10,r=0;r<n-1;r++)t<i&&(e.a+="0"),i*=10;e.a+=t}function Fbe(e,t){var n;for(++e.d,++e.c[t],n=t+1;n<e.a.length;)++e.a[n],n+=n&-n}function Zee(e){var t;return t=e.b.c.length==0?null:Xe(e.b,0),t!=null&&lte(e,0),t}function YLt(e){switch(e.g){case 0:return di;case 1:return ls;default:return 0}}function ZLt(e){return h2e(e,(Z6(),V5e))<0?-Fjt(uS(e)):e.l+e.m*tk+e.h*yb}function IJe(e){var t,n;return t=e/60|0,n=e%60,n==0?""+t:""+t+":"+(""+n)}function tv(e,t){var n=e.a[t],i=(Ote(),Noe)[typeof n];return i?i(n):twe(typeof n)}function ePt(e,t){return oe(t,104)&&(c(t,20).Bb&Is)!=0?new XY(t,e):new oS(t,e)}function tPt(e,t){return oe(t,104)&&(c(t,20).Bb&Is)!=0?new XY(t,e):new oS(t,e)}function nPt(e,t,n){return l5(new $e(n.e.a+n.f.a/2,n.e.b+n.f.b/2),e)==(zt(t),t)}function qbe(e){if(!e.c)throw J(new Co);return e.e=e.a=e.c,e.c=e.c.c,++e.d,e.a.f}function RJe(e){if(!e.e)throw J(new Co);return e.c=e.a=e.e,e.e=e.e.e,--e.d,e.a.f}function $Je(e,t,n,i){if(!e)throw J(new qt(zT(t,W(V(Br,1),Lt,1,5,[n,i]))))}function BJe(){BJe=te,s2t=Tn((Je(),W(V($s,1),cc,64,0,[$o,Kt,nn,bn,Yt])))}function zJe(){zJe=te,Uwt=Tn((Nr(),W(V(_C,1),_e,87,0,[qh,yo,go,Fh,Ca])))}function FJe(){FJe=te,Tht=Tn((es(),W(V(qke,1),_e,364,0,[Cf,Zd,vc,yc,Vs])))}function nT(){nT=te,Lht=new _8,Pht=new N8,_ht=new Ly,Dht=new wO,Iht=new n2}function Wq(){Wq=te,Joe=new j1e("EADES",0),sU=new j1e("FRUCHTERMAN_REINGOLD",1)}function qJe(e){this.g=e,this.f=new Fe,this.a=p.Math.min(this.g.c.c,this.g.d.c)}function HJe(e,t,n,i){wi(),km.call(this,26),this.c=e,this.a=t,this.d=n,this.b=i}function iPt(e,t){var n,i;for(i=t.c,n=i+1;n<=t.f;n++)e.a[n]>e.a[i]&&(i=n);return i}function QJe(e){var t;for(++e.a,t=e.c.a.length;e.a<t;++e.a)if(e.c.b[e.a])return}function rPt(e,t){var n;return n=ew(e.e.c,t.e.c),n==0?ji(e.e.d,t.e.d):n}function GJe(e){var t;return t=c(R(e,(De(),Cw)),318),t?t.a==e:!1}function UJe(e){var t;return t=c(R(e,(De(),Cw)),318),t?t.i==e:!1}function JJe(e,t){return t==(vZ(),vZ(),Vat)?e.toLocaleLowerCase():e.toLowerCase()}function sD(e){return e.__elementTypeCategory$==null?10:e.__elementTypeCategory$}function sPt(e){var t,n;if(e.a){n=null;do t=e.a,e.a=null,n=fet(t,n);while(e.a);e.a=n}}function oPt(e){var t,n;if(e.b){n=null;do t=e.b,e.b=null,n=fet(t,n);while(e.b);e.b=n}}function cPt(e,t){var n;for(n=0;e.e!=e.i.gc();)SMt(t,un(e),Pe(n)),n!=di&&++n}function ete(e,t){var n;return n=c(Ut(e.a,t),151),n||(n=new Dy,oi(e.a,t,n)),n}function lPt(e,t,n){var i;return i=e.a.e[c(t.a,9).p]-e.a.e[c(n.a,9).p],xs(D_(i))}function _t(e,t){var n;return n=(e.i==null&&ud(e),e.i),t>=0&&t<n.length?n[t]:null}function Hbe(e){return((e.i&2)!=0?"interface ":(e.i&1)!=0?"":"class ")+(j1(e),e.o)}function Kq(e){return Mc(e,di)>0?di:Mc(e,ls)<0?ls:Hn(e)}function wf(e,t,n){var i;if(t==null)throw J(new U4);return i=C1(e,t),SDt(e,t,n),i}function XJe(e,t){return zt(t),K0e(e),e.d.Ob()?(t.Ad(e.d.Pb()),!0):!1}function VJe(e){this.b=new Fe,this.a=new Fe,this.c=new Fe,this.d=new Fe,this.e=e}function WJe(e,t,n){NF.call(this),Qbe(this),this.a=e,this.c=n,this.b=t.d,this.f=t.e}function uPt(){return Jt(),W(V(sce,1),_e,252,0,[or,jr,Cr,Dc,lc,Ih,UL,PE])}function KJe(){KJe=te,n2t=Tn((_x(),W(V(IC,1),_e,260,0,[ap,IP,J7e,PC,X7e])))}function YJe(){YJe=te,fwt=Tn((Th(),W(V($h,1),_e,161,0,[Nt,fr,ch,Yg,K1])))}function ZJe(){ZJe=te,udt=Tn((dv(),W(V(ldt,1),_e,372,0,[VL,_U,DU,NU,AU])))}function eXe(){eXe=te,mbt=Tn((cQ(),W(V(bbt,1),_e,365,0,[iue,eue,rue,tue,nue])))}function tXe(){tXe=te,Pdt=Tn((Tu(),W(V(j6e,1),_e,166,0,[rP,GE,V1,UE,Db])))}function nXe(){nXe=te,T0t=Tn((ST(),W(V(s9e,1),_e,329,0,[r9e,Tle,Ele,iC,rC])))}function iXe(){iXe=te,wmt=Tn((RT(),W(V(mmt,1),_e,370,0,[S3,Mk,OC,kC,OP])))}function rXe(){rXe=te,Smt=Tn((BD(),W(V(hje,1),_e,331,0,[uje,Mue,fje,Aue,aje])))}function aPt(){return EQ(),W(V($Oe,1),_e,277,0,[gce,mce,dce,yce,bce,pce,vce,wce])}function fPt(){return q0(),W(V(hwt,1),_e,287,0,[Bje,Pr,js,Nk,us,Ui,Ak,Bh])}function hPt(){return V5(),W(V(VP,1),_e,235,0,[kae,oX,XP,JP,xae,sX,rX,yae])}function dPt(e,t){return A5(),-fc(c(R(e,(Uo(),x3)),15).a,c(R(t,x3),15).a)}function gPt(e,t,n,i){var r;e.j=-1,vve(e,K2e(e,t,n),(qs(),r=c(t,69).tk(),r.vl(i)))}function pPt(e,t,n){var i,r;for(r=new G(n);r.a<r.c.c.length;)i=Q(r),M2e(e,t,i)}function ao(e){var t,n;n=(t=new QK,t),Nn((!e.q&&(e.q=new Me(tf,e,11,10)),e.q),n)}function bPt(e,t){var n;return n=t>0?t-1:t,vPe(J9t(SXe(A0e(new V4,n),e.n),e.j),e.k)}function Yq(e,t){var n;return R0(e),n=new uHe(e,e.a.xd(),e.a.wd()|4,t),new jt(e,n)}function mPt(e,t){var n,i;return n=c(lv(e.d,t),18),n?(i=t,e.e.pc(i,n)):null}function sXe(e){this.d=e,this.c=e.c.vc().Jc(),this.b=null,this.a=null,this.e=(kz(),Toe)}function Um(e){if(e<0)throw J(new qt("Illegal Capacity: "+e));this.g=this.$i(e)}function wPt(e,t){if(0>e||e>t)throw J(new Kde("fromIndex: 0, toIndex: "+e+fxe+t))}function oXe(e,t){return!!cT(e,t,Hn(Ss(Xd,zd(Hn(Ss(t==null?0:Ri(t),Vd)),15))))}function vPt(e,t){d5(c(R(c(e.e,9),(Ge(),cr)),103))&&(Ct(),Rr(c(e.e,9).j,t))}function yPt(e){var t;return t=ue(he(R(e,(Ge(),Xg)))),t<0&&(t=0,Ee(e,Xg,t)),t}function Zq(e,t){var n,i;for(i=e.Jc();i.Ob();)n=c(i.Pb(),70),Ee(n,(De(),xk),t)}function xPt(e,t,n){var i;i=p.Math.max(0,e.b/2-.5),ET(n,i,1),qe(t,new KIe(n,i))}function cXe(e,t,n,i,r,o){var a;a=Iee(i),ks(a,r),ss(a,o),St(e.a,i,new PF(a,t,n.f))}function lXe(e,t){ii(e,(Gd(),mue),t.f),ii(e,Gbt,t.e),ii(e,bue,t.d),ii(e,Qbt,t.c)}function tte(e){var t;I2(!!e.c),t=e.c.a,ba(e.d,e.c),e.b==e.c?e.b=t:--e.a,e.c=null}function uXe(e){return e.a>=-.01&&e.a<=_h&&(e.a=0),e.b>=-.01&&e.b<=_h&&(e.b=0),e}function jx(e){LS();var t,n;for(n=r4e,t=0;t<e.length;t++)e[t]>n&&(n=e[t]);return n}function aXe(e,t){var n;if(n=JD(e.Ah(),t),!n)throw J(new qt(V0+t+Qse));return n}function nv(e,t){var n;for(n=e;Xi(n);)if(n=Xi(n),n==t)return!0;return!1}function kPt(e,t){return t&&e.b[t.g]==t?(dr(e.b,t.g,null),--e.c,!0):!1}function ba(e,t){var n;return n=t.c,t.a.b=t.b,t.b.a=t.a,t.a=t.b=null,t.c=null,--e.b,n}function Qc(e,t){var n,i,r,o;for(zt(t),i=e.c,r=0,o=i.length;r<o;++r)n=i[r],t.Ad(n)}function OPt(e,t){var n,i,r;for(i=t.a.jd(),n=c(t.a.kd(),18).gc(),r=0;r<n;r++)e.Ad(i)}function SPt(e){var t,n;for(t=e.a.d.j,n=e.c.d.j;t!=n;)yf(e.b,t),t=AH(t);yf(e.b,t)}function jPt(e){var t;for(t=0;t<e.c.length;t++)(ht(t,e.c.length),c(e.c[t],12)).p=t}function TPt(e,t,n){var i,r,o;for(r=t[n],i=0;i<r.length;i++)o=r[i],e.e[o.c.p][o.p]=i}function nte(e,t){var n,i,r,o;for(i=e.d,r=0,o=i.length;r<o;++r)n=i[r],wh(e.g,n).a=t}function fXe(e,t,n){var i,r;i=t;do r=ue(e.p[i.p])+n,e.p[i.p]=r,i=e.a[i.p];while(i!=t)}function EPt(e){var t;return t=p.Math.sqrt(e.a*e.a+e.b*e.b),t>0&&(e.a/=t,e.b/=t),e}function eH(e){this.b=(Rn(e),new Fl(e)),this.a=new Fe,this.d=new Fe,this.e=new as}function Qbe(e){e.b=(Hl(),Y0),e.f=(hl(),Z0),e.d=(zu(2,Sv),new Hc(2)),e.e=new as}function hXe(){hXe=te,iU=(Yf(),W(V(Nv,1),_e,240,0,[Vo,Vc,Wo])).length,Hoe=iU}function Yf(){Yf=te,Vo=new bY("BEGIN",0),Vc=new bY(WS,1),Wo=new bY("END",2)}function Sh(){Sh=te,t8=new qY(WS,0),oy=new qY("HEAD",1),n8=new qY("TAIL",2)}function oD(){oD=te,PU=new N1e("READING_DIRECTION",0),XOe=new N1e("ROTATION",1)}function cD(){cD=te,Uue=new X1e("DIRECT_ROUTING",0),Gue=new X1e("BEND_ROUTING",1)}function A5(){A5=te,hbt=cd(cd(cd(u7(new wr,(B5(),fC)),(FT(),Ble)),_9e),I9e)}function L1(){L1=te,gbt=cd(cd(cd(u7(new wr,(B5(),dC)),(FT(),L9e)),M9e),D9e)}function Tx(e,t){return K9t(oT(e,t,Hn(Ss(Xd,zd(Hn(Ss(t==null?0:Ri(t),Vd)),15)))))}function Gbe(e,t){return mh(),vf(Fg),p.Math.abs(e-t)<=Fg||e==t||isNaN(e)&&isNaN(t)}function Ube(e,t){return mh(),vf(Fg),p.Math.abs(e-t)<=Fg||e==t||isNaN(e)&&isNaN(t)}function Bu(e){var t;return e.w?e.w:(t=p_t(e),t&&!t.Sh()&&(e.w=t),t)}function CPt(e){var t;return e==null?null:(t=c(e,198),xHt(t,t.length))}function re(e,t){if(e.g==null||t>=e.i)throw J(new JY(t,e.i));return e.Ui(t,e.g[t])}function MPt(e,t){Ct();var n,i;for(i=new Fe,n=0;n<e;++n)It(i.c,t);return new iY(i)}function dXe(e){return R0(e),p5(!0,"n may not be negative"),new jt(e,new PXe(e.a))}function APt(e,t){return z0(),fc(e.b.c.length-e.e.c.length,t.b.c.length-t.e.c.length)}function eS(e,t){var n,i;i=e.a,n=l$t(e,t,null),i!=t&&!e.e&&(n=FS(e,t,n)),n&&n.mj()}function NPt(e,t){var n;return n=Hr(Ms(c(Ut(e.g,t),8)),fge(c(Ut(e.f,t),463).b)),n}function gXe(e,t,n){var i=function(){return e.apply(i,arguments)};return t.apply(i,n),i}function N5(e){var t;return L7(e==null||Array.isArray(e)&&(t=sD(e),!(t>=14&&t<=16))),e}function pXe(){pXe=te,Tdt=Tn((RD(),W(V(i6e,1),_e,284,0,[$U,e6e,n6e,ZOe,t6e,Ice])))}function bXe(){bXe=te,Edt=Tn((MS(),W(V(u6e,1),_e,285,0,[BE,s6e,l6e,c6e,o6e,r6e])))}function mXe(){mXe=te,Sdt=Tn((hQ(),W(V(WOe,1),_e,286,0,[_ce,Nce,Lce,Dce,Pce,IU])))}function wXe(){wXe=te,bdt=Tn((H5(),W(V(N9,1),_e,233,0,[A9,RE,M9,Rv,c3,o3])))}function vXe(){vXe=te,Wwt=Tn((aQ(),W(V(z7e,1),_e,328,0,[dae,R7e,B7e,P7e,$7e,I7e])))}function yXe(){yXe=te,ywt=Tn((bb(),W(V(Zue,1),_e,300,0,[Yue,MC,CC,Kue,TC,EC])))}function xXe(){xXe=te,gwt=Tn((Hd(),W(V(qje,1),_e,259,0,[Vue,TP,EP,HJ,FJ,qJ])))}function kXe(){kXe=te,i2t=Tn((Zr(),W(V(V7e,1),_e,103,0,[fp,Hh,r8,Hb,r1,xc])))}function OXe(){OXe=te,r2t=Tn((Ql(),W(V(KJ,1),_e,282,0,[hp,eg,RP,$C,RC,Rk])))}function _Pt(){return mv(),W(V(Ws,1),_e,96,0,[Nf,Z1,_f,Lf,i1,Ya,Vu,Df,Ka])}function iT(){iT=te,$P=new QY(o5e,0),gae=new QY("PARENT",1),K7e=new QY("ROOT",2)}function SXe(e,t){return e.n=t,e.n?(e.f=new Fe,e.e=new Fe):(e.f=null,e.e=null),e}function sb(e,t){var n;n=e.f,e.f=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new ev(e,3,n,e.f))}function tH(e,t){var n;n=e.b,e.b=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new ev(e,1,n,e.b))}function Jm(e,t){var n;n=e.b,e.b=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new ev(e,3,n,e.b))}function Xm(e,t){var n;n=e.c,e.c=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new ev(e,4,n,e.c))}function ob(e,t){var n;n=e.g,e.g=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new ev(e,4,n,e.g))}function Cc(e,t){var n;n=e.i,e.i=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new ev(e,5,n,e.i))}function Nl(e,t){var n;n=e.j,e.j=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new ev(e,6,n,e.j))}function Vm(e,t){var n;n=e.j,e.j=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new ev(e,1,n,e.j))}function Wm(e,t){var n;n=e.k,e.k=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new ev(e,2,n,e.k))}function nH(e,t){var n;n=e.a,e.a=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new ev(e,0,n,e.a))}function _g(e,t){var n;n=e.s,e.s=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Mee(e,4,n,e.s))}function iv(e,t){var n;n=e.t,e.t=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Mee(e,5,n,e.t))}function ite(e,t){var n;n=e.d,e.d=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Mee(e,2,n,e.d))}function tS(e,t){var n;n=e.F,e.F=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,5,n,t))}function lD(e,t){var n;return n=c(Ut((Fz(),cX),e),58),n?n.ek(t):ye(Br,Lt,1,t,5,1)}function P1(e,t){var n,i;return n=t in e.a,n&&(i=C1(e,t).pe(),i)?i.a:null}function DPt(e,t){var n,i,r;return n=(i=(w0(),r=new WA,r),t&&Qve(i,t),i),lme(n,e),n}function jXe(e,t,n){var i;return i=kS(n),oi(e.c,i,t),oi(e.d,t,n),oi(e.e,t,V2(t)),t}function mn(e,t,n,i,r,o){var a;return a=YZ(e,t),EXe(n,a),a.i=r?8:0,a.f=i,a.e=r,a.g=o,a}function Jbe(e,t,n,i,r){this.d=t,this.k=i,this.f=r,this.o=-1,this.p=1,this.c=e,this.a=n}function Xbe(e,t,n,i,r){this.d=t,this.k=i,this.f=r,this.o=-1,this.p=2,this.c=e,this.a=n}function Vbe(e,t,n,i,r){this.d=t,this.k=i,this.f=r,this.o=-1,this.p=6,this.c=e,this.a=n}function Wbe(e,t,n,i,r){this.d=t,this.k=i,this.f=r,this.o=-1,this.p=7,this.c=e,this.a=n}function Kbe(e,t,n,i,r){this.d=t,this.j=i,this.e=r,this.o=-1,this.p=4,this.c=e,this.a=n}function TXe(e,t){var n,i,r,o;for(i=t,r=0,o=i.length;r<o;++r)n=i[r],tJe(e.a,n);return e}function ma(e){var t,n,i,r;for(n=e,i=0,r=n.length;i<r;++i)t=n[i],Rn(t);return new m$e(e)}function Ybe(e){var t;return t=Hr(Ms(e.d.d),e.c.d),TS(t,e.c.e.a,e.c.e.b),ki(t,e.c.d)}function Zbe(e){var t;return t=Hr(Ms(e.c.d),e.d.d),TS(t,e.d.e.a,e.d.e.b),ki(t,e.d.d)}function LPt(e){var t=/function(?:\s+([\w$]+))?\s*\(/,n=t.exec(e);return n&&n[1]||qie}function EXe(e,t){if(e){t.n=e;var n=wNt(t);if(!n){XG[e]=[t];return}n.Pm=t}}function PPt(e,t,n){var i,r;return r=e.length,i=p.Math.min(n,r),wve(e,0,t,0,i,!0),t}function CXe(e,t,n){if(fS(e,n),!e.il()&&n!=null&&!e.dk(n))throw J(new BK);return n}function jn(e,t){var n;return zt(t),n=e[":"+t],N_(!!n,"Enum constant undefined: "+t),n}function IPt(e,t){var n,i;return n=e.c,i=t.e[e.p],i>0?c(Xe(n.a,i-1),9):null}function vf(e){if(!(e>=0))throw J(new qt("tolerance ("+e+") must be >= 0"));return e}function rT(){return Jue||(Jue=new tit,Cx(Jue,W(V(n3,1),Lt,139,0,[new NN]))),Jue}function iH(){iH=te,x9e=new NY("NO",0),Ile=new NY(_xe,1),y9e=new NY("LOOK_BACK",2)}function rH(){rH=te,QOe=new xY("ARD",0),LU=new xY("MSD",1),kce=new xY("MANUAL",2)}function Qs(){Qs=te,oC=new EY(nE,0),Jl=new EY("INPUT",1),Wc=new EY("OUTPUT",2)}function RPt(){return QD(),W(V(JOe,1),_e,268,0,[jce,UOe,Ece,Cce,Tce,Mce,KL,Sce,Oce])}function $Pt(){return UD(),W(V(t9e,1),_e,269,0,[kle,YSe,ZSe,yle,KSe,e9e,fJ,vle,xle])}function BPt(){return uu(),W(V(Z7e,1),_e,267,0,[s8,qP,YJ,zC,ZJ,tX,eX,pae,FP])}function eo(e,t,n){return db(e,t),Gc(e,n),_g(e,0),iv(e,1),Rg(e,!0),Ig(e,!0),e}function MXe(e,t){var n;return oe(t,45)?e.c.Kc(t):(n=Wte(e,t),zH(e,t),n)}function sT(e,t){var n,i,r,o;for(i=t,r=0,o=i.length;r<o;++r)n=i[r],tr(e,n,e.c.b,e.c)}function zPt(){eIe();for(var e=xoe,t=0;t<arguments.length;t++)e.push(arguments[t])}function FPt(e){var t,n,i,r;for(n=e.a,i=0,r=n.length;i<r;++i)t=n[i],gqe(t,t.length,null)}function sH(e){var t,n;for(n=e.c.Bc().Jc();n.Ob();)t=c(n.Pb(),18),t.$b();e.c.$b(),e.d=0}function uD(e,t){var n;if(n=e.gc(),t<0||t>n)throw J(new F2(t,n));return new a0e(e,t)}function AXe(e,t){var n,i;for(n=0,i=e.gc();n<i;++n)if(dc(t,e.Xb(n)))return n;return-1}function eme(e){var t,n;if(e==0)return 32;for(n=0,t=1;(t&e)==0;t<<=1)++n;return n}function zu(e,t){if(e<0)throw J(new qt(t+" cannot be negative but was: "+e));return e}function qPt(e,t){t.Tg("Hierarchical port constraint processing",1),czt(e),ftn(e),t.Ug()}function oH(e,t){e.b=p.Math.max(e.b,t.d),e.e+=t.r+(e.a.c.length==0?0:e.c),qe(e.a,t)}function NXe(e){I2(e.c>=0),jBt(e.d,e.c)<0&&(e.a=e.a-1&e.d.a.length-1,e.b=e.d.c),e.c=-1}function HPt(e){var t,n;for(n=new G(LYe(e));n.a<n.c.c.length;)t=c(Q(n),692),t.Zf()}function QPt(e,t){var n,i,r;r=t.c.i,n=c(Ut(e.f,r),60),i=n.d.c-n.e.c,Qc(t.b,new GNe(i))}function cH(e,t){return W9t(cT(e.a,t,Hn(Ss(Xd,zd(Hn(Ss(t==null?0:Ri(t),Vd)),15)))))}function _Xe(e,t,n,i){this.$j(),this.a=t,this.b=e,this.c=null,this.c=new xze(this,t,n,i)}function rte(e,t,n,i,r){this.d=e,this.n=t,this.g=n,this.o=i,this.p=-1,r||(this.o=-2-i-1)}function DXe(){Sge.call(this),this.n=-1,this.g=null,this.i=null,this.j=null,this.Bb|=Ga}function LXe(e){p1e(),this.g=new wn,this.f=new wn,this.b=new wn,this.c=new Qm,this.i=e}function tme(){this.f=new as,this.d=new Ide,this.c=new as,this.a=new Fe,this.b=new Fe}function PXe(e){mF.call(this,e.yd(64)?uge(0,Ha(e.xd(),1)):cL,e.wd()),this.b=1,this.a=e}function GPt(e,t){return A5(),c(R(t,(Uo(),x3)),15).a<e.gc()&&c(R(t,x3),15).a>=0}function nme(){nme=te,Q0t=Wn(Wn(Wn(new wr,(es(),Cf),(cs(),r3)),Zd,Pv),vc,Lv)}function IXe(){IXe=te,G0t=Wn(Wn(Wn(new wr,(es(),Cf),(cs(),r3)),Zd,Pv),vc,Lv)}function ime(){ime=te,U0t=Wn(Wn(Wn(new wr,(es(),Cf),(cs(),r3)),Zd,Pv),vc,Lv)}function RXe(){RXe=te,J0t=Wn(Wn(Wn(new wr,(es(),Cf),(cs(),r3)),Zd,Pv),vc,Lv)}function $Xe(){$Xe=te,X0t=Wn(Wn(Wn(new wr,(es(),Cf),(cs(),r3)),Zd,Pv),vc,Lv)}function BXe(){BXe=te,V0t=Wn(Wn(Wn(new wr,(es(),Cf),(cs(),r3)),Zd,Pv),vc,Lv)}function zXe(){zXe=te,Y0t=Fc(Wn(Wn(new wr,(es(),vc),(cs(),yU)),yc,pU),Vs,vU)}function FXe(){FXe=te,Rat=W(V(Fn,1),ci,30,15,[0,8,4,12,2,10,6,14,1,9,5,13,3,11,7,15])}function rme(e,t){var n;n=e.b,e.b=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,0,n,e.b))}function sme(e,t){var n;n=e.c,e.c=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,1,n,e.c))}function ste(e,t){var n;n=e.c,e.c=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,4,n,e.c))}function ome(e,t){var n;n=e.c,e.c=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,1,n,e.c))}function cme(e,t){var n;n=e.d,e.d=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,1,n,e.d))}function nS(e,t){var n;n=e.k,e.k=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,2,n,e.k))}function ote(e,t){var n;n=e.D,e.D=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,2,n,e.D))}function lH(e,t){var n;n=e.f,e.f=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,8,n,e.f))}function uH(e,t){var n;n=e.i,e.i=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,7,n,e.i))}function lme(e,t){var n;n=e.a,e.a=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,8,n,e.a))}function ume(e,t){var n;n=e.b,e.b=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,0,n,e.b))}function UPt(e,t,n){var i;e.b=t,e.a=n,i=(e.a&512)==512?new RLe:new DB,e.c=_Xt(i,e.b,e.a)}function qXe(e,t){return F1(e.e,t)?(qs(),Kee(t)?new HF(t,e):new p_(t,e)):new i$e(t,e)}function JPt(e){var t,n;return 0>e?new d1e:(t=e+1,n=new WGe(t,e),new Hge(null,n))}function XPt(e,t){Ct();var n;return n=new e5(1),Kr(e)?lo(n,e,t):gl(n.f,e,t),new PK(n)}function VPt(e,t){var n;n=new h0,c(t.b,68),c(t.b,68),c(t.b,68),Qc(t.a,new w0e(e,n,t))}function HXe(e,t){var n;return oe(t,8)?(n=c(t,8),e.a==n.a&&e.b==n.b):!1}function WPt(e){var t;return t=R(e,(De(),Oi)),oe(t,176)?hKe(c(t,176)):null}function QXe(e){var t;return e=p.Math.max(e,2),t=Pme(e),e>t?(t<<=1,t>0?t:KT):t}function cte(e){switch(xge(e.e!=3),e.e){case 2:return!1;case 0:return!0}return tLt(e)}function ame(e){var t;return e.b==null?(Sg(),Sg(),ZP):(t=e.sl()?e.rl():e.ql(),t)}function GXe(e,t){var n,i;for(i=t.vc().Jc();i.Ob();)n=c(i.Pb(),45),PD(e,n.jd(),n.kd())}function fme(e,t){var n;n=e.d,e.d=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,11,n,e.d))}function aH(e,t){var n;n=e.j,e.j=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,13,n,e.j))}function hme(e,t){var n;n=e.b,e.b=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,21,n,e.b))}function dme(e,t){e.r>0&&e.c<e.r&&(e.c+=t,e.i&&e.i.d>0&&e.g!=0&&dme(e.i,t/e.r*e.i.d))}function Ex(e){var t;return yZ(e.f.g,e.d),dn(e.b),e.c=e.a,t=c(e.a.Pb(),45),e.b=jme(e),t}function UXe(e,t){var n;return n=t==null?-1:Do(e.b,t,0),n<0?!1:(lte(e,n),!0)}function yf(e,t){var n;return zt(t),n=t.g,e.b[n]?!1:(dr(e.b,n,t),++e.c,!0)}function fH(e,t){var n,i;return n=1-t,i=e.a[n],e.a[n]=i.a[t],i.a[t]=e,e.b=!0,i.b=!1,i}function lte(e,t){var n;n=Mg(e.b,e.b.c.length-1),t<e.b.c.length&&(Su(e.b,t,n),_et(e,t))}function KPt(e,t){(Iq(),Ph?null:t.c).length==0&&JBe(t,new Gn),lo(e.a,Ph?null:t.c,t)}function JXe(e,t,n){var i,r,o;for(o=e.a.length-1,r=e.b,i=0;i<n;r=r+1&o,++i)dr(t,i,e.a[r])}function YPt(e,t){typeof window===iL&&typeof window.$gwt===iL&&(window.$gwt[e]=t)}function ZPt(e,t){lr(pi(new jt(null,new Tt(new an(e.b),1)),new TRe(e,t)),new CRe(e,t))}function N0(){N0=te,gk=new gi(jxe),lU=new gi(Dot),DE=new gi(Lot),QL=new gi(Pot)}function iS(){iS=te,JL=new M1e("TO_INTERNAL_LTR",0),oce=new M1e("TO_INPUT_DIRECTION",1)}function hH(){hH=te,EJ=new q1e("P1_NODE_PLACEMENT",0),O3=new q1e("P2_EDGE_ROUTING",1)}function Km(){Km=te,Ew=new yY("START",0),ep=new yY("MIDDLE",1),Tw=new yY("END",2)}function XXe(e,t,n){Kpe.call(this,e,t,n),this.a=new wn,this.b=new wn,this.d=new h_e(this)}function VXe(e){H0e.call(this),this.b=ue(he(R(e,(Ge(),Mf)))),this.a=c(R(e,W1),225)}function eIt(e,t){var n,i;return n=c(R(e,(Ge(),Uv)),8),i=c(R(t,Uv),8),ji(n.b,i.b)}function tIt(e,t){var n,i;i=new Fe,n=t;do It(i.c,n),n=c(Ut(e.k,n),17);while(n);return i}function ute(e,t,n){var i;return i=new Fe,Jve(e,t,i,n,!0,!0),e.b=new pH(i.c.length),i}function WXe(e,t){var n;return n=c(Ut(e.c,t),459),n||(n=new bLe,n.c=t,oi(e.c,n.c,n)),n}function ate(e,t){var n=e.a,i=0;for(var r in n)n.hasOwnProperty(r)&&(t[i++]=r);return t}function gme(e){var t,n;for(n=new cn(e);n.e!=n.i.gc();)t=c(un(n),19),Cc(t,0),Nl(t,0)}function KXe(e){var t,n;for(n=e.c.a.ec().Jc();n.Ob();)t=c(n.Pb(),221),ex(t,new KFe(t.f))}function pme(e){var t,n;for(n=e.c.a.ec().Jc();n.Ob();)t=c(n.Pb(),221),ode(t,new qZe(t.e))}function cb(e,t){var n,i;for(n=e.Nc(),K6(n,0,n.length,t),i=0;i<n.length;i++)e.fd(i,n[i])}function Gc(e,t){var n;n=e.zb,e.zb=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,1,n,e.zb))}function sr(e,t){var n,i;n=(i=new HK,i),n.n=t,Nn((!e.s&&(e.s=new Me(xl,e,21,17)),e.s),n)}function zi(e,t){var n,i;i=(n=new Fge,n),i.n=t,Nn((!e.s&&(e.s=new Me(xl,e,21,17)),e.s),i)}function fte(e,t){var n;return oe(t,18)?(n=c(t,18),e.Fc(n)):Yee(e,c(Rn(t),22).Jc())}function dH(e,t){var n;n=e.xb,e.xb=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,3,n,e.xb))}function gH(e,t){var n;n=e.yb,e.yb=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,2,n,e.yb))}function nIt(e,t){t.Tg(Wot,1),lr(So(new jt(null,new Tt(e.b,16)),new yO),new om),t.Ug()}function Ri(e){return Kr(e)?Dg(e):P2(e)?o5(e):L2(e)?XBe(e):X0e(e)?e.Hb():G0e(e)?Lm(e):Ape(e)}function Os(e,t){var n,i,r;for(zt(t),n=!1,r=t.Jc();r.Ob();)i=r.Pb(),n=n|e.Ec(i);return n}function YXe(e){var t,n,i;for(t=0,i=e.Jc();i.Ob();)n=i.Pb(),t+=n!=null?Ri(n):0,t=~~t;return t}function ZXe(e){var t;return e==0?"UTC":(e<0?(e=-e,t="UTC+"):t="UTC-",t+IJe(e))}function bme(e){return e.a<54?e.f<0?-1:e.f>0?1:0:(!e.c&&(e.c=F_(Zo(e.f))),e.c).e}function eVe(e,t){t?e.B==null&&(e.B=e.D,e.D=null):e.B!=null&&(e.D=e.B,e.B=null)}function gr(e,t,n,i,r,o,a,d,b,v,x,S,M){return Tet(e,t,n,i,r,o,a,d,b,v,x,S,M),Hte(e,!1),e}function hte(e,t,n,i,r,o){var a;this.c=e,a=new Fe,Ywe(e,a,t,e.b,n,i,r,o),this.a=new os(a,0)}function tVe(){this.c=new Mz(0),this.b=new Mz(i4e),this.d=new Mz(xct),this.a=new Mz(kct)}function nVe(e){this.e=e,this.d=new Cz(ov(b5(this.e).gc())),this.c=this.e.a,this.b=this.e.c}function pH(e){this.b=e,this.a=ye(Fn,ci,30,e+1,15,1),this.c=ye(Fn,ci,30,e,15,1),this.d=0}function iIt(){return H0(),W(V(a9e,1),_e,246,0,[gJ,fP,hP,c9e,l9e,o9e,u9e,pJ,H9,sC])}function rIt(){return Gs(),W(V(Rce,1),_e,262,0,[BU,Ea,zE,zU,P9,u3,FE,D9,L9,FU])}function iVe(e,t){return ue(he(vu(OD(qc(new jt(null,new Tt(e.c.b,16)),new ZNe(e)),t))))}function mme(e,t){return ue(he(vu(OD(qc(new jt(null,new Tt(e.c.b,16)),new YNe(e)),t))))}function rVe(e,t){return mh(),vf(_h),p.Math.abs(0-t)<=_h||t==0||isNaN(0)&&isNaN(t)?0:e/t}function sIt(e,t){return lS(),e==jw&&t==Dv||e==Dv&&t==jw||e==i3&&t==_v||e==_v&&t==i3}function oIt(e,t){return lS(),e==jw&&t==_v||e==jw&&t==i3||e==Dv&&t==i3||e==Dv&&t==_v}function cIt(e,t,n){var i,r,o;for(i=0,r=0;r<n;r++)o=t[r],e[r]=o<<1|i,i=o>>>31;i!=0&&(e[n]=i)}function wme(e,t,n){var i,r;for(r=_n(e,0);r.b!=r.d.c;)i=c(An(r),8),i.a+=t,i.b+=n;return e}function oT(e,t,n){var i;for(i=e.b[n&e.f];i;i=i.b)if(n==i.a&&T1(t,i.g))return i;return null}function cT(e,t,n){var i;for(i=e.c[n&e.f];i;i=i.d)if(n==i.f&&T1(t,i.i))return i;return null}function lIt(e,t){var n,i;return n=c(ke(e,(F0(),MJ)),15),i=c(ke(t,MJ),15),fc(n.a,i.a)}function uIt(e,t){var n;t.Tg("General Compactor",1),n=sBt(c(ke(e,(F0(),cue)),387)),n.Bg(e)}function aIt(e,t,n){n.Tg("DFS Treeifying phase",1),bBt(e,t),eXt(e,t),e.a=null,e.b=null,n.Ug()}function fIt(e,t,n,i){var r;r=new W4,Zp(r,"x",sQ(e,t,i.a)),Zp(r,"y",oQ(e,t,i.b)),y5(n,r)}function hIt(e,t,n,i){var r;r=new W4,Zp(r,"x",sQ(e,t,i.a)),Zp(r,"y",oQ(e,t,i.b)),y5(n,r)}function dte(){dte=te,GC=new _Le,Tae=W(V(xl,1),Zx,182,0,[]),Y2t=W(V(tf,1),C5e,62,0,[])}function _5(){_5=te,uce=new qi("edgelabelcenterednessanalysis.includelabel",(Bt(),K0))}function _l(){_l=te,Kke=new t4,Vke=new d0,Wke=new Ed,Xke=new R8,Yke=new NM,Zke=new o2}function dIt(e,t){t.Tg(Wot,1),jwe(a8t(new fz((s7(),new iee(e,!1,!1,new I8))))),t.Ug()}function gte(e){var t;return t=Wpe(e),k7(t.a,0)?(N2(),N2(),Ioe):(N2(),new uZ(t.b))}function pte(e){var t;return t=Wpe(e),k7(t.a,0)?(N2(),N2(),Ioe):(N2(),new uZ(t.c))}function gIt(e){var t;return t=Eq(e),k7(t.a,0)?(Dz(),Dz(),Wat):(Dz(),new _Be(t.b))}function pIt(e){return e.b.c.i.k==(Jt(),Cr)?c(R(e.b.c.i,(De(),Oi)),12):e.b.c}function sVe(e){return e.b.d.i.k==(Jt(),Cr)?c(R(e.b.d.i,(De(),Oi)),12):e.b.d}function oVe(e){switch(e.g){case 2:return Je(),Yt;case 4:return Je(),nn;default:return e}}function cVe(e){switch(e.g){case 1:return Je(),bn;case 3:return Je(),Kt;default:return e}}function bIt(e,t){var n;return n=I2e(e),dve(new $e(n.c,n.d),new $e(n.b,n.a),e.Kf(),t,e.$f())}function mIt(e){var t,n,i;for(i=0,n=new G(e.b);n.a<n.c.c.length;)t=c(Q(n),26),t.p=i,++i}function lT(e,t){var n,i;for(zt(t),i=t.vc().Jc();i.Ob();)n=c(i.Pb(),45),e.yc(n.jd(),n.kd())}function wIt(e,t,n){var i;for(i=n.Jc();i.Ob();)if(!Mq(e,t,i.Pb()))return!1;return!0}function vIt(e,t){var n;for(Rn(t);e.Ob();)if(n=e.Pb(),!Sme(c(n,9)))return!1;return!0}function yIt(e,t,n,i,r){var o;return n&&(o=Vi(t.Ah(),e.c),r=n.Oh(t,-1-(o==-1?i:o),null,r)),r}function xIt(e,t,n,i,r){var o;return n&&(o=Vi(t.Ah(),e.c),r=n.Qh(t,-1-(o==-1?i:o),null,r)),r}function lVe(e){var t;if(e.b==-2){if(e.e==0)t=-1;else for(t=0;e.a[t]==0;t++);e.b=t}return e.b}function kIt(e){if(zt(e),e.length==0)throw J(new Yh("Zero length BigInteger"));VVt(this,e)}function vme(e){this.i=e.gc(),this.i>0&&(this.g=this.$i(this.i+(this.i/8|0)+1),e.Oc(this.g))}function uVe(e,t,n){this.g=e,this.d=t,this.e=n,this.a=new Fe,hGt(this),Ct(),Rr(this.a,null)}function wa(e,t,n,i,r,o,a){Sn.call(this,e,t),this.d=n,this.e=i,this.c=r,this.b=o,this.a=mf(a)}function yme(e,t){t.q=e,e.d=p.Math.max(e.d,t.r),e.b+=t.d+(e.a.c.length==0?0:e.c),qe(e.a,t)}function bte(e,t){var n,i,r,o;return r=e.c,n=e.c+e.b,o=e.d,i=e.d+e.a,t.a>r&&t.a<n&&t.b>o&&t.b<i}function rv(e,t){var n,i;for(i=_n(e,0);i.b!=i.d.c;)n=c(An(i),8),n.a+=t.a,n.b+=t.b;return e}function OIt(e,t){return t<e.b.gc()?c(e.b.Xb(t),9):t==e.b.gc()?e.a:c(Xe(e.e,t-e.b.gc()-1),9)}function aD(e,t){return Bt(),Kr(e)?mbe(e,zn(t)):P2(e)?BZ(e,he(t)):L2(e)?uMt(e,Ze(t)):e.Dd(t)}function bH(e,t){var n;oe(t,93)?(c(e.c,78).Ek(),n=c(t,93),GXe(e,n)):c(e.c,78).Wb(t)}function aVe(e,t,n,i){oe(e.Cb,187)&&(c(e.Cb,187).tb=null),Gc(e,n),t&&CGt(e,t),i&&e.el(!0)}function fD(e,t){var n,i;for(zt(t),i=e.vc().Jc();i.Ob();)n=c(i.Pb(),45),t.Wd(n.jd(),n.kd())}function SIt(e){var t,n,i;return e.j==(Je(),Kt)&&(t=ytt(e),n=Cl(t,nn),i=Cl(t,Yt),i||i&&n)}function xme(){xme=te,Z0t=cd(a$e(Wn(Wn(new wr,(es(),vc),(cs(),yU)),yc,pU),Vs),vU)}function fVe(){fVe=te,ipt=cd(a$e(Wn(Wn(new wr,(es(),vc),(cs(),yU)),yc,pU),Vs),vU)}function hVe(){hVe=te,Fht=Tn((Jt(),W(V(sce,1),_e,252,0,[or,jr,Cr,Dc,lc,Ih,UL,PE])))}function dVe(){dVe=te,pdt=Tn((EQ(),W(V($Oe,1),_e,277,0,[gce,mce,dce,yce,bce,pce,vce,wce])))}function gVe(){gVe=te,dwt=Tn((q0(),W(V(hwt,1),_e,287,0,[Bje,Pr,js,Nk,us,Ui,Ak,Bh])))}function pVe(){pVe=te,N2t=Tn((V5(),W(V(VP,1),_e,235,0,[kae,oX,XP,JP,xae,sX,rX,yae])))}function bVe(){return FT(),W(V(enn,1),_e,265,0,[Ble,_9e,I9e,R9e,P9e,N9e,$9e,M9e,L9e,D9e,A9e])}function mH(){mH=te,aue=new IY(th,0),N8e=new IY("POLAR_COORDINATE",1),A8e=new IY("ID",2)}function rS(){rS=te,_E=new qi("debugSVG",(Bt(),!1)),Ske=new qi("overlapsExisted",!0)}function jIt(){var e;return Foe||(Foe=new oLe,e=new _ee(""),ljt(e,(T6(),wke)),KPt(Foe,e)),Foe}function mVe(e){return B2(),e.A.Gc((Cu(),cy))&&!e.B.Gc((uu(),qP))?mKe(e):null}function wVe(e,t){var n;return n=cye(rT(),e),n?(ii(t,(Dn(),ry),n),!0):!1}function Fu(e,t){var n;for(n=0;n<t.j.c.length;n++)c(tD(e,n),24).Fc(c(tD(t,n),18));return e}function TIt(e,t){var n,i;for(i=new G(t.b);i.a<i.c.c.length;)n=c(Q(i),26),e.a[n.p]=$Ht(n)}function sv(e){this.f=e,this.e=new lbe(this.f.i),this.a=this.e,this.b=jme(this),this.d=this.f.g}function ar(e,t){BF.call(this,Z2t,e,t),this.b=this,this.a=nl(e.Ah(),_t(this.e.Ah(),this.c))}function vVe(){this.a=c(Ve((Sf(),oU)),15).a,this.c=ue(he(Ve(cU))),this.b=ue(he(Ve(Xoe)))}function yVe(e,t){e.a=As(e.a,1),e.c=p.Math.min(e.c,t),e.b=p.Math.max(e.b,t),e.d=As(e.d,t)}function mte(e,t,n,i){var r;r=e.a.length,n>r?n=r:en(t,n+1),e.a=Fa(e.a,0,t)+(""+i)+hpe(e.a,n)}function lb(e,t,n){var i,r;return r=c(D7(e.d,t),15),i=c(D7(e.b,n),15),!r||!i?null:C5(e,r.a,i.a)}function EIt(e,t,n){return ji(l5(OS(e),new $e(t.e.a,t.e.b)),l5(OS(e),new $e(n.e.a,n.e.b)))}function CIt(e,t,n){return e==(hb(),mJ)?new tj:lu(t,1)!=0?new n1e(n.length):new gPe(n.length)}function vi(e,t){var n,i,r;if(n=e.qh(),n!=null&&e.th())for(i=0,r=n.length;i<r;++i)n[i].bj(t)}function sS(e,t){var n,i;for(n=e,i=Jr(n).e;i;){if(n=i,n==t)return!0;i=Jr(n).e}return!1}function _0(e){var t;return t=e.h,t==0?e.l+e.m*tk:t==Q1?e.l+e.m*tk-yb:e}function MIt(e,t,n){var i,r;return i=e.a.f[t.p],r=e.a.f[n.p],i<r?-1:i==r?0:1}function ov(e){return e<3?(zu(e,Ust),e+1):e<KT?xs(p.Math.ceil(e/.75)):di}function Zo(e){return fL<e&&e<yb?e<0?p.Math.ceil(e):p.Math.floor(e):_0(RJt(e))}function xVe(e){switch(e.a.g){case 1:return new _Re;case 3:return new IYe;default:return new hK}}function Wt(e,t){var n;return(e.Db&t)!=0?(n=kne(e,t),n==-1?e.Eb:N5(e.Eb)[n]):null}function AIt(e){var t;if(e.a==e.b.a)throw J(new Co);return t=e.a,e.c=t,e.a=c(za(e.a.e),229),t}function kVe(e){var t;e.d==null?(++e.e,e.f=0,PWe(null)):(++e.e,t=e.d,e.d=null,e.f=0,PWe(t))}function NIt(e,t){var n,i;for(i=new G(t);i.a<i.c.c.length;)n=c(Q(i),70),qe(e.d,n),BHt(e,n)}function _It(e,t){var n,i;for(i=new cn(e);i.e!=i.i.gc();)n=c(un(i),19),aa(n,n.i+t.b,n.j+t.d)}function Go(e,t){var n,i;return n=(i=new y1,i),n.G=t,!e.rb&&(e.rb=new G2(e,ah,e)),Nn(e.rb,n),n}function fi(e,t){var n,i;return n=(i=new mz,i),n.G=t,!e.rb&&(e.rb=new G2(e,ah,e)),Nn(e.rb,n),n}function hD(e){var t,n,i;for(i=0,n=new t5(e.a);n.a<n.c.a.length;)t=Y7(n),e.b.Gc(t)&&++i;return i}function DIt(e){var t,n,i;for(t=1,i=e.Jc();i.Ob();)n=i.Pb(),t=31*t+(n==null?0:Ri(n)),t=~~t;return t}function dD(e){var t;return e<128?(kFe(),t=Z5e[e],!t&&(t=Z5e[e]=new Fo(e)),t):new Fo(e)}function wH(e){var t;if(e.g>1||e.Ob())return++e.a,e.g=0,t=e.i,e.Ob(),t;throw J(new Co)}function LIt(e){P$e();var t;return BIe($le,e)||(t=new p2,t.a=e,Wge($le,e,t)),c(Zs($le,e),642)}function qa(e){var t,n,i,r;return r=e,i=0,r<0&&(r+=yb,i=Q1),n=xs(r/tk),t=xs(r-n*tk),el(t,n,i)}function OVe(e,t){var n;return n=e.a.get(t),n===void 0?++e.d:(B7t(e.a,t),--e.c,++e.b.g),n}function ec(e,t){var n;return t&&(n=t.lf(),n.dc()||(e.q?lT(e.q,n):e.q=new k$e(n))),e}function PIt(e,t){var n,i,r;return n=t.p-e.p,n==0?(i=e.f.a*e.f.b,r=t.f.a*t.f.b,ji(i,r)):n}function kme(e,t){switch(t){case 1:return!!e.n&&e.n.i!=0;case 2:return e.k!=null}return Upe(e,t)}function IIt(e){return e.b.c.length!=0&&c(Xe(e.b,0),70).a?c(Xe(e.b,0),70).a:cee(e)}function RIt(e,t){var n;try{t.be()}catch(i){if(i=vr(i),oe(i,81))n=i,It(e.c,n);else throw J(i)}}function $It(e,t){var n;t.Tg("Edge and layer constraint edge reversal",1),n=aVt(e),UZt(n),t.Ug()}function BIt(e,t){var n,i;return n=e.j,i=t.j,n!=i?n.g-i.g:e.p==t.p?0:n==(Je(),Kt)?e.p-t.p:t.p-e.p}function oS(e,t){this.b=e,this.e=t,this.d=t.j,this.f=(qs(),c(e,69).vk()),this.k=nl(t.e.Ah(),e)}function ub(e,t,n){this.b=(zt(e),e),this.d=(zt(t),t),this.e=(zt(n),n),this.c=this.d+(""+this.e)}function Ome(e,t,n,i,r){tWe.call(this,e,n,i,r),this.f=ye(e1,Hg,9,t.a.c.length,0,1),jh(t.a,this.f)}function uT(e,t,n,i,r){dr(e.c[t.g],n.g,i),dr(e.c[n.g],t.g,i),dr(e.b[t.g],n.g,r),dr(e.b[n.g],t.g,r)}function SVe(e,t){e.c&&(fit(e,t,!0),lr(new jt(null,new Tt(t,16)),new s_e(e))),fit(e,t,!1)}function gD(e){this.n=new Fe,this.e=new Ai,this.j=new Ai,this.k=new Fe,this.f=new Fe,this.p=e}function jVe(e){e.r=new Or,e.w=new Or,e.t=new Fe,e.i=new Fe,e.d=new Or,e.a=new c5,e.c=new wn}function Ym(){Ym=te,HL=new Uz("UP",0),qL=new Uz(vre,1),Goe=new Uz(nk,2),Uoe=new Uz(ik,3)}function vH(){vH=te,g9e=new CY("EQUALLY",0),_le=new CY("NORTH",1),p9e=new CY("NORTH_SOUTH",2)}function cS(){cS=te,$ce=new OY("ONE_SIDED",0),Bce=new OY("TWO_SIDED",1),YL=new OY("OFF",2)}function TVe(){TVe=te,h2t=Tn((uu(),W(V(Z7e,1),_e,267,0,[s8,qP,YJ,zC,ZJ,tX,eX,pae,FP])))}function EVe(){EVe=te,t2t=Tn((mv(),W(V(Ws,1),_e,96,0,[Nf,Z1,_f,Lf,i1,Ya,Vu,Df,Ka])))}function CVe(){CVe=te,ydt=Tn((QD(),W(V(JOe,1),_e,268,0,[jce,UOe,Ece,Cce,Tce,Mce,KL,Sce,Oce])))}function MVe(){MVe=te,O0t=Tn((UD(),W(V(t9e,1),_e,269,0,[kle,YSe,ZSe,yle,KSe,e9e,fJ,vle,xle])))}function xf(){xf=te,Iv=new Wz(WS,0),E9=new Wz(nk,1),C9=new Wz(ik,2),fce=new Wz("TOP",3)}function yH(){yH=te,Rle=new _Y("OFF",0),Q9=new _Y("SINGLE_EDGE",1),Wv=new _Y("MULTI_EDGE",2)}function pD(){pD=te,zJ=new U1e("MINIMUM_SPANNING_TREE",0),Mje=new U1e("MAXIMUM_SPANNING_TREE",1)}function zIt(e,t,n){var i,r;r=c(R(e,(Ge(),ho)),79),r&&(i=new nu,Lte(i,0,r),rv(i,n),Os(t,i))}function Sme(e){var t;return t=c(R(e,(De(),Ko)),64),e.k==(Jt(),Cr)&&(t==(Je(),Yt)||t==nn)}function FIt(e){var t;if(e){if(t=e,t.dc())throw J(new Co);return t.Xb(t.gc()-1)}return hQe(e.Jc())}function wte(e,t,n,i){return n==1?(!e.n&&(e.n=new Me(Bo,e,1,7)),Ns(e.n,t,i)):Q2e(e,t,n,i)}function bD(e,t){var n,i;return i=(n=new kj,n),Gc(i,t),Nn((!e.A&&(e.A=new El(cl,e,7)),e.A),i),i}function qIt(e,t,n){var i,r,o,a;return o=null,a=t,r=Gm(a,Yse),i=new $Re(e,n),o=(oZe(i.a,i.b,r),r),o}function xH(e,t,n){var i,r,o,a;a=Jr(e),i=a.d,r=a.c,o=e.n,t&&(o.a=o.a-i.b-r.a),n&&(o.b=o.b-i.d-r.b)}function HIt(e,t){var n,i,r;return n=e.l+t.l,i=e.m+t.m+(n>>22),r=e.h+t.h+(i>>22),el(n&au,i&au,r&Q1)}function AVe(e,t){var n,i,r;return n=e.l-t.l,i=e.m-t.m+(n>>22),r=e.h-t.h+(i>>22),el(n&au,i&au,r&Q1)}function mD(e,t){var n,i;for(zt(t),i=t.Jc();i.Ob();)if(n=i.Pb(),!e.Gc(n))return!1;return!0}function vte(e){var t;return(!e.a||(e.Bb&1)==0&&e.a.Sh())&&(t=Qa(e),oe(t,160)&&(e.a=c(t,160))),e.a}function vr(e){var t;return oe(e,81)?e:(t=e&&e.__java$exception,t||(t=new kWe(e),eLe(t)),t)}function yte(e){if(oe(e,196))return c(e,127);if(e)return null;throw J(new K4(Glt))}function NVe(e){switch(e.g){case 0:return new $W;case 1:return new k$;case 2:default:return null}}function jme(e){return e.a.Ob()?!0:e.a!=e.e?!1:(e.a=new Cbe(e.f.f),e.a.Ob())}function _Ve(e,t){if(t==null)return!1;for(;e.a!=e.b;)if(yi(t,EH(e)))return!0;return!1}function DVe(e,t){return!e||!t||e==t?!1:DKe(e.d.c,t.d.c+t.d.b)&&DKe(t.d.c,e.d.c+e.d.b)}function QIt(){return Iq(),Ph?new _ee(null):mtt(jIt(),"com.google.common.base.Strings")}function yr(e,t){var n,i;return n=t.Nc(),i=n.length,i==0?!1:(D0e(e.c,e.c.length,n),!0)}function GIt(e,t){var n,i;return n=e.c,i=t.e[e.p],i<n.a.c.length-1?c(Xe(n.a,i+1),9):null}function UIt(e){var t,n;for(OKt(e),n=new G(e.d);n.a<n.c.c.length;)t=c(Q(n),108),t.i&&gQt(t)}function LVe(e,t){var n,i;for(i=new G(e.b);i.a<i.c.c.length;)n=c(Q(i),70),Ee(n,(De(),xk),t)}function JIt(e,t,n){var i,r;for(r=new G(e.b);r.a<r.c.c.length;)i=c(Q(r),19),aa(i,i.i+t,i.j+n)}function xte(e){var t,n,i;for(t=new Ai,i=_n(e.d,0);i.b!=i.d.c;)n=c(An(i),65),ei(t,n.c);return t}function Tme(e){var t,n,i,r;for(t=1,n=0,r=e.gc();n<r;++n)i=e.Ti(n),t=31*t+(i==null?0:Ri(i));return t}function PVe(e){var t,n;return n=(t=new kj,t),Gc(n,"T"),Nn((!e.d&&(e.d=new El(cl,e,11)),e.d),n),n}function IVe(e,t){var n;return n=Pd(t.a.gc()),lr(Yq(new jt(null,new Tt(t,1)),e.i),new jRe(e,n)),n}function RVe(e,t,n,i){var r;return Q_(t,e.e.Pd().gc()),Q_(n,e.c.Pd().gc()),r=e.a[t][n],dr(e.a[t],n,i),r}function XIt(e,t,n,i){c(n.b,68),c(n.b,68),c(i.b,68),c(i.b,68),c(i.b,68),Qc(i.a,new m0e(e,t,i))}function VIt(e,t){e.d==(Nr(),go)||e.d==Ca?c(t.a,60).c.Ec(c(t.b,60)):c(t.b,60).c.Ec(c(t.a,60))}function Eme(e,t){this.c=e,this.d=t,this.b=this.d/this.c.c.Pd().gc()|0,this.a=this.d%this.c.c.Pd().gc()}function WIt(e,t,n,i,r){return LS(),p.Math.min(Brt(e,t,n,i,r),Brt(n,i,e,t,MF(new $e(r.a,r.b))))}function $Ve(e,t){if(!e)throw J(new qt(zT("value already present: %s",W(V(Br,1),Lt,1,5,[t]))))}function BVe(e,t,n){var i;sc(e.a),Qc(n.i,new Y_e(e)),i=new yF(c(Ut(e.a,t.b),68)),BKe(e,i,t),n.f=i}function KIt(e){var t;zg(e,!0),t=qg,xi(e,(Ge(),z9))&&(t+=c(R(e,z9),15).a),Ee(e,z9,Pe(t))}function kte(e){var t,n,i,r;for(r=new Fe,i=e.Jc();i.Ob();)n=c(i.Pb(),19),t=wv(n),yr(r,t);return r}function Cme(e){var t,n;return n=(w0(),t=new VO,t),e&&Nn((!e.a&&(e.a=new Me(Hi,e,6,6)),e.a),n),n}function D5(e,t){var n,i;if(i=0,e<64&&e<=t)for(t=t<64?t:63,n=e;n<=t;n++)i=id(i,$d(1,n));return i}function zVe(e){switch(e.g){case 1:return up;case 2:return n1;case 3:return LP;default:return PP}}function YIt(e){switch(c(R(e,(Ge(),Ro)),166).g){case 2:case 4:return!0;default:return!1}}function Mme(e,t){switch(t){case 0:!e.o&&(e.o=new Al((oc(),s1),e0,e,0)),e.o.c.$b();return}Hne(e,t)}function ZIt(e,t){var n,i;for(pq(t,"predicate"),i=0;e.Ob();i++)if(n=e.Pb(),t.Lb(n))return i;return-1}function Ame(e){Ct();var t,n,i;for(i=0,n=e.Jc();n.Ob();)t=n.Pb(),i=i+(t!=null?Ri(t):0),i=i|0;return i}function eRt(e){var t;return t=new Te,t.a=e,t.b=oRt(e),t.c=ye(nt,Be,2,2,6,1),t.c[0]=ZXe(e),t.c[1]=ZXe(e),t}function W(e,t,n,i,r){return r.Pm=e,r.Qm=t,r.Rm=je,r.__elementTypeId$=n,r.__elementTypeCategory$=i,r}function tRt(e,t,n,i){return new y1e(W(V(Mb,1),qQ,45,0,[(mne(e,t),new Mm(e,t)),(mne(n,i),new Mm(n,i))]))}function kH(){kH=te,ace=new Vz(th,0),CU=new Vz(Zot,1),MU=new Vz(ect,2),XL=new Vz("BOTH",3)}function lS(){lS=te,jw=new Jz("Q1",0),Dv=new Jz("Q4",1),_v=new Jz("Q2",2),i3=new Jz("Q3",3)}function D0(){D0=te,ZL=new SY("ONLY_WITHIN_GROUP",0),a6e=new SY(Sre,1),$v=new SY("ENFORCED",2)}function ab(){ab=te,Ace=new kY(th,0),_9=new kY("INCOMING_ONLY",1),l3=new kY("OUTGOING_ONLY",2)}function L5(){L5=te,cwt=new O$,owt=new RA}function Ote(){Ote=te,Noe={boolean:i8t,number:b9t,string:m9t,object:Met,function:Met,undefined:VSt}}function FVe(){FVe=te,E0t=Tn((H0(),W(V(a9e,1),_e,246,0,[gJ,fP,hP,c9e,l9e,o9e,u9e,pJ,H9,sC])))}function qVe(){qVe=te,Cdt=Tn((Gs(),W(V(Rce,1),_e,262,0,[BU,Ea,zE,zU,P9,u3,FE,D9,L9,FU])))}function nRt(e){var t,n,i,r;for(n=e.a,i=0,r=n.length;i<r;++i)t=n[i],eWe(e,t,(Je(),bn)),eWe(e,t,Kt)}function HVe(e){var t,n,i;return n=e.n,i=e.o,t=e.d,new pf(n.a-t.b,n.b-t.d,i.a+(t.b+t.c),i.b+(t.d+t.a))}function iRt(e,t){return!e||!t||e==t?!1:ew(e.b.c,t.b.c+t.b.b)<0&&ew(t.b.c,e.b.c+e.b.b)<0}function Ste(e,t,n){return e>=128?!1:e<64?O7(Yr($d(1,e),n),0):O7(Yr($d(1,e-64),t),0)}function Nme(e,t,n){var i;if(i=e.gc(),t>i)throw J(new F2(t,i));return e.Qi()&&(n=JHe(e,n)),e.Ci(t,n)}function rRt(e,t){var n,i;return n=c(c(Ut(e.g,t.a),49).a,68),i=c(c(Ut(e.g,t.b),49).a,68),qit(n,i)}function uS(e){var t,n,i;return t=~e.l+1&au,n=~e.m+(t==0?1:0)&au,i=~e.h+(t==0&&n==0?1:0)&Q1,el(t,n,i)}function sRt(e){LS();var t,n,i;for(n=ye(Vr,Be,8,2,0,1),i=0,t=0;t<2;t++)i+=.5,n[t]=Bzt(i,e);return n}function QVe(e,t){var n,i,r,o;for(n=!1,i=e.a[t].length,o=0;o<i-1;o++)r=o+1,n=n|mBt(e,t,o,r);return n}function GVe(e){var t,n;return n=new Rq,ec(n,e),Ee(n,(N0(),gk),e),t=new wn,lKt(e,n,t),zZt(e,n,t),n}function Ee(e,t,n){return n==null?(!e.q&&(e.q=new wn),E5(e.q,t)):(!e.q&&(e.q=new wn),oi(e.q,t,n)),e}function wD(e,t,n){return n==null?(!e.q&&(e.q=new wn),E5(e.q,t)):(!e.q&&(e.q=new wn),oi(e.q,t,n)),e}function UVe(e,t){return l5(OS(c(R(t,(Uo(),Iw)),87)),new $e(e.c.e.a-e.b.e.a,e.c.e.b-e.b.e.b))<=0}function JVe(e,t){this.b=e,fx.call(this,(c(re(Ne((j0(),Gt).o),10),20),t.i),t.g),this.a=(dte(),Tae)}function _me(e,t,n){this.q=new p.Date,this.q.setFullYear(e+G0,t,n),this.q.setHours(0,0,0,0),HT(this,0)}function Dme(){this.o=null,this.k=null,this.j=null,this.d=null,this.b=null,this.n=null,this.a=null}function XVe(e,t){for(;e.g==null&&!e.c?Ipe(e):e.g==null||e.i!=0&&c(e.g[e.i-1],51).Ob();)t.Bi(mQ(e))}function vD(e,t,n){switch(n.g){case 2:e.b=t;break;case 1:e.c=t;break;case 4:e.d=t;break;case 3:e.a=t}}function Lme(e,t){switch(t){case 7:return!!e.e&&e.e.i!=0;case 8:return!!e.d&&e.d.i!=0}return Cwe(e,t)}function VVe(e){var t,n;return t=e.t-e.k[e.o.p]*e.d+e.j[e.o.p]>e.f,n=e.u+e.e[e.o.p]*e.d>e.f*e.s*e.d,t||n}function aT(e){var t;return t=e.a[e.b],t==null?null:(dr(e.a,e.b,null),e.b=e.b+1&e.a.length-1,t)}function WVe(e,t,n){var i,r;return i=new qee(t,n),r=new mi,e.b=Snt(e,e.b,i,r),r.b||++e.c,e.b.b=!1,r.d}function KVe(e){var t,n;return n=qD(e.h),n==32?(t=qD(e.m),t==32?qD(e.l)+32:t+20-10):n-12}function Pme(e){var t;if(e<0)return ls;if(e==0)return 0;for(t=KT;(t&e)==0;t>>=1);return t}function oRt(e){var t;return e==0?"Etc/GMT":(e<0?(e=-e,t="Etc/GMT-"):t="Etc/GMT+",t+IJe(e))}function Ime(e){var t;return(!e.c||(e.Bb&1)==0&&(e.c.Db&64)!=0)&&(t=Qa(e),oe(t,89)&&(e.c=c(t,29))),e.c}function L0(e){var t,n;for(n=new G(e.a.b);n.a<n.c.c.length;)t=c(Q(n),84),t.g.c=-t.g.c-t.g.b;OQ(e)}function P0(e){var t,n;for(n=new G(e.a.b);n.a<n.c.c.length;)t=c(Q(n),60),t.d.c=-t.d.c-t.d.b;Hve(e)}function cRt(e){var t,n,i;return t=c(e.e&&e.e(),10),i=(n=t.slice(),c(Uee(n,t),10)),new ha(t,i,t.length)}function jte(e){var t,n,i;t=~e.l+1&au,n=~e.m+(t==0?1:0)&au,i=~e.h+(t==0&&n==0?1:0)&Q1,e.l=t,e.m=n,e.h=i}function Lo(e){var t,n,i,r,o;for(t=new as,i=e,r=0,o=i.length;r<o;++r)n=i[r],t.a+=n.a,t.b+=n.b;return t}function Rme(e,t){Ct();var n,i,r,o,a;for(a=!1,i=t,r=0,o=i.length;r<o;++r)n=i[r],a=a|e.Ec(n);return a}function Tte(e,t,n){var i,r,o,a;return o=null,a=t,r=Gm(a,"labels"),i=new QRe(e,n),o=(Ntt(i.a,i.b,r),r),o}function YVe(e,t,n){var i;return i=new Fe,Jve(e,t,i,(Je(),nn),!0,!1),Jve(e,n,i,Yt,!1,!1),i}function lRt(e,t,n,i){var r;return r=Dve(e,t,n,i),!r&&(r=a$t(e,n,i),r&&!qx(e,t,r))?null:r}function uRt(e,t,n,i){var r;return r=Lve(e,t,n,i),!r&&(r=zte(e,n,i),r&&!qx(e,t,r))?null:r}function ZVe(e,t){var n;for(n=0;n<e.a.a.length;n++)if(!c(TFe(e.a,n),181).Lb(t))return!1;return!0}function aRt(e,t,n){if(Rn(t),n.Ob())for(ege(t,Mqe(n.Pb()));n.Ob();)ege(t,e.a),ege(t,Mqe(n.Pb()));return t}function $me(e){Ct();var t,n,i;for(i=1,n=e.Jc();n.Ob();)t=n.Pb(),i=31*i+(t!=null?Ri(t):0),i=i|0;return i}function eWe(e,t,n){var i,r,o,a;for(a=bT(t,n),o=0,r=a.Jc();r.Ob();)i=c(r.Pb(),12),oi(e.c,i,Pe(o++))}function fb(e){var t,n;for(n=new G(e.a.b);n.a<n.c.c.length;)t=c(Q(n),84),t.f.$b();f9t(e.b,e),hnt(e)}function I1(e){var t;return T0(e),t=new bs,e.a.zd(t)?(C6(),new VK(zt(t.a))):(C6(),C6(),pke)}function Bme(e){var t;return e.b<=0?!1:(t=Zh("MLydhHmsSDkK",dl(ms(e.c,0))),t>1||t>=0&&e.b<3)}function fRt(e,t,n){return!k6(pi(new jt(null,new Tt(e.c,16)),new d6(new ERe(t,n)))).zd((Hp(),hk))}function Ete(e,t,n){this.g=e,this.e=new as,this.f=new as,this.d=new Ai,this.b=new Ai,this.a=t,this.c=n}function Cte(e,t,n,i){this.b=new Fe,this.n=new Fe,this.i=i,this.j=n,this.s=e,this.t=t,this.r=0,this.d=0}function tWe(e,t,n,i){this.b=new wn,this.g=new wn,this.d=(gT(),hJ),this.c=e,this.e=t,this.d=n,this.a=i}function nWe(e,t,n){e.g=Qne(e,t,(Je(),nn),e.b),e.d=Qne(e,n,nn,e.b),!(e.g.c==0||e.d.c==0)&&HZe(e)}function iWe(e,t,n){e.g=Qne(e,t,(Je(),Yt),e.j),e.d=Qne(e,n,Yt,e.j),!(e.g.c==0||e.d.c==0)&&HZe(e)}function hRt(e,t,n,i,r){var o;return o=Eve(e,t),n&&jte(o),r&&(e=Gzt(e,t),i?W0=uS(e):W0=el(e.l,e.m,e.h)),o}function dRt(e,t,n,i,r){var o,a;if(a=e.length,o=n.length,t<0||i<0||r<0||t+r>a||i+r>o)throw J(new Ede)}function rWe(e,t){N_(e>=0,"Negative initial capacity"),N_(t>=0,"Non-positive load factor"),sc(this)}function aS(){aS=te,IOe=new s4,ROe=new gW,tdt=new pW,edt=new bW,Zht=new oR,POe=(zt(Zht),new kt)}function fT(){fT=te,B9e=new LY(th,0),zle=new LY("MIDDLE_TO_MIDDLE",1),bP=new LY("AVOID_OVERLAP",2)}function zme(e,t,n){switch(t){case 0:!e.o&&(e.o=new Al((oc(),s1),e0,e,0)),bH(e.o,n);return}Une(e,t,n)}function gRt(e,t){switch(t.g){case 0:oe(e.b,638)||(e.b=new vVe);break;case 1:oe(e.b,639)||(e.b=new mFe)}}function sWe(e){switch(e.g){case 0:return new T$;default:throw J(new qt(jG+(e.f!=null?e.f:""+e.g)))}}function oWe(e){switch(e.g){case 0:return new $A;default:throw J(new qt(jG+(e.f!=null?e.f:""+e.g)))}}function cWe(e){switch(e.g){case 0:return new Wy;default:throw J(new qt(bse+(e.f!=null?e.f:""+e.g)))}}function lWe(e){switch(e.g){case 0:return new C$;default:throw J(new qt(bse+(e.f!=null?e.f:""+e.g)))}}function uWe(e){switch(e.g){case 0:return new S$;default:throw J(new qt(bse+(e.f!=null?e.f:""+e.g)))}}function fS(e,t){if(!e.Ji()&&t==null)throw J(new qt("The 'no null' constraint is violated"));return t}function Fme(e){var t,n,i;for(t=new nu,i=_n(e,0);i.b!=i.d.c;)n=c(An(i),8),M6(t,0,new Cs(n));return t}function Dg(e){var t,n;for(t=0,n=0;n<e.length;n++)t=(t<<5)-t+(en(n,e.length),e.charCodeAt(n))|0;return t}function pRt(e){var t,n;t=c(R(e,(De(),Ul)),9),t&&(n=t.c,fl(n.a,t),n.a.c.length==0&&fl(Jr(t).b,n))}function bRt(e,t){var n,i;return n=c(ke(e,(Ah(),xP)),15).a,i=c(ke(t,xP),15).a,n==i||n<i?-1:n>i?1:0}function aWe(e,t){var n,i,r;for(r=e.b;r;){if(n=e.a.Le(t,r.d),n==0)return r;i=n<0?0:1,r=r.a[i]}return null}function Cx(e,t){var n,i,r,o,a;for(i=t,r=0,o=i.length;r<o;++r)n=i[r],a=new Tqe(e),n.tf(a),yKt(a);sc(e.f)}function fWe(e,t,n){var i,r;this.g=e,this.c=t,this.a=this,this.d=this,r=QXe(n),i=ye(Mat,lL,229,r,0,1),this.b=i}function mRt(){wi();var e;return _ae||(e=t7t(Q0("M",!0)),e=KF(Q0("M",!1),e),_ae=e,_ae)}function qme(e){switch(e.g){case 1:return xct;default:case 2:return 0;case 3:return kct;case 4:return i4e}}function Hme(e,t){return cnt(e,t)?(St(e.b,c(R(t,(De(),X1)),24),t),ei(e.a,t),!0):!1}function wRt(e){return qe(e.c,(L5(),cwt)),Ube(e.a,ue(he(Ve((Kte(),aJ)))))?new pm:new rDe(e)}function vRt(e){for(;!e.d||!e.d.Ob();)if(e.b&&!e7(e.b))e.d=c(w5(e.b),51);else return null;return e.d}function yRt(e,t){return xi(e,(De(),Pi))&&xi(t,Pi)?c(R(e,Pi),15).a-c(R(t,Pi),15).a:0}function xRt(e,t){return xi(e,(De(),Pi))&&xi(t,Pi)?c(R(t,Pi),15).a-c(R(e,Pi),15).a:0}function Mte(e,t){var n;return t===e?!0:oe(t,231)?(n=c(t,231),yi(e.Zb(),n.Zb())):!1}function Ate(e){switch(e.i){case 2:return!0;case 1:return!1;case-1:++e.c;default:return e.Yl()}}function hWe(e){return Ph?ye(Zat,lot,574,0,0,1):c(jh(e.a,ye(Zat,lot,574,e.a.c.length,0,1)),848)}function Qme(e,t){var n;t*2+1>=e.b.c.length||(Qme(e,2*t+1),n=2*t+2,n<e.b.c.length&&Qme(e,n),_et(e,t))}function kRt(e,t){var n,i;for(i=_n(e,0);i.b!=i.d.c;)n=c(An(i),221),n.e.length>0&&(t.Ad(n),n.i&&KBt(n))}function Gme(e,t,n){var i;for(i=n-1;i>=0&&e[i]===t[i];i--);return i<0?0:dY(Yr(e[i],Us),Yr(t[i],Us))?-1:1}function ORt(e,t){var n;return!e||e==t||!xi(t,(De(),Mw))?!1:(n=c(R(t,(De(),Mw)),9),n!=e)}function Mx(e,t,n){var i,r;return r=(i=new QK,i),eo(r,t,n),Nn((!e.q&&(e.q=new Me(tf,e,11,10)),e.q),r),r}function Nte(e,t){var n,i;return i=c(Wt(e.a,4),131),n=ye(Sae,coe,420,t,0,1),i!=null&&mc(i,0,n,0,i.length),n}function _te(e){var t,n,i,r;for(r=x8t(C2t,e),n=r.length,i=ye(nt,Be,2,n,6,1),t=0;t<n;++t)i[t]=r[t];return i}function dWe(e,t){var n;return n=new rie((e.f&256)!=0,e.i,e.a,e.d,(e.f&16)!=0,e.j,e.g,t),e.e!=null||(n.c=e),n}function SRt(e,t){var n,i;for(i=e.Zb().Bc().Jc();i.Ob();)if(n=c(i.Pb(),18),n.Gc(t))return!0;return!1}function gWe(e,t,n){var i,r,o,a;for(zt(n),a=!1,o=e.dd(t),r=n.Jc();r.Ob();)i=r.Pb(),o.Rb(i),a=!0;return a}function jRt(e,t){var n;return e===t?!0:oe(t,93)?(n=c(t,93),J2e(Jp(e),n.vc())):!1}function pWe(e,t,n){var i,r;for(r=n.Jc();r.Ob();)if(i=c(r.Pb(),45),e.ze(t,i.kd()))return!0;return!1}function bWe(e,t,n){return e.d[t.p][n.p]||(vzt(e,t,n),e.d[t.p][n.p]=!0,e.d[n.p][t.p]=!0),e.a[t.p][n.p]}function hS(e,t){e.D==null&&e.B!=null&&(e.D=e.B,e.B=null),ote(e,t==null?null:(zt(t),t)),e.C&&e.fl(null)}function OH(){OH=te,wae=new fF("ELK",0),aTe=new fF("JSON",1),uTe=new fF("DOT",2),fTe=new fF("SVG",3)}function hT(){hT=te,Yle=new nF(Sre,0),TJ=new nF(Ect,1),Kle=new nF("FAN",2),Wle=new nF("CONSTRAINT",3)}function yD(){yD=te,CJ=new PY(th,0),h8e=new PY("RADIAL_COMPACTION",1),d8e=new PY("WEDGE_COMPACTION",2)}function dT(){dT=te,Lle=new MY("STACKED",0),Dle=new MY("REVERSE_STACKED",1),dP=new MY("SEQUENCED",2)}function va(){va=te,vke=new pY("CONCURRENT",0),bl=new pY("IDENTITY_FINISH",1),yke=new pY("UNORDERED",2)}function R1(){R1=te,WJ=new HY(o5e,0),Zg=new HY("INCLUDE_CHILDREN",1),LC=new HY("SEPARATE_CHILDREN",2)}function SH(){SH=te,G7e=new Qp(15),Kwt=new Gr((Dn(),zh),G7e),DC=Dk,F7e=kwt,q7e=qb,Q7e=C3,H7e=ny}function Dte(){Dte=te,ece=zHe(W(V(_C,1),_e,87,0,[(Nr(),go),yo])),tce=zHe(W(V(_C,1),_e,87,0,[Ca,Fh]))}function TRt(e){var t,n,i;for(t=0,i=ye(Vr,Be,8,e.b,0,1),n=_n(e,0);n.b!=n.d.c;)i[t++]=c(An(n),8);return i}function Lte(e,t,n){var i,r,o;for(i=new Ai,o=_n(n,0);o.b!=o.d.c;)r=c(An(o),8),ei(i,new Cs(r));gWe(e,t,i)}function ERt(e,t){var n;n=Ve((Kte(),aJ))!=null&&t.Rg()!=null?ue(he(t.Rg()))/ue(he(Ve(aJ))):1,oi(e.b,t,n)}function CRt(e,t){var n,i;return n=c(e.d.Ac(t),18),n?(i=e.e.hc(),i.Fc(n),e.e.d-=n.gc(),n.$b(),i):null}function Ume(e,t){var n,i;if(i=e.c[t],i!=0)for(e.c[t]=0,e.d-=i,n=t+1;n<e.a.length;)e.a[n]-=i,n+=n&-n}function Jme(e){var t;if(t=e.a.c.length,t>0)return R6(t-1,e.a.c.length),Mg(e.a,t-1);throw J(new nLe)}function MRt(e,t,n){if(t<0)throw J(new zc(Wct+t));t<e.j.c.length?Su(e.j,t,n):(hGe(e,t),qe(e.j,n))}function mWe(e,t,n){if(e>t)throw J(new qt(JQ+e+uot+t));if(e<0||t>n)throw J(new Kde(JQ+e+gxe+t+fxe+n))}function wWe(e){if(!e.a||(e.a.i&8)==0)throw J(new oo("Enumeration class expected for layout option "+e.f))}function vWe(e){UHe.call(this,"The given string does not match the expected format for individual spacings.",e)}function yWe(e){switch(e.i){case-2:return!0;case-1:return!1;case 1:--e.c;default:return e.Zl()}}function Lg(e){switch(e.c){case 0:return AZ(),H5e;case 1:return new G4(Ret(new t5(e)));default:return new VLe(e)}}function xWe(e){switch(e.gc()){case 0:return AZ(),H5e;case 1:return new G4(e.Jc().Pb());default:return new x1e(e)}}function Xme(e){var t;return t=(!e.a&&(e.a=new Me(tg,e,9,5)),e.a),t.i!=0?w8t(c(re(t,0),691)):null}function ARt(e,t){var n;return n=As(e,t),dY(Oee(e,t),0)|gF(Oee(e,n),0)?n:As(cL,Oee(Vp(n,63),1))}function Vme(e,t,n){var i,r;return K2(t,e.c.length),i=n.Nc(),r=i.length,r==0?!1:(D0e(e.c,t,i),!0)}function NRt(e,t){var n,i;for(n=e.a.length-1;t!=e.b;)i=t-1&n,dr(e.a,t,e.a[i]),t=i;dr(e.a,e.b,null),e.b=e.b+1&n}function _Rt(e,t){var n,i;for(n=e.a.length-1,e.c=e.c-1&n;t!=e.c;)i=t+1&n,dr(e.a,t,e.a[i]),t=i;dr(e.a,e.c,null)}function cv(e){var t;++e.j,e.i==0?e.g=null:e.i<e.g.length&&(t=e.g,e.g=e.$i(e.i),mc(t,0,e.g,0,e.i))}function Ax(e){return(e.c!=e.b.b||e.i!=e.g.b)&&(M2(e.a.c,0),yr(e.a,e.b),yr(e.a,e.g),e.c=e.b.b,e.i=e.g.b),e.a}function ju(e){return Kr(e)?nt:P2(e)?kr:L2(e)?ir:X0e(e)||G0e(e)?e.Pm:e.Pm||Array.isArray(e)&&V(Nat,1)||Nat}function DRt(e){return e?(e.i&1)!=0?e==kl?ir:e==Fn?Lr:e==py?O9:e==ns?kr:e==qw?Ow:e==L3?Sw:e==Rl?ak:CE:e:null}function kWe(e){nPe(),xF(this),dq(this),this.e=e,vnt(this,e),this.g=e==null?pl:jo(e),this.a="",this.b=e,this.a=""}function OWe(){u9t.call(this,new Ebe(ov(16))),zu(2,qst),this.b=2,this.a=new ype(null,null,0,null),QN(this.a,this.a)}function hb(){hb=te,gP=new eF("BARYCENTER",0),lC=new eF(Kot,1),mJ=new eF(Yot,2),bJ=new eF("MEDIAN",3)}function gT(){gT=te,Ole=new TY("DUMMY_NODE_OVER",0),n9e=new TY("DUMMY_NODE_UNDER",1),hJ=new TY("EQUAL",2)}function dS(){dS=te,Ple=new AY("CONSERVATIVE",0),w9e=new AY("CONSERVATIVE_SOFT",1),cC=new AY("SLOPPY",2)}function SWe(e){var t,n,i;for(i=0,n=new Ht(Vt(e.a.Jc(),new U));hn(n);)t=c(sn(n),17),t.c.i==t.d.i||++i;return i}function jH(e){var t,n,i,r,o;for(o=1,n=e,i=0,r=n.length;i<r;++i)t=n[i],o=31*o+(t!=null?Ri(t):0),o=o|0;return o}function Tn(e){var t,n,i,r,o;for(t={},i=e,r=0,o=i.length;r<o;++r)n=i[r],t[":"+(n.f!=null?n.f:""+n.g)]=n;return t}function jWe(e,t,n){var i,r,o,a;for(r=n,o=0,a=r.length;o<a;++o)if(i=r[o],e.b.ze(t,i.jd()))return i;return null}function LRt(e){var t,n;if(e==null)return null;for(t=0,n=e.length;t<n;t++)if(!cFe(e[t]))return e[t];return null}function Pte(e,t){return!e||t&&!e.j||oe(e,129)&&c(e,129).a.b==0?0:e.ff()}function TH(e,t){return!e||t&&!e.k||oe(e,129)&&c(e,129).a.a==0?0:e.gf()}function TWe(e,t){var n;for(n=0;n<t.length;n++)if(e==(en(n,t.length),t.charCodeAt(n)))return!0;return!1}function PRt(e,t){return t<e.length&&(en(t,e.length),e.charCodeAt(t)!=63)&&(en(t,e.length),e.charCodeAt(t)!=35)}function EWe(e,t){var n,i,r;for(r=t-e.f,i=new G(e.d);i.a<i.c.c.length;)n=c(Q(i),320),TKe(n,n.e,n.f+r);e.f=t}function IRt(e){var t,n;for(n=new G(e.r);n.a<n.c.c.length;)if(t=c(Q(n),9),e.n[t.p]<=0)return t;return null}function RRt(e){var t;return t=new qJe(e),H_(e.a,Iht,new Ho(W(V(GL,1),Lt,378,0,[t]))),t.d&&qe(t.f,t.d),t.f}function $Rt(e){var t;for(Rn(e),d0e(!0,"numberToAdvance must be nonnegative"),t=0;t<0&&hn(e);t++)sn(e);return t}function Wme(e,t){var n,i,r;return i=!1,n=t.q.d,t.d<e.b&&(r=Fve(t.q,e.b),t.q.d>r&&(dZe(t.q,r),i=n!=t.q.d)),i}function CWe(e,t){var n,i,r,o,a,d,b,v;return b=t.i,v=t.j,i=e.f,r=i.i,o=i.j,a=b-r,d=v-o,n=p.Math.sqrt(a*a+d*d),n}function MWe(e,t){var n,i,r;n=e,r=0;do{if(n==t)return r;if(i=n.e,!i)throw J(new GN);n=Jr(i),++r}while(!0)}function db(e,t){var n,i,r;i=e.Wk(t,null),r=null,t&&(r=(x6(),n=new Om,n),eS(r,e.r)),i=Ch(e,r,i),i&&i.mj()}function BRt(e,t){var n,i;for(i=lu(e.d,1)!=0,n=!0;n;)n=!1,n=t.c.kg(t.e,i),n=n|XD(e,t,i,!1),i=!i;pme(e)}function Kme(e,t){var n,i;return i=qH(e),i||(n=(jie(),Rtt(t)),i=new UDe(n),Nn(i.Cl(),e)),i}function xD(e,t){var n,i;return n=c(e.c.Ac(t),18),n?(i=e.hc(),i.Fc(n),e.d-=n.gc(),n.$b(),e.mc(i)):e.jc()}function zRt(e){var t;if(!(e.c.c<0?e.a>=e.c.b:e.a<=e.c.b))throw J(new Co);return t=e.a,e.a+=e.c.c,++e.b,Pe(t)}function FRt(e){var t,n;if(e==null)return!1;for(t=0,n=e.length;t<n;t++)if(!cFe(e[t]))return!1;return!0}function AWe(e,t){var n;for(n=0;n<t.length;n++)if(e==(en(n,t.length),t.charCodeAt(n)))return!0;return!1}function NWe(e){var t;if(e.c!=0)return e.c;for(t=0;t<e.a.length;t++)e.c=e.c*33+(e.a[t]&-1);return e.c=e.c*e.e,e.c}function EH(e){var t;return dn(e.a!=e.b),t=e.d.a[e.a],jBe(e.b==e.d.c&&t!=null),e.c=e.a,e.a=e.a+1&e.d.a.length-1,t}function _We(e,t,n,i){var r,o;e.a=t,o=i?0:1,e.f=(r=new set(e.c,e.a,n,o),new Qnt(n,e.a,r,e.e,e.b,e.c==(hb(),lC)))}function qRt(e,t,n){var i,r;for(r=t.a.a.ec().Jc();r.Ob();)if(i=c(r.Pb(),60),vHe(e,i,n))return!0;return!1}function lv(e,t){Rn(e);try{return e.xc(t)}catch(n){if(n=vr(n),oe(n,214)||oe(n,174))return null;throw J(n)}}function HRt(e,t){Rn(e);try{return e.Ac(t)}catch(n){if(n=vr(n),oe(n,214)||oe(n,174))return null;throw J(n)}}function Ite(e,t,n){return p.Math.abs(t-e)<vG||p.Math.abs(n-e)<vG?!0:t-e>vG?e-n>vG:n-e>vG}function Mc(e,t){var n;return Oo(e)&&Oo(t)&&(n=e-t,!isNaN(n))?n:h2e(Oo(e)?qa(e):e,Oo(t)?qa(t):t)}function QRt(e,t,n){var i;i=new ctt(e,t),St(e.r,t.$f(),i),n&&!$7(e.u)&&(i.c=new $He(e.d),Qc(t.Pf(),new tNe(i)))}function Rte(e){var t;return t=new age(e.a),ec(t,e),Ee(t,(De(),Oi),e),t.o.a=e.g,t.o.b=e.f,t.n.a=e.i,t.n.b=e.j,t}function GRt(e){var t;return t=vF(Y0t),c(R(e,(De(),Lc)),24).Gc((Gs(),P9))&&Wn(t,(es(),vc),(cs(),OU)),t}function URt(e){var t,n,i,r;for(r=new Or,i=new G(e);i.a<i.c.c.length;)n=c(Q(i),19),t=qXt(n),Os(r,t);return r}function Yme(e,t){var n,i,r;for(r=1,n=e,i=t>=0?t:-t;i>0;)i%2==0?(n*=n,i=i/2|0):(r*=n,i-=1);return t<0?1/r:r}function JRt(e,t){var n,i,r;for(r=1,n=e,i=t>=0?t:-t;i>0;)i%2==0?(n*=n,i=i/2|0):(r*=n,i-=1);return t<0?1/r:r}function I0(e,t){var n,i,r,o;return o=(r=e?qH(e):null,Cet((i=t,r&&r.El(),i))),o==t&&(n=qH(e),n&&n.El()),o}function Zme(e,t,n){var i,r;return r=e.a,e.a=t,(e.Db&4)!=0&&(e.Db&1)==0&&(i=new Ur(e,1,1,r,t),n?n.lj(i):n=i),n}function DWe(e,t,n){var i,r;return r=e.b,e.b=t,(e.Db&4)!=0&&(e.Db&1)==0&&(i=new Ur(e,1,3,r,t),n?n.lj(i):n=i),n}function LWe(e,t,n){var i,r;return r=e.f,e.f=t,(e.Db&4)!=0&&(e.Db&1)==0&&(i=new Ur(e,1,0,r,t),n?n.lj(i):n=i),n}function XRt(e,t,n,i){var r,o;for(o=e.Jc();o.Ob();)r=c(o.Pb(),70),r.n.a=t.a+(i.a-r.o.a)/2,r.n.b=t.b,t.b+=r.o.b+n}function VRt(e,t,n,i,r,o,a,d){var b;for(b=n;o<a;)b>=i||t<n&&d.Le(e[t],e[b])<=0?dr(r,o++,e[t++]):dr(r,o++,e[b++])}function PWe(e){var t,n;if(e!=null)for(n=0;n<e.length;++n)t=e[n],t&&(c(t.g,375),t.i)}function WRt(e,t,n,i,r){t==0||i==0||(t==1?r[i]=Uwe(r,n,i,e[0]):i==1?r[t]=Uwe(r,e,t,n[0]):XGt(e,n,r,t,i))}function $te(e){return(Je(),vl).Gc(e.j)?ue(he(R(e,(De(),I9)))):Lo(W(V(Vr,1),Be,8,0,[e.i.n,e.n,e.a])).b}function IWe(e,t){var n;return n=new Eh(e),mu(n,(Jt(),jr)),Ee(n,(De(),Oi),t),Ee(n,(Ge(),cr),(Zr(),xc)),n}function RWe(e,t,n){var i,r;for(r=e.Jc();r.Ob();){if(i=c(r.Pb(),9),i==t)return-1;if(i==n)return 1}return 0}function KRt(e,t,n){var i,r,o,a;for(i=n/e.gc(),r=0,a=e.Jc();a.Ob();)o=c(a.Pb(),189),EWe(o,o.f+i*r),rqt(o,t,i),++r}function YRt(e){var t,n,i;for(i=new G(e.b);i.a<i.c.c.length;)n=c(Q(i),221),t=n.c.ig()?n.f:n.a,t&&nYt(t,n.j)}function ZRt(e){var t,n,i;for(i=0,n=new G(e.a);n.a<n.c.c.length;)t=c(Q(n),175),i=p.Math.max(i,t.g);return i}function ewe(){this.a=new QO,this.f=new G_e(this),this.b=new U_e(this),this.i=new J_e(this),this.e=new X_e(this)}function gS(){gS=te,_P=new oF(o5e,0),VJ=new oF("CONTAINER",1),N7e=new oF("PARENT",2),_7e=new oF("ROOT",3)}function P5(){P5=te,eTe=new GY("PARALLEL_NODE",0),ly=new GY("HIERARCHICAL_NODE",1),nX=new GY("ROOT_NODE",2)}function CH(){CH=te,rje=new zY("EQUAL_BETWEEN_STRUCTURES",0),sje=new zY("TO_ASPECT_RATIO",1),Sue=new zY(th,2)}function twe(e){throw Ote(),J(new YLe("Unexpected typeof result '"+e+"'; please report this bug to the GWT team"))}function $We(e){switch(e.g){case 0:return new y$;case 1:return new RW;case 2:return new x$;default:return null}}function nwe(e,t){switch(t){case 1:!e.n&&(e.n=new Me(Bo,e,1,7)),En(e.n);return;case 2:nS(e,null);return}Mme(e,t)}function BWe(e,t){var n;e.a.c.length>0&&(n=c(Xe(e.a,e.a.c.length-1),572),Hme(n,t))||qe(e.a,new KGe(t))}function zWe(e,t){var n;e.c.length!=0&&(n=c(jh(e,ye(e1,Hg,9,e.c.length,0,1)),201),rge(n,new Md),Yet(n,t))}function FWe(e,t){var n;e.c.length!=0&&(n=c(jh(e,ye(e1,Hg,9,e.c.length,0,1)),201),rge(n,new $y),Yet(n,t))}function Pe(e){var t,n;return e>-129&&e<128?(bFe(),t=e+128,n=eke[t],!n&&(n=eke[t]=new qo(e)),n):new qo(e)}function pS(e){var t,n;return e>-129&&e<128?(SFe(),t=e+128,n=rke[t],!n&&(n=rke[t]=new $t(e)),n):new $t(e)}function qWe(e){var t;return t=new b0,t.a+="VerticalSegment ",Sc(t,e.e),t.a+=" ",Zn(t,kge(new nY,new G(e.k))),t.a}function e$t(e){Pu();var t,n;t=e.d.c-e.e.c,n=c(e.g,157),Qc(n.b,new $Ne(t)),Qc(n.c,new BNe(t)),ws(n.i,new zNe(t))}function t$t(e){var t;return t=c(Oh(e.c.c,""),236),t||(t=new O5(y6(v6(new Lp,""),"Other")),gb(e.c.c,"",t)),t}function pT(e){var t;return(e.Db&64)!=0?kf(e):(t=new Ba(kf(e)),t.a+=" (name: ",Ys(t,e.zb),t.a+=")",t.a)}function iwe(e,t,n){var i,r;return r=e.sb,e.sb=t,(e.Db&4)!=0&&(e.Db&1)==0&&(i=new Ur(e,1,4,r,t),n?n.lj(i):n=i),n}function Bte(e,t){var n,i,r;for(n=0,r=Po(e,t).Jc();r.Ob();)i=c(r.Pb(),12),n+=R(i,(De(),Ul))!=null?1:0;return n}function Nx(e,t,n){var i,r,o;for(i=0,o=_n(e,0);o.b!=o.d.c&&(r=ue(he(An(o))),!(r>n));)r>=t&&++i;return i}function n$t(e,t,n){var i,r;return i=new _1(e.e,3,13,null,(r=t.c,r||(Mt(),Gh)),$g(e,t),!1),n?n.lj(i):n=i,n}function i$t(e,t,n){var i,r;return i=new _1(e.e,4,13,(r=t.c,r||(Mt(),Gh)),null,$g(e,t),!1),n?n.lj(i):n=i,n}function rwe(e,t,n){var i,r;return r=e.r,e.r=t,(e.Db&4)!=0&&(e.Db&1)==0&&(i=new Ur(e,1,8,r,e.r),n?n.lj(i):n=i),n}function Pg(e,t){var n,i;return n=c(t,688),i=n.cl(),!i&&n.dl(i=oe(t,89)?new n$e(e,c(t,29)):new LQe(e,c(t,160))),i}function kD(e,t,n){var i;e.Zi(e.i+1),i=e.Xi(t,n),t!=e.i&&mc(e.g,t,e.g,t+1,e.i-t),dr(e.g,t,i),++e.i,e.Ki(t,n),e.Li()}function r$t(e,t){var n;e.c=t,e.a=eBt(t),e.a<54&&(e.f=(n=t.d>1?zQe(t.a[0],t.a[1]):zQe(t.a[0],0),ib(t.e>0?n:Ng(n))))}function s$t(e,t){var n;return t.a&&(n=t.a.a.length,e.a?Zn(e.a,e.b):e.a=new Lu(e.d),JQe(e.a,t.a,t.d.length,n)),e}function o$t(e,t){var n,i,r,o;if(t.cj(e.a),o=c(Wt(e.a,8),2014),o!=null)for(n=o,i=0,r=n.length;i<r;++i)null.Sm()}function OD(e,t){var n;return n=new bs,e.a.zd(n)?(C6(),new VK(zt(TJe(e,n.a,t)))):(T0(e),C6(),C6(),pke)}function HWe(e){var t;return Mc(e,0)<0&&(e=_0(vMt(Oo(e)?qa(e):e))),t=Hn(Vp(e,32)),64-(t!=0?qD(t):qD(Hn(e))+32)}function yi(e,t){return Kr(e)?Ot(e,t):P2(e)?kze(e,t):L2(e)?(zt(e),ve(e)===ve(t)):X0e(e)?e.Fb(t):G0e(e)?v$e(e,t):Gpe(e,t)}function QWe(e,t){Rn(e);try{return e._b(t)}catch(n){if(n=vr(n),oe(n,214)||oe(n,174))return!1;throw J(n)}}function swe(e,t){Rn(e);try{return e.Gc(t)}catch(n){if(n=vr(n),oe(n,214)||oe(n,174))return!1;throw J(n)}}function c$t(e,t){Rn(e);try{return e.Kc(t)}catch(n){if(n=vr(n),oe(n,214)||oe(n,174))return!1;throw J(n)}}function owe(e,t,n,i){switch(t){case 1:return!e.n&&(e.n=new Me(Bo,e,1,7)),e.n;case 2:return e.k}return t2e(e,t,n,i)}function bT(e,t){switch(t.g){case 2:case 1:return Po(e,t);case 3:case 4:return Eu(Po(e,t))}return Ct(),Ct(),Rs}function ya(e,t,n){if(t<0)uve(e,n);else{if(!n.pk())throw J(new qt(V0+n.ve()+pE));c(n,69).uk().Ck(e,e.ei(),t)}}function GWe(e,t,n){if(e<0||t>n)throw J(new zc(JQ+e+gxe+t+", size: "+n));if(e>t)throw J(new qt(JQ+e+uot+t))}function Ig(e,t){var n;n=(e.Bb&256)!=0,t?e.Bb|=256:e.Bb&=-257,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new bf(e,1,2,n,t))}function cwe(e,t){var n;n=(e.Bb&256)!=0,t?e.Bb|=256:e.Bb&=-257,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new bf(e,1,8,n,t))}function lwe(e,t){var n;n=(e.Bb&512)!=0,t?e.Bb|=512:e.Bb&=-513,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new bf(e,1,9,n,t))}function Rg(e,t){var n;n=(e.Bb&512)!=0,t?e.Bb|=512:e.Bb&=-513,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new bf(e,1,3,n,t))}function MH(e,t){var n;n=(e.Bb&256)!=0,t?e.Bb|=256:e.Bb&=-257,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new bf(e,1,8,n,t))}function l$t(e,t,n){var i,r;return r=e.a,e.a=t,(e.Db&4)!=0&&(e.Db&1)==0&&(i=new Ur(e,1,5,r,e.a),n?T2e(n,i):n=i),n}function UWe(e){var t;return(e.Db&64)!=0?kf(e):(t=new Ba(kf(e)),t.a+=" (source: ",Ys(t,e.d),t.a+=")",t.a)}function mT(e,t){var n;return e.b==-1&&e.a&&(n=e.a.nk(),e.b=n?e.c.Eh(e.a.Jj(),n):Vi(e.c.Ah(),e.a)),e.c.vh(e.b,t)}function JWe(e,t){var n,i;for(i=new cn(e);i.e!=i.i.gc();)if(n=c(un(i),29),ve(t)===ve(n))return!0;return!1}function u$t(e){FQ();var t,n,i,r;for(n=sne(),i=0,r=n.length;i<r;++i)if(t=n[i],Do(t.a,e,0)!=-1)return t;return Qoe}function XWe(e){return e>=65&&e<=70?e-65+10:e>=97&&e<=102?e-97+10:e>=48&&e<=57?e-48:0}function VWe(e){return e-=e>>1&1431655765,e=(e>>2&858993459)+(e&858993459),e=(e>>4)+e&252645135,e+=e>>8,e+=e>>16,e&63}function uwe(e){var t,n;return t=e.k,t==(Jt(),Cr)?(n=c(R(e,(De(),Ko)),64),n==(Je(),Kt)||n==bn):!1}function WWe(e,t){var n,i;for(i=new cn(e);i.e!=i.i.gc();)if(n=c(un(i),146),ve(t)===ve(n))return!0;return!1}function a$t(e,t,n){var i,r,o;return o=(r=NS(e.b,t),r),o&&(i=c(IQ(nD(e,o),""),29),i)?Dve(e,i,t,n):null}function zte(e,t,n){var i,r,o;return o=(r=NS(e.b,t),r),o&&(i=c(IQ(nD(e,o),""),29),i)?Lve(e,i,t,n):null}function wT(e,t,n){var i;if(i=e.gc(),t>i)throw J(new F2(t,i));if(e.Qi()&&e.Gc(n))throw J(new qt(DL));e.Ei(t,n)}function f$t(e,t){t.Tg("Sort end labels",1),lr(pi(So(new jt(null,new Tt(e.b,16)),new i4),new r4),new XI),t.Ug()}function Nr(){Nr=te,qh=new h_(nE,0),yo=new h_(ik,1),go=new h_(nk,2),Fh=new h_(vre,3),Ca=new h_("UP",4)}function SD(){SD=te,PJ=new FY("P1_STRUCTURE",0),IJ=new FY("P2_PROCESSING_ORDER",1),RJ=new FY("P3_EXECUTION",2)}function KWe(){KWe=te,dbt=cd(cd(u7(cd(cd(u7(Wn(new wr,(B5(),fC),(FT(),Ble)),hC),P9e),R9e),dC),N9e),$9e)}function h$t(e){var t,n,i;for(t=new Fe,i=new G(e.b);i.a<i.c.c.length;)n=c(Q(i),598),yr(t,c(n.Af(),18));return t}function d$t(e){var t,n,i;for(i=0,n=e.length,t=0;t<n;t++)e[t]==32||e[t]==13||e[t]==10||e[t]==9||(e[i++]=e[t]);return i}function g$t(e){var t;return t=e.a[e.c-1&e.a.length-1],t==null?null:(e.c=e.c-1&e.a.length-1,dr(e.a,e.c,null),t)}function YWe(e){var t,n;for(n=e.p.a.ec().Jc();n.Ob();)if(t=c(n.Pb(),220),t.f&&e.b[t.c]<-1e-10)return t;return null}function awe(e,t){switch(e.b.g){case 0:case 1:return t;case 2:case 3:return new pf(t.d,0,t.a,t.b);default:return null}}function ZWe(e){switch(e.g){case 2:return yo;case 1:return go;case 4:return Fh;case 3:return Ca;default:return qh}}function fwe(e){switch(e.g){case 1:return Yt;case 2:return Kt;case 3:return nn;case 4:return bn;default:return $o}}function jD(e){switch(e.g){case 1:return bn;case 2:return Yt;case 3:return Kt;case 4:return nn;default:return $o}}function AH(e){switch(e.g){case 1:return nn;case 2:return bn;case 3:return Yt;case 4:return Kt;default:return $o}}function p$t(e){switch(e){case 0:return new kLe;case 1:return new yLe;case 2:return new xLe;default:throw J(new GN)}}function b$t(e){switch(c(R(e,(De(),Nb)),316).g){case 1:Ee(e,Nb,(D1(),bk));break;case 2:Ee(e,Nb,(D1(),a3))}}function TD(e,t){this.e=t,this.a=HWe(e),this.a<54?this.f=ib(e):this.c=(ld(),Mc(e,0)>=0?$0(e):F7($0(Ng(e))))}function eKe(e,t,n,i,r,o){this.e=new Fe,this.f=(Qs(),oC),qe(this.e,e),this.d=t,this.a=n,this.b=i,this.f=r,this.c=o}function m$t(e){var t;if(!e.a)throw J(new oo("Cannot offset an unassigned cut."));t=e.c-e.b,e.b+=t,fHe(e,t),hHe(e,t)}function tKe(e){var t;return t=Wpe(e),k7(t.a,0)?(N2(),N2(),Ioe):(N2(),new uZ(hY(t.a,0)?wbe(t)/ib(t.a):0))}function w$t(e,t){var n;if(n=JD(e,t),oe(n,336))return c(n,38);throw J(new qt(V0+t+"' is not a valid attribute"))}function ji(e,t){return e<t?-1:e>t?1:e==t?e==0?ji(1/e,1/t):0:isNaN(e)?isNaN(t)?0:1:-1}function vT(e,t,n){var i,r;return e.Nj()?(r=e.Oj(),i=Vne(e,t,n),e.Hj(e.Gj(7,Pe(n),i,t,r)),i):Vne(e,t,n)}function Fte(e,t){var n,i,r;e.d==null?(++e.e,--e.f):(r=t.jd(),n=t.yi(),i=(n&di)%e.d.length,uLt(e,i,Qtt(e,i,n,r)))}function bS(e,t){var n;n=(e.Bb&Ga)!=0,t?e.Bb|=Ga:e.Bb&=-1025,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new bf(e,1,10,n,t))}function mS(e,t){var n;n=(e.Bb&jv)!=0,t?e.Bb|=jv:e.Bb&=-4097,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new bf(e,1,12,n,t))}function wS(e,t){var n;n=(e.Bb&Pl)!=0,t?e.Bb|=Pl:e.Bb&=-8193,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new bf(e,1,15,n,t))}function vS(e,t){var n;n=(e.Bb&q1)!=0,t?e.Bb|=q1:e.Bb&=-2049,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new bf(e,1,11,n,t))}function v$t(e,t){var n;return n=ji(e.b.c,t.b.c),n!=0||(n=ji(e.a.a,t.a.a),n!=0)?n:ji(e.a.b,t.a.b)}function NH(e){var t,n;return n=c(R(e,(Ge(),Xu)),87),n==(Nr(),qh)?(t=ue(he(R(e,XU))),t>=1?yo:Fh):n}function y$t(e){var t,n;for(n=$tt(Bu(e)).Jc();n.Ob();)if(t=zn(n.Pb()),qT(e,t))return _Dt((RIe(),z2t),t);return null}function x$t(e,t,n){var i,r;for(r=e.a.ec().Jc();r.Ob();)if(i=c(r.Pb(),9),mD(n,c(Xe(t,i.p),18)))return i;return null}function k$t(e,t,n){var i,r;for(r=oe(t,104)&&(c(t,20).Bb&Is)!=0?new XY(t,e):new oS(t,e),i=0;i<n;++i)XH(r);return r}function O$t(e,t){var n,i,r,o,a;for(a=nl(e.e.Ah(),t),o=0,n=c(e.g,123),r=0;r<e.i;++r)i=n[r],a.$l(i.Jk())&&++o;return o}function S$t(e,t,n){var i,r;return i=c(t.mf(e.a),34),r=c(n.mf(e.a),34),i!=null&&r!=null?aD(i,r):i!=null?-1:r!=null?1:0}function nKe(e,t,n){var i,r;if(e.c)B2e(e.c,t,n);else for(r=new G(e.b);r.a<r.c.c.length;)i=c(Q(r),168),nKe(i,t,n)}function qte(e,t){var n,i;for(i=new G(t);i.a<i.c.c.length;)n=c(Q(i),49),fl(e.b.b,n.b),BAt(c(n.a,197),c(n.b,84))}function hwe(e,t){var n,i,r;for(zt(t),n=!1,i=new G(e);i.a<i.c.c.length;)r=Q(i),t.Gc(r)&&(z7(i),n=!0);return n}function j$t(e){var t,n;for(n=Kp(new b0,91),t=!0;e.Ob();)t||(n.a+=Jc),t=!1,Sc(n,e.Pb());return(n.a+="]",n).a}function dwe(e){var t;return t=ye(Na,fd,30,2,15,1),e-=Is,t[0]=(e>>10)+hL&_r,t[1]=(e&1023)+56320&_r,od(t,0,t.length)}function gwe(e,t){var n;n=(e.Bb&Is)!=0,t?e.Bb|=Is:e.Bb&=-65537,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new bf(e,1,20,n,t))}function pwe(e,t){var n;n=(e.Bb&nc)!=0,t?e.Bb|=nc:e.Bb&=-32769,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new bf(e,1,18,n,t))}function Hte(e,t){var n;n=(e.Bb&nc)!=0,t?e.Bb|=nc:e.Bb&=-32769,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new bf(e,1,18,n,t))}function yS(e,t){var n;n=(e.Bb&ad)!=0,t?e.Bb|=ad:e.Bb&=-16385,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new bf(e,1,16,n,t))}function bwe(e,t,n){var i;return i=0,t&&(hx(e.a)?i+=t.f.a/2:i+=t.f.b/2),n&&(hx(e.a)?i+=n.f.a/2:i+=n.f.b/2),i}function Zm(e,t,n){var i;return i=e.a.get(t),e.a.set(t,n===void 0?null:n),i===void 0?(++e.c,++e.b.g):++e.d,i}function Qte(e,t,n){var i,r;return i=(w0(),r=new y2,r),nH(i,t),tH(i,n),e&&Nn((!e.a&&(e.a=new Ar(Yu,e,5)),e.a),i),i}function T$t(e,t,n){var i;i=n,!i&&(i=A0e(new V4,0)),i.Tg(Rot,2),fYe(e.b,t,i.dh(1)),EYt(e,t,i.dh(1)),Een(t,i.dh(1)),i.Ug()}function Po(e,t){var n;return e.i||lve(e),n=c(Zs(e.g,t),49),n?new nd(e.j,c(n.a,15).a,c(n.b,15).a):(Ct(),Ct(),Rs)}function As(e,t){var n;return Oo(e)&&Oo(t)&&(n=e+t,fL<n&&n<yb)?n:_0(HIt(Oo(e)?qa(e):e,Oo(t)?qa(t):t))}function Ss(e,t){var n;return Oo(e)&&Oo(t)&&(n=e*t,fL<n&&n<yb)?n:_0(gYt(Oo(e)?qa(e):e,Oo(t)?qa(t):t))}function Ha(e,t){var n;return Oo(e)&&Oo(t)&&(n=e-t,fL<n&&n<yb)?n:_0(AVe(Oo(e)?qa(e):e,Oo(t)?qa(t):t))}function _H(e){var t;switch(e.gc()){case 0:return UF(),Eoe;case 1:return new dZ(Rn(e.Xb(0)));default:return t=e,new kee(t)}}function E$t(e){switch(c(R(e,(Ge(),W1)),225).g){case 1:return new dg;case 3:return new h4;default:return new u2}}function C$t(e){var t;return t=gv(e),t>34028234663852886e22?nr:t<-34028234663852886e22?Qr:t}function sd(e){var t,n,i;for(t=new Fe,i=new G(e.j);i.a<i.c.c.length;)n=c(Q(i),12),qe(t,n.b);return Rn(t),new T7(t)}function pr(e){var t,n,i;for(t=new Fe,i=new G(e.j);i.a<i.c.c.length;)n=c(Q(i),12),qe(t,n.e);return Rn(t),new T7(t)}function $i(e){var t,n,i;for(t=new Fe,i=new G(e.j);i.a<i.c.c.length;)n=c(Q(i),12),qe(t,n.g);return Rn(t),new T7(t)}function Gte(e){var t;return(e.Db&64)!=0?kf(e):(t=new Ba(kf(e)),t.a+=" (identifier: ",Ys(t,e.k),t.a+=")",t.a)}function R0(e){if(e.c)R0(e.c);else if(e.d)throw J(new oo("Stream already terminated, can't be modified or used"))}function iKe(e,t,n){switch(t.g){case 1:e.b-=n.b/2;break;case 3:e.b+=n.b/2;break;case 4:e.a-=n.a/2;break;case 2:e.a+=n.a/2}}function M$t(e,t){return Ot(t.b&&t.c?nb(t.b)+"->"+nb(t.c):"e_"+Ri(t),e.b&&e.c?nb(e.b)+"->"+nb(e.c):"e_"+Ri(e))}function A$t(e,t){return Ot(t.b&&t.c?nb(t.b)+"->"+nb(t.c):"e_"+Ri(t),e.b&&e.c?nb(e.b)+"->"+nb(e.c):"e_"+Ri(e))}function N$t(e){return Dte(),Bt(),!!(cKe(c(e.a,84).j,c(e.b,87))||c(e.a,84).d.e!=0&&cKe(c(e.a,84).j,c(e.b,87)))}function Ute(){L2e();var e,t,n;n=$tn+++Date.now(),e=xs(p.Math.floor(n*gL))&UQ,t=xs(n-e*axe),this.a=e^1502,this.b=t^dre}function rKe(e,t,n,i,r){Q$e(this),this.b=e,this.d=ye(e1,Hg,9,t.a.c.length,0,1),this.f=n,jh(t.a,this.d),this.g=i,this.c=r}function mwe(e,t){e.n.c.length==0&&qe(e.n,new kq(e.s,e.t,e.i)),qe(e.b,t),Kwe(c(Xe(e.n,e.n.c.length-1),211),t),Jit(e,t)}function _$t(e,t,n){var i;n.Tg("Straight Line Edge Routing",1),n.bh(t,g4e),i=c(ke(t,(vx(),k3)),19),crt(e,i),n.bh(t,kG)}function gt(e){var t,n,i,r;return n=(t=c(Jf((i=e.Pm,r=i.f,r==On?i:r)),10),new ha(t,c(gf(t,t.length),10),0)),yf(n,e),n}function D$t(e){var t,n;for(n=oUt(Bu(W2(e))).Jc();n.Ob();)if(t=zn(n.Pb()),qT(e,t))return DDt(($Ie(),F2t),t);return null}function Jte(e,t){var n,i,r;for(r=0,i=c(t.Kb(e),22).Jc();i.Ob();)n=c(i.Pb(),17),et(Ze(R(n,(De(),Jg))))||++r;return r}function sKe(e){var t,n,i,r;for(t=new nze(e.Pd().gc()),r=0,i=M5(e.Pd().Jc());i.Ob();)n=i.Pb(),yAt(t,n,Pe(r++));return aQt(t.a)}function L$t(e){var t,n,i;for(n=0,i=e.length;n<i;n++)if(e[n]==null)throw J(new K4("at index "+n));return t=e,new Ho(t)}function P$t(e,t,n){var i;try{aRt(e,t,n)}catch(r){throw r=vr(r),oe(r,602)?(i=r,J(new ube(i))):J(r)}return t}function oKe(e,t){var n,i;for(n=_n(e,0);n.b!=n.d.c;){if(i=UN(he(An(n))),i==t)return;if(i>t){$Qe(n);break}}oq(n,t)}function I$t(e,t){var n,i,r;i=kx(t),r=ue(he(av(i,(Ge(),Mf)))),n=p.Math.max(0,r/2-.5),ET(t,n,1),qe(e,new rRe(t,n))}function ft(e,t){var n,i,r,o,a;if(n=t.f,gb(e.c.d,n,t),t.g!=null)for(r=t.g,o=0,a=r.length;o<a;++o)i=r[o],gb(e.c.e,i,t)}function R$t(e,t,n,i){var r,o,a;for(r=t+1;r<n;++r)for(o=r;o>t&&i.Le(e[o-1],e[o])>0;--o)a=e[o],dr(e,o,e[o-1]),dr(e,o-1,a)}function xa(e,t,n,i){if(t<0)$ve(e,n,i);else{if(!n.pk())throw J(new qt(V0+n.ve()+pE));c(n,69).uk().Ak(e,e.ei(),t,i)}}function $$t(e,t){var n;if(n=JD(e.Ah(),t),oe(n,104))return c(n,20);throw J(new qt(V0+t+"' is not a valid reference"))}function jo(e){var t;return Array.isArray(e)&&e.Rm===je?qp(ju(e))+"@"+(t=Ri(e)>>>0,t.toString(16)):e.toString()}function B$t(e,t){return e.h==aL&&e.m==0&&e.l==0?(t&&(W0=el(0,0,0)),y$e((Z6(),X5e))):(t&&(W0=el(e.l,e.m,e.h)),el(0,0,0))}function z$t(e,t){switch(t.g){case 2:return e.b;case 1:return e.c;case 4:return e.d;case 3:return e.a;default:return!1}}function cKe(e,t){switch(t.g){case 2:return e.b;case 1:return e.c;case 4:return e.d;case 3:return e.a;default:return!1}}function wwe(e,t,n,i){switch(t){case 3:return e.f;case 4:return e.g;case 5:return e.i;case 6:return e.j}return owe(e,t,n,i)}function DH(e,t){if(t==e.d)return e.e;if(t==e.e)return e.d;throw J(new qt("Node "+t+" not part of edge "+e))}function F$t(e){return e.e==null?e:(!e.c&&(e.c=new rie((e.f&256)!=0,e.i,e.a,e.d,(e.f&16)!=0,e.j,e.g,null)),e.c)}function q$t(e){return e.k!=(Jt(),or)?!1:Sx(new jt(null,new U2(new Ht(Vt($i(e).a.Jc(),new U)))),new tA)}function cu(e){var t;if(e.b){if(cu(e.b),e.b.d!=e.c)throw J(new ua)}else e.d.dc()&&(t=c(e.f.c.xc(e.e),18),t&&(e.d=t))}function H$t(e){B2();var t,n,i,r;for(t=e.o.b,i=c(c(Si(e.r,(Je(),bn)),24),85).Jc();i.Ob();)n=c(i.Pb(),116),r=n.e,r.b+=t}function Q$t(e,t){var n,i,r;for(i=kVt(e,t),r=i[i.length-1]/2,n=0;n<i.length;n++)if(i[n]>=r)return t.c+n;return t.c+t.b.gc()}function vwe(e,t,n,i,r){var o,a,d;for(a=r;t.b!=t.c;)o=c(w5(t),9),d=c(Po(o,i).Xb(0),12),e.d[d.p]=a++,It(n.c,d);return a}function yT(e){var t;this.a=(t=c(e.e&&e.e(),10),new ha(t,c(gf(t,t.length),10),0)),this.b=ye(Br,Lt,1,this.a.a.length,5,1)}function ywe(e){Kte(),this.c=mf(W(V(inn,1),Lt,837,0,[x0t])),this.b=new wn,this.a=e,oi(this.b,aJ,1),Qc(k0t,new iDe(this))}function Tu(){Tu=te,rP=new s_(th,0),GE=new s_("FIRST",1),V1=new s_(Zot,2),UE=new s_("LAST",3),Db=new s_(ect,4)}function xT(){xT=te,$E=new Kz("LAYER_SWEEP",0),FOe=new Kz("MEDIAN_LAYER_SWEEP",1),WL=new Kz(Mre,2),qOe=new Kz(th,3)}function LH(){LH=te,P8e=new $Y("ASPECT_RATIO_DRIVEN",0),wue=new $Y("MAX_SCALE_DRIVEN",1),L8e=new $Y("AREA_DRIVEN",2)}function PH(){PH=te,mae=new aF(t4e,0),sTe=new aF("GROUP_DEC",1),cTe=new aF("GROUP_MIXED",2),oTe=new aF("GROUP_INC",3)}function $1(){$1=te,fae=new cF(nE,0),DP=new cF("POLYLINE",1),i8=new cF("ORTHOGONAL",2),Ik=new cF("SPLINES",3)}function xwe(){xwe=te,Xmt=new gi(J4e),Lje=(Aq(),Lue),Jmt=new wt(X4e,Lje),Umt=new wt(V4e,50),Gmt=new wt(W4e,(Bt(),!0))}function G$t(e){var t,n,i,r,o;return o=P2e(e),n=WN(e.c),i=!n,i&&(r=new mg,wf(o,"knownLayouters",r),t=new DDe(r),ws(e.c,t)),o}function kwe(e,t){var n,i,r,o,a,d;for(i=0,n=0,o=t,a=0,d=o.length;a<d;++a)r=o[a],r>0&&(i+=r,++n);return n>1&&(i+=e.d*(n-1)),i}function Owe(e){var t,n,i;for(i=new yg,i.a+="[",t=0,n=e.gc();t<n;)Ys(i,A7(e.Ti(t))),++t<n&&(i.a+=Jc);return i.a+="]",i.a}function Xte(e,t,n){var i,r;for(i=0,r=e.length;i<r;i++)if(Ste((en(i,e.length),e.charCodeAt(i)),t,n))return!0;return!1}function U$t(e){var t;return e==null?!0:(t=e.length,t>0&&(en(t-1,e.length),e.charCodeAt(t-1)==58)&&!Xte(e,HC,QC))}function Swe(e,t){var n;return ve(e)===ve(t)?!0:oe(t,92)?(n=c(t,92),e.e==n.e&&e.d==n.d&&IDt(e,n.a)):!1}function I5(e){switch(Je(),e.g){case 4:return Kt;case 1:return nn;case 3:return bn;case 2:return Yt;default:return $o}}function J$t(e){var t,n;if(e.b)return e.b;for(n=Ph?null:e.d;n;){if(t=Ph?null:n.b,t)return t;n=Ph?null:n.d}return T6(),wke}function ew(e,t){return mh(),vf(Fg),p.Math.abs(e-t)<=Fg||e==t||isNaN(e)&&isNaN(t)?0:e<t?-1:e>t?1:Gp(isNaN(e),isNaN(t))}function lKe(e,t){_6();var n,i,r,o;for(i=KUe(e),r=t,K6(i,0,i.length,r),n=0;n<i.length;n++)o=CFt(e,i[n],n),n!=o&&vT(e,n,o)}function jwe(e){var t,n,i;for(i=ue(he(e.a.mf((Dn(),UJ)))),n=new G(e.a.Qf());n.a<n.c.c.length;)t=c(Q(n),692),hst(e,t,i)}function X$t(e){var t,n,i,r;for(t=(e.j==null&&(e.j=(U6(),r=Aoe.ke(e),dqt(r))),e.j),n=0,i=t.length;n<i;++n);}function Vte(e,t){var n,i;for(i=new G(t);i.a<i.c.c.length;)n=c(Q(i),49),qe(e.b.b,c(n.b,84)),jee(c(n.a,197),c(n.b,84))}function V$t(e,t,n){var i,r;for(r=e.a.b,i=r.c.length;i<n;i++)Up(r,0,new hc(e.a));zr(t,c(Xe(r,r.c.length-n),26)),e.b[t.p]=n}function W$t(e,t,n){var i;n.Tg(Jct,1),(!t.a&&(t.a=new Me(Mn,t,10,11)),t.a).i!=0&&(i=c(ke(t,(Qd(),SC)),19),cit(e,i)),n.Ug()}function K$t(e,t,n,i,r){Ru(),Of(uf(ff(af(hf(new Ra,0),r.d.e-e),t),r.d)),Of(uf(ff(af(hf(new Ra,0),n-r.a.e),r.a),i))}function uKe(e,t){var n,i,r,o;t&&(r=P1(t,"x"),n=new jDe(e),Vm(n.a,(zt(r),r)),o=P1(t,"y"),i=new TDe(e),Wm(i.a,(zt(o),o)))}function aKe(e,t){var n,i,r,o;t&&(r=P1(t,"x"),n=new CDe(e),Jm(n.a,(zt(r),r)),o=P1(t,"y"),i=new MDe(e),Xm(i.a,(zt(o),o)))}function fKe(e,t){var n;return e.d?jc(e.b,t)?c(Ut(e.b,t),43):(n=t.bg(),oi(e.b,t,n),n):t.bg()}function Twe(e,t,n){var i,r;if(++e.j,n.dc())return!1;for(r=n.Jc();r.Ob();)i=r.Pb(),e.oj(t,e.Xi(t,i)),++t;return!0}function Y$t(e,t){var n,i,r,o;for(r=new Hc(t.gc()),i=t.Jc();i.Ob();)n=i.Pb(),o=hie(e,c(n,57)),o&&It(r.c,o);return r}function uv(e,t,n){var i,r;for(r=e.Jc();r.Ob();)if(i=r.Pb(),ve(t)===ve(i)||t!=null&&yi(t,i))return n&&r.Qb(),!0;return!1}function Z$t(e,t,n,i){var r,o;if(o=n-t,o<3)for(;o<3;)e*=10,++o;else{for(r=1;o>3;)r*=10,--o;e=(e+(r>>1))/r|0}return i.i=e,!0}function eBt(e){var t,n,i;return e.e==0?0:(t=e.d<<5,n=e.a[e.d-1],e.e<0&&(i=lVe(e),i==e.d-1&&(--n,n=n|0)),t-=qD(n),t)}function tBt(e){var t,n,i;return e<ZG.length?ZG[e]:(n=e>>5,t=e&31,i=ye(Fn,ci,30,n+1,15,1),i[n]=1<<t,new Wp(1,n+1,i))}function hKe(e){var t,n,i;return n=e.ih(),n?(t=e.Bh(),oe(t,176)&&(i=hKe(c(t,176)),i!=null)?i+"."+n:n):null}function Ewe(e){var t;return!e.c&&(e.c=new t2),Rr(e.d,new gO),UXt(e),t=RXt(e),lr(new jt(null,new Tt(e.d,16)),new nNe(e)),t}function nBt(e,t){t.Tg("End label post-processing",1),lr(pi(So(new jt(null,new Tt(e.b,16)),new JI),new DM),new zV),t.Ug()}function Eu(e){var t,n;return oe(e,312)?(n=oLt(c(e,312)),t=n,t):oe(e,437)?c(e,437).a:oe(e,59)?new WLe(e):new a1e(e)}function iBt(e){var t=e.e;function n(i){return!i||i.length==0?"":"	"+i.join(`
	`)}return t&&(t.stack||n(e[Hie]))}function Cwe(e,t){switch(t){case 3:return e.f!=0;case 4:return e.g!=0;case 5:return e.i!=0;case 6:return e.j!=0}return kme(e,t)}function Mwe(e,t){switch(t){case 3:sb(e,0);return;case 4:ob(e,0);return;case 5:Cc(e,0);return;case 6:Nl(e,0);return}nwe(e,t)}function rBt(e){switch(e.g){case 0:return new a$;case 1:return new f$;default:throw J(new qt(Sse+(e.f!=null?e.f:""+e.g)))}}function dKe(e){switch(e.g){case 0:return new IW;case 1:return new h$;default:throw J(new qt(Tre+(e.f!=null?e.f:""+e.g)))}}function sBt(e){switch(e.g){case 1:return new c$;case 2:return new GBe;default:throw J(new qt(Sse+(e.f!=null?e.f:""+e.g)))}}function gKe(e){switch(e.g){case 0:return new Fde;case 1:return new TLe;default:throw J(new qt(jG+(e.f!=null?e.f:""+e.g)))}}function tw(e,t){switch(t.g){case 1:return g5(e.j,(_l(),Vke));case 2:return g5(e.j,(_l(),Kke));default:return Ct(),Ct(),Rs}}function pKe(e,t){var n,i;if(t){for(n=0;n<e.i;++n)if(i=c(e.g[n],374),i.kj(t))return!1;return Nn(e,t)}else return!1}function Awe(e){var t,n,i,r;for(t=new mg,r=new nx(e.b.Jc());r.b.Ob();)i=c(r.b.Pb(),697),n=bQt(i),TMt(t,t.a.length,n);return t.a}function IH(e){var t;return(e.Db&64)!=0?pT(e):(t=new Ba(pT(e)),t.a+=" (instanceClassName: ",Ys(t,e.D),t.a+=")",t.a)}function Nwe(e,t){var n;return e.i>0&&(t.length<e.i&&(n=lD(ju(t).c,e.i),t=n),mc(e.g,0,t,0,e.i)),t.length>e.i&&dr(t,e.i,null),t}function oBt(e,t,n){var i,r;return i=ue(e.p[t.i.p])+ue(e.d[t.i.p])+t.n.b+t.a.b,r=ue(e.p[n.i.p])+ue(e.d[n.i.p])+n.n.b+n.a.b,r-i}function Vi(e,t){var n,i,r;if(n=(e.i==null&&ud(e),e.i),i=t.Jj(),i!=-1){for(r=n.length;i<r;++i)if(n[i]==t)return i}return-1}function Wte(e,t){var n,i,r;return e.f>0?(e.Zj(),i=t==null?0:Ri(t),r=(i&di)%e.d.length,n=Qtt(e,r,i,t),n!=-1):!1}function RH(e){var t,n,i,r;for(r=0,n=0,i=e.length;n<i;n++)t=(en(n,e.length),e.charCodeAt(n)),t<64&&(r=id(r,$d(1,t)));return r}function cBt(e){var t,n,i,r,o;for(n=c(e.g,686),i=e.i-1;i>=0;--i)for(t=n[i],r=0;r<i;++r)if(o=n[r],Bit(e,t,o)){F5(e,i);break}}function ED(e,t){var n,i,r,o;for(o=nl(e.e.Ah(),t),n=c(e.g,123),r=0;r<e.i;++r)if(i=n[r],o.$l(i.Jk()))return!1;return!0}function bKe(e,t){var n,i;if(i=new h6(e.a.$c(t,!0)),i.a.gc()<=1)throw J(new U4);return n=i.a.ec().Jc(),n.Pb(),c(n.Pb(),41)}function lBt(e,t,n){var i,r;for(i=Yr(n,Us),r=0;Mc(i,0)!=0&&r<t;r++)i=As(i,Yr(e[r],Us)),e[r]=Hn(i),i=Im(i,32);return Hn(i)}function $H(e,t){cge();var n,i;return n=T_((xz(),xz(),EE)),i=null,t==n&&(i=c(Tc(U5e,e),622)),i||(i=new yqe(e),t==n&&lo(U5e,e,i)),i}function mKe(e){B2();var t;return t=new Cs(c(e.e.mf((Dn(),C3)),8)),e.B.Gc((uu(),s8))&&(t.a<=0&&(t.a=20),t.b<=0&&(t.b=20)),t}function uBt(e){Hq(),c(e.mf((Dn(),lp)),185).Gc((uu(),eX))&&(c(e.mf(iy),185).Ec((Ql(),Rk)),c(e.mf(lp),185).Kc(eX))}function wKe(e){var t,n;t=e.d==(H5(),M9),n=j2e(e),t&&!n||!t&&n?Ee(e.a,(Ge(),vd),(Hd(),EP)):Ee(e.a,(Ge(),vd),(Hd(),TP))}function aBt(e){var t,n,i,r;for(i=qQt(e),Rr(i,Qht),r=e.d,r.c.length=0,n=new G(i);n.a<n.c.c.length;)t=c(Q(n),458),yr(r,t.b)}function Kte(){Kte=te,Lz(),aJ=(Ge(),$b),k0t=mf(W(V(Xue,1),e4e,149,0,[uP,Mf,m3,Rb,Xv,gle,F9,q9,ple,tC,Jv,ip,Vv]))}function fBt(e,t){var n;return n=c(ql(e,su(new Ls,new rs,new mo,W(V(ml,1),_e,132,0,[(va(),bl)]))),16),n.Oc(pFe(n.gc()))}function Zf(e,t){var n,i,r;return e.f>0&&(e.Zj(),i=t==null?0:Ri(t),r=(i&di)%e.d.length,n=bve(e,r,i,t),n)?n.kd():null}function vKe(e,t){var n,i,r;return oe(t,45)?(n=c(t,45),i=n.jd(),r=lv(e.Pc(),i),T1(r,n.kd())&&(r!=null||e.Pc()._b(i))):!1}function Uc(e,t,n){var i,r,o;return e.Nj()?(i=e.i,o=e.Oj(),kD(e,i,t),r=e.Gj(3,null,t,i,o),n?n.lj(r):n=r):kD(e,e.i,t),n}function hBt(e,t,n){var i,r;return i=new _1(e.e,4,10,(r=t.c,oe(r,89)?c(r,29):(Mt(),rf)),null,$g(e,t),!1),n?n.lj(i):n=i,n}function dBt(e,t,n){var i,r;return i=new _1(e.e,3,10,null,(r=t.c,oe(r,89)?c(r,29):(Mt(),rf)),$g(e,t),!1),n?n.lj(i):n=i,n}function yKe(e){hv();var t;return(e.q?e.q:(Ct(),Ct(),Yd))._b((Ge(),Dw))?t=c(R(e,Dw),205):t=c(R(Jr(e),eC),205),t}function $0(e){ld();var t,n;return n=Hn(e),t=Hn(Vp(e,32)),t!=0?new GQe(n,t):n>10||n<0?new A1(1,n):qat[n]}function xKe(e){if(e.b==null){for(;e.a.Ob();)if(e.b=e.a.Pb(),!c(e.b,52).Gh())return!0;return e.b=null,!1}else return!0}function kKe(e,t,n){hXe(),jLe.call(this),this.a=H2(fft,[Be,mxe],[599,219],0,[iU,Hoe],2),this.c=new c5,this.g=e,this.f=t,this.d=n}function OKe(e){this.e=ye(Fn,ci,30,e.length,15,1),this.c=ye(kl,eh,30,e.length,16,1),this.b=ye(kl,eh,30,e.length,16,1),this.f=0}function gBt(e){var t,n;for(e.j=ye(ns,no,30,e.p.c.length,15,1),n=new G(e.p);n.a<n.c.c.length;)t=c(Q(n),9),e.j[t.p]=t.o.b/e.i}function SKe(e,t){var n,i;e.a=As(e.a,1),e.c=p.Math.min(e.c,t),e.b=p.Math.max(e.b,t),e.d+=t,n=t-e.f,i=e.e+n,e.f=i-e.e-n,e.e=i}function pBt(e,t){t.Tg("Min Size Postprocessing",1),ii(e,(Gd(),Yv),p.Math.max(ue(he(ke(e,Yv))),ue(he(ke(e,vC))))),t.Ug()}function jKe(e,t){e.Vj();try{e.d._c(e.e++,t),e.f=e.d.j,e.g=-1}catch(n){throw n=vr(n),oe(n,99)?J(new ua):J(n)}}function Yte(){Yte=te,Cae=new p0,ATe=new tB,NTe=new Nd,_Te=new nB,DTe=new bm,LTe=new Ky,PTe=new mm,ITe=new nN,RTe=new iN}function _we(){_we=te,W7e=new Qp(15),c2t=new Gr((Dn(),zh),W7e),u2t=new Gr(lh,15),l2t=new Gr(uae,Pe(0)),o2t=new Gr(K9,YS)}function BH(){BH=te,mC=new RY("P1_WIDTH_APPROXIMATION",0),NJ=new RY("P2_PACKING",1),fue=new RY("P3_WHITESPACE_ELIMINATION",2)}function CD(e,t){var n,i;for(i=t.length,n=0;n<i;n+=2)Ac(e,(en(n,t.length),t.charCodeAt(n)),(en(n+1,t.length),t.charCodeAt(n+1)))}function TKe(e,t,n){var i,r,o,a;for(o=t-e.e,a=n-e.f,r=new G(e.a);r.a<r.c.c.length;)i=c(Q(r),175),AD(i,i.s+o,i.t+a);e.e=t,e.f=n}function bBt(e,t){var n,i,r,o;for(o=t.b.b,e.a=new Ai,e.b=ye(Fn,ci,30,o,15,1),n=0,r=_n(t.b,0);r.b!=r.d.c;)i=c(An(r),41),i.g=n++}function av(e,t){var n,i;return i=null,xi(e,(Ge(),lJ))&&(n=c(R(e,lJ),105),n.nf(t)&&(i=n.mf(t))),i==null&&(i=R(Jr(e),t)),i}function kT(e,t){var n;QZt(t),n=c(R(e,(Ge(),eJ)),286),n&&Ee(e,eJ,pFt(n)),jg(e.c),jg(e.f),kbe(e.d),kbe(c(R(e,sJ),216))}function Zte(e,t){var n;return Oo(e)&&Oo(t)&&(n=e%t,fL<n&&n<yb)?n:_0((Iye(Oo(e)?qa(e):e,Oo(t)?qa(t):t,!0),W0))}function Dwe(e,t,n){var i,r,o,a,d;return a=e.k,d=t.k,i=n[a.g][d.g],r=he(av(e,i)),o=he(av(t,i)),p.Math.max((zt(r),r),(zt(o),o))}function Lwe(e,t,n){var i,r;i=c(Tc(l8,t),122),r=c(Tc(WC,t),122),n?(lo(l8,e,i),lo(WC,e,r)):(lo(WC,e,i),lo(l8,e,r))}function EKe(e,t){var n,i,r,o;return n=t>>5,t&=31,r=e.d+n+(t==0?0:1),i=ye(Fn,ci,30,r,15,1),pHt(i,e.a,n,t),o=new Wp(e.e,r,i),V7(o),o}function xS(e,t,n){var i,r,o;for(r=null,o=e.b;o;){if(i=e.a.Le(t,o.d),n&&i==0)return o;i>=0?o=o.a[1]:(r=o,o=o.a[0])}return r}function MD(e,t,n){var i,r,o;for(r=null,o=e.b;o;){if(i=e.a.Le(t,o.d),n&&i==0)return o;i<=0?o=o.a[0]:(r=o,o=o.a[1])}return r}function CKe(e,t,n){var i,r,o,a;for(r=c(Ut(e.b,n),172),i=0,a=new G(t.j);a.a<a.c.c.length;)o=c(Q(a),114),r[o.d.p]&&++i;return i}function mBt(e,t,n,i){var r,o,a;return r=!1,fZt(e.f,n,i)&&(qBt(e.f,e.a[t][n],e.a[t][i]),o=e.a[t],a=o[i],o[i]=o[n],o[n]=a,r=!0),r}function wBt(e,t){var n,i,r;for(i=new Ht(Vt($i(e).a.Jc(),new U));hn(i);)if(n=c(sn(i),17),r=n.d.i,r.c==t)return!1;return!0}function vBt(e){var t;t=e.a;do t=c(sn(new Ht(Vt($i(t).a.Jc(),new U))),17).d.i,t.k==(Jt(),jr)&&qe(e.e,t);while(t.k==(Jt(),jr))}function ene(e){var t;e.c!=0&&(t=c(Xe(e.a,e.b),296),t.b==1?(++e.b,e.b<e.a.c.length&&At(c(Xe(e.a,e.b),296))):--t.b,--e.c)}function MKe(e){var t,n,i,r,o;if(e==null)return null;for(o=new Fe,n=_te(e),i=0,r=n.length;i<r;++i)t=n[i],qe(o,Nc(t,!0));return o}function AKe(e){var t,n,i,r,o;if(e==null)return null;for(o=new Fe,n=_te(e),i=0,r=n.length;i<r;++i)t=n[i],qe(o,Nc(t,!0));return o}function NKe(e){var t,n,i,r,o;if(e==null)return null;for(o=new Fe,n=_te(e),i=0,r=n.length;i<r;++i)t=n[i],qe(o,Nc(t,!0));return o}function _Ke(e){var t,n;return t=c(Wt(e.a,4),131),t!=null?(n=ye(Sae,coe,420,t.length,0,1),mc(t,0,n,0,t.length),n):_2t}function tne(e,t){for(var n=0;!t[n]||t[n]=="";)n++;for(var i=t[n++];n<t.length;n++)!t[n]||t[n]==""||(i+=e+t[n]);return i}function od(e,t,n){var i,r,o,a;for(o=t+n,fs(t,o,e.length),a="",r=t;r<o;)i=p.Math.min(r+1e4,o),a+=sAt(e.slice(r,i)),r=i;return a}function yBt(){return Error.stackTraceLimit>0?(p.Error.stackTraceLimit=Error.stackTraceLimit=64,!0):"stack"in new Error}function Cu(){Cu=te,zP=new uF("PORTS",0),Qb=new uF("PORT_LABELS",1),BP=new uF("NODE_LABELS",2),cy=new uF("MINIMUM_SIZE",3)}function B1(){B1=te,rp=new Zz(th,0),f9e=new Zz("NODES_AND_EDGES",1),Cle=new Zz("PREFER_EDGES",2),Mle=new Zz("PREFER_NODES",3)}function xBt(e,t){return mh(),mh(),vf(Fg),(p.Math.abs(e-t)<=Fg||e==t||isNaN(e)&&isNaN(t)?0:e<t?-1:e>t?1:Gp(isNaN(e),isNaN(t)))>0}function Pwe(e,t){return mh(),mh(),vf(Fg),(p.Math.abs(e-t)<=Fg||e==t||isNaN(e)&&isNaN(t)?0:e<t?-1:e>t?1:Gp(isNaN(e),isNaN(t)))<0}function DKe(e,t){return mh(),mh(),vf(Fg),(p.Math.abs(e-t)<=Fg||e==t||isNaN(e)&&isNaN(t)?0:e<t?-1:e>t?1:Gp(isNaN(e),isNaN(t)))<=0}function Iwe(e){switch(e.g){case 12:case 13:case 14:case 15:case 16:case 17:case 18:case 19:case 20:return!0;default:return!1}}function Rwe(e,t,n,i,r,o){this.a=e,this.c=t,this.b=n,this.f=i,this.d=r,this.e=o,this.c>0&&this.b>0&&(this.g=JF(this.c,this.b,this.a))}function kBt(e,t){var n=e.a,i;t=String(t),n.hasOwnProperty(t)&&(i=n[t]);var r=(Ote(),Noe)[typeof i],o=r?r(i):twe(typeof i);return o}function kS(e){var t,n,i;if(i=null,t=bd in e.a,n=!t,n)throw J(new Kh("Every element must have an id."));return i=G5(C1(e,bd)),i}function nw(e){var t,n;for(n=aet(e),t=null;e.c==2;)bi(e),t||(t=(wi(),wi(),new E7(2)),wb(t,n),n=t),n.Hm(aet(e));return n}function zH(e,t){var n,i,r;return e.Zj(),i=t==null?0:Ri(t),r=(i&di)%e.d.length,n=bve(e,r,i,t),n?(MXe(e,n),n.kd()):null}function LKe(e,t){return e.e>t.e?1:e.e<t.e?-1:e.d>t.d?e.e:e.d<t.d?-t.e:e.e*Gme(e.a,t.a,e.d)}function PKe(e){return e>=48&&e<48+p.Math.min(10,10)?e-48:e>=97&&e<97?e-97+10:e>=65&&e<65?e-65+10:-1}function OBt(e,t){if(t.c==e)return t.d;if(t.d==e)return t.c;throw J(new qt("Input edge is not connected to the input port."))}function cd(e,t){if(e.a<0)throw J(new oo("Did not call before(...) or after(...) before calling add(...)."));return Dge(e,e.a,t),e}function IKe(e,t){var n,i,r;if(e.c)sb(e.c,t);else for(n=t-ku(e),r=new G(e.a);r.a<r.c.c.length;)i=c(Q(r),168),IKe(i,ku(i)+n)}function RKe(e,t){var n,i,r;if(e.c)ob(e.c,t);else for(n=t-Ml(e),r=new G(e.d);r.a<r.c.c.length;)i=c(Q(r),168),RKe(i,Ml(i)+n)}function $we(e){return Oq(),oe(e,167)?c(Ut(WP,Jat),297).Qg(e):jc(WP,ju(e))?c(Ut(WP,ju(e)),297).Qg(e):null}function tl(e){var t,n;return(e.Db&32)==0&&(n=(t=c(Wt(e,16),29),pn(t||e.fi())-pn(e.fi())),n!=0&&R5(e,32,ye(Br,Lt,1,n,5,1))),e}function R5(e,t,n){var i;(e.Db&t)!=0?n==null?JGt(e,t):(i=kne(e,t),i==-1?e.Eb=n:dr(N5(e.Eb),i,n)):n!=null&&bXt(e,t,n)}function SBt(e,t,n,i){var r,o;t.c.length!=0&&(r=aJt(n,i),o=pGt(t),lr(Yq(new jt(null,new Tt(o,1)),new zR),new Wqe(e,n,r,i)))}function jBt(e,t){var n,i,r,o;return i=e.a.length-1,n=t-e.b&i,o=e.c-t&i,r=e.c-e.b&i,jBe(n<r),n>=o?(_Rt(e,t),-1):(NRt(e,t),1)}function TBt(e,t){var n,i;for(n=(en(t,e.length),e.charCodeAt(t)),i=t+1;i<e.length&&(en(i,e.length),e.charCodeAt(i)==n);)++i;return i-t}function Bwe(e){var t,n;switch(n=e.Nc(),n.length){case 0:return UF(),Eoe;case 1:return t=n[0],new dZ(Rn(t));default:return new kee(L$t(n))}}function zwe(e){switch(typeof e){case Iie:return Dg(e);case Zye:return o5(e);case K5:return XBe(e);default:return e==null?0:Lm(e)}}function EBt(e){if(FH(h9,e))return Bt(),k9;if(FH(Bse,e))return Bt(),K0;throw J(new qt("Expecting true or false"))}function CBt(e,t){return e.e<t.e?-1:e.e>t.e?1:e.f<t.f?-1:e.f>t.f?1:Ri(e)-Ri(t)}function $Ke(e,t){var n;return ve(t)===ve(e)?!0:!oe(t,24)||(n=c(t,24),n.gc()!=e.gc())?!1:e.Hc(n)}function FH(e,t){return zt(e),t==null?!1:Ot(e,t)?!0:e.length==t.length&&Ot(e.toLowerCase(),t.toLowerCase())}function fv(e){var t,n;return Mc(e,-129)>0&&Mc(e,128)<0?(OFe(),t=Hn(e)+128,n=tke[t],!n&&(n=tke[t]=new xm(e)),n):new xm(e)}function $5(){$5=te,LE=new Xz(th,0),Qke=new Xz("INSIDE_PORT_SIDE_GROUPS",1),ice=new Xz("GROUP_MODEL_ORDER",2),rce=new Xz(Sre,3)}function qH(e){var t,n,i;if(i=e.Gh(),!i)for(t=0,n=e.Mh();n;n=n.Mh()){if(++t>ure)return n.Nh();if(i=n.Gh(),i||n==e)break}return i}function MBt(e){var t;return e.b||X9t(e,(t=nTt(e.e,e.a),!t||!Ot(Bse,Zf((!t.b&&(t.b=new yu((Mt(),Bs),Yo,t)),t.b),"qualified")))),e.c}function ABt(e){var t,n;for(n=new G(e.a.b);n.a<n.c.c.length;)if(t=c(Q(n),70),et(Ze(R(t,(Ge(),b3)))))return!0;return!1}function NBt(e,t){mee();var n,i;for(i=new Ht(Vt(sd(e).a.Jc(),new U));hn(i);)if(n=c(sn(i),17),n.d.i==t||n.c.i==t)return n;return null}function BKe(e,t,n){var i,r,o;for(o=new G(n.a);o.a<o.c.c.length;)r=c(Q(o),227),i=new yF(c(Ut(e.a,r.b),68)),qe(t.a,i),BKe(e,i,r)}function zKe(e,t,n){var i,r,o;i=t.c.p,o=t.p,e.b[i][o]=new aHe(e,t),n&&(e.a[i][o]=new o_e(t),r=c(R(t,(De(),Mw)),9),r&&St(e.d,r,t))}function _Bt(e,t,n){var i;e.a=n,e.a.Tg(Xct,1),(!t.a&&(t.a=new Me(Mn,t,10,11)),t.a).i!=0&&(i=c(ke(t,(Qd(),SC)),19),Itt(e,i)),e.a.Ug()}function FKe(e,t){var n,i;return n=t.ni(e.a),n&&(i=zn(Zf((!n.b&&(n.b=new yu((Mt(),Bs),Yo,n)),n.b),hi)),i!=null)?i:t.ve()}function DBt(e,t){var n,i;return n=t.ni(e.a),n&&(i=zn(Zf((!n.b&&(n.b=new yu((Mt(),Bs),Yo,n)),n.b),hi)),i!=null)?i:t.ve()}function LBt(e,t){(!t&&console.groupCollapsed!=null?console.groupCollapsed:console.group??console.log).call(console,e)}function PBt(e,t,n,i){i==e,c(n.b,68),c(n.b,68),c(i.b,68),c(i.b,68).c.b,Tbe(i,t,e)}function Fwe(e,t,n){t.b=p.Math.max(t.b,-n.a),t.c=p.Math.max(t.c,n.a-e.a),t.d=p.Math.max(t.d,-n.b),t.a=p.Math.max(t.a,n.b-e.b)}function IBt(e,t,n){var i,r,o;return i=c(re(ou(e.a),t),88),o=(r=i.c,r||(Mt(),Gh)),(o.Sh()?I0(e.b,c(o,52)):o)==n?AQ(i):eS(i,n),o}function qwe(e,t,n){this.c=e,this.f=new Fe,this.e=new as,this.j=new F0e,this.n=new F0e,this.b=t,this.g=new pf(t.c,t.d,t.b,t.a),this.a=n}function nne(e){var t,n,i,r;for(this.a=new Ld,this.d=new Or,this.e=0,n=e,i=0,r=n.length;i<r;++i)t=n[i],!this.f&&(this.f=t),jee(this,t)}function qKe(e){ld(),e.length==0?(this.e=0,this.d=1,this.a=W(V(Fn,1),ci,30,15,[0])):(this.e=1,this.d=e.length,this.a=e,V7(this))}function OT(e,t,n){jLe.call(this),this.a=ye(fft,mxe,219,(Yf(),W(V(Nv,1),_e,240,0,[Vo,Vc,Wo])).length,0,1),this.b=e,this.d=t,this.c=n}function RBt(e){var t,n,i,r,o,a;for(a=c(R(e,(De(),Oi)),12),Ee(a,I9,e.i.n.b),t=rd(e.e),i=t,r=0,o=i.length;r<o;++r)n=i[r],ss(n,a)}function $Bt(e){var t,n,i,r,o,a;for(n=c(R(e,(De(),Oi)),12),Ee(n,I9,e.i.n.b),t=rd(e.g),r=t,o=0,a=r.length;o<a;++o)i=r[o],ks(i,n)}function BBt(e,t){var n,i,r,o;for(i=0,r=t.gc();i<r;++i)n=t.Rl(i),oe(n,104)&&(c(n,20).Bb&nc)!=0&&(o=t.Sl(i),o!=null&&hie(e,c(o,57)))}function zBt(){var e;return VG!=0&&(e=Date.now(),e-_at>2e3&&(_at=e,WG=p.setTimeout(t8t,10))),VG++==0?(sPt((Ude(),G5e)),!0):!1}function FBt(e,t,n){var i;(eft?(J$t(e),!0):tft||ift?(T6(),!0):nft&&(T6(),!1))&&(i=new $ze(t),i.b=n,JHt(e,i))}function ine(e,t){var n;n=!e.A.Gc((Cu(),Qb))||e.q==(Zr(),xc),e.u.Gc((Ql(),eg))?n?xen(e,t):est(e,t):e.u.Gc(hp)&&(n?HZt(e,t):pst(e,t))}function HKe(e){var t;ve(ke(e,(Dn(),j3)))===ve((R1(),WJ))&&(Xi(e)?(t=c(ke(Xi(e),j3),348),ii(e,j3,t)):ii(e,j3,LC))}function qBt(e,t,n){var i,r;$ne(e.e,t,n,(Je(),Yt)),$ne(e.i,t,n,nn),e.a&&(r=c(R(t,(De(),Oi)),12),i=c(R(n,Oi),12),See(e.g,r,i))}function QKe(e,t,n){return new pf(p.Math.min(e.a,t.a)-n/2,p.Math.min(e.b,t.b)-n/2,p.Math.abs(e.a-t.a)+n,p.Math.abs(e.b-t.b)+n)}function HBt(e,t){var n,i;return n=fc(e.a.c.p,t.a.c.p),n!=0?n:(i=fc(e.a.d.i.p,t.a.d.i.p),i!=0?i:fc(t.a.d.p,e.a.d.p))}function QBt(e,t,n){var i,r,o,a;return o=t.j,a=n.j,o!=a?o.g-a.g:(i=e.f[t.p],r=e.f[n.p],i==0&&r==0?0:i==0?-1:r==0?1:ji(i,r))}function GKe(e){var t;this.d=new Fe,this.j=new as,this.g=new as,t=e.g.b,this.f=c(R(Jr(t),(Ge(),Xu)),87),this.e=ue(he(GH(t,Xv)))}function UKe(e){this.d=new Fe,this.e=new M0,this.c=ye(Fn,ci,30,(Je(),W(V($s,1),cc,64,0,[$o,Kt,nn,bn,Yt])).length,15,1),this.b=e}function Hwe(e,t,n){var i;switch(i=n[e.g][t],e.g){case 1:case 3:return new $e(0,i);case 2:case 4:return new $e(i,0);default:return null}}function GBt(e,t){var n;if(n=Tx(e.o,t),n==null)throw J(new Kh("Node did not exist in input."));return qve(e,t),lie(e,t),_ve(e,t,n),null}function JKe(e,t,n){var i,r;r=c(B_(t.f),207);try{r.kf(e,n),mpe(t.f,r)}catch(o){throw o=vr(o),oe(o,102)?(i=o,J(i)):J(o)}}function XKe(e,t,n){var i,r,o,a,d,b;return i=null,d=Bye(rT(),t),o=null,d&&(r=null,b=Rye(d,n),a=null,b!=null&&(a=e.of(d,b)),r=a,o=r),i=o,i}function rne(e,t,n,i){var r;if(r=e.length,t>=r)return r;for(t=t>0?t:0;t<r&&!Ste((en(t,e.length),e.charCodeAt(t)),n,i);t++);return t}function jh(e,t){var n,i;for(i=e.c.length,t.length<i&&(t=Tz(new Array(i),t)),n=0;n<i;++n)dr(t,n,e.c[n]);return t.length>i&&dr(t,i,null),t}function VKe(e,t){var n,i;for(i=e.a.length,t.length<i&&(t=Tz(new Array(i),t)),n=0;n<i;++n)dr(t,n,e.a[n]);return t.length>i&&dr(t,i,null),t}function UBt(e){var t;if(e==null)return null;if(t=IUt(Nc(e,!0)),t==null)throw J(new ZK("Invalid hexBinary value: '"+e+"'"));return t}function HH(e,t,n){var i;t.a.length>0&&(qe(e.b,new Kze(t.a,n)),i=t.a.length,0<i?t.a=Fa(t.a,0,0):0>i&&(t.a+=J$e(ye(Na,fd,30,-i,15,1))))}function WKe(e,t,n){var i,r,o;if(!n[t.d])for(n[t.d]=!0,r=new G(Ax(t));r.a<r.c.c.length;)i=c(Q(r),220),o=DH(i,t),WKe(e,o,n)}function KKe(e,t){var n,i,r,o;for(n=0,r=new G(t.a);r.a<r.c.c.length;)i=c(Q(r),9),o=i.o.a+i.d.c+i.d.b+e.j,n=p.Math.max(n,o);return n}function gb(e,t,n){var i,r,o;return r=c(Ut(e.e,t),395),r?(o=Yge(r,n),Z$e(e,r),o):(i=new j0e(e,t,n),oi(e.e,t,i),_He(i),null)}function JBt(e,t){var n;if(n=Ut(e.q,t),n==null)throw J(new Kh("Port did not exist in input."));return qve(e,t),lie(e,t),_ve(e,t,n),null}function sne(){return FQ(),W(V($ft,1),_e,169,0,[Ift,Pft,Rft,Eft,Tft,Cft,Nft,Aft,Mft,Lft,Dft,_ft,Sft,Oft,jft,xft,yft,kft,wft,mft,vft,Qoe])}function OS(e){switch(e.g){case 4:return new $e(0,-1);case 1:return new $e(1,0);case 2:return new $e(-1,0);default:return new $e(0,1)}}function one(e){switch(e.g){case 1:return Nr(),Ca;case 4:return Nr(),go;case 2:return Nr(),yo;case 3:return Nr(),Fh}return Nr(),qh}function XBt(e){var t;switch(t=e.fj(null),t){case 10:return 0;case 15:return 1;case 14:return 2;case 11:return 3;case 21:return 4}return-1}function Th(){Th=te,Nt=new f_("PARENTS",0),fr=new f_("NODES",1),ch=new f_("EDGES",2),Yg=new f_("PORTS",3),K1=new f_("LABELS",4)}function VBt(e,t,n,i){var r,o,a;return r=new _1(e.e,1,13,(a=t.c,a||(Mt(),Gh)),(o=n.c,o||(Mt(),Gh)),$g(e,t),!1),i?i.lj(r):i=r,i}function WBt(e,t,n){var i;switch(i=n.q.getFullYear()-G0+G0,i<0&&(i=-i),t){case 1:e.a+=i;break;case 2:qd(e,i%100,2);break;default:qd(e,i,t)}}function _n(e,t){var n,i;if(K2(t,e.b),t>=e.b>>1)for(i=e.c,n=e.b;n>t;--n)i=i.b;else for(i=e.a.a,n=0;n<t;++n)i=i.a;return new Rze(e,t,i)}function YKe(e){this.b=new Fe,this.e=new Fe,this.d=e,this.a=!k6(pi(new jt(null,new U2(new kh(e.b))),new d6(new jR))).zd((Hp(),hk))}function KBt(e){var t;e.g&&(e.c.ig()?e.f:e.a)&&(t=e.c.ig()?e.f:e.a,Xve(t.a,e.o,!0),Xve(t.a,e.o,!1),Ee(e.o,(Ge(),cr),(Zr(),Hb)))}function ZKe(e,t){var n,i,r;r=t.d.i,i=r.k,!(i==(Jt(),or)||i==Ih)&&(n=new Ht(Vt($i(r).a.Jc(),new U)),hn(n)&&oi(e.k,t,c(sn(n),17)))}function YBt(e,t){return L1(),ji((e.a.b==0?new $e(e.c.e.a,e.c.e.b):c(N6(e.a),8)).b,(t.a.b==0?new $e(t.c.e.a,t.c.e.b):c(N6(t.a),8)).b)}function ZBt(e,t){return L1(),ji((e.a.b==0?new $e(e.c.e.a,e.c.e.b):c(N6(e.a),8)).a,(t.a.b==0?new $e(t.c.e.a,t.c.e.b):c(N6(t.a),8)).a)}function ezt(e,t){return L1(),ji((e.a.b==0?new $e(e.b.e.a,e.b.e.b):c(df(e.a),8)).a,(t.a.b==0?new $e(t.b.e.a,t.b.e.b):c(df(t.a),8)).a)}function tzt(e,t){return L1(),ji((e.a.b==0?new $e(e.b.e.a,e.b.e.b):c(df(e.a),8)).b,(t.a.b==0?new $e(t.b.e.a,t.b.e.b):c(df(t.a),8)).b)}function _x(){_x=te,ap=new d_("DISTRIBUTED",0),IP=new d_("JUSTIFIED",1),J7e=new d_("BEGIN",2),PC=new d_(WS,3),X7e=new d_("END",4)}function cne(e,t){var n,i,r;return i=_t(e.Ah(),t),n=t-e.gi(),n<0?(r=e.Fh(i),r>=0?e.Th(r):Xne(e,i)):n<0?Xne(e,i):c(i,69).uk().zk(e,e.ei(),n)}function eYe(e){var t,n,i;for(i=(!e.o&&(e.o=new Al((oc(),s1),e0,e,0)),e.o),n=i.c.Jc();n.e!=n.i.gc();)t=c(n.Wj(),45),t.kd();return V_(i)}function Ve(e){var t;if(oe(e.a,4)){if(t=$we(e.a),t==null)throw J(new oo(Yct+e.b+"'. "+Kct+(j1(KP),KP.k)+Z4e));return t}else return e.a}function nzt(e){var t;if(e==null)return null;if(t=Men(Nc(e,!0)),t==null)throw J(new ZK("Invalid base64Binary value: '"+e+"'"));return t}function un(e){var t;try{return t=e.i.Xb(e.e),e.Vj(),e.g=e.e++,t}catch(n){throw n=vr(n),oe(n,99)?(e.Vj(),J(new Co)):J(n)}}function lne(e){var t;try{return t=e.c.Ti(e.e),e.Vj(),e.g=e.e++,t}catch(n){throw n=vr(n),oe(n,99)?(e.Vj(),J(new Co)):J(n)}}function QH(e){var t,n,i,r;for(r=0,n=0,i=e.length;n<i;n++)t=(en(n,e.length),e.charCodeAt(n)),t>=64&&t<128&&(r=id(r,$d(1,t-64)));return r}function GH(e,t){var n,i;return i=null,xi(e,(Dn(),Lk))&&(n=c(R(e,Lk),105),n.nf(t)&&(i=n.mf(t))),i==null&&Jr(e)&&(i=R(Jr(e),t)),i}function izt(e,t){var n;return n=c(R(e,(Ge(),ho)),79),iZ(t,$ht)?n?Ou(n):(n=new nu,Ee(e,ho,n)):n&&Ee(e,ho,null),n}function rzt(e,t){var n,i,r;for(r=new Hc(t.gc()),i=t.Jc();i.Ob();)n=c(i.Pb(),295),n.c==n.f?AS(e,n,n.c):kQt(e,n)||It(r.c,n);return r}function tYe(e,t){var n,i,r;for(n=e.o,r=c(c(Si(e.r,t),24),85).Jc();r.Ob();)i=c(r.Pb(),116),i.e.a=cFt(i,n.a),i.e.b=n.b*ue(he(i.b.mf(rU)))}function szt(e,t){var n,i,r,o;return r=e.k,n=ue(he(R(e,(De(),Aw)))),o=t.k,i=ue(he(R(t,Aw))),o!=(Jt(),Cr)?-1:r!=Cr?1:n==i?0:n<i?-1:1}function ozt(e,t){var n,i;return n=c(c(Ut(e.g,t.a),49).a,68),i=c(c(Ut(e.g,t.b),49).a,68),A0(t.a,t.b)-A0(t.a,fge(n.b))-A0(t.b,fge(i.b))}function SS(e,t){var n,i;if(++e.j,t!=null&&(n=(i=e.a.Cb,oe(i,101)?c(i,101).qh():null),IGt(t,n))){R5(e.a,4,n);return}R5(e.a,4,c(t,131))}function UH(e){switch(b1e(),this.c=new Fe,this.d=e,e.g){case 0:case 2:this.a=vpe(Hke),this.b=nr;break;case 3:case 1:this.a=Hke,this.b=Qr}}function czt(e){var t;d5(c(R(e,(Ge(),cr)),103))&&(t=e.b,ttt((ht(0,t.c.length),c(t.c[0],26))),ttt(c(Xe(t,t.c.length-1),26)))}function lzt(e,t){t.Tg("Self-Loop post-processing",1),lr(pi(pi(So(new jt(null,new Tt(e.b,16)),new UM),new uR),new aR),new fR),t.Ug()}function nYe(e,t,n){var i,r;if(e.c)Cc(e.c,e.c.i+t),Nl(e.c,e.c.j+n);else for(r=new G(e.b);r.a<r.c.c.length;)i=c(Q(r),168),nYe(i,t,n)}function uzt(e){var t,n,i;for(i=e.c.a,e.p=(Rn(i),new Fl(i)),n=new G(i);n.a<n.c.c.length;)t=c(Q(n),9),t.p=GQt(t).a;Ct(),Rr(e.p,new NR)}function azt(e,t){var n,i;if(e.j.length!=t.j.length)return!1;for(n=0,i=e.j.length;n<i;n++)if(!Ot(e.j[n],t.j[n]))return!1;return!0}function iYe(e,t){Ct();var n,i,r,o;for(n=e,o=t,oe(e,24)&&!oe(t,24)&&(n=t,o=e),r=n.Jc();r.Ob();)if(i=r.Pb(),o.Gc(i))return!1;return!0}function fzt(e,t,n,i){if(t.a<i.a)return!0;if(t.a==i.a){if(t.b<i.b)return!0;if(t.b==i.b&&e.b>n.b)return!0}return!1}function rYe(e){var t;return t=new b0,t.a+="n",e.k!=(Jt(),or)&&Zn(Zn((t.a+="(",t),lZ(e.k).toLowerCase()),")"),Zn((t.a+="_",t),_D(e)),t.a}function ST(){ST=te,r9e=new o_(t4e,0),Tle=new o_(Mre,1),Ele=new o_("LINEAR_SEGMENTS",2),iC=new o_("BRANDES_KOEPF",3),rC=new o_(bct,4)}function B5(){B5=te,xJ=new tF("P1_TREEIFICATION",0),fC=new tF("P2_NODE_ORDERING",1),hC=new tF("P3_NODE_PLACEMENT",2),dC=new tF(Sct,3)}function z5(e,t,n,i){var r;return n>=0?e.Ph(t,n,i):(e.Mh()&&(i=(r=e.Ch(),r>=0?e.xh(i):e.Mh().Qh(e,-1-r,null,i))),e.zh(t,n,i))}function Qwe(e,t){switch(t){case 7:!e.e&&(e.e=new Et(Ii,e,7,4)),En(e.e);return;case 8:!e.d&&(e.d=new Et(Ii,e,8,5)),En(e.d);return}Mwe(e,t)}function ii(e,t,n){return n==null?(!e.o&&(e.o=new Al((oc(),s1),e0,e,0)),zH(e.o,t)):(!e.o&&(e.o=new Al((oc(),s1),e0,e,0)),PD(e.o,t,n)),e}function pc(e,t){var n;n=e.dd(t);try{return n.Pb()}catch(i){throw i=vr(i),oe(i,113)?J(new zc("Can't get element "+t)):J(i)}}function sYe(e,t){var n;switch(n=c(Zs(e.b,t),129).n,t.g){case 1:e.t>=0&&(n.d=e.t);break;case 3:e.t>=0&&(n.a=e.t)}e.C&&(n.b=e.C.b,n.c=e.C.c)}function hzt(e){var t;t=e.a;do t=c(sn(new Ht(Vt(pr(t).a.Jc(),new U))),17).c.i,t.k==(Jt(),jr)&&e.b.Ec(t);while(t.k==(Jt(),jr));e.b=Eu(e.b)}function oYe(e,t){var n,i,r;for(r=e,i=new Ht(Vt(pr(t).a.Jc(),new U));hn(i);)n=c(sn(i),17),n.c.i.c&&(r=p.Math.max(r,n.c.i.c.p));return r}function dzt(e,t){var n,i,r;for(r=0,i=c(c(Si(e.r,t),24),85).Jc();i.Ob();)n=c(i.Pb(),116),r+=n.d.d+n.b.Kf().b+n.d.a,i.Ob()&&(r+=e.w);return r}function gzt(e,t){var n,i,r;for(r=0,i=c(c(Si(e.r,t),24),85).Jc();i.Ob();)n=c(i.Pb(),116),r+=n.d.b+n.b.Kf().a+n.d.c,i.Ob()&&(r+=e.w);return r}function cYe(e){var t,n,i,r;if(i=0,r=wv(e),r.c.length==0)return 1;for(n=new G(r);n.a<n.c.c.length;)t=c(Q(n),19),i+=cYe(t);return i}function lYe(e){var t,n;for(this.b=new Fe,this.c=e,this.a=!1,n=new G(e.a);n.a<n.c.c.length;)t=c(Q(n),9),this.a=this.a|t.k==(Jt(),or)}function pzt(e,t,n){var i,r,o,a;return i=e.bd(t),i!=-1&&(e.Nj()?(o=e.Oj(),a=QF(e,i),r=e.Gj(4,a,null,i,o),n?n.lj(r):n=r):QF(e,i)),n}function Ns(e,t,n){var i,r,o,a;return i=e.bd(t),i!=-1&&(e.Nj()?(o=e.Oj(),a=F5(e,i),r=e.Gj(4,a,null,i,o),n?n.lj(r):n=r):F5(e,i)),n}function bzt(e,t,n,i){var r,o,a;n.Uh(t)&&(qs(),Kee(t)?(r=c(n.Jh(t),164),BBt(e,r)):(o=(a=t,a?c(i,52).di(a):null),o&&qSt(n.Jh(t),o)))}function JH(e,t,n,i){var r,o,a;return o=_t(e.Ah(),t),r=t-e.gi(),r<0?(a=e.Fh(o),a>=0?e.Ih(a,n,!0):ow(e,o,n)):c(o,69).uk().wk(e,e.ei(),r,n,i)}function mzt(e,t,n,i){var r,o;o=t.nf((Dn(),E3))?c(t.mf(E3),24):e.j,r=u$t(o),r!=(FQ(),Qoe)&&(n&&!Iwe(r)||X2e(RUt(e,r,i),t))}function une(e,t){return Kr(e)?!!jat[t]:e.Qm?!!e.Qm[t]:P2(e)?!!Sat[t]:L2(e)?!!Oat[t]:!1}function wzt(e){switch(e.g){case 1:return Ym(),HL;case 3:return Ym(),qL;case 2:return Ym(),Uoe;case 4:return Ym(),Goe;default:return null}}function vzt(e,t,n){if(e.e)switch(e.b){case 1:AAt(e.c,t,n);break;case 0:NAt(e.c,t,n)}else wGe(e.c,t,n);e.a[t.p][n.p]=e.c.i,e.a[n.p][t.p]=e.c.e}function uYe(e){var t,n;if(e==null)return null;for(n=ye(e1,Be,201,e.length,0,2),t=0;t<n.length;t++)n[t]=c(RDt(e[t],e[t].length),201);return n}function aYe(e){var t;t=c(R(e,(Uo(),e8e)),100),Ee(e,(Li(),G9),new $e(0,0)),mit(new J_,e,t.b-ue(he(R(e,Qle))),t.d-ue(he(R(e,Gle))))}function XH(e){var t;if(Ate(e))return tq(e),e.sl()&&(t=LT(e.e,e.b,e.c,e.a,e.j),e.j=t),e.g=e.a,++e.a,++e.c,e.i=0,e.j;throw J(new Co)}function fYe(e,t,n){n.Tg("Compound graph preprocessor",1),e.a=new Qm,Wrt(e,t,null),tYt(e,t),SJt(e),Ee(t,(De(),b6e),e.a),e.a=null,sc(e.b),n.Ug()}function hYe(e,t,n){var i,r,o;for(r=new Ht(Vt((t?pr(e):$i(e)).a.Jc(),new U));hn(r);)i=c(sn(r),17),o=t?i.c.i:i.d.i,o.k==(Jt(),lc)&&zr(o,n)}function yzt(e,t){var n,i,r;for(t.Tg("Untreeify",1),n=c(R(e,(Li(),G9e)),16),r=n.Jc();r.Ob();)i=c(r.Pb(),65),ei(i.b.d,i),ei(i.c.b,i);t.Ug()}function dYe(e,t,n){var i,r,o;return i=t.i.j.c.length,xi(t,(De(),Pi))&&xi(n,Pi)?(r=cw(t,n,e.b,i),o=cw(n,t,e.b,i),r<o?-1:r>o?1:0):0}function hv(){hv=te,dJ=new Yz(th,0),Sle=new Yz("PORT_POSITION",1),v3=new Yz("NODE_SIZE_WHERE_SPACE_PERMITS",2),w3=new Yz("NODE_SIZE",3)}function Hd(){Hd=te,Vue=new m7("AUTOMATIC",0),TP=new m7(nk,1),EP=new m7(ik,2),HJ=new m7("TOP",3),FJ=new m7(vxe,4),qJ=new m7(WS,5)}function Dx(e,t,n){var i,r;if(r=e.gc(),t>=r)throw J(new F2(t,r));if(e.Qi()&&(i=e.bd(n),i>=0&&i!=t))throw J(new qt(DL));return e.Vi(t,n)}function $g(e,t){var n,i,r;if(r=GYe(e,t),r>=0)return r;if(e.ml()){for(i=0;i<e.i;++i)if(n=e.nl(c(e.g[i],57)),ve(n)===ve(t))return i}return-1}function Gwe(e,t){if(this.a=c(Rn(e),257),this.b=c(Rn(t),257),e.Cd(t)>0||e==(JK(),Ooe)||t==(XK(),Soe))throw J(new qt("Invalid range: "+mGe(e,t)))}function Uwe(e,t,n,i){PS();var r,o;for(r=0,o=0;o<n;o++)r=As(Ss(Yr(t[o],Us),Yr(i,Us)),Yr(Hn(r),Us)),e[o]=Hn(r),r=Vp(r,32);return Hn(r)}function Jwe(e,t,n){var i,r;for(r=0,i=0;i<Hoe;i++)r=p.Math.max(r,Pte(e.a[t.g][i],n));return t==(Yf(),Vc)&&e.b&&(r=p.Math.max(r,e.b.b)),r}function VH(e,t){var n,i;if(Lge(t>0),(t&-t)==t)return xs(t*lu(e,31)*4656612873077393e-25);do n=lu(e,31),i=n%t;while(n-i+(t-1)<0);return xs(i)}function xzt(e,t){var n,i,r;for(n=Dm(new Fp,e),r=new G(t);r.a<r.c.c.length;)i=c(Q(r),126),Of(uf(ff(hf(af(new Ra,0),0),n),i));return n}function AD(e,t,n){var i,r;for(JIt(e,t-e.s,n-e.t),r=new G(e.n);r.a<r.c.c.length;)i=c(Q(r),211),_K(i,i.e+t-e.s),az(i,i.f+n-e.t);e.s=t,e.t=n}function kzt(e,t,n){switch(n.g){case 1:e.a=t.a/2,e.b=0;break;case 2:e.a=t.a,e.b=t.b/2;break;case 3:e.a=t.a/2,e.b=t.b;break;case 4:e.a=0,e.b=t.b/2}}function ND(e,t,n,i){var r,o;for(r=t;r<e.c.length;r++)if(o=(ht(r,e.c.length),c(e.c[r],12)),n.Mb(o))It(i.c,o);else return r;return e.c.length}function Ozt(e){var t,n,i;for(i=c(Si(e.a,(dv(),_U)),16).Jc();i.Ob();)n=c(i.Pb(),108),t=i2e(n),B6(e,n,t[0],(Km(),Tw),0),B6(e,n,t[1],Ew,1)}function Szt(e){var t,n,i;for(i=c(Si(e.a,(dv(),DU)),16).Jc();i.Ob();)n=c(i.Pb(),108),t=i2e(n),B6(e,n,t[0],(Km(),Tw),0),B6(e,n,t[1],Ew,1)}function ane(e){switch(e.g){case 0:return null;case 1:return new tVe;case 2:return new qde;default:throw J(new qt(Sse+(e.f!=null?e.f:""+e.g)))}}function gYe(e){var t;return t=ue(he(ke(e,(Dn(),sy))))*p.Math.sqrt((!e.a&&(e.a=new Me(Mn,e,10,11)),e.a).i),new $e(t,t/ue(he(ke(e,Z9))))}function fne(e){var t;return e.f&&e.f.Sh()&&(t=c(e.f,52),e.f=c(I0(e,t),83),e.f!=t&&(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,9,8,t,e.f))),e.f}function hne(e){var t;return e.i&&e.i.Sh()&&(t=c(e.i,52),e.i=c(I0(e,t),83),e.i!=t&&(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,9,7,t,e.i))),e.i}function Hs(e){var t;return e.b&&(e.b.Db&64)!=0&&(t=e.b,e.b=c(I0(e,t),20),e.b!=t&&(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,9,21,t,e.b))),e.b}function WH(e,t){var n,i,r;e.d==null?(++e.e,++e.f):(i=t.yi(),LJt(e,e.f+1),r=(i&di)%e.d.length,n=e.d[r],!n&&(n=e.d[r]=e.bk()),n.Ec(t),++e.f)}function Xwe(e,t,n){var i;return t.rk()?!1:t.Gk()!=-2?(i=t.gk(),i==null?n==null:yi(i,n)):t.ok()==e.e.Ah()&&n==null}function KH(){var e;zu(16,Ust),e=QXe(16),this.b=ye(joe,lL,309,e,0,1),this.c=ye(joe,lL,309,e,0,1),this.a=null,this.e=null,this.i=0,this.f=e-1,this.g=0}function Eh(e){t0e.call(this),this.k=(Jt(),or),this.j=(zu(6,Sv),new Hc(6)),this.b=(zu(2,Sv),new Hc(2)),this.d=new qK,this.f=new Ide,this.a=e}function jzt(e){var t,n,i,r,o;for(n=0,r=new G(e.a);r.a<r.c.c.length;)i=c(Q(r),126),i.d=n++;return t=AHt(e),o=null,t.c.length>1&&(o=xzt(e,t)),o}function Tzt(e){var t,n,i;for(t=0,i=new G(e.c.a);i.a<i.c.c.length;)n=c(Q(i),9),t+=Vf(new Ht(Vt($i(n).a.Jc(),new U)));return t/e.c.a.c.length}function dne(e){var t,n;for(n=new cn(e);n.e!=n.i.gc();)if(t=c(un(n),88),t.e||(!t.d&&(t.d=new Ar(Ks,t,1)),t.d).i!=0)return!0;return!1}function gne(e){var t,n;for(n=new cn(e);n.e!=n.i.gc();)if(t=c(un(n),88),t.e||(!t.d&&(t.d=new Ar(Ks,t,1)),t.d).i!=0)return!0;return!1}function pYe(e,t,n,i){var r,o,a;for(r=c(Si(i?e.a:e.b,t),24),a=r.Jc();a.Ob();)if(o=c(a.Pb(),19),TQ(e,n,o))return!0;return!1}function Ezt(e,t){for(var n,i;e.Ob();)if(!t.Ob()||(n=e.Pb(),i=t.Pb(),!(ve(n)===ve(i)||n!=null&&yi(n,i))))return!1;return!t.Ob()}function Czt(e){var t,n;e.c.length<=1||(t=Nnt(e,(Je(),bn)),det(e,c(t.a,15).a,c(t.b,15).a),n=Nnt(e,Yt),det(e,c(n.a,15).a,c(n.b,15).a))}function Mzt(e,t,n){var i,r;for(r=e.a.b,i=r.c.length;i<n;i++)Up(r,r.c.length,new hc(e.a));zr(t,(ht(n-1,r.c.length),c(r.c[n-1],26))),e.b[t.p]=n}function bYe(e,t){var n,i,r;for(e.b[t.g]=1,i=_n(t.d,0);i.b!=i.d.c;)n=c(An(i),65),r=n.c,e.b[r.g]==1?ei(e.a,n):e.b[r.g]==2?e.b[r.g]=1:bYe(e,r)}function pne(){pne=te,Eje=(sie(),Oje),Tje=new Qp(8),new Gr((Dn(),zh),Tje),new Gr(lh,8),Bmt=xje,Sje=Nmt,jje=_mt,$mt=new Gr(MP,(Bt(),!1))}function Azt(e,t,n){var i;n.Tg("Shrinking tree compaction",1),et(Ze(R(t,(rS(),_E))))?(VPt(e,t.f),AJe(t.f,(i=t.c,i))):AJe(t.f,t.c),n.Ug()}function Vwe(e,t,n,i){switch(t){case 7:return!e.e&&(e.e=new Et(Ii,e,7,4)),e.e;case 8:return!e.d&&(e.d=new Et(Ii,e,8,5)),e.d}return wwe(e,t,n,i)}function bne(e){var t;return e.a&&e.a.Sh()&&(t=c(e.a,52),e.a=c(I0(e,t),146),e.a!=t&&(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,9,5,t,e.a))),e.a}function pb(e){return e<48||e>102?-1:e<=57?e-48:e<65?-1:e<=70?e-65+10:e<97?-1:e-97+10}function mne(e,t){if(e==null)throw J(new K4("null key in entry: null="+t));if(t==null)throw J(new K4("null value in entry: "+e+"=null"))}function mYe(e,t){var n;return n=W(V(ns,1),no,30,15,[Pte(e.a[0],t),Pte(e.a[1],t),Pte(e.a[2],t)]),e.d&&(n[0]=p.Math.max(n[0],n[2]),n[2]=n[0]),n}function wYe(e,t){var n;return n=W(V(ns,1),no,30,15,[TH(e.a[0],t),TH(e.a[1],t),TH(e.a[2],t)]),e.d&&(n[0]=p.Math.max(n[0],n[2]),n[2]=n[0]),n}function Wwe(e,t,n){d5(c(R(t,(Ge(),cr)),103))||(obe(e,t,Bg(t,n)),obe(e,t,Bg(t,(Je(),bn))),obe(e,t,Bg(t,Kt)),Ct(),Rr(t.j,new i_e(e)))}function vYe(e){var t,n;for(e.c||PYt(e),n=new nu,t=new G(e.a),Q(t);t.a<t.c.c.length;)ei(n,c(Q(t),415).a);return dn(n.b!=0),ba(n,n.c.b),n}function Nzt(e,t,n){var i,r,o,a,d;for(d=e.r+t,e.r+=t,e.d+=n,i=n/e.n.c.length,r=0,a=new G(e.n);a.a<a.c.c.length;)o=c(Q(a),211),CUt(o,d,i,r),++r}function _zt(e){var t,n,i;for(e.b.a.$b(),e.a=ye(nU,Lt,60,e.c.c.a.b.c.length,0,1),t=0,i=new G(e.c.c.a.b);i.a<i.c.c.length;)n=c(Q(i),60),n.f=t++}function Dzt(e){var t,n,i;for(e.b.a.$b(),e.a=ye(Zoe,Lt,84,e.c.a.a.b.c.length,0,1),t=0,i=new G(e.c.a.a.b);i.a<i.c.c.length;)n=c(Q(i),84),n.i=t++}function Lzt(e){var t,n,i,r,o;for(i=new G(e.b);i.a<i.c.c.length;)for(n=c(Q(i),26),t=0,o=new G(n.a);o.a<o.c.c.length;)r=c(Q(o),9),r.p=t++}function Pzt(e,t,n){var i,r,o,a;for(a=0,i=n/e.a.c.length,o=new G(e.a);o.a<o.c.c.length;)r=c(Q(o),175),AD(r,r.s,r.t+a*i),Nzt(r,e.d-r.r+t,i),++a}function yYe(e){var t;if(t=$Rt(e),!hn(e))throw J(new zc("position (0) must be less than the number of elements that remained ("+t+")"));return sn(e)}function Izt(e,t){var n;return e.a||(n=ye(ns,no,30,0,15,1),sx(e.b.a,new qAe(n)),ZDe(n,gXe(He.prototype.Ke,He,[])),e.a=new jze(n,e.d)),zq(e.a,t)}function xYe(e){switch(e.g){case 1:return Je(),Yt;case 4:return Je(),Kt;case 3:return Je(),nn;case 2:return Je(),bn;default:return Je(),$o}}function Rzt(e,t,n){t.k==(Jt(),or)&&n.k==jr&&(e.d=Bte(t,(Je(),bn)),e.b=Bte(t,Kt)),n.k==or&&t.k==jr&&(e.d=Bte(n,(Je(),Kt)),e.b=Bte(n,bn))}function wne(e,t){var n,i,r;for(r=Po(e,t),i=r.Jc();i.Ob();)if(n=c(i.Pb(),12),R(n,(De(),Ul))!=null||N7(new kh(n.b)))return!0;return!1}function $zt(e,t,n){n.Tg("Linear segments node placement",1),e.b=c(R(t,(De(),d3)),317),htn(e,t),RKt(e,t),rYt(e,t),qen(e),e.a=null,e.b=null,n.Ug()}function Kwe(e,t){return Cc(t,e.e+e.d+(e.c.c.length==0?0:e.b)),Nl(t,e.f),e.a=p.Math.max(e.a,t.f),e.d+=t.g+(e.c.c.length==0?0:e.b),qe(e.c,t),!0}function Bzt(e,t){var n,i,r,o,a,d;for(r=t.length-1,a=0,d=0,i=0;i<=r;i++)o=t[i],n=YHt(r,i)*Yme(1-e,r-i)*Yme(e,i),a+=o.a*n,d+=o.b*n;return new $e(a,d)}function kYe(e,t){var n,i,r,o,a;for(n=t.gc(),e.Zi(e.i+n),o=t.Jc(),a=e.i,e.i+=n,i=a;i<e.i;++i)r=o.Pb(),M7(e,i,e.Xi(i,r)),e.Ki(i,r),e.Li();return n!=0}function zzt(e,t,n){var i,r,o;return e.Nj()?(i=e.Cj(),o=e.Oj(),++e.j,e.oj(i,e.Xi(i,t)),r=e.Gj(3,null,t,i,o),n?n.lj(r):n=r):KBe(e,e.Cj(),t),n}function Fzt(e,t,n){var i,r,o;return i=c(re(gc(e.a),t),88),o=(r=i.c,oe(r,89)?c(r,29):(Mt(),rf)),((o.Db&64)!=0?I0(e.b,o):o)==n?AQ(i):eS(i,n),o}function qzt(e){var t;return e==null?null:new O0((t=Nc(e,!0),t.length>0&&(en(0,t.length),t.charCodeAt(0)==43)?(en(1,t.length+1),t.substr(1)):t))}function Hzt(e){var t;return e==null?null:new O0((t=Nc(e,!0),t.length>0&&(en(0,t.length),t.charCodeAt(0)==43)?(en(1,t.length+1),t.substr(1)):t))}function Ywe(e,t,n,i,r,o,a,d){var b,v;i&&(b=i.a[0],b&&Ywe(e,t,n,b,r,o,a,d),Tne(e,n,i.d,r,o,a,d)&&t.Ec(i),v=i.a[1],v&&Ywe(e,t,n,v,r,o,a,d))}function jT(e,t){var n,i,r,o;for(o=e.gc(),t.length<o&&(t=Tz(new Array(o),t)),r=t,i=e.Jc(),n=0;n<o;++n)dr(r,n,i.Pb());return t.length>o&&dr(t,o,null),t}function Qzt(e,t){var n,i;if(i=e.gc(),t==null){for(n=0;n<i;n++)if(e.Xb(n)==null)return n}else for(n=0;n<i;n++)if(yi(t,e.Xb(n)))return n;return-1}function vne(e,t){var n,i,r;return n=t.jd(),r=t.kd(),i=e.xc(n),!(!(ve(r)===ve(i)||r!=null&&yi(r,i))||i==null&&!e._b(n))}function Gzt(e,t){var n,i,r;return t<=22?(n=e.l&(1<<t)-1,i=r=0):t<=44?(n=e.l,i=e.m&(1<<t-22)-1,r=0):(n=e.l,i=e.m,r=e.h&(1<<t-44)-1),el(n,i,r)}function Uzt(e,t){switch(t.g){case 1:return e.f.n.d+e.t;case 3:return e.f.n.a+e.t;case 2:return e.f.n.c+e.s;case 4:return e.f.n.b+e.s;default:return 0}}function Jzt(e,t){var n,i;switch(i=t.c,n=t.a,e.b.g){case 0:n.d=e.e-i.a-i.d;break;case 1:n.d+=e.e;break;case 2:n.c=e.e-i.a-i.d;break;case 3:n.c=e.e+i.d}}function YH(){YH=te,uue=new iF(th,0),E8e=new iF(ict,1),C8e=new iF("EDGE_LENGTH_BY_POSITION",2),T8e=new iF("CROSSING_MINIMIZATION_BY_POSITION",3)}function yne(e,t){var n,i;if(n=c(Tx(e.n,t),19),n)return n;if(i=c(Tx(e.p,t),127),i)return i;throw J(new Kh("Referenced shape does not exist: "+t))}function OYe(e,t){if(e.g==-1)throw J(new Tl);e.Vj();try{e.d.fd(e.g,t),e.f=e.d.j}catch(n){throw n=vr(n),oe(n,99)?J(new ua):J(n)}}function Zwe(e,t){var n,i;if(oe(t,257)){i=c(t,257);try{return n=e.Cd(i),n==0}catch(r){if(r=vr(r),oe(r,214))return!1;throw J(r)}}return!1}function Xzt(e,t){if(e.c==t)return e.d;if(e.d==t)return e.c;throw J(new qt("Node 'one' must be either source or target of edge 'edge'."))}function Vzt(e,t){if(e.c.i==t)return e.d.i;if(e.d.i==t)return e.c.i;throw J(new qt("Node "+t+" is neither source nor target of edge "+e))}function Wzt(e,t,n){n.Tg("Self-Loop ordering",1),lr(qc(pi(pi(So(new jt(null,new Tt(t.b,16)),new EO),new mW),new U8),new lR),new MNe(e)),n.Ug()}function xne(e,t,n,i,r,o){var a,d,b,v,x;for(a=ZFt(t,n,o),d=n==(Je(),Kt)||n==Yt?-1:1,v=e[n.g],x=0;x<v.length;x++)b=v[x],b>0&&(b+=r),v[x]=a,a+=d*(b+i)}function Kzt(e){var t;for(t=0;t<e.a.c.length;t++)if(xi(c(Xe(e.a,t),9),(Ge(),ule))&&et(Ze(R(c(Xe(e.a,t),9),ule))))return!0;return!1}function SYe(e){var t,n,i;for(i=e.f,e.n=ye(ns,no,30,i,15,1),e.d=ye(ns,no,30,i,15,1),t=0;t<i;t++)n=c(Xe(e.c.b,t),26),e.n[t]=KKe(e,n),e.d[t]=int(e,n)}function jYe(e,t,n,i){var r;this.c=e,this.d=t,r=new Ai,tr(r,n,r.c.b,r.c),this.a=r,this.b=c(R(i,(Uo(),Iw)),87),this.e=ue(he(R(i,i8e))),Nst(this)}function Yzt(e,t,n){var i,r;return e.a?r=ji(n.j,t.j):r=ji(t.j,n.j),r==0?(i=fc(c(ke(t,(Qd(),jP)),15).a,c(ke(n,jP),15).a),i):r}function kne(e,t){var n,i,r;for(r=0,i=2;i<t;i<<=1)(e.Db&i)!=0&&++r;if(r==0){for(n=t<<=1;n<=128;n<<=1)if((e.Db&n)!=0)return 0;return-1}else return r}function TYe(e,t){var n,i,r,o,a;for(a=nl(e.e.Ah(),t),o=null,n=c(e.g,123),r=0;r<e.i;++r)i=n[r],a.$l(i.Jk())&&(!o&&(o=new S4),Nn(o,i));o&&bst(e,o)}function EYe(e){var t,n,i;if(!e)return null;if(e.dc())return"";for(i=new yg,n=e.Jc();n.Ob();)t=n.Pb(),Ys(i,zn(t)),i.a+=" ";return VY(i,i.a.length-1)}function CYe(e,t){var n=new Array(t),i;switch(e){case 14:case 15:i=0;break;case 16:i=!1;break;default:return n}for(var r=0;r<t;++r)n[r]=i;return n}function iw(e){var t,n,i;for(n=new G(e.a.b);n.a<n.c.c.length;)t=c(Q(n),60),t.c.$b();O1(e.d)?i=e.a.c:i=e.a.d,Qc(i,new ZAe(e)),e.c.bf(e),Ont(e)}function MYe(e){var t,n,i,r;for(n=new G(e.e.c);n.a<n.c.c.length;){for(t=c(Q(n),292),r=new G(t.b);r.a<r.c.c.length;)i=c(Q(r),448),Aye(i);utt(t)}}function AYe(e){var t,n,i;for(i=di,n=new G(e.a);n.a<n.c.c.length;)t=c(Q(n),9),xi(t,(De(),Pi))&&(i=p.Math.min(i,c(R(t,Pi),15).a));return i}function ZH(e){var t,n,i,r,o;for(i=0,o=0,r=0,n=new G(e.a);n.a<n.c.c.length;)t=c(Q(n),175),o=p.Math.max(o,t.r),i+=t.d+(r>0?e.c:0),++r;e.b=i,e.d=o}function NYe(e,t){var n;return n=W(V(ns,1),no,30,15,[Jwe(e,(Yf(),Vo),t),Jwe(e,Vc,t),Jwe(e,Wo,t)]),e.f&&(n[0]=p.Math.max(n[0],n[2]),n[2]=n[0]),n}function _Ye(e){var t;xi(e,(Ge(),_w))&&(t=c(R(e,_w),24),t.Gc((mv(),Nf))?(t.Kc(Nf),t.Ec(_f)):t.Gc(_f)&&(t.Kc(_f),t.Ec(Nf)))}function DYe(e){var t;xi(e,(Ge(),_w))&&(t=c(R(e,_w),24),t.Gc((mv(),Lf))?(t.Kc(Lf),t.Ec(Ya)):t.Gc(Ya)&&(t.Kc(Ya),t.Ec(Lf)))}function One(e,t,n,i){var r,o,a,d;return e.a==null&&KHt(e,t),a=t.b.j.c.length,o=n.d.p,d=i.d.p,r=d-1,r<0&&(r=a-1),o<=r?e.a[r]-e.a[o]:e.a[a-1]-e.a[o]+e.a[r]}function Zzt(e){var t;for(t=0;t<e.a.c.length;t++)if(xi(c(Xe(e.a,t),9),(Ge(),ale))&&!et(Ze(R(c(Xe(e.a,t),9),ale))))return!1;return!0}function eFt(e,t,n){var i,r,o,a,d;for(o=e.c,d=n?t:e,i=n?e:t,r=d.p+1;r<i.p;++r)if(a=c(Xe(o.a,r),9),!(a.k==(Jt(),Ih)||BFt(a)))return!1;return!0}function tFt(e){var t,n;if(!e.b)for(e.b=Tq(c(e.f,19).jh().i),n=new cn(c(e.f,19).jh());n.e!=n.i.gc();)t=c(un(n),158),qe(e.b,new KK(t));return e.b}function nFt(e){var t,n;if(!e.e)for(e.e=Tq(xpe(c(e.f,19)).i),n=new cn(xpe(c(e.f,19)));n.e!=n.i.gc();)t=c(un(n),127),qe(e.e,new cDe(t));return e.e}function LYe(e){var t,n;if(!e.a)for(e.a=Tq(gq(c(e.f,19)).i),n=new cn(gq(c(e.f,19)));n.e!=n.i.gc();)t=c(un(n),19),qe(e.a,new EF(e,t));return e.a}function rw(e){var t;if(!e.C&&(e.D!=null||e.B!=null))if(t=PZt(e),t)e.fl(t);else try{e.fl(null)}catch(n){if(n=vr(n),!oe(n,63))throw J(n)}return e.C}function iFt(e){switch(e.q.g){case 5:cZe(e,(Je(),Kt)),cZe(e,bn);break;case 4:Ert(e,(Je(),Kt)),Ert(e,bn);break;default:vet(e,(Je(),Kt)),vet(e,bn)}}function rFt(e){switch(e.q.g){case 5:lZe(e,(Je(),nn)),lZe(e,Yt);break;case 4:Crt(e,(Je(),nn)),Crt(e,Yt);break;default:yet(e,(Je(),nn)),yet(e,Yt)}}function Lx(e,t){var n,i,r;for(r=new as,i=e.Jc();i.Ob();)n=c(i.Pb(),37),IS(n,r.a,0),r.a+=n.f.a+t,r.b=p.Math.max(r.b,n.f.b);return r.b>0&&(r.b+=t),r}function eQ(e,t){var n,i,r;for(r=new as,i=e.Jc();i.Ob();)n=c(i.Pb(),37),IS(n,0,r.b),r.b+=n.f.b+t,r.a=p.Math.max(r.a,n.f.a);return r.a>0&&(r.a+=t),r}function PYe(e,t){var n,i;if(t.length==0)return 0;for(n=ZZ(e.a,t[0],(Je(),Yt)),n+=ZZ(e.a,t[t.length-1],nn),i=0;i<t.length;i++)n+=zHt(e,i,t);return n}function IYe(){BT(),this.c=new Fe,this.i=new Fe,this.e=new Ld,this.f=new Ld,this.g=new Ld,this.j=new Fe,this.a=new Fe,this.b=new wn,this.k=new wn}function Sne(e,t){var n,i;return e.Db>>16==6?e.Cb.Qh(e,5,uh,t):(i=Hs(c(_t((n=c(Wt(e,16),29),n||e.fi()),e.Db>>16),20)),e.Cb.Qh(e,i.n,i.f,t))}function sFt(e){U6();var t=e.e;if(t&&t.stack){var n=t.stack,i=t+`
`;return n.substring(0,i.length)==i&&(n=n.substring(i.length)),n.split(`
`)}return[]}function oFt(e){var t;return t=(FXe(),Rat),t[e>>>28]|t[e>>24&15]<<4|t[e>>20&15]<<8|t[e>>16&15]<<12|t[e>>12&15]<<16|t[e>>8&15]<<20|t[e>>4&15]<<24|t[e&15]<<28}function RYe(e){var t,n,i;e.b==e.c&&(i=e.a.length,n=Pme(p.Math.max(8,i))<<1,e.b!=0?(t=gf(e.a,n),JXe(e,t,i),e.a=t,e.b=0):M2(e.a,n),e.c=i)}function cFt(e,t){var n;return n=e.b,n.nf((Dn(),fu))?n.$f()==(Je(),Yt)?-n.Kf().a-ue(he(n.mf(fu))):t+ue(he(n.mf(fu))):n.$f()==(Je(),Yt)?-n.Kf().a:t}function _D(e){var t;return e.b.c.length!=0&&c(Xe(e.b,0),70).a?c(Xe(e.b,0),70).a:(t=cee(e),t??""+(e.c?Do(e.c.a,e,0):-1))}function tQ(e){var t;return e.f.c.length!=0&&c(Xe(e.f,0),70).a?c(Xe(e.f,0),70).a:(t=cee(e),t??""+(e.i?Do(e.i.j,e,0):-1))}function lFt(e,t){var n,i;if(t<0||t>=e.gc())return null;for(n=t;n<e.gc();++n)if(i=c(e.Xb(n),134),n==e.gc()-1||!i.o)return new Ps(Pe(n),i);return null}function e2e(e){var t,n,i,r,o;for(o=0,r=Qr,i=0,n=new G(e.a);n.a<n.c.c.length;)t=c(Q(n),175),o+=t.r+(i>0?e.c:0),r=p.Math.max(r,t.d),++i;e.e=o,e.b=r}function uFt(e){var t,n;if(!e.b)for(e.b=Tq(c(e.f,127).jh().i),n=new cn(c(e.f,127).jh());n.e!=n.i.gc();)t=c(un(n),158),qe(e.b,new KK(t));return e.b}function aFt(e,t){var n,i,r;if(t.dc())return _6(),_6(),YP;for(n=new ZBe(e,t.gc()),r=new cn(e);r.e!=r.i.gc();)i=un(r),t.Gc(i)&&Nn(n,i);return n}function t2e(e,t,n,i){return t==0?i?(!e.o&&(e.o=new Al((oc(),s1),e0,e,0)),e.o):(!e.o&&(e.o=new Al((oc(),s1),e0,e,0)),V_(e.o)):JH(e,t,n,i)}function jne(e){var t,n;if(e.rb)for(t=0,n=e.rb.i;t<n;++t)x_(re(e.rb,t));if(e.vb)for(t=0,n=e.vb.i;t<n;++t)x_(re(e.vb,t));I7((Dl(),ps),e),e.Bb|=1}function Fi(e,t,n,i,r,o,a,d,b,v,x,S,M,L){return Tet(e,t,i,null,r,o,a,d,b,v,M,!0,L),pwe(e,x),oe(e.Cb,89)&&bv(ru(c(e.Cb,89)),2),n&&hme(e,n),gwe(e,S),e}function fFt(e){var t,n;if(e==null)return null;n=0;try{n=Hu(e,ls,di)&_r}catch(i){if(i=vr(i),oe(i,133))t=Xq(e),n=t[0];else throw J(i)}return dD(n)}function hFt(e){var t,n;if(e==null)return null;n=0;try{n=Hu(e,ls,di)&_r}catch(i){if(i=vr(i),oe(i,133))t=Xq(e),n=t[0];else throw J(i)}return dD(n)}function dFt(e,t){var n,i,r;return r=e.h-t.h,r<0||(n=e.l-t.l,i=e.m-t.m+(n>>22),r+=i>>22,r<0)?!1:(e.l=n&au,e.m=i&au,e.h=r&Q1,!0)}function Tne(e,t,n,i,r,o,a){var d,b;return!(t.Re()&&(b=e.a.Le(n,i),b<0||!r&&b==0)||t.Se()&&(d=e.a.Le(n,o),d>0||!a&&d==0))}function gFt(e,t){aS();var n;if(n=e.j.g-t.j.g,n!=0)return 0;switch(e.j.g){case 2:return Jte(t,ROe)-Jte(e,ROe);case 4:return Jte(e,IOe)-Jte(t,IOe)}return 0}function pFt(e){switch(e.g){case 0:return Nce;case 1:return _ce;case 2:return Dce;case 3:return Lce;case 4:return IU;case 5:return Pce;default:return null}}function fo(e,t,n){var i,r;return i=(r=new GK,db(r,t),Gc(r,n),Nn((!e.c&&(e.c=new Me($w,e,12,10)),e.c),r),r),_g(i,0),iv(i,1),Rg(i,!0),Ig(i,!0),i}function F5(e,t){var n,i;if(t>=e.i)throw J(new JY(t,e.i));return++e.j,n=e.g[t],i=e.i-t-1,i>0&&mc(e.g,t+1,e.g,t,i),dr(e.g,--e.i,null),e.Oi(t,n),e.Li(),n}function $Ye(e,t){var n,i;return e.Db>>16==17?e.Cb.Qh(e,21,ef,t):(i=Hs(c(_t((n=c(Wt(e,16),29),n||e.fi()),e.Db>>16),20)),e.Cb.Qh(e,i.n,i.f,t))}function bFt(e){var t,n,i,r;for(Ct(),Rr(e.c,e.a),r=new G(e.c);r.a<r.c.c.length;)for(i=Q(r),n=new G(e.b);n.a<n.c.c.length;)t=c(Q(n),690),t._e(i)}function mFt(e){var t,n,i,r;for(Ct(),Rr(e.c,e.a),r=new G(e.c);r.a<r.c.c.length;)for(i=Q(r),n=new G(e.b);n.a<n.c.c.length;)t=c(Q(n),378),t._e(i)}function wFt(e){var t,n,i,r,o;for(r=di,o=null,i=new G(e.d);i.a<i.c.c.length;)n=c(Q(i),220),n.d.j^n.e.j&&(t=n.e.e-n.d.e-n.a,t<r&&(r=t,o=n));return o}function n2e(){n2e=te,pht=new wt(Txe,(Bt(),!1)),hht=new wt(Exe,100),Lke=(tT(),Koe),dht=new wt(Cxe,Lke),ght=new wt(Mxe,dd),bht=new wt(Axe,Pe(di))}function BYe(e,t){var n,i,r;for(i=new Ht(Vt(sd(e).a.Jc(),new U));hn(i);)return n=c(sn(i),17),r=c(t.Kb(n),9),new Rj(Rn(r.n.b+r.o.b/2));return Kj(),Kj(),koe}function zYe(e,t,n){var i,r,o,a,d,b,v,x;for(v=0,r=e.a[t],o=0,a=r.length;o<a;++o)for(i=r[o],x=bT(i,n),b=x.Jc();b.Ob();)d=c(b.Pb(),12),oi(e.f,d,Pe(v++))}function FYe(e,t,n){var i,r,o,a;if(n)for(r=n.a.length,i=new Xp(r),a=(i.b-i.a)*i.c<0?(x0(),wp):new S0(i);a.Ob();)o=c(a.Pb(),15),St(e,t,G5(tv(n,o.a)))}function qYe(e,t,n){var i,r,o,a;if(n)for(r=n.a.length,i=new Xp(r),a=(i.b-i.a)*i.c<0?(x0(),wp):new S0(i);a.Ob();)o=c(a.Pb(),15),St(e,t,G5(tv(n,o.a)))}function i2e(e){z0();var t;return t=c(jT(b5(e.k),ye($s,cc,64,2,0,1)),128),K6(t,0,t.length,null),t[0]==(Je(),Kt)&&t[1]==Yt&&(dr(t,0,Yt),dr(t,1,Kt)),t}function HYe(e,t,n){var i,r,o;return r=WJt(e,t,n),o=Wve(e,r),Qee(e.b),See(e,t,n),Ct(),Rr(r,new d_e(e)),i=Wve(e,r),Qee(e.b),See(e,n,t),new Ps(Pe(o),Pe(i))}function QYe(){QYe=te,lpt=Wn(new wr,(es(),Vs),(cs(),IE)),vJ=new qi("linearSegments.inputPrio",Pe(0)),yJ=new qi("linearSegments.outputPrio",Pe(0))}function vFt(e){var t,n,i,r;for(n=0,t=0,r=new cn(e);r.e!=r.i.gc();)i=c(un(r),19),n=p.Math.max(i.g+i.i,n),t=p.Math.max(i.f+i.j,t);return new $e(n,t)}function yFt(e,t){var n,i,r,o;for(o=0,i=new G(e);i.a<i.c.c.length;)n=c(Q(i),19),o+=p.Math.pow(n.g*n.f-t,2);return r=p.Math.sqrt(o/(e.c.length-1)),r}function qu(){qu=te,PP=new lF("UNKNOWN",0),n1=new lF("ABOVE",1),up=new lF("BELOW",2),LP=new lF("INLINE",3),new qi("org.eclipse.elk.labelSide",PP)}function xFt(e,t){if(oe(t,273))return m7t(e,c(t,74));if(oe(t,278))return c(t,278);throw J(new qt(m9+Mh(new Ho(W(V(Br,1),Lt,1,5,[t])))))}function GYe(e,t){var n;if(e.Wi()&&t!=null){for(n=0;n<e.i;++n)if(yi(t,e.g[n]))return n}else for(n=0;n<e.i;++n)if(ve(e.g[n])===ve(t))return n;return-1}function kFt(e,t,n){var i,r;return t.c==(Qs(),Wc)&&n.c==Jl?-1:t.c==Jl&&n.c==Wc?1:(i=MWe(t.a,e.a),r=MWe(n.a,e.a),t.c==Wc?r-i:i-r)}function B0(e,t,n){if(n&&(t<0||t>n.a.c.length))throw J(new qt("index must be >= 0 and <= layer node count"));e.c&&fl(e.c.a,e),e.c=n,n&&Up(n.a,t,e)}function UYe(e,t){this.c=new wn,this.a=e,this.b=t,this.d=c(R(e,(De(),d3)),317),ve(R(e,(Ge(),_Se)))===ve((Z_(),RU))?this.e=new vLe:this.e=new wLe}function Ene(e,t){var n,i;n=e.dd(t);try{return i=n.Pb(),n.Qb(),i}catch(r){throw r=vr(r),oe(r,113)?J(new zc("Can't remove element "+t)):J(r)}}function OFt(e,t){var n,i,r;if(i=new _z,r=new _me(i.q.getFullYear()-G0,i.q.getMonth(),i.q.getDate()),n=xKt(e,t,r),n==0||n<t.length)throw J(new qt(t));return r}function r2e(e,t){var n,i,r;for(zt(t),Lge(t!=e),r=e.b.c.length,i=t.Jc();i.Ob();)n=i.Pb(),qe(e.b,zt(n));return r!=e.b.c.length?(Qme(e,0),!0):!1}function DD(){DD=te,$ke=(Dn(),AC),new Gr(QJ,(Bt(),!0)),wht=qb,vht=C3,yht=lp,mht=E3,zke=NC,xht=iy,Rke=(n2e(),pht),Pke=dht,Ike=ght,Bke=bht,uU=hht}function SFt(e,t){if(t==e.c)return e.d;if(t==e.d)return e.c;throw J(new qt("'port' must be either the source port or target port of the edge."))}function jFt(e,t){var n,i;for(e.b=0,e.d=new yz,i=new G(t.a);i.a<i.c.c.length;)n=c(Q(i),9),c(R(n,(De(),QE)),15).a==-1&&(Urt(e,n),e.d.a.c.length=0)}function JYe(e,t){var n,i,r,o,a;for(i=0,r=0,n=0,a=new G(e);a.a<a.c.c.length;)o=c(Q(a),189),i=p.Math.max(i,o.e),r+=o.b+(n>0?t:0),++n;return new $e(i,r)}function TFt(e,t,n){var i,r;switch(r=e.o,i=e.d,t.g){case 1:return-i.d-n;case 3:return r.b+i.a+n;case 2:return r.a+i.c+n;case 4:return-i.b-n;default:return 0}}function s2e(e,t,n,i){var r,o,a,d;for(zr(t,c(i.Xb(0),26)),d=i.hd(1,i.gc()),o=c(n.Kb(t),22).Jc();o.Ob();)r=c(o.Pb(),17),a=r.c.i==t?r.d.i:r.c.i,s2e(e,a,n,d)}function XYe(e){var t;return t=new wn,xi(e,(De(),Vce))?c(R(e,Vce),93):(lr(pi(new jt(null,new Tt(e.j,16)),new VM),new _Ne(t)),Ee(e,Vce,t),t)}function EFt(e,t,n){var i;n.Tg("AbsolutPlacer",1),(!t.a&&(t.a=new Me(Mn,t,10,11)),t.a).i!=0&&(i=c(ke(t,(Qd(),SC)),19),Cc(i,i.i-Het(e,i)),zZe(e,i)),n.Ug()}function TT(e,t){var n,i;return i=null,e.nf((Dn(),Lk))&&(n=c(e.mf(Lk),105),n.nf(t)&&(i=n.mf(t))),i==null&&e.Rf()&&(i=e.Rf().mf(t)),i==null&&(i=Ve(t)),i}function o2e(e,t){var n,i;return e.Db>>16==6?e.Cb.Qh(e,6,Ii,t):(i=Hs(c(_t((n=c(Wt(e,16),29),n||(oc(),iX)),e.Db>>16),20)),e.Cb.Qh(e,i.n,i.f,t))}function c2e(e,t){var n,i;return e.Db>>16==7?e.Cb.Qh(e,1,QP,t):(i=Hs(c(_t((n=c(Wt(e,16),29),n||(oc(),dTe)),e.Db>>16),20)),e.Cb.Qh(e,i.n,i.f,t))}function l2e(e,t){var n,i;return e.Db>>16==9?e.Cb.Qh(e,9,Mn,t):(i=Hs(c(_t((n=c(Wt(e,16),29),n||(oc(),pTe)),e.Db>>16),20)),e.Cb.Qh(e,i.n,i.f,t))}function VYe(e,t){var n,i;return e.Db>>16==5?e.Cb.Qh(e,9,uX,t):(i=Hs(c(_t((n=c(Wt(e,16),29),n||(Mt(),n0)),e.Db>>16),20)),e.Cb.Qh(e,i.n,i.f,t))}function WYe(e,t){var n,i;return e.Db>>16==7?e.Cb.Qh(e,6,uh,t):(i=Hs(c(_t((n=c(Wt(e,16),29),n||(Mt(),r0)),e.Db>>16),20)),e.Cb.Qh(e,i.n,i.f,t))}function u2e(e,t){var n,i;return e.Db>>16==3?e.Cb.Qh(e,0,UP,t):(i=Hs(c(_t((n=c(Wt(e,16),29),n||(Mt(),t0)),e.Db>>16),20)),e.Cb.Qh(e,i.n,i.f,t))}function a2e(e,t){var n,i;return e.Db>>16==3?e.Cb.Qh(e,12,Mn,t):(i=Hs(c(_t((n=c(Wt(e,16),29),n||(oc(),hTe)),e.Db>>16),20)),e.Cb.Qh(e,i.n,i.f,t))}function CFt(e,t,n){var i,r,o;for(n<0&&(n=0),o=e.i,r=n;r<o;r++)if(i=re(e,r),t==null){if(i==null)return r}else if(ve(t)===ve(i)||yi(t,i))return r;return-1}function MFt(e,t){var n,i;return n=t.ni(e.a),n?(i=zn(Zf((!n.b&&(n.b=new yu((Mt(),Bs),Yo,n)),n.b),QG)),Ot(RL,i)?I7(e,Bu(t.ok())):i):null}function jS(e,t){var n,i;if(t){if(t==e)return!0;for(n=0,i=c(t,52).Mh();i&&i!=t;i=i.Mh()){if(++n>ure)return jS(e,i);if(i==e)return!0}}return!1}function AFt(e){switch(AF(),e.q.g){case 5:qet(e,(Je(),Kt)),qet(e,bn);break;case 4:Vtt(e,(Je(),Kt)),Vtt(e,bn);break;default:rst(e,(Je(),Kt)),rst(e,bn)}}function NFt(e){switch(AF(),e.q.g){case 5:ltt(e,(Je(),nn)),ltt(e,Yt);break;case 4:tYe(e,(Je(),nn)),tYe(e,Yt);break;default:sst(e,(Je(),nn)),sst(e,Yt)}}function _Ft(e){var t,n;t=c(R(e,(Sf(),sht)),15),t?(n=t.a,n==0?Ee(e,(N0(),lU),new Ute):Ee(e,(N0(),lU),new Lq(n))):Ee(e,(N0(),lU),new Lq(1))}function DFt(e,t){var n;switch(n=e.i,t.g){case 1:return-(e.n.b+e.o.b);case 2:return e.n.a-n.o.a;case 3:return e.n.b-n.o.b;case 4:return-(e.n.a+e.o.a)}return 0}function LFt(e,t){switch(e.g){case 0:return t==(Tu(),V1)?CU:MU;case 1:return t==(Tu(),V1)?CU:XL;case 2:return t==(Tu(),V1)?XL:MU;default:return XL}}function LD(e,t){var n,i,r;for(fl(e.a,t),e.e-=t.r+(e.a.c.length==0?0:e.c),r=mse,i=new G(e.a);i.a<i.c.c.length;)n=c(Q(i),175),r=p.Math.max(r,n.d);e.b=r}function PFt(e,t,n){var i,r,o;if(o=c(Ut(e.r,t),301),r=null,o)switch(o.g){case 2:i=he(Ut(e.i,t)),r=(zt(n),n+(zt(i),i));break;default:r=n}else r=n;return r}function IFt(e,t,n){var i,r,o;if(o=c(Ut(e.r,t),301),r=null,o)switch(o.g){case 2:i=he(Ut(e.j,t)),r=(zt(n),n+(zt(i),i));break;default:r=n}else r=n;return r}function Qa(e){var t;return(e.Bb&1)==0&&e.r&&e.r.Sh()&&(t=c(e.r,52),e.r=c(I0(e,t),146),e.r!=t&&(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,9,8,t,e.r))),e.r}function Cne(e,t,n){var i;return i=W(V(ns,1),no,30,15,[R2e(e,(Yf(),Vo),t,n),R2e(e,Vc,t,n),R2e(e,Wo,t,n)]),e.f&&(i[0]=p.Math.max(i[0],i[2]),i[2]=i[0]),i}function RFt(e,t){var n,i,r;if(r=rzt(e,t),r.c.length!=0)for(Rr(r,new tW),n=r.c.length,i=0;i<n;i++)AS(e,(ht(i,r.c.length),c(r.c[i],295)),GXt(e,r,i))}function ET(e,t,n){var i,r;i=t*n,oe(e.g,157)?(r=j5(e),r.f.d?r.f.a||(e.d.a+=i+_h):(e.d.d-=i+_h,e.d.a+=i+_h)):oe(e.g,9)&&(e.d.d-=i,e.d.a+=2*i)}function $Ft(e){var t,n,i,r;for(r=c(Si(e.a,(dv(),AU)),16).Jc();r.Ob();)for(i=c(r.Pb(),108),n=b5(i.k).Jc();n.Ob();)t=c(n.Pb(),64),B6(e,i,t,(Km(),ep),1)}function BFt(e){var t,n;if(e.k==(Jt(),jr)){for(n=new Ht(Vt(sd(e).a.Jc(),new U));hn(n);)if(t=c(sn(n),17),!vs(t)&&e.c==w2e(t,e).c)return!0}return!1}function zFt(e){var t,n;if(e.k==(Jt(),jr)){for(n=new Ht(Vt(sd(e).a.Jc(),new U));hn(n);)if(t=c(sn(n),17),!vs(t)&&t.c.i.c==t.d.i.c)return!0}return!1}function f2e(e,t){var n,i;return e.Db>>16==11?e.Cb.Qh(e,10,Mn,t):(i=Hs(c(_t((n=c(Wt(e,16),29),n||(oc(),gTe)),e.Db>>16),20)),e.Cb.Qh(e,i.n,i.f,t))}function KYe(e,t){var n,i;return e.Db>>16==10?e.Cb.Qh(e,11,ef,t):(i=Hs(c(_t((n=c(Wt(e,16),29),n||(Mt(),i0)),e.Db>>16),20)),e.Cb.Qh(e,i.n,i.f,t))}function YYe(e,t){var n,i;return e.Db>>16==10?e.Cb.Qh(e,12,tf,t):(i=Hs(c(_t((n=c(Wt(e,16),29),n||(Mt(),dy)),e.Db>>16),20)),e.Cb.Qh(e,i.n,i.f,t))}function ZYe(e,t){var n,i,r,o,a;if(t)for(r=t.a.length,n=new Xp(r),a=(n.b-n.a)*n.c<0?(x0(),wp):new S0(n);a.Ob();)o=c(a.Pb(),15),i=X6(t,o.a),i&&Htt(e,i)}function FFt(){w1e();var e,t;for(btn((j0(),Gt)),otn(Gt),jne(Gt),MTe=(Mt(),Gh),t=new G($Te);t.a<t.c.c.length;)e=c(Q(t),251),FS(e,Gh,null);return!0}function h2e(e,t){var n,i,r,o,a,d,b,v;return b=e.h>>19,v=t.h>>19,b!=v?v-b:(r=e.h,d=t.h,r!=d?r-d:(i=e.m,a=t.m,i!=a?i-a:(n=e.l,o=t.l,n-o)))}function eZe(e,t,n){var i,r,o,a,d;for(r=e[n.g],d=new G(t.d);d.a<d.c.c.length;)a=c(Q(d),108),o=a.i,o&&o.i==n&&(i=a.d[n.g],r[i]=p.Math.max(r[i],o.j.b))}function qFt(e,t){var n,i,r,o,a;for(i=0,r=0,n=0,a=new G(t.d);a.a<a.c.c.length;)o=c(Q(a),320),ZH(o),i=p.Math.max(i,o.b),r+=o.d+(n>0?e.b:0),++n;t.b=i,t.e=r}function tZe(e){var t,n,i;if(i=e.b,SIe(e.i,i.length)){for(n=i.length*2,e.b=ye(joe,lL,309,n,0,1),e.c=ye(joe,lL,309,n,0,1),e.f=n-1,e.i=0,t=e.a;t;t=t.c)FD(e,t,t);++e.g}}function CT(e,t){return e.b.a=p.Math.min(e.b.a,t.c),e.b.b=p.Math.min(e.b.b,t.d),e.a.a=p.Math.max(e.a.a,t.c),e.a.b=p.Math.max(e.a.b,t.d),It(e.c,t),!0}function HFt(e,t,n){var i;i=t.c.i,i.k==(Jt(),jr)?(Ee(e,(De(),sh),c(R(i,sh),12)),Ee(e,Wa,c(R(i,Wa),12))):(Ee(e,(De(),sh),t.c),Ee(e,Wa,n.d))}function QFt(e,t,n){return n.Tg(Oct,1),U7(e.b),Iu(e.b,(B5(),xJ),xJ),Iu(e.b,fC,fC),Iu(e.b,hC,hC),Iu(e.b,dC,dC),e.a=VT(e.b,t),Nqt(e,t,n.dh(1)),n.Ug(),t}function TS(e,t,n){LS();var i,r,o,a,d,b;return a=t/2,o=n/2,i=p.Math.abs(e.a),r=p.Math.abs(e.b),d=1,b=1,i>a&&(d=a/i),r>o&&(b=o/r),S1(e,p.Math.min(d,b)),e}function GFt(){_Q();var e,t;try{if(t=c(k2e((y0(),nf),b9),2092),t)return t}catch(n){if(n=vr(n),oe(n,102))e=n,ope((Bn(),e));else throw J(n)}return new Pp}function UFt(){_Q();var e,t;try{if(t=c(k2e((y0(),nf),Ja),2019),t)return t}catch(n){if(n=vr(n),oe(n,102))e=n,ope((Bn(),e));else throw J(n)}return new j4}function JFt(){YUe();var e,t;try{if(t=c(k2e((y0(),nf),Cb),2101),t)return t}catch(n){if(n=vr(n),oe(n,102))e=n,ope((Bn(),e));else throw J(n)}return new Dd}function XFt(e,t,n){var i,r;return r=e.e,e.e=t,(e.Db&4)!=0&&(e.Db&1)==0&&(i=new Ur(e,1,4,r,t),n?n.lj(i):n=i),r!=t&&(t?n=FS(e,vQ(e,t),n):n=FS(e,e.a,n)),n}function nZe(){_z.call(this),this.e=-1,this.a=!1,this.p=ls,this.k=-1,this.c=-1,this.b=-1,this.g=!1,this.f=-1,this.j=-1,this.n=-1,this.i=-1,this.d=-1,this.o=ls}function VFt(e,t){var n,i,r;if(i=e.b.d.d,e.a||(i+=e.b.d.a),r=t.b.d.d,t.a||(r+=t.b.d.a),n=ji(i,r),n==0){if(!e.a&&t.a)return-1;if(!t.a&&e.a)return 1}return n}function WFt(e,t){var n,i,r;if(i=e.b.b.d,e.a||(i+=e.b.b.a),r=t.b.b.d,t.a||(r+=t.b.b.a),n=ji(i,r),n==0){if(!e.a&&t.a)return-1;if(!t.a&&e.a)return 1}return n}function KFt(e,t){var n,i,r;if(i=e.b.g.d,e.a||(i+=e.b.g.a),r=t.b.g.d,t.a||(r+=t.b.g.a),n=ji(i,r),n==0){if(!e.a&&t.a)return-1;if(!t.a&&e.a)return 1}return n}function d2e(){d2e=te,Oht=Fc(Wn(Wn(Wn(new wr,(es(),yc),(cs(),kOe)),yc,OOe),Vs,SOe),Vs,fOe),jht=Wn(Wn(new wr,yc,rOe),yc,hOe),Sht=Fc(new wr,Vs,gOe)}function YFt(e){var t,n,i,r,o;for(t=c(R(e,(De(),qE)),93),o=e.n,i=t.Bc().Jc();i.Ob();)n=c(i.Pb(),319),r=n.i,r.c+=o.a,r.d+=o.b,n.c?Pnt(n):Int(n);Ee(e,qE,null)}function ZFt(e,t,n){var i,r;switch(r=e.b,i=r.d,t.g){case 1:return-i.d-n;case 2:return r.o.a+i.c+n;case 3:return r.o.b+i.a+n;case 4:return-i.b-n;default:return-1}}function iZe(e,t){var n,i;for(i=new G(t);i.a<i.c.c.length;)n=c(Q(i),9),e.c[n.c.p][n.p].a=RZ(e.i),e.c[n.c.p][n.p].d=ue(e.c[n.c.p][n.p].a),e.c[n.c.p][n.p].b=1}function eqt(e,t){var n,i,r,o;for(o=0,i=new G(e);i.a<i.c.c.length;)n=c(Q(i),168),o+=p.Math.pow(Ml(n)*ku(n)-t,2);return r=p.Math.sqrt(o/(e.c.length-1)),r}function tqt(e,t,n){var i,r;for(n.Tg("Interactive node placement",1),e.a=c(R(t,(De(),d3)),317),r=new G(t.b);r.a<r.c.c.length;)i=c(Q(r),26),NXt(e,i);n.Ug()}function nqt(e){var t,n,i,r,o;if(i=0,r=Vx,e.b)for(t=0;t<360;t++)n=t*.017453292519943295,dye(e,e.d,0,0,Sb,n),o=e.b.Cg(e.d),o<r&&(i=n,r=o);dye(e,e.d,0,0,Sb,i)}function iqt(e,t){var n,i,r,o;for(o=new wn,t.e=null,t.f=null,i=new G(t.i);i.a<i.c.c.length;)n=c(Q(i),68),r=c(Ut(e.g,n.a),49),n.a=iq(n.b),oi(o,n.a,r);e.g=o}function rqt(e,t,n){var i,r,o,a,d,b;for(r=t-e.e,o=r/e.d.c.length,a=0,b=new G(e.d);b.a<b.c.c.length;)d=c(Q(b),320),i=e.b-d.b+n,TKe(d,d.e+a*o,d.f),Pzt(d,o,i),++a}function rZe(e){var t;if(e.f.Zj(),e.b!=-1){if(++e.b,t=e.f.d[e.a],e.b<t.i)return;++e.a}for(;e.a<e.f.d.length;++e.a)if(t=e.f.d[e.a],t&&t.i!=0){e.b=0;return}e.b=-1}function sqt(e,t){var n,i,r;for(r=t.c.length,n=nGt(e,r==0?"":(ht(0,t.c.length),zn(t.c[0]))),i=1;i<r&&n;++i)n=c(n,52).Wh((ht(i,t.c.length),zn(t.c[i])));return n}function sZe(e,t,n,i){var r,o,a;return o=OVt(e,t,n,i),a=rye(e,o),$ne(e,t,n,i),Qee(e.b),Ct(),Rr(o,new g_e(e)),r=rye(e,o),$ne(e,n,t,i),Qee(e.b),new Ps(Pe(a),Pe(r))}function oqt(e,t){var n;t.Tg("Delaunay triangulation",1),n=new Fe,Qc(e.i,new W_e(n)),et(Ze(R(e,(rS(),_E)))),e.e?Os(e.e,xst(n)):e.e=xst(n),t.Ug()}function nQ(){nQ=te,Iue=new sF("P1_NODE_Y_PLACEMENT",0),Rue=new sF("P2_NODE_RELATIVE_PLACEMENT",1),$ue=new sF("P3_NODE_ABSOLUTE_PLACEMENT",2),Bue=new sF(Sct,3)}function cqt(e,t,n){var i,r;for(m_(e,e.j+t,e.k+n),r=new cn((!e.a&&(e.a=new Ar(Yu,e,5)),e.a));r.e!=r.i.gc();)i=c(un(r),373),YY(i,i.a+t,i.b+n);b_(e,e.b+t,e.c+n)}function g2e(e,t,n,i){switch(n){case 7:return!e.e&&(e.e=new Et(Ii,e,7,4)),Uc(e.e,t,i);case 8:return!e.d&&(e.d=new Et(Ii,e,8,5)),Uc(e.d,t,i)}return Pne(e,t,n,i)}function p2e(e,t,n,i){switch(n){case 7:return!e.e&&(e.e=new Et(Ii,e,7,4)),Ns(e.e,t,i);case 8:return!e.d&&(e.d=new Et(Ii,e,8,5)),Ns(e.d,t,i)}return wte(e,t,n,i)}function oZe(e,t,n){var i,r,o,a,d;if(n)for(o=n.a.length,i=new Xp(o),d=(i.b-i.a)*i.c<0?(x0(),wp):new S0(i);d.Ob();)a=c(d.Pb(),15),r=X6(n,a.a),r&&Fet(e,r,t)}function PD(e,t,n){var i,r,o,a,d;return e.Zj(),o=t==null?0:Ri(t),e.f>0&&(a=(o&di)%e.d.length,r=bve(e,a,o,t),r)?(d=r.ld(n),d):(i=e.ak(o,t,n),e.c.Ec(i),null)}function b2e(e,t){var n,i,r,o;switch(Pg(e,t).Il()){case 3:case 2:{for(n=Fx(t),r=0,o=n.i;r<o;++r)if(i=c(re(n,r),38),zm(uo(e,i))==5)return i;break}}return null}function lqt(e){var t,n,i,r,o;if(SIe(e.f,e.b.length))for(i=ye(Mat,lL,229,e.b.length*2,0,1),e.b=i,r=i.length-1,n=e.a;n!=e;n=n.Zd())o=c(n,229),t=o.d&r,o.a=i[t],i[t]=o}function cZe(e,t){var n,i,r,o;for(o=0,r=c(c(Si(e.r,t),24),85).Jc();r.Ob();)i=c(r.Pb(),116),o=p.Math.max(o,i.e.a+i.b.Kf().a);n=c(Zs(e.b,t),129),n.n.b=0,n.a.a=o}function lZe(e,t){var n,i,r,o;for(n=0,o=c(c(Si(e.r,t),24),85).Jc();o.Ob();)r=c(o.Pb(),116),n=p.Math.max(n,r.e.b+r.b.Kf().b);i=c(Zs(e.b,t),129),i.n.d=0,i.a.b=n}function uqt(e){var t,n,i;for(n=new G(e.p);n.a<n.c.c.length;)t=c(Q(n),9),t.k==(Jt(),or)&&(i=t.o.b,e.i=p.Math.min(e.i,i),e.g=p.Math.max(e.g,i))}function uZe(e,t,n){var i,r,o;for(o=new G(t);o.a<o.c.c.length;)i=c(Q(o),9),e.c[i.c.p][i.p].e=!1;for(r=new G(t);r.a<r.c.c.length;)i=c(Q(r),9),qye(e,i,n)}function aqt(e){var t,n;return n=c(R(e,(De(),Lc)),24),t=vF(Spt),n.Gc((Gs(),u3))&&Fu(t,Ept),n.Gc(FE)&&Fu(t,Cpt),n.Gc(D9)&&Fu(t,jpt),n.Gc(L9)&&Fu(t,Tpt),t}function m2e(e){if(e<0)throw J(new qt("The input must be positive"));return e<zje.length?ib(zje[e]):p.Math.sqrt(Sb*e)*(JRt(e,e)/Yme(2.718281828459045,e))}function ES(e,t){var n;if(e.Wi()&&t!=null){for(n=0;n<e.i;++n)if(yi(t,e.g[n]))return!0}else for(n=0;n<e.i;++n)if(ve(e.g[n])===ve(t))return!0;return!1}function fqt(e,t){if(t==null){for(;e.a.Ob();)if(c(e.a.Pb(),45).kd()==null)return!0}else for(;e.a.Ob();)if(yi(t,c(e.a.Pb(),45).kd()))return!0;return!1}function hqt(e,t){var n,i,r;return t===e?!0:oe(t,675)?(r=c(t,2025),$Ke((i=e.g,i||(e.g=new _N(e))),(n=r.g,n||(r.g=new _N(r))))):!1}function dqt(e){var t,n,i,r;for(t="$z",n="nz",r=p.Math.min(e.length,5),i=r-1;i>=0;i--)if(Ot(e[i].d,t)||Ot(e[i].d,n)){e.length>=i+1&&e.splice(0,i+1);break}return e}function ID(e,t){var n;return Oo(e)&&Oo(t)&&(n=e/t,fL<n&&n<yb)?n<0?p.Math.ceil(n):p.Math.floor(n):_0(Iye(Oo(e)?qa(e):e,Oo(t)?qa(t):t,!1))}function w2e(e,t){if(t==e.c.i)return e.d.i;if(t==e.d.i)return e.c.i;throw J(new qt("'node' must either be the source node or target node of the edge."))}function gqt(e){var t,n,i,r;if(r=c(R(e,(De(),p6e)),37),r){for(i=new as,t=Jr(e.c.i);t!=r;)n=t.e,t=Jr(n),$2(ki(ki(i,n.n),t.c),t.d.b,t.d.d);return i}return Hht}function pqt(e){var t;t=c(R(e,(De(),Nw)),339),lr(So(new jt(null,new Tt(t.d,16)),new wW),new ANe(e)),lr(pi(new jt(null,new Tt(t.d,16)),new vW),new NNe(e))}function Mne(e,t){var n,i,r,o;for(r=t?$i(e):pr(e),i=new Ht(Vt(r.a.Jc(),new U));hn(i);)if(n=c(sn(i),17),o=w2e(n,e),o.k==(Jt(),jr)&&o.c!=e.c)return o;return null}function Ane(e,t,n){var i,r;i=Nx(t.j,n.s,n.c)+Nx(n.e,t.s,t.c),r=Nx(n.j,t.s,t.c)+Nx(t.e,n.s,n.c),i==r?i>0&&(e.b+=2,e.a+=i):(e.b+=1,e.a+=p.Math.min(i,r))}function aZe(e,t){var n,i;if(i=!1,Kr(t)&&(i=!0,y5(e,new J2(zn(t)))),i||oe(t,245)&&(i=!0,y5(e,(n=mZ(c(t,245)),new c6(n)))),!i)throw J(new YK(m5e))}function bqt(e,t,n,i){var r,o,a;return r=new _1(e.e,1,10,(a=t.c,oe(a,89)?c(a,29):(Mt(),rf)),(o=n.c,oe(o,89)?c(o,29):(Mt(),rf)),$g(e,t),!1),i?i.lj(r):i=r,i}function v2e(e){var t,n;switch(c(R(Jr(e),(Ge(),SSe)),425).g){case 0:return t=e.n,n=e.o,new $e(t.a+n.a/2,t.b+n.b/2);case 1:return new Cs(e.n);default:return null}}function RD(){RD=te,$U=new p7(th,0),e6e=new p7("LEFTUP",1),n6e=new p7("RIGHTUP",2),ZOe=new p7("LEFTDOWN",3),t6e=new p7("RIGHTDOWN",4),Ice=new p7("BALANCED",5)}function mqt(e,t,n){var i,r,o;if(i=ji(e.a[t.p],e.a[n.p]),i==0){if(r=c(R(t,(De(),yk)),16),o=c(R(n,yk),16),r.Gc(n))return-1;if(o.Gc(t))return 1}return i}function wqt(e){switch(e.g){case 1:return new l$;case 2:return new fj;case 3:return new k4;case 0:return null;default:throw J(new qt(Sse+(e.f!=null?e.f:""+e.g)))}}function y2e(e,t,n){switch(t){case 1:!e.n&&(e.n=new Me(Bo,e,1,7)),En(e.n),!e.n&&(e.n=new Me(Bo,e,1,7)),ur(e.n,c(n,18));return;case 2:nS(e,zn(n));return}zme(e,t,n)}function x2e(e,t,n){switch(t){case 3:sb(e,ue(he(n)));return;case 4:ob(e,ue(he(n)));return;case 5:Cc(e,ue(he(n)));return;case 6:Nl(e,ue(he(n)));return}y2e(e,t,n)}function iQ(e,t,n){var i,r,o;o=(i=new GK,i),r=Ch(o,t,null),r&&r.mj(),Gc(o,n),Nn((!e.c&&(e.c=new Me($w,e,12,10)),e.c),o),_g(o,0),iv(o,1),Rg(o,!0),Ig(o,!0)}function k2e(e,t){var n,i,r;return n=f7(e.i,t),oe(n,244)?(r=c(n,244),r.wi()==null,r.ti()):oe(n,496)?(i=c(n,2016),r=i.b,r):null}function vqt(e,t,n,i){var r,o;return Rn(t),Rn(n),o=c(D7(e.d,t),15),$Je(!!o,"Row %s not in %s",t,e.e),r=c(D7(e.b,n),15),$Je(!!r,"Column %s not in %s",n,e.c),RVe(e,o.a,r.a,i)}function yqt(e){var t,n,i,r,o,a;for(n=null,r=e,o=0,a=r.length;o<a;++o){i=r[o];try{Q7(i)}catch(d){if(d=vr(d),oe(d,102))t=d,n?AZe(n,t):n=t;else throw J(d)}}n&&WSt(n)}function fZe(e,t,n,i,r,o,a){var d,b,v,x,S;if(x=r[o],v=o==a-1,d=v?i:0,S=CYe(d,x),i!=10&&W(V(e,a-o),t[o],n[o],d,S),!v)for(++o,b=0;b<x;++b)S[b]=fZe(e,t,n,i,r,o,a);return S}function xqt(e){var t,n,i,r,o;for(i=new sv(new Bp(e.b).a);i.b;)n=Ex(i),t=c(n.jd(),9),o=c(c(n.kd(),49).a,9),r=c(c(n.kd(),49).b,8),ki(Xf(t.n),ki(Ms(o.n),r))}function kqt(e,t){var n,i,r,o;for(o=new G(t.a);o.a<o.c.c.length;)for(r=c(Q(o),9),Zj(e.d),i=new Ht(Vt($i(r).a.Jc(),new U));hn(i);)n=c(sn(i),17),vtt(e,r,n.d.i)}function MT(e){if(e.g==-1)throw J(new Tl);e.Vj();try{e.i.ed(e.g),e.f=e.i.j,e.g<e.e&&--e.e,e.g=-1}catch(t){throw t=vr(t),oe(t,99)?J(new ua):J(t)}}function Oqt(e){var t,n,i,r;for(r=-1,i=0,n=new G(e);n.a<n.c.c.length;){if(t=c(Q(n),253),t.c==(Qs(),Jl)){r=i==0?0:i-1;break}else i==e.c.length-1&&(r=i);i+=1}return r}function Sqt(e){var t,n,i,r;for(r=0,t=0,i=new G(e.c);i.a<i.c.c.length;)n=c(Q(i),19),Cc(n,e.e+r),Nl(n,e.f),r+=n.g+e.b,t=p.Math.max(t,n.f+e.b);e.d=r-e.b,e.a=t-e.b}function Px(e){var t,n,i;for(n=new G(e.a.b);n.a<n.c.c.length;)t=c(Q(n),60),i=t.d.c,t.d.c=t.d.d,t.d.d=i,i=t.d.b,t.d.b=t.d.a,t.d.a=i,i=t.b.a,t.b.a=t.b.b,t.b.b=i;Hve(e)}function Ix(e){var t,n,i;for(n=new G(e.a.b);n.a<n.c.c.length;)t=c(Q(n),84),i=t.g.c,t.g.c=t.g.d,t.g.d=i,i=t.g.b,t.g.b=t.g.a,t.g.a=i,i=t.e.a,t.e.a=t.e.b,t.e.b=i;OQ(e)}function jqt(e){var t,n,i,r,o;for(o=b5(e.k),n=(Je(),W(V($s,1),cc,64,0,[$o,Kt,nn,bn,Yt])),i=0,r=n.length;i<r;++i)if(t=n[i],t!=$o&&!o.Gc(t))return t;return null}function Nne(e,t){var n,i;return i=c(u5(I1(pi(new jt(null,new Tt(t.j,16)),new Hy))),12),i&&(n=c(Xe(i.e,0),17),n)?c(R(n,(De(),Pi)),15).a:YLt(e.d)}function hZe(e){var t,n;return n=wQ(e),Y2(n)?null:(t=(Rn(n),c(yYe(new Ht(Vt(n.a.Jc(),new U))),74)),to(c(re((!t.b&&(t.b=new Et(vn,t,4,7)),t.b),0),83)))}function rQ(e){var t;return e.o||(t=e.sk(),t?e.o=new dpe(e,e,null):e.$k()?e.o=new e0e(e,null):zm(uo((Dl(),ps),e))==1?e.o=new jGe(e):e.o=new pZ(e,null)),e.o}function Tqt(e,t,n,i){var r,o,a,d,b;n.Uh(t)&&(r=(a=t,a?c(i,52).di(a):null),r&&(b=n.Jh(t),d=t.t,d>1||d==-1?(o=c(b,16),r.Wb(Y$t(e,o))):r.Wb(hie(e,c(b,57)))))}function Eqt(e,t,n,i){eIe();var r=xoe;function o(){for(var a=0;a<r.length;a++)r[a]()}if(e)try{_vt(o)()}catch(a){e(t,a)}else _vt(o)()}function Cqt(e,t){var n,i,r,o;for(r=(o=new an(e.b).a.vc().Jc(),new mr(o));r.a.Ob();)if(i=(n=c(r.a.Pb(),45),c(n.jd(),34)),nge(t,c(i,15))<0)return!1;return!0}function Mqt(e,t){var n,i,r,o;for(r=(o=new an(e.b).a.vc().Jc(),new mr(o));r.a.Ob();)if(i=(n=c(r.a.Pb(),45),c(n.jd(),34)),nge(t,c(i,15))>0)return!1;return!0}function Aqt(e){switch(c(R(e.b,(Ge(),mSe)),382).g){case 1:lr(qc(So(new jt(null,new Tt(e.d,16)),new _p),new am),new ER);break;case 2:fVt(e);break;case 0:tGt(e)}}function Nqt(e,t,n){var i,r,o;for(i=n,!i&&(i=new V4),i.Tg("Layout",e.a.c.length),o=new G(e.a);o.a<o.c.c.length;){if(r=c(Q(o),43),i.Zg())return;r.If(t,i.dh(1))}i.Ug()}function _qt(e,t){var n,i;for(fl(e.b,t),i=new G(e.n);i.a<i.c.c.length;)if(n=c(Q(i),211),Do(n.c,t,0)!=-1){fl(n.c,t),Sqt(n),n.c.c.length==0&&fl(e.n,n);break}lrt(e)}function dZe(e,t){var n,i,r,o,a;for(a=e.f,r=0,o=0,i=new G(e.a);i.a<i.c.c.length;)n=c(Q(i),175),AD(n,e.e,a),K_(n,t),o=p.Math.max(o,n.r),a+=n.d+e.c,r=a;e.d=o,e.b=r}function bb(){bb=te,Yue=new w7("V_TOP",0),MC=new w7("V_CENTER",1),CC=new w7("V_BOTTOM",2),Kue=new w7("H_LEFT",3),TC=new w7("H_CENTER",4),EC=new w7("H_RIGHT",5)}function O2e(e){var t;return(e.Db&64)!=0?IH(e):(t=new Ba(IH(e)),t.a+=" (abstract: ",xg(t,(e.Bb&256)!=0),t.a+=", interface: ",xg(t,(e.Bb&512)!=0),t.a+=")",t.a)}function Dqt(e){var t;e.c==null&&(t=ve(e.b)===ve(Q5e)?null:e.b,e.d=t==null?pl:QFe(t)?qjt(lHe(t)):Kr(t)?rxe:qp(ju(t)),e.a=e.a+": "+(QFe(t)?I7t(lHe(t)):t+""),e.c="("+e.d+") "+e.a)}function Lqt(){function e(){try{return new Map().entries().next().done}catch{return!1}}return typeof Map===Rie&&Map.prototype.entries&&e()?Map:uen()}function Pqt(e,t){var n,i,r,o;for(o=new os(e.e,0),n=0;o.b<o.d.gc();){if(i=ue((dn(o.b<o.d.gc()),he(o.d.Xb(o.c=o.b++)))),r=i-t,r>yse)return n;r>-1e-6&&++n}return n}function sQ(e,t,n){if(oe(t,273))return lJt(e,c(t,74),n);if(oe(t,278))return PFt(e,c(t,278),n);throw J(new qt(m9+Mh(new Ho(W(V(Br,1),Lt,1,5,[t,n])))))}function oQ(e,t,n){if(oe(t,273))return uJt(e,c(t,74),n);if(oe(t,278))return IFt(e,c(t,278),n);throw J(new qt(m9+Mh(new Ho(W(V(Br,1),Lt,1,5,[t,n])))))}function S2e(e,t){var n;t!=e.b?(n=null,e.b&&(n=vq(e.b,e,-4,n)),t&&(n=z5(t,e,-4,n)),n=DWe(e,t,n),n&&n.mj()):(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,3,t,t))}function gZe(e,t){var n;t!=e.f?(n=null,e.f&&(n=vq(e.f,e,-1,n)),t&&(n=z5(t,e,-1,n)),n=LWe(e,t,n),n&&n.mj()):(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,0,t,t))}function Iqt(e,t,n,i){var r,o,a,d;return wu(e.e)&&(r=t.Jk(),d=t.kd(),o=n.kd(),a=E0(e,1,r,d,o,r.Hk()?$S(e,r,o,oe(r,104)&&(c(r,20).Bb&Is)!=0):-1,!0),i?i.lj(a):i=a),i}function pZe(e){var t,n,i;if(e==null)return null;if(n=c(e,16),n.dc())return"";for(i=new yg,t=n.Jc();t.Ob();)Ys(i,(Ci(),zn(t.Pb()))),i.a+=" ";return VY(i,i.a.length-1)}function bZe(e){var t,n,i;if(e==null)return null;if(n=c(e,16),n.dc())return"";for(i=new yg,t=n.Jc();t.Ob();)Ys(i,(Ci(),zn(t.Pb()))),i.a+=" ";return VY(i,i.a.length-1)}function Rqt(e,t){var n,i,r,o,a;for(o=new G(t.a);o.a<o.c.c.length;)for(r=c(Q(o),9),i=new Ht(Vt(pr(r).a.Jc(),new U));hn(i);)n=c(sn(i),17),a=n.c.i.p,e.n[a]=e.n[a]-1}function $qt(e,t,n){var i,r;return i=e.c[t.c.p][t.p],r=e.c[n.c.p][n.p],i.a!=null&&r.a!=null?BZ(i.a,r.a):i.a!=null?-1:r.a!=null?1:0}function mZe(e,t){var n,i,r,o,a,d;if(t)for(o=t.a.length,n=new Xp(o),d=(n.b-n.a)*n.c<0?(x0(),wp):new S0(n);d.Ob();)a=c(d.Pb(),15),r=X6(t,a.a),i=new mDe(e),Xqe(i.a,r)}function wZe(e,t){var n,i,r,o,a,d;if(t)for(o=t.a.length,n=new Xp(o),d=(n.b-n.a)*n.c<0?(x0(),wp):new S0(n);d.Ob();)a=c(d.Pb(),15),r=X6(t,a.a),i=new lDe(e),Jqe(i.a,r)}function Bqt(e){var t;if(e!=null&&e.length>0&&ms(e,e.length-1)==33)try{return t=Rtt(Fa(e,0,e.length-1)),t.e==null}catch(n){if(n=vr(n),!oe(n,33))throw J(n)}return!1}function zqt(e,t,n){var i,r,o;switch(i=Jr(t),r=NH(i),o=new bc,_o(o,t),n.g){case 1:$r(o,jD(I5(r)));break;case 2:$r(o,I5(r))}return Ee(o,(Ge(),Qv),he(R(e,Qv))),o}function j2e(e){var t,n;return t=c(sn(new Ht(Vt(pr(e.a).a.Jc(),new U))),17),n=c(sn(new Ht(Vt($i(e.a).a.Jc(),new U))),17),et(Ze(R(t,(De(),Jg))))||et(Ze(R(n,Jg)))}function dv(){dv=te,VL=new r_("ONE_SIDE",0),_U=new r_("TWO_SIDES_CORNER",1),DU=new r_("TWO_SIDES_OPPOSING",2),NU=new r_("THREE_SIDES",3),AU=new r_("FOUR_SIDES",4)}function vZe(e,t){var n,i,r,o;for(o=new Fe,r=0,i=t.Jc();i.Ob();){for(n=Pe(c(i.Pb(),15).a+r);n.a<e.f&&!QCt(e,n.a);)n=Pe(n.a+1),++r;if(n.a>=e.f)break;It(o.c,n)}return o}function Fqt(e){var t,n;for(n=new G(e.e.b);n.a<n.c.c.length;)t=c(Q(n),26),MZt(e,t);lr(pi(So(So(new jt(null,new Tt(e.e.b,16)),new Jy),new RO),new ij),new C_e(e))}function T2e(e,t){return t?e.kj(t)?!1:e.i?e.i.lj(t):oe(t,152)?(e.i=c(t,152),!0):(e.i=new V$,e.i.lj(t)):!1}function yZe(e,t,n){var i,r,o;return i=t.Jk(),o=t.kd(),r=i.Hk()?E0(e,3,i,null,o,$S(e,i,o,oe(i,104)&&(c(i,20).Bb&Is)!=0),!0):E0(e,1,i,i.gk(),o,-1,!0),n?n.lj(r):n=r,n}function qqt(e){if(e=Nc(e,!0),Ot(h9,e)||Ot("1",e))return Bt(),k9;if(Ot(Bse,e)||Ot("0",e))return Bt(),K0;throw J(new ZK("Invalid boolean value: '"+e+"'"))}function E2e(e,t,n){var i,r,o;for(r=e.vc().Jc();r.Ob();)if(i=c(r.Pb(),45),o=i.jd(),ve(t)===ve(o)||t!=null&&yi(t,o))return n&&(i=new qz(i.jd(),i.kd()),r.Qb()),i;return null}function Hqt(e){B2();var t,n,i;e.B.Gc((uu(),YJ))&&(i=e.f.i,t=new mq(e.a.c),n=new X4,n.b=t.c-i.c,n.d=t.d-i.d,n.c=i.c+i.b-(t.c+t.b),n.a=i.d+i.a-(t.d+t.a),e.e.Yf(n))}function xZe(e,t,n,i){var r,o,a;for(a=p.Math.min(n,Vit(c(e.b,68),t,n,i)),o=new G(e.a);o.a<o.c.c.length;)r=c(Q(o),227),r!=t&&(a=p.Math.min(a,xZe(r,t,a,i)));return a}function C2e(e){var t,n,i,r;for(r=ye(e1,Be,201,e.b.c.length,0,2),i=new os(e.b,0);i.b<i.d.gc();)t=(dn(i.b<i.d.gc()),c(i.d.Xb(i.c=i.b++),26)),n=i.b-1,r[n]=q_(t.a);return r}function M2e(e,t,n){var i,r,o;i=c(Oh(e.a,n),34),i!=null&&(o=c(Oh(e.b,i),66),uv(o,n,!0)),r=c(Oh(e.b,t),66),r||(r=new Ai,gb(e.b,t,r)),tr(r,n,r.c.b,r.c),gb(e.a,n,t)}function _ne(e,t,n,i,r){var o,a,d,b;for(a=P9t(t1e(p0e(wzt(n)),i),TFt(e,n,r)),b=Bg(e,n).Jc();b.Ob();)d=c(b.Pb(),12),t[d.p]&&(o=t[d.p].i,qe(a.d,new PZ(o,awe(a,o))));Ewe(a)}function A2e(e,t){this.f=new wn,this.b=new wn,this.j=new wn,this.a=e,this.c=t,this.c>0&&zYe(this,this.c-1,(Je(),nn)),this.c<this.a.length-1&&zYe(this,this.c+1,(Je(),Yt))}function Qqt(e,t){var n,i,r,o,a;for(o=new G(t.d);o.a<o.c.c.length;)for(r=c(Q(o),108),a=c(Ut(e.c,r),117).o,i=new t5(r.b);i.a<i.c.a.length;)n=c(Y7(i),64),Nbe(r,n,a)}function N2e(e){e.length>0&&e[0].length>0&&(this.c=et(Ze(R(Jr(e[0][0]),(De(),w6e))))),this.a=ye(W0t,Be,2096,e.length,0,2),this.b=ye(K0t,Be,2097,e.length,0,2),this.d=new OWe}function Gqt(e){return e.c.length==0?!1:(ht(0,e.c.length),c(e.c[0],17)).c.i.k==(Jt(),jr)?!0:Sx(qc(new jt(null,new Tt(e,16)),new hA),new NW)}function kZe(e,t){var n,i,r,o,a,d,b;for(d=wv(t),o=t.f,b=t.g,a=p.Math.sqrt(o*o+b*b),r=0,i=new G(d);i.a<i.c.c.length;)n=c(Q(i),19),r+=kZe(e,n);return p.Math.max(r,a)}function Zr(){Zr=te,fp=new y7(nE,0),Hh=new y7("FREE",1),r8=new y7("FIXED_SIDE",2),Hb=new y7("FIXED_ORDER",3),r1=new y7("FIXED_RATIO",4),xc=new y7("FIXED_POS",5)}function Uqt(e,t){var n,i,r;if(n=t.ni(e.a),n){for(r=zn(Zf((!n.b&&(n.b=new yu((Mt(),Bs),Yo,n)),n.b),Xa)),i=1;i<(Dl(),qTe).length;++i)if(Ot(qTe[i],r))return i}return 0}function Jqt(e){var t,n,i,r,o;if(e==null)return pl;for(o=new ub(Jc,"[","]"),n=e,i=0,r=n.length;i<r;++i)t=n[i],N1(o,""+t);return o.a?o.e.length==0?o.a.a:o.a.a+(""+o.e):o.c}function Xqt(e){var t,n,i,r,o;if(e==null)return pl;for(o=new ub(Jc,"[","]"),n=e,i=0,r=n.length;i<r;++i)t=n[i],N1(o,""+t);return o.a?o.e.length==0?o.a.a:o.a.a+(""+o.e):o.c}function OZe(e){var t,n,i;for(i=new ub(Jc,"{","}"),n=e.vc().Jc();n.Ob();)t=c(n.Pb(),45),N1(i,pGe(e,t.jd())+"="+pGe(e,t.kd()));return i.a?i.e.length==0?i.a.a:i.a.a+(""+i.e):i.c}function Vqt(e){for(var t,n,i,r;!e7(e.o);)n=c(w5(e.o),49),i=c(n.a,126),t=c(n.b,220),r=DH(t,i),t.e==i?(jF(r.g,t),i.e=r.e+t.a):(jF(r.b,t),i.e=r.e-t.a),qe(e.e.a,i)}function _2e(e,t){var n,i,r;for(n=null,r=c(t.Kb(e),22).Jc();r.Ob();)if(i=c(r.Pb(),17),!n)n=i.c.i==e?i.d.i:i.c.i;else if((i.c.i==e?i.d.i:i.c.i)!=n)return!1;return!0}function SZe(e,t){var n,i,r,o,a;for(n=Ztt(e,!1,t),r=new G(n);r.a<r.c.c.length;)i=c(Q(r),135),i.d==0?(vee(i,null),yee(i,null)):(o=i.a,a=i.b,vee(i,a),yee(i,o))}function Wqt(e){var t,n;return t=new wr,Fu(t,Npt),n=c(R(e,(De(),Lc)),24),n.Gc((Gs(),FE))&&Fu(t,Ppt),n.Gc(D9)&&Fu(t,_pt),n.Gc(u3)&&Fu(t,Lpt),n.Gc(L9)&&Fu(t,Dpt),t}function q5(){q5=te,new Gr((Dn(),lh),20),Rje=new Qp(5),new Gr(zh,Rje),Vmt=AC,Kmt=Y9,new Gr(QJ,(Bt(),!1)),Ije=NC,Wmt=Y1,W9=(xwe(),Xmt),Fue=Jmt,Pje=Umt,zue=Gmt}function D2e(e,t,n){var i,r,o,a,d;for(X$t(e),r=(e.k==null&&(e.k=ye(Coe,Be,81,0,0,1)),e.k),o=0,a=r.length;o<a;++o)i=r[o],D2e(i);d=e.f,d&&D2e(d)}function Kqt(e){var t,n,i,r;for(CYt(e),n=new Ht(Vt(sd(e).a.Jc(),new U));hn(n);)t=c(sn(n),17),i=t.c.i==e,r=i?t.d:t.c,i?ss(t,null):ks(t,null),Ee(t,(De(),k6e),r),YGt(e,r.i)}function Yqt(e,t,n){var i,r,o,a;for(a=Do(e.e,t,0),o=new Pde,o.b=n,i=new os(e.e,a);i.b<i.d.gc();)r=(dn(i.b<i.d.gc()),c(i.d.Xb(i.c=i.b++),9)),r.p=n,qe(o.e,r),iu(i);return o}function Zqt(e){var t,n,i;for(n=new cn((!e.a&&(e.a=new Me(Mn,e,10,11)),e.a));n.e!=n.i.gc();)if(t=c(un(n),19),i=wQ(t),!hn(new Ht(Vt(i.a.Jc(),new U))))return t;return null}function eHt(e){var t,n,i;for(n=new cn((!e.a&&(e.a=new Me(Mn,e,10,11)),e.a));n.e!=n.i.gc();)if(t=c(un(n),19),i=wQ(t),!hn(new Ht(Vt(i.a.Jc(),new U))))return t;return null}function cQ(){cQ=te,iue=new l_("OVERLAP_REMOVAL",0),eue=new l_(Nct,1),rue=new l_("ROTATION",2),tue=new l_("GRAPH_SIZE_CALCULATION",3),nue=new l_("OUTGOING_EDGE_ANGLES",4)}function jZe(e){switch(e.g){case 0:return new j$;case 1:return new GO;default:throw J(new qt("No implementation is available for the edge router "+(e.f!=null?e.f:""+e.g)))}}function tHt(){var e;return M2t?c(NS((y0(),nf),b9),2094):(e=c(oe(Tc((y0(),nf),b9),563)?Tc(nf,b9):new Ott,563),M2t=!0,gZt(e),Mtn(e),jne(e),lo(nf,b9,e),e)}function Dne(e,t,n){var i,r;if(e.j==0)return n;if(r=c(CXe(e,t,n),76),i=n.Jk(),!i.pk()||!e.a.$l(i))throw J(new Mo("Invalid entry feature '"+i.ok().zb+"."+i.ve()+"'"));return r}function nHt(e,t){var n,i,r,o,a,d,b,v;for(d=e.a,b=0,v=d.length;b<v;++b)for(a=d[b],i=a,r=0,o=i.length;r<o;++r)if(n=i[r],ve(t)===ve(n)||t!=null&&yi(t,n))return!0;return!1}function iHt(e){var t,n,i;return Mc(e,0)>=0?(n=ID(e,QQ),i=Zte(e,QQ)):(t=Vp(e,1),n=ID(t,5e8),i=Zte(t,5e8),i=As($d(i,1),Yr(e,1))),id($d(i,32),Yr(n,Us))}function rHt(e,t,n,i){var r,o,a,d,b;for(r=null,o=0,d=new G(t);d.a<d.c.c.length;)a=c(Q(d),19),b=a.i+a.g,e<a.j+a.f+i&&(r?n.i-b<n.i-o&&(r=a):r=a,o=r.i+r.g);return r?o+i:0}function sHt(e,t,n,i){var r,o,a,d,b;for(o=null,r=0,d=new G(t);d.a<d.c.c.length;)a=c(Q(d),19),b=a.j+a.f,e<a.i+a.g+i&&(o?n.j-b<n.j-r&&(o=a):o=a,r=o.j+o.f);return o?r+i:0}function oHt(e){var t,n,i;for(t=!1,i=e.b.c.length,n=0;n<i;n++)Bme(c(Xe(e.b,n),439))?!t&&n+1<i&&Bme(c(Xe(e.b,n+1),439))&&(t=!0,c(Xe(e.b,n),439).a=!0):t=!1}function cHt(e,t,n,i,r){var o,a;for(o=0,a=0;a<r;a++)o=As(o,Ha(Yr(t[a],Us),Yr(i[a],Us))),e[a]=Hn(o),o=Im(o,32);for(;a<n;a++)o=As(o,Yr(t[a],Us)),e[a]=Hn(o),o=Im(o,32)}function lHt(e,t){PS();var n,i;for(i=(ld(),YG),n=e;t>1;t>>=1)(t&1)!=0&&(i=Ox(i,n)),n.d==1?n=Ox(n,n):n=new qKe(Oit(n.a,n.d,ye(Fn,ci,30,n.d<<1,15,1)));return i=Ox(i,n),i}function L2e(){L2e=te;var e,t,n,i;for(bke=ye(ns,no,30,25,15,1),mke=ye(ns,no,30,33,15,1),i=152587890625e-16,t=32;t>=0;t--)mke[t]=i,i*=.5;for(n=1,e=24;e>=0;e--)bke[e]=n,n*=.5}function uHt(e){var t,n;if(et(Ze(ke(e,(Ge(),qv))))){for(n=new Ht(Vt(z1(e).a.Jc(),new U));hn(n);)if(t=c(sn(n),74),sw(t)&&et(Ze(ke(t,Lb))))return!0}return!1}function TZe(e){var t,n,i,r;for(t=new Ai,n=new Ai,r=_n(e,0);r.b!=r.d.c;)i=c(An(r),12),i.e.c.length==0?tr(n,i,n.c.b,n.c):tr(t,i,t.c.b,t.c);return Eu(t).Fc(n),t}function EZe(e,t){var n,i,r;Sr(e.f,t)&&(t.b=e,i=t.c,Do(e.j,i,0)!=-1||qe(e.j,i),r=t.d,Do(e.j,r,0)!=-1||qe(e.j,r),n=t.a.b,n.c.length!=0&&(!e.i&&(e.i=new GKe(e)),NIt(e.i,n)))}function aHt(e){var t,n,i,r,o;return n=e.c.d,i=n.j,r=e.d.d,o=r.j,i==o?n.p<r.p?0:1:AH(i)==o?0:fwe(i)==o?1:(t=e.b,Cl(t.b,AH(i))?0:1)}function lQ(e,t){var n,i,r,o,a,d;r=e,a=K7(r,"layoutOptions"),!a&&(a=K7(r,Ilt)),a&&(d=a,i=null,d&&(i=(o=ate(d,ye(nt,Be,2,0,6,1)),new lY(d,o))),i&&(n=new WRe(d,t),ws(i,n)))}function to(e){if(oe(e,209))return c(e,19);if(oe(e,196))return yh(c(e,127));throw J(e?new vg("Only support nodes and ports."):new K4(Glt))}function fHt(e,t,n,i){return(t>=0&&Ot(e.substr(t,3),"GMT")||t>=0&&Ot(e.substr(t,3),"UTC"))&&(n[0]=t+3),mye(e,n,i)}function hHt(e,t){var n,i,r,o,a;for(o=e.g.a,a=e.g.b,i=new G(e.d);i.a<i.c.c.length;)n=c(Q(i),70),r=n.n,r.a=o,e.i==(Je(),Kt)?r.b=a+e.j.b-n.o.b:r.b=a,ki(r,t),o+=n.o.a+e.e}function CZe(e,t,n){if(e.b)throw J(new oo("The task is already done."));return e.p!=null?!1:(e.p=t,e.r=n,e.k&&(e.o=(Og(),Ss(Zo(Date.now()),qg))),!0)}function P2e(e){var t,n,i,r,o,a,d;return d=new W4,n=e.Og(),r=n!=null,r&&I6(d,bd,e.Og()),i=e.ve(),o=i!=null,o&&I6(d,hi,e.ve()),t=e.Ng(),a=t!=null,a&&I6(d,"description",e.Ng()),d}function MZe(e,t,n){var i,r,o;return o=e.q,e.q=t,(e.Db&4)!=0&&(e.Db&1)==0&&(r=new Ur(e,1,9,o,t),n?n.lj(r):n=r),t?(i=t.c,i!=e.r&&(n=e.Wk(i,n))):e.r&&(n=e.Wk(null,n)),n}function dHt(e,t,n){var i,r,o,a,d;for(n=(d=t,z5(d,e.e,-1-e.c,n)),a=wpe(e.a),o=(i=new sv(new Bp(a.a).a),new bz(i));o.a.b;)r=c(Ex(o.a).jd(),88),n=FS(r,vQ(r,e.a),n);return n}function gHt(e,t,n){var i,r,o,a,d;for(n=(d=t,vq(d,e.e,-1-e.c,n)),a=wpe(e.a),o=(i=new sv(new Bp(a.a).a),new bz(i));o.a.b;)r=c(Ex(o.a).jd(),88),n=FS(r,vQ(r,e.a),n);return n}function pHt(e,t,n,i){var r,o,a;if(i==0)mc(t,0,e,n,e.length-n);else for(a=32-i,e[e.length-1]=0,o=e.length-1;o>n;o--)e[o]|=t[o-n-1]>>>a,e[o-1]=t[o-n-1]<<i;for(r=0;r<n;r++)e[r]=0}function bHt(e){var t,n,i,r,o;for(t=0,n=0,o=e.Jc();o.Ob();)i=c(o.Pb(),116),t=p.Math.max(t,i.d.b),n=p.Math.max(n,i.d.c);for(r=e.Jc();r.Ob();)i=c(r.Pb(),116),i.d.b=t,i.d.c=n}function mHt(e){var t,n,i,r,o;for(n=0,t=0,o=e.Jc();o.Ob();)i=c(o.Pb(),116),n=p.Math.max(n,i.d.d),t=p.Math.max(t,i.d.a);for(r=e.Jc();r.Ob();)i=c(r.Pb(),116),i.d.d=n,i.d.a=t}function Lne(e,t,n,i,r){var o,a;o=c(ql(pi(t.Mc(),new Y8),su(new Ls,new rs,new mo,W(V(ml,1),_e,132,0,[(va(),bl)]))),16),NT(o),a=c(lb(e.b,n,i),16),r==0?a.ad(0,o):a.Fc(o)}function wHt(e,t,n){n.Tg("Grow Tree",1),e.b=t.f,et(Ze(R(t,(rS(),_E))))?(e.c=new h0,lQe(e,null)):e.c=new h0,e.a=!1,fnt(e,t.f),Ee(t,Ske,(Bt(),!!e.a)),n.Ug()}function mb(e){var t;this.d=new wn,this.c=e.c,this.e=e.d,this.b=e.b,this.f=new PFe(e.e),this.a=e.a,e.f?this.g=e.f:this.g=(t=c(Jf(VP),10),new ha(t,c(gf(t,t.length),10),0))}function I2e(e){var t,n,i,r;for(t=null,r=new G(e.Pf());r.a<r.c.c.length;)i=c(Q(r),190),n=new pf(i.Jf().a,i.Jf().b,i.Kf().a,i.Kf().b),t?AT(t,n):t=n;return!t&&(t=new c5),t}function Pne(e,t,n,i){var r,o;return n==1?(!e.n&&(e.n=new Me(Bo,e,1,7)),Uc(e.n,t,i)):(o=c(_t((r=c(Wt(e,16),29),r||e.fi()),n),69),o.uk().xk(e,tl(e),n-pn(e.fi()),t,i))}function Ine(e,t,n){var i,r,o,a,d;for(i=n.gc(),e.Zi(e.i+i),d=e.i-t,d>0&&mc(e.g,t,e.g,t+i,d),a=n.Jc(),e.i+=i,r=0;r<i;++r)o=a.Pb(),M7(e,t,e.Xi(t,o)),e.Ki(t,o),e.Li(),++t;return i!=0}function Ch(e,t,n){var i;return t!=e.q?(e.q&&(n=vq(e.q,e,-10,n)),t&&(n=z5(t,e,-10,n)),n=MZe(e,t,n)):(e.Db&4)!=0&&(e.Db&1)==0&&(i=new Ur(e,1,9,t,t),n?n.lj(i):n=i),n}function Rne(e,t,n,i){return d0e((n&ad)==0,"flatMap does not support SUBSIZED characteristic"),d0e((n&4)==0,"flatMap does not support SORTED characteristic"),Rn(e),Rn(t),new cGe(e,t,n,i)}function AZe(e,t){ipe(t,"Cannot suppress a null exception."),N_(t!=e,"Exception can not suppress itself."),!e.i&&(e.k==null?e.k=W(V(Coe,1),Be,81,0,[t]):e.k[e.k.length]=t)}function vHt(e,t){var n;if(n=x$e(e.b.$f(),t.b.$f()),n!=0)return n;switch(e.b.$f().g){case 1:case 2:return fc(e.b.Lf(),t.b.Lf());case 3:case 4:return fc(t.b.Lf(),e.b.Lf())}return 0}function yHt(e){var t,n,i;for(i=e.e.c.length,e.a=H2(Fn,[Be,ci],[54,30],15,[i,i],2),n=new G(e.c);n.a<n.c.c.length;)t=c(Q(n),292),e.a[t.c.a][t.d.a]+=c(R(t,(Sf(),dk)),15).a}function xHt(e,t){var n,i,r,o,a;if(e==null)return null;for(a=ye(Na,fd,30,2*t,15,1),i=0,r=0;i<t;++i)n=e[i]>>4&15,o=e[i]&15,a[r++]=bTe[n],a[r++]=bTe[o];return od(a,0,a.length)}function dl(e){var t,n;return e>=Is?(t=hL+(e-Is>>10&1023)&_r,n=56320+(e-Is&1023)&_r,String.fromCharCode(t)+(""+String.fromCharCode(n))):String.fromCharCode(e&_r)}function kHt(e,t){B2();var n,i,r,o;return r=c(c(Si(e.r,t),24),85),r.gc()>=2?(i=c(r.Jc().Pb(),116),n=e.u.Gc((Ql(),$C)),o=e.u.Gc(Rk),!i.a&&!n&&(r.gc()==2||o)):!1}function NZe(e,t,n,i,r){var o,a,d;for(o=Ent(e,t,n,i,r),d=!1;!o;)bQ(e,r,!0),d=!0,o=Ent(e,t,n,i,r);d&&bQ(e,r,!1),a=kte(r),a.c.length!=0&&(e.d&&e.d.Fg(a),NZe(e,r,n,i,a))}function uQ(){uQ=te,pue=new rF("NODE_SIZE_REORDERER",0),hue=new rF("INTERACTIVE_NODE_REORDERER",1),gue=new rF("MIN_SIZE_PRE_PROCESSOR",2),due=new rF("MIN_SIZE_POST_PROCESSOR",3)}function aQ(){aQ=te,dae=new v7(th,0),R7e=new v7("DIRECTED",1),B7e=new v7("UNDIRECTED",2),P7e=new v7("ASSOCIATION",3),$7e=new v7("GENERALIZATION",4),I7e=new v7("DEPENDENCY",5)}function OHt(e,t){var n;if(!yh(e))throw J(new oo(klt));switch(n=yh(e),t.g){case 1:return-(e.j+e.f);case 2:return e.i-n.g;case 3:return e.j-n.f;case 4:return-(e.i+e.g)}return 0}function SHt(e,t,n){var i,r,o;return i=t.Jk(),o=t.kd(),r=i.Hk()?E0(e,4,i,o,null,$S(e,i,o,oe(i,104)&&(c(i,20).Bb&Is)!=0),!0):E0(e,i.rk()?2:1,i,o,i.gk(),-1,!0),n?n.lj(r):n=r,n}function CS(e,t){var n,i;for(zt(t),i=e.b.c.length,qe(e.b,t);i>0;){if(n=i,i=(i-1)/2|0,e.a.Le(Xe(e.b,i),t)<=0)return Su(e.b,n,t),!0;Su(e.b,n,Xe(e.b,i))}return Su(e.b,i,t),!0}function R2e(e,t,n,i){var r,o;if(r=0,n)r=TH(e.a[n.g][t.g],i);else for(o=0;o<iU;o++)r=p.Math.max(r,TH(e.a[o][t.g],i));return t==(Yf(),Vc)&&e.b&&(r=p.Math.max(r,e.b.a)),r}function jHt(e,t){var n,i,r,o,a,d;return r=e.i,o=t.i,!r||!o||r.i!=o.i||r.i==(Je(),nn)||r.i==(Je(),Yt)?!1:(a=r.g.a,n=a+r.j.a,d=o.g.a,i=d+o.j.a,a<=i&&n>=d)}function _Ze(e){switch(e.g){case 0:return new v$;case 1:return new PA;default:throw J(new qt("No implementation is available for the width approximator "+(e.f!=null?e.f:""+e.g)))}}function $2e(e,t,n,i){var r;if(r=!1,Kr(i)&&(r=!0,I6(t,n,zn(i))),r||L2(i)&&(r=!0,$2e(e,t,n,i)),r||oe(i,245)&&(r=!0,Zp(t,n,c(i,245))),!r)throw J(new YK(m5e))}function THt(e,t){var n,i,r;if(n=t.ni(e.a),n&&(r=Zf((!n.b&&(n.b=new yu((Mt(),Bs),Yo,n)),n.b),Ua),r!=null)){for(i=1;i<(Dl(),zTe).length;++i)if(Ot(zTe[i],r))return i}return 0}function EHt(e,t){var n,i,r;if(n=t.ni(e.a),n&&(r=Zf((!n.b&&(n.b=new yu((Mt(),Bs),Yo,n)),n.b),Ua),r!=null)){for(i=1;i<(Dl(),FTe).length;++i)if(Ot(FTe[i],r))return i}return 0}function DZe(e,t){var n,i,r,o;if(zt(t),o=e.a.gc(),o<t.gc())for(n=e.a.ec().Jc();n.Ob();)i=n.Pb(),t.Gc(i)&&n.Qb();else for(r=t.Jc();r.Ob();)i=r.Pb(),e.a.Ac(i)!=null;return o!=e.a.gc()}function LZe(e){var t,n;switch(n=Ms(Lo(W(V(Vr,1),Be,8,0,[e.i.n,e.n,e.a]))),t=e.i.d,e.j.g){case 1:n.b-=t.d;break;case 2:n.a+=t.c;break;case 3:n.b+=t.a;break;case 4:n.a-=t.b}return n}function CHt(e){var t;for(t=(_5(),c(sn(new Ht(Vt(pr(e).a.Jc(),new U))),17).c.i);t.k==(Jt(),jr);)Ee(t,(De(),iP),(Bt(),!0)),t=c(sn(new Ht(Vt(pr(t).a.Jc(),new U))),17).c.i}function $ne(e,t,n,i){var r,o,a,d;for(d=bT(t,i),a=d.Jc();a.Ob();)r=c(a.Pb(),12),e.d[r.p]=e.d[r.p]+e.c[n.p];for(d=bT(n,i),o=d.Jc();o.Ob();)r=c(o.Pb(),12),e.d[r.p]=e.d[r.p]-e.c[t.p]}function B2e(e,t,n){var i,r;for(r=new cn((!e.a&&(e.a=new Me(Mn,e,10,11)),e.a));r.e!=r.i.gc();)i=c(un(r),19),aa(i,i.i+t,i.j+n);ws((!e.b&&(e.b=new Me(Ii,e,12,3)),e.b),new MRe(t,n))}function MHt(e,t,n,i){var r,o;for(o=t,r=o.d==null||e.a.Le(n.d,o.d)>0?1:0;o.a[r]!=n;)o=o.a[r],r=e.a.Le(n.d,o.d)>0?1:0;o.a[r]=i,i.b=n.b,i.a[0]=n.a[0],i.a[1]=n.a[1],n.a[0]=null,n.a[1]=null}function AHt(e){var t,n,i,r;for(t=new Fe,n=ye(kl,eh,30,e.a.c.length,16,1),npe(n,n.length),r=new G(e.a);r.a<r.c.c.length;)i=c(Q(r),126),n[i.d]||(It(t.c,i),WKe(e,i,n));return t}function PZe(e,t){var n,i,r,o,a;for(r=t==1?tce:ece,i=r.a.ec().Jc();i.Ob();)for(n=c(i.Pb(),87),a=c(Si(e.f.c,n),24).Jc();a.Ob();)o=c(a.Pb(),49),fl(e.b.b,o.b),fl(e.b.a,c(o.b,84).d)}function NHt(e,t){var n;t.Tg("Hierarchical port position processing",1),n=e.b,n.c.length>0&&wit((ht(0,n.c.length),c(n.c[0],26)),e),n.c.length>1&&wit(c(Xe(n,n.c.length-1),26),e),t.Ug()}function _Ht(e){Ql();var t,n;return t=_i(eg,W(V(KJ,1),_e,282,0,[hp])),!(hD(xq(t,e))>1||(n=_i($C,W(V(KJ,1),_e,282,0,[RC,Rk])),hD(xq(n,e))>1))}function z2e(e,t){var n;n=Tc((y0(),nf),e),oe(n,496)?lo(nf,e,new e$e(this,t)):lo(nf,e,this),zne(this,t),t==(x6(),CTe)?(this.wb=c(this,2017),c(t,2019)):this.wb=(j0(),Gt)}function DHt(e){var t,n,i;if(e==null)return null;for(t=null,n=0;n<qC.length;++n)try{return PIe(qC[n],e)}catch(r){if(r=vr(r),oe(r,33))i=r,t=i;else throw J(r)}throw J(new Uq(t))}function IZe(){IZe=te,Gat=W(V(nt,1),Be,2,6,["Sun","Mon","Tue","Wed","Thu","Fri","Sat"]),Uat=W(V(nt,1),Be,2,6,["Jan","Feb","Mar","Apr",Z5,"Jun","Jul","Aug","Sep","Oct","Nov","Dec"])}function R(e,t){var n,i;return i=(!e.q&&(e.q=new wn),Ut(e.q,t)),i??(n=t.Rg(),oe(n,4)&&(n==null?(!e.q&&(e.q=new wn),E5(e.q,t)):(!e.q&&(e.q=new wn),oi(e.q,t,n))),n)}function es(){es=te,Cf=new i_("P1_CYCLE_BREAKING",0),Zd=new i_("P2_LAYERING",1),vc=new i_("P3_NODE_ORDERING",2),yc=new i_("P4_NODE_PLACEMENT",3),Vs=new i_("P5_EDGE_ROUTING",4)}function LHt(e,t){nT();var n;if(e.c==t.c){if(e.b==t.b||sIt(e.b,t.b)){if(n=q8t(e.b)?1:-1,e.a&&!t.a)return n;if(!e.a&&t.a)return-n}return fc(e.b.g,t.b.g)}else return ji(e.c,t.c)}function PHt(e,t,n,i){var r,o,a,d,b;return a=HYe(e.a,t,n),d=c(a.a,15).a,o=c(a.b,15).a,i&&(b=c(R(t,(De(),Ul)),9),r=c(R(n,Ul),9),b&&r&&(wGe(e.b,b,r),d+=e.b.i,o+=e.b.e)),d>o}function RZe(e,t){var n,i,r;if(q2e(e,t))return!0;for(i=new G(t);i.a<i.c.c.length;)if(n=c(Q(i),19),r=hZe(n),TQ(e,n,r)||CWe(e,n)-e.g<=e.a)return!0;return!1}function $D(){$D=te,BJ=(sie(),Oje),Due=Rmt,_ue=Imt,bje=Dmt,Nue=Pmt,pje=new Qp(8),Tmt=new Gr((Dn(),zh),pje),Emt=new Gr(lh,8),Cmt=xje,dje=Mmt,gje=Amt,jmt=new Gr(MP,(Bt(),!1))}function fQ(){fQ=te,Jje=new Qp(15),wwt=new Gr((Dn(),zh),Jje),vwt=new Gr(lh,15),Xje=new Gr(NP,Pe(0)),Qje=Twt,bwt=qb,mwt=lp,Hje=new Gr(K9,Zct),Gje=AC,Uje=C3,Wue=Owt,pwt=CP}function IHt(e,t){if(oe(t,209))return GBt(e,c(t,19));if(oe(t,196))return JBt(e,c(t,127));if(t)return null;throw J(new qt(m9+Mh(new Ho(W(V(Br,1),Lt,1,5,[t])))))}function RHt(e,t){if(oe(t,363))return PLt(e,c(t,158));if(oe(t,273))return QKt(e,c(t,74));if(t)return null;throw J(new qt(m9+Mh(new Ho(W(V(Br,1),Lt,1,5,[t])))))}function Bne(e){if((!e.b&&(e.b=new Et(vn,e,4,7)),e.b).i!=1||(!e.c&&(e.c=new Et(vn,e,5,8)),e.c).i!=1)throw J(new qt(Jlt));return to(c(re((!e.b&&(e.b=new Et(vn,e,4,7)),e.b),0),83))}function $Ze(e){if((!e.b&&(e.b=new Et(vn,e,4,7)),e.b).i!=1||(!e.c&&(e.c=new Et(vn,e,5,8)),e.c).i!=1)throw J(new qt(Jlt));return to(c(re((!e.c&&(e.c=new Et(vn,e,5,8)),e.c),0),83))}function F2e(e,t,n){var i,r,o;if(++e.j,r=e.Cj(),t>=r||t<0)throw J(new zc(toe+t+Tb+r));if(n>=r||n<0)throw J(new zc(noe+n+Tb+r));return t!=n?i=(o=e.Aj(n),e.oj(t,o),o):i=e.vj(n),i}function BZe(e){var t,n,i;if(i=e,e)for(t=0,n=e.Bh();n;n=n.Bh()){if(++t>ure)return BZe(n);if(i=n,n==e)throw J(new oo("There is a cycle in the containment hierarchy of "+e))}return i}function Mh(e){var t,n,i;for(i=new ub(Jc,"[","]"),n=e.Jc();n.Ob();)t=n.Pb(),N1(i,ve(t)===ve(e)?"(this Collection)":t==null?pl:jo(t));return i.a?i.e.length==0?i.a.a:i.a.a+(""+i.e):i.c}function q2e(e,t){var n,i;if(i=!1,t.gc()<2)return!1;for(n=0;n<t.gc();n++)n<t.gc()-1?i=i|TQ(e,c(t.Xb(n),19),c(t.Xb(n+1),19)):i=i|TQ(e,c(t.Xb(n),19),c(t.Xb(0),19));return i}function zZe(e,t){var n,i,r;if(r=(!t.e&&(t.e=new Et(Ii,t,7,4)),t.e).i,r>0)for(i=0;i<r;i++)n=c(re(H6(c(re((!t.e&&(t.e=new Et(Ii,t,7,4)),t.e),i),74)),0),19),Cc(n,n.i+t.i),zZe(e,n)}function FZe(e,t){var n;t!=e.a?(n=null,e.a&&(n=c(e.a,52).Qh(e,4,uh,n)),t&&(n=c(t,52).Oh(e,4,uh,n)),n=Zme(e,t,n),n&&n.mj()):(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,1,t,t))}function H2e(e,t){var n;t!=e.e?(e.e&&dUe(wpe(e.e),e),t&&(!t.b&&(t.b=new pz(new UK)),Oze(t.b,e)),n=XFt(e,t,null),n&&n.mj()):(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,4,t,t))}function $Ht(e){var t,n,i,r;if(hx(c(R(e.b,(Ge(),Xu)),87)))return 0;for(t=0,i=new G(e.a);i.a<i.c.c.length;)n=c(Q(i),9),n.k==(Jt(),or)&&(r=n.o.a,t=p.Math.max(t,r));return t}function BHt(e,t){var n;n=t.o,O1(e.f)?(e.j.a=p.Math.max(e.j.a,n.a),e.j.b+=n.b,e.d.c.length>1&&(e.j.b+=e.e)):(e.j.a+=n.a,e.j.b=p.Math.max(e.j.b,n.b),e.d.c.length>1&&(e.j.a+=e.e))}function z0(){z0=te,fdt=W(V($s,1),cc,64,0,[(Je(),Kt),nn,bn]),adt=W(V($s,1),cc,64,0,[nn,bn,Yt]),hdt=W(V($s,1),cc,64,0,[bn,Yt,Kt]),ddt=W(V($s,1),cc,64,0,[Yt,Kt,nn])}function qZe(e){var t,n,i,r,o,a,d,b,v;for(this.a=uYe(e),this.b=new Fe,n=e,i=0,r=n.length;i<r;++i)for(t=n[i],o=new Fe,qe(this.b,o),d=t,b=0,v=d.length;b<v;++b)a=d[b],qe(o,new Fl(a.j))}function zHt(e,t,n){var i,r,o;return o=0,i=n[t],t<n.length-1&&(r=n[t+1],e.b[t]?(o=Ttn(e.d,i,r),o+=ZZ(e.a,i,(Je(),nn)),o+=ZZ(e.a,r,Yt)):o=zLt(e.a,i,r)),e.c[t]&&(o+=lLt(e.a,i)),o}function FHt(e,t,n,i,r){var o,a,d,b;for(b=null,d=new G(i);d.a<d.c.c.length;)if(a=c(Q(d),447),a!=n&&Do(a.e,r,0)!=-1){b=a;break}o=Iee(r),ks(o,n.b),ss(o,b.b),St(e.a,r,new PF(o,t,n.f))}function HZe(e){for(;e.g.c!=0&&e.d.c!=0;)hZ(e.g).c>hZ(e.d).c?(e.i+=e.g.c,ene(e.d)):hZ(e.d).c>hZ(e.g).c?(e.e+=e.d.c,ene(e.g)):(e.i+=MFe(e.g),e.e+=MFe(e.d),ene(e.g),ene(e.d))}function qHt(e,t,n){var i,r,o,a;for(o=t.q,a=t.r,new eb((Wf(),sp),t,o,1),new eb(sp,o,a,1),r=new G(n);r.a<r.c.c.length;)i=c(Q(r),117),i!=o&&i!=t&&i!=a&&(Dye(e.a,i,t),Dye(e.a,i,a))}function QZe(e,t,n,i){e.a.d=p.Math.min(t,n),e.a.a=p.Math.max(t,i)-e.a.d,t<n?(e.b=.5*(t+n),e.g=xse*e.b+.9*t,e.f=xse*e.b+.9*n):(e.b=.5*(t+i),e.g=xse*e.b+.9*i,e.f=xse*e.b+.9*t)}function HHt(e){var t,n,i,r;if(e.b!=0){for(t=new Ai,r=_n(e,0);r.b!=r.d.c;)i=c(An(r),41),Os(t,xte(i)),n=i.e,n.a=c(R(i,(Li(),wP)),15).a,n.b=c(R(i,vP),15).a;return t}return new Ai}function QHt(e){switch(c(R(e,(Ge(),Ro)),166).g){case 1:Ee(e,Ro,(Tu(),UE));break;case 2:Ee(e,Ro,(Tu(),Db));break;case 3:Ee(e,Ro,(Tu(),GE));break;case 4:Ee(e,Ro,(Tu(),V1))}}function GHt(e,t,n){var i;n.Tg("Self-Loop routing",1),i=E$t(t),bF(R(t,(Bq(),jC))),lr(qc(pi(pi(So(new jt(null,new Tt(t.b,16)),new CO),new hR),new dR),new gR),new WIe(e,i)),n.Ug()}function MS(){MS=te,BE=new b7(th,0),s6e=new b7(nk,1),l6e=new b7(ik,2),c6e=new b7("LEFT_RIGHT_CONSTRAINT_LOCKING",3),o6e=new b7("LEFT_RIGHT_CONNECTION_LOCKING",4),r6e=new b7(ict,5)}function GZe(e,t,n){var i,r,o,a,d,b,v;d=n.a/2,o=n.b/2,i=p.Math.abs(t.a-e.a),r=p.Math.abs(t.b-e.b),b=1,v=1,i>d&&(b=d/i),r>o&&(v=o/r),a=p.Math.min(b,v),e.a+=a*(t.a-e.a),e.b+=a*(t.b-e.b)}function UHt(e,t,n,i,r){var o,a;for(a=!1,o=c(Xe(n.b,0),19);ZWt(e,t,o,i,r)&&(a=!0,_qt(n,o),n.b.c.length!=0);)o=c(Xe(n.b,0),19);return n.b.c.length==0&&LD(n.j,n),a&&ZH(t.q),a}function Q2e(e,t,n,i){var r,o;return n==0?(!e.o&&(e.o=new Al((oc(),s1),e0,e,0)),_F(e.o,t,i)):(o=c(_t((r=c(Wt(e,16),29),r||e.fi()),n),69),o.uk().yk(e,tl(e),n-pn(e.fi()),t,i))}function zne(e,t){var n;t!=e.sb?(n=null,e.sb&&(n=c(e.sb,52).Qh(e,1,FC,n)),t&&(n=c(t,52).Oh(e,1,FC,n)),n=iwe(e,t,n),n&&n.mj()):(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,4,t,t))}function UZe(e,t){var n,i,r,o;if(t)r=P1(t,"x"),n=new gDe(e),Jm(n.a,(zt(r),r)),o=P1(t,"y"),i=new pDe(e),Xm(i.a,(zt(o),o));else throw J(new Kh("All edge sections need an end point."))}function JZe(e,t){var n,i,r,o;if(t)r=P1(t,"x"),n=new fDe(e),Vm(n.a,(zt(r),r)),o=P1(t,"y"),i=new hDe(e),Wm(i.a,(zt(o),o));else throw J(new Kh("All edge sections need a start point."))}function JHt(e,t){var n,i,r,o,a,d,b;for(i=hWe(e),o=0,d=i.length;o<d;++o)WZe(t);for(b=!Ph&&e.e?Ph?null:e.d:null;b;){for(n=hWe(b),r=0,a=n.length;r<a;++r)WZe(t);b=!Ph&&b.e?Ph?null:b.d:null}}function XZe(e,t){var n,i;i=c(R(t,(Ge(),cr)),103),Ee(t,(De(),O6e),i),n=t.e,n&&(lr(new jt(null,new Tt(n.a,16)),new bde(e)),lr(So(new jt(null,new Tt(n.b,16)),new mO),new mde(e)))}function XHt(e){var t,n,i,r;if(t=!1,xi(e,(De(),qE)))for(n=c(R(e,qE),93),r=new G(e.j);r.a<r.c.c.length;)i=c(Q(r),12),XUt(i)&&(t||(aGt(Jr(e)),t=!0),aBt(c(n.xc(i),319)))}function VHt(e){var t,n,i,r,o,a,d,b,v;return v=P2e(e),n=e.e,o=n!=null,o&&I6(v,AG,e.e),d=e.k,a=!!d,a&&I6(v,"type",lZ(e.k)),i=WN(e.j),r=!i,r&&(b=new mg,wf(v,Zse,b),t=new LDe(b),ws(e.j,t)),v}function WHt(e){var t,n,i,r;for(r=Kp((zu(e.gc(),"size"),new Z4),123),i=!0,n=Jp(e).Jc();n.Ob();)t=c(n.Pb(),45),i||(r.a+=Jc),i=!1,Sc(Kp(Sc(r,t.jd()),61),t.kd());return(r.a+="}",r).a}function VZe(e,t){var n,i,r;return t&=63,t<22?(n=e.l<<t,i=e.m<<t|e.l>>22-t,r=e.h<<t|e.m>>22-t):t<44?(n=0,i=e.l<<t-22,r=e.m<<t-22|e.l>>44-t):(n=0,i=0,r=e.l<<t-44),el(n&au,i&au,r&Q1)}function gv(e){if(W5e==null&&(W5e=new RegExp("^\\s*[+-]?(NaN|Infinity|((\\d+\\.?\\d*)|(\\.\\d+))([eE][+-]?\\d+)?[dDfF]?)\\s*$")),!W5e.test(e))throw J(new Yh(hw+e+'"'));return parseFloat(e)}function WZe(e){var t,n,i;t=Ot(typeof console,bre)?null:new Ir,t&&(T6(),n=(i=900,i>=qg?"error":i>=900?"warn":i>=800?"info":"log"),Oqe(n,e.a),e.b&&Gve(t,n,e.b,"Exception: ",!0))}function KZe(e,t){var n,i,r,o,a;for(r=t==1?tce:ece,i=r.a.ec().Jc();i.Ob();)for(n=c(i.Pb(),87),a=c(Si(e.f.c,n),24).Jc();a.Ob();)o=c(a.Pb(),49),qe(e.b.b,c(o.b,84)),qe(e.b.a,c(o.b,84).d)}function YZe(e,t,n,i){var r,o,a,d,b;switch(b=e.b,o=t.d,a=o.j,d=Hwe(a,b.d[a.g],n),r=ki(Ms(o.n),o.a),o.j.g){case 3:case 1:d.a+=r.a;break;case 2:d.b+=r.b;break;case 4:d.b+=r.b}tr(i,d,i.c.b,i.c)}function KHt(e,t){var n,i,r,o;for(o=t.b.j,e.a=ye(Fn,ci,30,o.c.length,15,1),r=0,i=0;i<o.c.length;i++)n=(ht(i,o.c.length),c(o.c[i],12)),n.e.c.length==0&&n.g.c.length==0?r+=1:r+=3,e.a[i]=r}function hQ(){hQ=te,_ce=new g7("ALWAYS_UP",0),Nce=new g7("ALWAYS_DOWN",1),Lce=new g7("DIRECTION_UP",2),Dce=new g7("DIRECTION_DOWN",3),Pce=new g7("SMART_UP",4),IU=new g7("SMART_DOWN",5)}function ZZe(e){switch(e.g){case 0:return new uK;case 1:return new fK;case 2:return new HB;case 3:return new DRe;case 4:return new XFe;default:throw J(new qt(bse+(e.f!=null?e.f:""+e.g)))}}function YHt(e,t){if(e<0||t<0)throw J(new qt("k and n must be positive"));if(t>e)throw J(new qt("k must be smaller than n"));return t==0||t==e?1:e==0?0:m2e(e)/(m2e(t)*m2e(e-t))}function G2e(e,t){var n,i,r,o;for(n=new WY(e);n.g==null&&!n.c?Ipe(n):n.g==null||n.i!=0&&c(n.g[n.i-1],51).Ob();)if(o=c(mQ(n),57),oe(o,176))for(i=c(o,176),r=0;r<t.length;r++)t[r].Jg(i)}function Fne(e){var t;return(e.Db&64)!=0?Gte(e):(t=new Ba(Gte(e)),t.a+=" (height: ",rx(t,e.f),t.a+=", width: ",rx(t,e.g),t.a+=", x: ",rx(t,e.i),t.a+=", y: ",rx(t,e.j),t.a+=")",t.a)}function ZHt(e){var t,n,i,r,o,a,d;for(t=new M0,i=e,r=0,o=i.length;r<o;++r)if(n=i[r],a=Rn(n.jd()),d=gb(t,a,Rn(n.kd())),d!=null)throw J(new qt("duplicate key: "+a));this.b=(Ct(),new PK(t))}function eQt(e){var t,n,i,r,o;if(e==null)return pl;for(o=new ub(Jc,"[","]"),n=e,i=0,r=n.length;i<r;++i)t=n[i],N1(o,String.fromCharCode(t));return o.a?o.e.length==0?o.a.a:o.a.a+(""+o.e):o.c}function U2e(){U2e=te,jke=(Wq(),sU),Qft=new wt(VQ,jke),Pe(1),Hft=new wt(Oxe,Pe(300)),Pe(0),Jft=new wt(Sxe,Pe(0)),Xft=new wt(xre,dd),Gft=new wt(kre,5),Vft=sU,Uft=Joe}function tQt(e,t){var n;if(t!=null&&!e.c.Fk().dk(t))throw n=oe(t,57)?c(t,57).Ah().zb:qp(ju(t)),J(new m6(V0+e.c.ve()+"'s type '"+e.c.Fk().ve()+"' does not permit a value of type '"+n+"'"))}function nQt(e,t,n){var i,r;for(r=new os(e.b,0);r.b<r.d.gc();)i=(dn(r.b<r.d.gc()),c(r.d.Xb(r.c=r.b++),70)),ve(R(i,(De(),x6e)))===ve(t)&&(Z2e(i.n,Jr(e.c.i),n),iu(r),qe(t.b,i))}function eet(e){var t,n;return n=p.Math.sqrt((e.k==null&&(e.k=mme(e,new Hf)),ue(e.k)/(e.b*(e.g==null&&(e.g=iVe(e,new d2)),ue(e.g))))),t=Hn(Zo(p.Math.round(n))),t=p.Math.min(t,e.f),t}function iQt(){var e,t,n;for(t=0,e=0;e<1;e++){if(n=xve((en(e,1),"X".charCodeAt(e))),n==0)throw J(new Qn((en(e,2),"Unknown Option: "+"X".substr(e))));t|=n}return t}function rQt(e){var t,n,i,r,o,a;for(t=new bx,n=new bx,C0(t,e),C0(n,e);n.b!=n.c;)for(r=c(w5(n),37),a=new G(r.a);a.a<a.c.c.length;)o=c(Q(a),9),o.e&&(i=o.e,C0(t,i),C0(n,i));return t}function bc(){_l(),t0e.call(this),this.j=(Je(),$o),this.a=new as,new qK,this.f=(zu(2,Sv),new Hc(2)),this.e=(zu(4,Sv),new Hc(4)),this.g=(zu(4,Sv),new Hc(4)),this.b=new VIe(this.e,this.g)}function sQt(e,t){var n,i;return!(et(Ze(R(t,(De(),Jg))))||(i=t.c.i,e==(Tu(),GE)&&i.k==(Jt(),lc))||(n=c(R(i,(Ge(),Ro)),166),n==V1))}function oQt(e,t){var n,i;return!(et(Ze(R(t,(De(),Jg))))||(i=t.d.i,e==(Tu(),UE)&&i.k==(Jt(),lc))||(n=c(R(i,(Ge(),Ro)),166),n==Db))}function cQt(e,t){var n,i,r,o,a,d,b;for(a=e.d,b=e.o,d=new pf(-a.b,-a.d,a.b+b.a+a.c,a.d+b.b+a.a),i=t,r=0,o=i.length;r<o;++r)n=i[r],n&&AT(d,n.i);a.b=-d.c,a.d=-d.d,a.c=d.b-a.b-b.a,a.a=d.a-a.d-b.b}function lQt(e,t){if(t.a)switch(c(R(t.b,(De(),O6e)),103).g){case 0:case 1:Aqt(t);case 2:lr(new jt(null,new Tt(t.d,16)),new QM),ZGt(e.a,t)}else lr(new jt(null,new Tt(t.d,16)),new QM)}function BD(){BD=te,uje=new a_("CENTER_DISTANCE",0),Mue=new a_("CIRCLE_UNDERLAP",1),fje=new a_("RECTANGLE_UNDERLAP",2),Aue=new a_("INVERTED_OVERLAP",3),aje=new a_("MINIMUM_ROOT_DISTANCE",4)}function uQt(e){Yve();var t,n,i,r,o;if(e==null)return null;for(i=e.length,r=i*2,t=ye(Na,fd,30,r,15,1),n=0;n<i;n++)o=e[n],o<0&&(o+=256),t[n*2]=gX[o>>4],t[n*2+1]=gX[o&15];return od(t,0,t.length)}function aQt(e){var t,n,i;switch(i=e.c.length,i){case 0:return nee(),Aat;case 1:return t=c(Ret(new G(e)),45),E7t(t.jd(),t.kd());default:return n=c(jh(e,ye(Mb,qQ,45,e.c.length,0,1)),178),new v1e(n)}}function Bg(e,t){switch(t.g){case 1:return g5(e.j,(_l(),Wke));case 2:return g5(e.j,(_l(),Xke));case 3:return g5(e.j,(_l(),Yke));case 4:return g5(e.j,(_l(),Zke));default:return Ct(),Ct(),Rs}}function fQt(e,t){var n,i,r;n=ECt(t,e.e),i=c(Ut(e.g.f,n),15).a,r=e.a.c.length-1,e.a.c.length!=0&&c(Xe(e.a,r),296).c==i?(++c(Xe(e.a,r),296).a,++c(Xe(e.a,r),296).b):qe(e.a,new NBe(i))}function F0(){F0=te,Rbt=(Dn(),Dk),$bt=lh,Dbt=qb,Lbt=C3,Pbt=lp,_bt=E3,y8e=NC,Ibt=iy,oue=(lye(),xbt),cue=kbt,k8e=Tbt,lue=Mbt,O8e=Ebt,S8e=Cbt,x8e=Obt,MJ=Sbt,AJ=jbt,yP=Abt,j8e=Nbt,v8e=ybt}function tet(e,t){var n,i,r,o,a;if(e.e<=t||h_t(e,e.g,t))return e.g;for(o=e.r,i=e.g,a=e.r,r=(o-i)/2+i;i+1<o;)n=UT(e,r,!1),n.b<=r&&n.a<=t?(a=r,o=r):i=r,r=(o-i)/2+i;return a}function hQt(e,t,n){var i;i=Mnt(e,t,!0),CZe(n,"Recursive Graph Layout",i),G2e(t,W(V($je,1),Lt,528,0,[new bg])),ga(t,(Dn(),ry))||G2e(t,W(V($je,1),Lt,528,0,[new zW])),Yye(e,t,null,n),net(n)}function net(e){var t;if(e.p==null)throw J(new oo("The task has not begun yet."));e.b||(e.k&&(t=(Og(),Ss(Zo(Date.now()),qg)),e.q=ib(Ha(t,e.o))*1e-9),e.c<e.r&&dme(e,e.r-e.c),e.b=!0)}function dQt(e){var t,n,i;for(i=new nu,ei(i,new $e(e.j,e.k)),n=new cn((!e.a&&(e.a=new Ar(Yu,e,5)),e.a));n.e!=n.i.gc();)t=c(un(n),373),ei(i,new $e(t.a,t.b));return ei(i,new $e(e.b,e.c)),i}function iet(e,t,n,i,r){var o,a,d,b,v,x;if(r)for(b=r.a.length,o=new Xp(b),x=(o.b-o.a)*o.c<0?(x0(),wp):new S0(o);x.Ob();)v=c(x.Pb(),15),d=X6(r,v.a),a=new rHe(e,t,n,i),jit(a.a,a.b,a.c,a.d,d)}function J2e(e,t){var n;if(ve(e)===ve(t))return!0;if(oe(t,24)){n=c(t,24);try{return e.gc()==n.gc()&&e.Hc(n)}catch(i){if(i=vr(i),oe(i,174)||oe(i,214))return!1;throw J(i)}}return!1}function qne(e,t,n,i,r,o){switch(this.c=e,t.g){case 2:if(e.a.Le(r,n)<0)throw J(new qt(hxe+r+cot+n));break;case 1:e.a.Le(r,r);break;case 3:e.a.Le(n,n)}this.f=t,this.b=n,this.a=i,this.e=r,this.d=o}function X2e(e,t){var n;qe(e.d,t),n=t.Kf(),e.c?(e.e.a=p.Math.max(e.e.a,n.a),e.e.b+=n.b,e.d.c.length>1&&(e.e.b+=e.a)):(e.e.a+=n.a,e.e.b=p.Math.max(e.e.b,n.b),e.d.c.length>1&&(e.e.a+=e.a))}function gQt(e){var t,n,i,r;switch(r=e.i,t=r.b,i=r.j,n=r.g,r.a.g){case 0:n.a=(e.g.b.o.a-i.a)/2;break;case 1:n.a=t.d.n.a+t.d.a.a;break;case 2:n.a=t.d.n.a+t.d.a.a-i.a;break;case 3:n.b=t.d.n.b+t.d.a.b}}function pQt(e,t,n){var i,r,o;for(r=new Ht(Vt(sd(n).a.Jc(),new U));hn(r);)i=c(sn(r),17),!vs(i)&&!(!vs(i)&&i.c.i.c==i.d.i.c)&&(o=Ytt(e,i,n,new OLe),o.c.length>1&&It(t.c,o))}function ret(e,t,n,i,r){if(i<t||r<n)throw J(new qt("The highx must be bigger then lowx and the highy must be bigger then lowy"));return e.a<t?e.a=t:e.a>i&&(e.a=i),e.b<n?e.b=n:e.b>r&&(e.b=r),e}function bQt(e){if(oe(e,144))return FJt(c(e,144));if(oe(e,236))return G$t(c(e,236));if(oe(e,21))return VHt(c(e,21));throw J(new qt(m9+Mh(new Ho(W(V(Br,1),Lt,1,5,[e])))))}function mQt(e,t,n,i,r){var o,a,d;for(o=!0,a=0;a<i;a++)o=o&n[a]==0;if(r==0)mc(n,i,e,0,t),a=t;else{for(d=32-r,o=o&n[a]<<d==0,a=0;a<t-1;a++)e[a]=n[a+i]>>>r|n[a+i+1]<<d;e[a]=n[a+i]>>>r,++a}return o}function V2e(e,t,n,i){var r,o,a;if(t.k==(Jt(),jr)){for(o=new Ht(Vt(pr(t).a.Jc(),new U));hn(o);)if(r=c(sn(o),17),a=r.c.i.k,a==jr&&e.c.a[r.c.i.c.p]==i&&e.c.a[t.c.p]==n)return!0}return!1}function wQt(e,t,n){var i;n.Tg("YPlacer",1),e.a=ue(he(ke(t,(q5(),Pje)))),e.b=ue(he(ke(t,(Dn(),lh)))),(!t.a&&(t.a=new Me(Mn,t,10,11)),t.a).i!=0&&(i=c(ke(t,(Qd(),SC)),19),lnt(e,i,0)),n.Ug()}function vQt(e,t){var n,i,r,o;return t&=63,n=e.h&Q1,t<22?(o=n>>>t,r=e.m>>t|n<<22-t,i=e.l>>t|e.m<<22-t):t<44?(o=0,r=n>>>t-22,i=e.m>>t-22|e.h<<44-t):(o=0,r=0,i=n>>>t-44),el(i&au,r&au,o&Q1)}function set(e,t,n,i){var r;this.b=i,this.e=e==(hb(),lC),r=t[n],this.d=H2(kl,[Be,eh],[172,30],16,[r.length,r.length],2),this.a=H2(Fn,[Be,ci],[54,30],15,[r.length,r.length],2),this.c=new A2e(t,n)}function yQt(e){var t,n,i;for(e.k=new qpe((Je(),W(V($s,1),cc,64,0,[$o,Kt,nn,bn,Yt])).length,e.j.c.length),i=new G(e.j);i.a<i.c.c.length;)n=c(Q(i),114),t=n.d.j,St(e.k,t,n);e.e=CJt(b5(e.k))}function oet(e,t){var n,i,r;Sr(e.d,t),n=new m2,oi(e.c,t,n),n.f=$te(t.c),n.a=$te(t.d),n.d=(BT(),r=t.c.i.k,r==(Jt(),or)||r==Ih),n.e=(i=t.d.i.k,i==or||i==Ih),n.b=t.c.j==(Je(),Yt),n.c=t.d.j==nn}function xQt(e){var t,n,i,r,o;for(o=di,r=di,i=new G(Ax(e));i.a<i.c.c.length;)n=c(Q(i),220),t=n.e.e-n.d.e,n.e==e&&t<r?r=t:t<o&&(o=t);return r==di&&(r=-1),o==di&&(o=-1),new Ps(Pe(r),Pe(o))}function kQt(e,t){var n,i,r,o;for(n=t.a.o.a,o=new nd(Jr(t.a).b,t.c,t.f+1),r=new Gj(o);r.b<r.d.gc();)if(i=(dn(r.b<r.d.gc()),c(r.d.Xb(r.c=r.b++),26)),i.c.a>=n)return AS(e,t,i.p),!0;return!1}function Rx(e,t,n,i){var r,o,a,d,b,v;for(a=n.length,o=0,r=-1,v=JJe((en(t,e.length+1),e.substr(t)),(vZ(),gke)),d=0;d<a;++d)b=n[d].length,b>o&&wMt(v,JJe(n[d],gke))&&(r=d,o=b);return r>=0&&(i[0]=t+o),r}function OQt(e,t,n){var i,r,o,a,d,b,v,x;o=e.d.p,d=o.e,b=o.r,e.g=new E_(b),a=e.d.o.c.p,i=a>0?d[a-1]:ye(e1,Hg,9,0,0,1),r=d[a],v=a<d.length-1?d[a+1]:ye(e1,Hg,9,0,0,1),x=t==n-1,x?pee(e.g,r,v):pee(e.g,i,r)}function cet(e){var t;return(e.Db&64)!=0?Fne(e):(t=new Lu(l5e),!e.a||Zn(Zn((t.a+=' "',t),e.a),'"'),Zn(Cm(Zn(Cm(Zn(Cm(Zn(Cm((t.a+=" (",t),e.i),","),e.j)," | "),e.g),","),e.f),")"),t.a)}function uet(e,t,n){var i,r,o,a,d;for(d=nl(e.e.Ah(),t),r=c(e.g,123),i=0,a=0;a<e.i;++a)if(o=r[a],d.$l(o.Jk())){if(i==n)return vv(e,a),qs(),c(t,69).vk()?o:o.kd();++i}throw J(new zc(wE+n+Tb+i))}function aet(e){var t,n,i;if(t=e.c,t==2||t==7||t==1)return wi(),wi(),KC;for(i=Xye(e),n=null;(t=e.c)!=2&&t!=7&&t!=1;)n||(n=(wi(),wi(),new E7(1)),wb(n,i),i=n),wb(n,Xye(e));return i}function SQt(e,t,n){return e<0||e>n?sve(e,n,"start index"):t<0||t>n?sve(t,n,"end index"):zT("end index (%s) must not be less than start index (%s)",W(V(Br,1),Lt,1,5,[Pe(t),Pe(e)]))}function fet(e,t){var n,i,r,o;for(i=0,r=e.length;i<r;i++){o=e[i];try{o[1]?o[0].Sm()&&(t=ZCt(t,o)):o[0].Sm()}catch(a){if(a=vr(a),oe(a,81))n=a,jz(),PAt(oe(n,477)?c(n,477).ie():n);else throw J(a)}}return t}function AS(e,t,n){var i,r,o;for(n!=t.c+t.b.gc()&&LKt(t.a,OIt(t,n-t.c)),o=t.a.c.p,e.a[o]=p.Math.max(e.a[o],t.a.o.a),r=c(R(t.a,(De(),HE)),16).Jc();r.Ob();)i=c(r.Pb(),70),Ee(i,uce,(Bt(),!0))}function jQt(e,t){var n,i,r;r=XJt(t),Ee(t,(De(),Uce),r),r&&(i=di,co(e.f,r)&&(i=c(Ao(co(e.f,r)),15).a),n=c(Xe(t.g,0),17),et(Ze(R(n,Jg)))||oi(e,r,Pe(p.Math.min(c(R(n,Pi),15).a,i))))}function TQt(e){var t,n,i,r;for(n=di,r=!0,t=0;t<e.a.c.length;t++)xi(c(Xe(e.a,t),9),(Ge(),iJ))&&(r=!1,i=c(R(c(Xe(e.a,t),9),iJ),15).a,n=n<i?n:i);return r&&(n=c(Ve((Ge(),iJ)),15).a),n}function het(e,t,n){var i,r,o,a,d;for(t.p=-1,d=tw(t,(Qs(),Wc)).Jc();d.Ob();)for(a=c(d.Pb(),12),r=new G(a.g);r.a<r.c.c.length;)i=c(Q(r),17),o=i.d.i,t!=o&&(o.p<0?n.Ec(i):o.p>0&&het(e,o,n));t.p=0}function EQt(e){var t,n,i,r;for(t=Kp(Zn(new Lu("Predicates."),"and"),40),n=!0,r=new Gj(e);r.b<r.d.gc();)i=(dn(r.b<r.d.gc()),r.d.Xb(r.c=r.b++)),n||(t.a+=","),t.a+=""+i,n=!1;return(t.a+=")",t).a}function det(e,t,n){var i,r,o;if(!(n<=t+2))for(r=(n-t)/2|0,i=0;i<r;++i)o=(ht(t+i,e.c.length),c(e.c[t+i],12)),Su(e,t+i,(ht(n-i-1,e.c.length),c(e.c[n-i-1],12))),ht(n-i-1,e.c.length),e.c[n-i-1]=o}function get(e,t){var n,i,r;if(t.c.length!=0){for(n=RZe(e,t),r=!1;!n;)bQ(e,t,!0),r=!0,n=RZe(e,t);r&&bQ(e,t,!1),i=kte(t),e.b&&e.b.Fg(i),e.a=CWe(e,(ht(0,t.c.length),c(t.c[0],19))),get(e,i)}}function Hne(e,t){var n,i,r;if(i=_t(e.Ah(),t),n=t-e.gi(),n<0)if(i)if(i.pk())r=e.Fh(i),r>=0?e.hi(r):uve(e,i);else throw J(new qt(V0+i.ve()+pE));else throw J(new qt(Dlt+t+Llt));else ya(e,n,i)}function W2e(e){var t,n;if(n=null,t=!1,oe(e,213)&&(t=!0,n=c(e,213).a),t||oe(e,266)&&(t=!0,n=""+c(e,266).a),t||oe(e,482)&&(t=!0,n=""+c(e,482).a),!t)throw J(new YK(m5e));return n}function K2e(e,t,n){var i,r,o,a,d,b;for(b=nl(e.e.Ah(),t),i=0,d=e.i,r=c(e.g,123),a=0;a<e.i;++a)if(o=r[a],b.$l(o.Jk())){if(n==i)return a;++i,d=a+1}if(n==i)return d;throw J(new zc(wE+n+Tb+i))}function CQt(e,t){var n,i,r,o;if(e.f.c.length==0)return null;for(o=new c5,i=new G(e.f);i.a<i.c.c.length;)n=c(Q(i),70),r=n.o,o.b=p.Math.max(o.b,r.a),o.a+=r.b;return o.a+=(e.f.c.length-1)*t,o}function MQt(e){var t,n,i,r;for(i=e.a.d.j,r=e.a.d.j,n=new G(e.i.d);n.a<n.c.c.length;)t=c(Q(n),70),Ee(t,(Ge(),b3),null);i==(Je(),Kt)||r==Kt?Eg(e,bn,(xf(),Iv),null):Eg(e,Kt,(xf(),Iv),null)}function Y2e(e){var t,n,i,r;for(e.e=0,r=_n(e.f,0);r.b!=r.d.c;)i=c(An(r),9),i.p>=e.d.b.c.length&&(t=new hc(e.d),t.p=i.p-1,qe(e.d.b,t),n=new hc(e.d),n.p=i.p,qe(e.d.b,n)),zr(i,c(Xe(e.d.b,i.p),26))}function AQt(e){var t,n,i,r;for(n=new Ai,Os(n,e.o),i=new yz;n.b!=0;)t=c(n.b==0?null:(dn(n.b!=0),ba(n,n.a.a)),504),r=fst(e,t,!0),r&&qe(i.a,t);for(;i.a.c.length!=0;)t=c(Jme(i),504),fst(e,t,!1)}function it(e){var t;this.c=new Ai,this.f=e.e,this.e=e.d,this.i=e.g,this.d=e.c,this.b=e.b,this.k=e.j,this.a=e.a,e.i?this.j=e.i:this.j=(t=c(Jf($h),10),new ha(t,c(gf(t,t.length),10),0)),this.g=e.f}function q0(){q0=te,Bje=new r5(nE,0),Pr=new r5("BOOLEAN",1),js=new r5("INT",2),Nk=new r5("STRING",3),us=new r5("DOUBLE",4),Ui=new r5("ENUM",5),Ak=new r5("ENUMSET",6),Bh=new r5("OBJECT",7)}function AT(e,t){var n,i,r,o,a;i=p.Math.min(e.c,t.c),o=p.Math.min(e.d,t.d),r=p.Math.max(e.c+e.b,t.c+t.b),a=p.Math.max(e.d+e.a,t.d+t.a),r<i&&(n=i,i=r,r=n),a<o&&(n=o,o=a,a=n),tFe(e,i,o,r-i,a-o)}function pet(e,t){var n,i;if(e.f){for(;t.Ob();)if(n=c(t.Pb(),76),i=n.Jk(),oe(i,104)&&(c(i,20).Bb&nc)!=0&&(!e.e||i.nk()!=o8||i.Jj()!=0)&&n.kd()!=null)return t.Ub(),!0;return!1}else return t.Ob()}function bet(e,t){var n,i;if(e.f){for(;t.Sb();)if(n=c(t.Ub(),76),i=n.Jk(),oe(i,104)&&(c(i,20).Bb&nc)!=0&&(!e.e||i.nk()!=o8||i.Jj()!=0)&&n.kd()!=null)return t.Pb(),!0;return!1}else return t.Sb()}function Dl(){Dl=te,FTe=W(V(nt,1),Be,2,6,[N5e,IL,qG,Kut,HG,aoe,AG]),zTe=W(V(nt,1),Be,2,6,[N5e,"empty",IL,PL,"elementOnly"]),qTe=W(V(nt,1),Be,2,6,[N5e,"preserve","replace",ih]),ps=new fFe}function Z2e(e,t,n){var i,r,o;if(t!=n){i=t;do ki(e,i.c),r=i.e,r&&(o=i.d,$2(e,o.b,o.d),ki(e,r.n),i=Jr(r));while(r);i=n;do Hr(e,i.c),r=i.e,r&&(o=i.d,IBe(e,o.b,o.d),Hr(e,r.n),i=Jr(r));while(r)}}function Qne(e,t,n,i){var r,o,a,d,b;if(i.f.c+i.i.c==0)for(a=e.a[e.c],d=0,b=a.length;d<b;++d)o=a[d],oi(i,o,new uVe(e,o,n));return r=c(Ao(co(i.f,t)),674),r.b=0,r.c=r.f,r.c==0||At(c(Xe(r.a,r.b),296)),r}function met(e){var t;this.j=new Fe,this.f=new Or,this.b=(t=c(Jf($s),10),new ha(t,c(gf(t,t.length),10),0)),this.d=ye(Fn,ci,30,(Je(),W(V($s,1),cc,64,0,[$o,Kt,nn,bn,Yt])).length,15,1),this.g=e}function H5(){H5=te,A9=new d7("MEDIAN_LAYER",0),RE=new d7("TAIL_LAYER",1),M9=new d7("HEAD_LAYER",2),Rv=new d7("SPACE_EFFICIENT_LAYER",3),c3=new d7("WIDEST_LAYER",4),o3=new d7("CENTER_LAYER",5)}function eve(e,t,n){var i,r,o;if(!e.b[t.g]){for(e.b[t.g]=!0,i=n,!i&&(i=new J_),ei(i.b,t),o=e.a[t.g].Jc();o.Ob();)r=c(o.Pb(),65),r.b!=t&&eve(e,r.b,i),r.c!=t&&eve(e,r.c,i),ei(i.a,r);return i}return null}function NQt(e){switch(e.g){case 0:case 1:case 2:return Je(),Kt;case 3:case 4:case 5:return Je(),bn;case 6:case 7:case 8:return Je(),Yt;case 9:case 10:case 11:return Je(),nn;default:return Je(),$o}}function _Qt(e,t){var n;return e.c.length==0?!1:(n=yKe((ht(0,e.c.length),c(e.c[0],17)).c.i),Ru(),n==(hv(),v3)||n==w3?!0:Sx(qc(new jt(null,new Tt(e,16)),new Z8),new x_e(t)))}function Gne(e,t){if(oe(t,209))return njt(e,c(t,19));if(oe(t,196))return ijt(e,c(t,127));if(oe(t,446))return tjt(e,c(t,171));throw J(new qt(m9+Mh(new Ho(W(V(Br,1),Lt,1,5,[t])))))}function wet(e,t,n){var i,r;if(this.f=e,i=c(Ut(e.b,t),263),r=i?i.a:0,vbe(n,r),n>=(r/2|0))for(this.e=i?i.c:null,this.d=r;n++<r;)RJe(this);else for(this.c=i?i.b:null;n-- >0;)qbe(this);this.b=t,this.a=null}function DQt(e,t){var n,i;t.a?sXt(e,t):(n=c(aY(e.b,t.b),60),n&&n==e.a[t.b.f]&&n.a&&n.a!=t.b.a&&n.c.Ec(t.b),i=c(uY(e.b,t.b),60),i&&e.a[i.f]==t.b&&i.a&&i.a!=t.b.a&&t.b.c.Ec(i),rZ(e.b,t.b))}function vet(e,t){var n,i;if(n=c(Zs(e.b,t),129),c(c(Si(e.r,t),24),85).dc()){n.n.b=0,n.n.c=0;return}n.n.b=e.C.b,n.n.c=e.C.c,e.A.Gc((Cu(),Qb))&&Ynt(e,t),i=gzt(e,t),nie(e,t)==(_x(),ap)&&(i+=2*e.w),n.a.a=i}function yet(e,t){var n,i;if(n=c(Zs(e.b,t),129),c(c(Si(e.r,t),24),85).dc()){n.n.d=0,n.n.a=0;return}n.n.d=e.C.d,n.n.a=e.C.a,e.A.Gc((Cu(),Qb))&&Znt(e,t),i=dzt(e,t),nie(e,t)==(_x(),ap)&&(i+=2*e.w),n.a.b=i}function LQt(e,t){var n,i,r,o;for(o=new Fe,i=new G(t);i.a<i.c.c.length;)n=c(Q(i),68),qe(o,new E1e(n,!0)),qe(o,new E1e(n,!1));r=new SHe(e),r.a.a.$b(),qQe(o,e.b,new Ho(W(V(sft,1),Lt,690,0,[r])))}function PQt(e,t){var n,i,r;t.Tg("End label pre-processing",1),n=ue(he(R(e,(Ge(),m3)))),i=ue(he(R(e,Xv))),r=hx(c(R(e,Xu),87)),lr(So(new jt(null,new Tt(e.b,16)),new z8),new Bze(n,i,r)),t.Ug()}function tve(e,t){var n,i,r;if(!e.d[t.p]){for(e.d[t.p]=!0,e.a[t.p]=!0,i=new Ht(Vt($i(t).a.Jc(),new U));hn(i);)n=c(sn(i),17),!vs(n)&&(r=n.d.i,e.a[r.p]?qe(e.b,n):tve(e,r));e.a[t.p]=!1}}function Q5(e,t,n){var i;switch(i=0,c(R(t,(Ge(),Ro)),166).g){case 2:i=2*-n+e.a,++e.a;break;case 1:i=-n;break;case 3:i=n;break;case 4:i=2*n+e.b,++e.b}return xi(t,(De(),Pi))&&(i+=c(R(t,Pi),15).a),i}function xet(e,t,n){var i,r,o;for(n.yc(t,e),qe(e.n,t),o=e.p.yg(t),t.j==e.p.zg()?oKe(e.e,o):oKe(e.j,o),cq(e),r=Bd(ma(W(V(Ta,1),Lt,22,0,[new p6(t),new Q4(t)])));hn(r);)i=c(sn(r),12),n._b(i)||xet(e,i,n)}function IQt(e,t,n){var i,r,o;for(n.Tg("Processor set neighbors",1),e.a=t.b.b==0?1:t.b.b,r=null,i=_n(t.b,0);!r&&i.b!=i.d.c;)o=c(An(i),41),et(Ze(R(o,(Li(),cp))))&&(r=o);r&&_nt(e,new k1(r),n),n.Ug()}function nve(e){var t,n,i;return n=c(ke(e,(Dn(),qb)),24),n.Gc((Cu(),cy))?(i=c(ke(e,lp),24),t=new Cs(c(ke(e,C3),8)),i.Gc((uu(),s8))&&(t.a<=0&&(t.a=20),t.b<=0&&(t.b=20)),t):new as}function ive(e){var t,n,i;if(!e.b){for(i=new eB,n=new a5(GT(e));n.e!=n.i.gc();)t=c(lne(n),20),(t.Bb&nc)!=0&&Nn(i,t);cv(i),e.b=new fx((c(re(Ne((j0(),Gt).o),8),20),i.i),i.g),ru(e).b&=-9}return e.b}function pv(e){var t,n,i;for(n=e.length,i=0;i<n&&(en(i,e.length),e.charCodeAt(i)<=32);)++i;for(t=n;t>i&&(en(t-1,e.length),e.charCodeAt(t-1)<=32);)--t;return i>0||t<n?(fs(i,t,e.length),e.substr(i,t-i)):e}function RQt(e,t){var n,i,r,o,a,d,b,v;b=c(jT(b5(t.k),ye($s,cc,64,2,0,1)),128),v=t.g,n=fGe(t,b[0]),r=aGe(t,b[1]),i=One(e,v,n,r),o=fGe(t,b[1]),d=aGe(t,b[0]),a=One(e,v,o,d),i<=a?(t.a=n,t.c=r):(t.a=o,t.c=d)}function ket(e,t,n,i,r){var o,a,d,b,v;if(t)for(d=t.Jc();d.Ob();)for(a=c(d.Pb(),9),v=nye(a,(Qs(),Wc),n).Jc();v.Ob();)b=c(v.Pb(),12),o=c(Ao(co(r.f,b)),117),o||(o=new gD(e.d),It(i.c,o),xet(o,b,r))}function NT(e){var t;Ct();var n,i,r,o,a,d;if(oe(e,59))for(o=0,r=e.gc()-1;o<r;++o,--r)t=e.Xb(o),e.fd(o,e.Xb(r)),e.fd(r,t);else for(n=e.cd(),a=e.dd(e.gc());n.Tb()<a.Vb();)i=n.Pb(),d=a.Ub(),n.Wb(d),a.Wb(i)}function dQ(e,t){var n,i,r,o,a,d;for(d=0,o=new bx,C0(o,t);o.b!=o.c;)for(a=c(w5(o),221),d+=PYe(a.d,a.e),r=new G(a.b);r.a<r.c.c.length;)i=c(Q(r),37),n=c(Xe(e.b,i.p),221),n.s||(d+=dQ(e,n));return d}function Oet(e,t,n){var i,r;jVe(this),t==(Hm(),op)?Sr(this.r,e.c):Sr(this.w,e.c),n==op?Sr(this.r,e.d):Sr(this.w,e.d),oet(this,e),i=$te(e.c),r=$te(e.d),QZe(this,i,r,r),this.o=(BT(),p.Math.abs(i-r)<.2)}function jet(e,t,n){var i,r,o,a,d,b;if(d=c(Wt(e.a,8),2014),d!=null)for(r=d,o=0,a=r.length;o<a;++o)null.Sm();i=n,(e.a.Db&1)==0&&(b=new Eqe(e,n,t),i.bj(b)),oe(i,683)?c(i,683).dj(e.a):i.aj()==e.a&&i.cj(null)}function $Qt(){var e;return kvt?c(NS((y0(),nf),Cb),2023):(len(),e=c(oe(Tc((y0(),nf),Cb),589)?Tc(nf,Cb):new Hqe,589),kvt=!0,Jen(e),Etn(e),oi((m1e(),ETe),e,new aB),jne(e),lo(nf,Cb,e),e)}function BQt(e,t,n,i){var r;return r=Rx(e,n,W(V(nt,1),Be,2,6,[tre,nre,ire,rre,sre,ore,cre]),t),r<0&&(r=Rx(e,n,W(V(nt,1),Be,2,6,["Sun","Mon","Tue","Wed","Thu","Fri","Sat"]),t)),r<0?!1:(i.d=r,!0)}function zQt(e,t,n,i){var r;return r=Rx(e,n,W(V(nt,1),Be,2,6,[tre,nre,ire,rre,sre,ore,cre]),t),r<0&&(r=Rx(e,n,W(V(nt,1),Be,2,6,["Sun","Mon","Tue","Wed","Thu","Fri","Sat"]),t)),r<0?!1:(i.d=r,!0)}function gl(e,t,n){var i,r,o,a;if(a=e.b.Ae(t),r=(i=e.a.get(a),i??ye(Br,Lt,1,0,5,1)),r.length==0)e.a.set(a,r);else if(o=jWe(e,t,r),o)return o.ld(n);return dr(r,r.length,new qz(t,n)),++e.c,++e.b.g,null}function FQt(e){var t,n,i;for(zUt(e),i=new Fe,n=new G(e.a.a.b);n.a<n.c.c.length;)t=c(Q(n),84),qe(i,new C1e(t,!0)),qe(i,new C1e(t,!1));Dzt(e.c),H_(i,e.b,new Ho(W(V(GL,1),Lt,378,0,[e.c]))),tUt(e)}function zD(e,t){var n,i,r;for(r=new Fe,i=new G(e.c.a.b);i.a<i.c.c.length;)n=c(Q(i),60),t.Lb(n)&&(qe(r,new T1e(n,!0)),qe(r,new T1e(n,!1)));_zt(e.e),qQe(r,e.d,new Ho(W(V(sft,1),Lt,690,0,[e.e])))}function qQt(e){var t,n,i,r;for(n=new wn,r=new G(e.d);r.a<r.c.c.length;)i=c(Q(r),190),t=c(i.mf((De(),vk)),17),co(n.f,t)||oi(n,t,new gHe(t)),qe(c(Ao(co(n.f,t)),458).b,i);return new Fl(new x1(n))}function HQt(e,t){var n,i,r,o,a;for(i=new ZQe(e.j.c.length),n=null,o=new G(e.j);o.a<o.c.c.length;)r=c(Q(o),12),r.j!=n&&(i.b==i.c||Jtt(i,n,t),sbe(i),n=r.j),a=Ttt(r),a&&Zpe(i,a);i.b==i.c||Jtt(i,n,t)}function QQt(e,t){var n,i,r;for(i=new os(e.b,0);i.b<i.d.gc();)n=(dn(i.b<i.d.gc()),c(i.d.Xb(i.c=i.b++),70)),r=c(R(n,(Ge(),yd)),281),r==(Sh(),oy)&&(iu(i),qe(t.b,n),xi(n,(De(),vk))||Ee(n,vk,e))}function GQt(e){var t,n,i,r,o;for(t=Vf(new Ht(Vt($i(e).a.Jc(),new U))),r=new Ht(Vt(pr(e).a.Jc(),new U));hn(r);)i=c(sn(r),17),n=i.c.i,o=Vf(new Ht(Vt($i(n).a.Jc(),new U))),t=p.Math.max(t,o);return Pe(t)}function rve(e,t,n){var i,r,o;i=c(ke(e,(Dn(),CP)),24),r=0,o=0,t.a>n.a&&(i.Gc((bb(),TC))?r=(t.a-n.a)/2:i.Gc(EC)&&(r=t.a-n.a)),t.b>n.b&&(i.Gc((bb(),MC))?o=(t.b-n.b)/2:i.Gc(CC)&&(o=t.b-n.b)),B2e(e,r,o)}function Tet(e,t,n,i,r,o,a,d,b,v,x,S,M){oe(e.Cb,89)&&bv(ru(c(e.Cb,89)),4),Gc(e,n),e.f=a,mS(e,d),vS(e,b),bS(e,v),wS(e,x),Rg(e,S),yS(e,M),Ig(e,!0),_g(e,r),e.Xk(o),db(e,t),i!=null&&(e.i=null,aH(e,i))}function sve(e,t,n){if(e<0)return zT(Rst,W(V(Br,1),Lt,1,5,[n,Pe(e)]));if(t<0)throw J(new qt($st+t));return zT("%s (%s) must not be greater than size (%s)",W(V(Br,1),Lt,1,5,[n,Pe(e),Pe(t)]))}function ove(e,t,n,i,r,o){var a,d,b,v;if(a=i-n,a<7){R$t(t,n,i,o);return}if(b=n+r,d=i+r,v=b+(d-b>>1),ove(t,e,b,v,-r,o),ove(t,e,v,d,-r,o),o.Le(e[v-1],e[v])<=0){for(;n<i;)dr(t,n++,e[b++]);return}VRt(e,b,v,d,t,n,i,o)}function UQt(e,t){var n,i,r,o,a,d,b;for(b=t.d,r=t.b.j,d=new G(b);d.a<d.c.c.length;)for(a=c(Q(d),108),o=ye(kl,eh,30,r.c.length,16,1),oi(e.b,a,o),n=a.a.d.p-1,i=a.c.d.p;n!=i;)n=(n+1)%r.c.length,o[n]=!0}function JQt(e,t){if(nme(),xi(e,(De(),Pi))&&xi(t,Pi))return fc(c(R(e,Pi),15).a,c(R(t,Pi),15).a);throw J(new Y4("The BF model order layer assigner requires all real nodes to have a model order."))}function XQt(e,t){if(ime(),xi(e,(De(),Pi))&&xi(t,Pi))return fc(c(R(e,Pi),15).a,c(R(t,Pi),15).a);throw J(new Y4("The DF model order layer assigner requires all real nodes to have a model order."))}function VQt(e,t){for(e.r=new gD(e.p),AK(e.r,e),Os(e.r.j,e.j),Ou(e.j),ei(e.j,t),ei(e.r.e,t),cq(e),cq(e.r);e.f.c.length!=0;)X$e(c(Xe(e.f,0),135));for(;e.k.c.length!=0;)X$e(c(Xe(e.k,0),135));return e.r}function Une(e,t,n){var i,r,o;if(r=_t(e.Ah(),t),i=t-e.gi(),i<0)if(r)if(r.pk())o=e.Fh(r),o>=0?e.$h(o,n):$ve(e,r,n);else throw J(new qt(V0+r.ve()+pE));else throw J(new qt(Dlt+t+Llt));else xa(e,i,r,n)}function Eet(e){var t,n;if(e.f){for(;e.n>0;){if(t=c(e.k.Xb(e.n-1),76),n=t.Jk(),oe(n,104)&&(c(n,20).Bb&nc)!=0&&(!e.e||n.nk()!=o8||n.Jj()!=0)&&t.kd()!=null)return!0;--e.n}return!1}else return e.n>0}function Cet(e){var t,n,i,r;if(n=c(e,52).Yh(),n)try{if(i=null,t=NS((y0(),nf),kit(F$t(n))),t&&(r=t.Zh(),r&&(i=r.Dl(y9t(n.e)))),i&&i!=e)return Cet(i)}catch(o){if(o=vr(o),!oe(o,63))throw J(o)}return e}function WQt(e,t,n){var i,r,o;n.Tg("Remove overlaps",1),n.bh(t,g4e),i=c(ke(t,(vx(),k3)),19),e.f=i,e.a=ane(c(ke(t,(F0(),yP)),304)),r=he(ke(t,(Dn(),lh))),tx(e,(zt(r),r)),o=wv(i),Jrt(e,t,o,n),n.bh(t,kG)}function KQt(e){var t,n,i;if(et(Ze(ke(e,(Dn(),AP))))){for(i=new Fe,n=new Ht(Vt(z1(e).a.Jc(),new U));hn(n);)t=c(sn(n),74),sw(t)&&et(Ze(ke(t,tae)))&&It(i.c,t);return i}else return Ct(),Ct(),Rs}function Met(e){if(!e)return iPe(),Pat;var t=e.valueOf?e.valueOf():e;if(t!==e){var n=Noe[typeof t];return n?n(t):twe(typeof t)}else return e instanceof Array||e instanceof p.Array?new RN(e):new B4(e)}function Aet(e,t,n){var i,r,o;switch(o=e.o,i=c(Zs(e.p,n),256),r=i.i,r.b=DT(i),r.a=_T(i),r.b=p.Math.max(r.b,o.a),r.b>o.a&&!t&&(r.b=o.a),r.c=-(r.b-o.a)/2,n.g){case 1:r.d=-r.a;break;case 3:r.d=o.b}pie(i),bie(i)}function Net(e,t,n){var i,r,o;switch(o=e.o,i=c(Zs(e.p,n),256),r=i.i,r.b=DT(i),r.a=_T(i),r.a=p.Math.max(r.a,o.b),r.a>o.b&&!t&&(r.a=o.b),r.d=-(r.a-o.b)/2,n.g){case 4:r.c=-r.b;break;case 2:r.c=o.a}pie(i),bie(i)}function YQt(e,t){var n,i,r;return oe(t.g,9)&&c(t.g,9).k==(Jt(),Cr)?nr:(r=j5(t),r?p.Math.max(0,e.b/2-.5):(n=kx(t),n?(i=ue(he(av(n,(Ge(),$b)))),p.Math.max(0,i/2-.5)):nr))}function ZQt(e,t){var n,i,r;return oe(t.g,9)&&c(t.g,9).k==(Jt(),Cr)?nr:(r=j5(t),r?p.Math.max(0,e.b/2-.5):(n=kx(t),n?(i=ue(he(av(n,(Ge(),$b)))),p.Math.max(0,i/2-.5)):nr))}function eGt(e,t){var n,i,r,o,a;if(!t.dc()){if(r=c(t.Xb(0),134),t.gc()==1){mnt(e,r,r,1,0,t);return}for(n=1;n<t.gc();)(r.j||!r.o)&&(o=lFt(t,n),o&&(i=c(o.a,15).a,a=c(o.b,134),mnt(e,r,a,n,i,t),n=i+1,r=a))}}function tGt(e){var t,n,i,r,o,a;for(a=new Fl(e.d),Rr(a,new rA),t=(EQ(),W(V($Oe,1),_e,277,0,[gce,mce,dce,yce,bce,pce,vce,wce])),n=0,o=new G(a);o.a<o.c.c.length;)r=c(Q(o),108),i=t[n%t.length],FGt(r,i),++n}function cve(e,t){var n,i,r,o,a,d,b,v,x,S;return x=null,S=e,a=P1(S,"x"),n=new vDe(t),_Je(n.a,a),d=P1(S,"y"),i=new yDe(t),DJe(i.a,d),b=P1(S,Vse),r=new xDe(t),LJe(r.a,b),v=P1(S,Xse),o=new kDe(t),x=(PJe(o.a,v),v),x}function bv(e,t){Vnt(e,t),(e.b&1)!=0&&(e.a.a=null),(e.b&2)!=0&&(e.a.f=null),(e.b&4)!=0&&(e.a.g=null,e.a.i=null),(e.b&16)!=0&&(e.a.d=null,e.a.e=null),(e.b&8)!=0&&(e.a.b=null),(e.b&32)!=0&&(e.a.j=null,e.a.c=null)}function nGt(e,t){var n,i,r;if(r=0,t.length>0)try{r=Hu(t,ls,di)}catch(o){throw o=vr(o),oe(o,133)?(i=o,J(new Uq(i))):J(o)}return n=(!e.a&&(e.a=new RK(e)),e.a),r<n.i&&r>=0?c(re(n,r),57):null}function iGt(e,t){if(e<0)return zT(Rst,W(V(Br,1),Lt,1,5,["index",Pe(e)]));if(t<0)throw J(new qt($st+t));return zT("%s (%s) must be less than size (%s)",W(V(Br,1),Lt,1,5,["index",Pe(e),Pe(t)]))}function rGt(e){var t,n,i,r,o;if(e==null)return pl;for(o=new ub(Jc,"[","]"),n=e,i=0,r=n.length;i<r;++i)t=n[i],o.a?Zn(o.a,o.b):o.a=new Lu(o.d),j7(o.a,""+t);return o.a?o.e.length==0?o.a.a:o.a.a+(""+o.e):o.c}function sGt(e){var t,n,i,r,o;if(e==null)return pl;for(o=new ub(Jc,"[","]"),n=e,i=0,r=n.length;i<r;++i)t=n[i],o.a?Zn(o.a,o.b):o.a=new Lu(o.d),j7(o.a,""+t);return o.a?o.e.length==0?o.a.a:o.a.a+(""+o.e):o.c}function oGt(e){var t,n,i,r,o;if(e==null)return pl;for(o=new ub(Jc,"[","]"),n=e,i=0,r=n.length;i<r;++i)t=n[i],o.a?Zn(o.a,o.b):o.a=new Lu(o.d),j7(o.a,""+t);return o.a?o.e.length==0?o.a.a:o.a.a+(""+o.e):o.c}function cGt(e){var t,n,i,r,o;if(e==null)return pl;for(o=new ub(Jc,"[","]"),n=e,i=0,r=n.length;i<r;++i)t=n[i],o.a?Zn(o.a,o.b):o.a=new Lu(o.d),j7(o.a,""+t);return o.a?o.e.length==0?o.a.a:o.a.a+(""+o.e):o.c}function _et(e,t){var n,i,r,o,a,d;for(n=e.b.c.length,r=Xe(e.b,t);t*2+1<n&&(i=(o=2*t+1,a=o+1,d=o,a<n&&e.a.Le(Xe(e.b,a),Xe(e.b,o))<0&&(d=a),d),!(e.a.Le(r,Xe(e.b,i))<0));)Su(e.b,t,Xe(e.b,i)),t=i;Su(e.b,t,r)}function Jne(e,t,n){var i,r;return i=n.d,r=n.e,e.g[i.d]<=e.i[t.d]&&e.i[t.d]<=e.i[i.d]&&e.g[r.d]<=e.i[t.d]&&e.i[t.d]<=e.i[r.d]?!(e.i[i.d]<e.i[r.d]):e.i[i.d]<e.i[r.d]}function lGt(e,t){var n;if(n=c(R(t,(Ge(),KE)),302),n!=e)throw J(new Y4("The hierarchy aware processor "+n+" in child node "+t+" is only allowed if the root node specifies the same hierarchical processor."))}function uGt(e,t){var n,i,r,o,a;for(i=(!t.s&&(t.s=new Me(xl,t,21,17)),t.s),o=null,r=0,a=i.i;r<a;++r)switch(n=c(re(i,r),182),zm(uo(e,n))){case 2:case 3:!o&&(o=new Fe),It(o.c,n)}return o||(Ct(),Ct(),Rs)}function Det(e,t,n){var i,r,o,a,d,b;for(b=nr,o=new G(snt(e.b));o.a<o.c.c.length;)for(r=c(Q(o),180),d=new G(snt(t.b));d.a<d.c.c.length;)a=c(Q(d),180),i=WIt(r.a,r.b,a.a,a.b,n),b=p.Math.min(b,i);return b}function $r(e,t){if(!t)throw J(new U4);if(e.j=t,!e.d)switch(e.j.g){case 1:e.a.a=e.o.a/2,e.a.b=0;break;case 2:e.a.a=e.o.a,e.a.b=e.o.b/2;break;case 3:e.a.a=e.o.a/2,e.a.b=e.o.b;break;case 4:e.a.a=0,e.a.b=e.o.b/2}}function aGt(e){var t,n,i,r,o,a,d;for(i=0,n=new G(e.b);n.a<n.c.c.length;)for(t=c(Q(n),26),o=new G(t.a);o.a<o.c.c.length;)for(r=c(Q(o),9),r.p=i++,d=new G(r.j);d.a<d.c.c.length;)a=c(Q(d),12),a.p=i++}function fGt(e,t){Pu();var n,i,r,o,a,d;for(n=null,a=t.Jc();a.Ob();)o=c(a.Pb(),134),!o.o&&(i=bjt(o.a),r=CCt(o.a),d=new QT(i,r,null,c(o.d.a.ec().Jc().Pb(),17)),qe(d.c,o.a),It(e.c,d),n&&qe(n.d,d),n=d)}function hGt(e){var t,n,i,r,o,a;for(a=bT(e.d,e.e),o=a.Jc();o.Ob();)for(r=c(o.Pb(),12),i=e.e==(Je(),Yt)?r.e:r.g,n=new G(i);n.a<n.c.c.length;)t=c(Q(n),17),!vs(t)&&t.c.i.c!=t.d.i.c&&(fQt(e,t),++e.f,++e.c)}function Let(e,t){var n,i;if(t.dc())return Ct(),Ct(),Rs;for(i=new Fe,qe(i,Pe(ls)),n=1;n<e.f;++n)e.a==null&&Xnt(e),e.a[n]&&qe(i,Pe(n));return i.c.length==1?(Ct(),Ct(),Rs):(qe(i,Pe(di)),hKt(t,i))}function dGt(e,t){var n,i,r,o,a,d,b;a=t.c.i.k!=(Jt(),or),b=a?t.d:t.c,n=SFt(t,b).i,r=c(Ut(e.k,b),126),i=e.i[n.p].a,Nze(b.i)<(n.c?Do(n.c.a,n,0):-1)?(o=r,d=i):(o=i,d=r),Of(uf(ff(hf(af(new Ra,0),4),o),d))}function Pet(e,t,n){var i,r,o,a,d,b;if(n)for(r=n.a.length,i=new Xp(r),d=(i.b-i.a)*i.c<0?(x0(),wp):new S0(i);d.Ob();)a=c(d.Pb(),15),b=yne(e,G5(tv(n,a.a))),b&&(o=(!t.b&&(t.b=new Et(vn,t,4,7)),t.b),Nn(o,b))}function Iet(e,t,n){var i,r,o,a,d,b;if(n)for(r=n.a.length,i=new Xp(r),d=(i.b-i.a)*i.c<0?(x0(),wp):new S0(i);d.Ob();)a=c(d.Pb(),15),b=yne(e,G5(tv(n,a.a))),b&&(o=(!t.c&&(t.c=new Et(vn,t,5,8)),t.c),Nn(o,b))}function FD(e,t,n){var i,r;i=t.a&e.f,t.b=e.b[i],e.b[i]=t,r=t.f&e.f,t.d=e.c[r],e.c[r]=t,n?(t.e=n.e,t.e?t.e.c=t:e.a=t,t.c=n.c,t.c?t.c.e=t:e.e=t):(t.e=e.e,t.c=null,e.e?e.e.c=t:e.a=t,e.e=t),++e.i,++e.g}function Ret(e){var t,n,i;if(t=e.Pb(),!e.Ob())return t;for(i=Sc(Zn(new b0,"expected one element but was: <"),t),n=0;n<4&&e.Ob();n++)Sc((i.a+=Jc,i),e.Pb());throw e.Ob()&&(i.a+=", ..."),i.a+=">",J(new qt(i.a))}function gGt(e){var t,n;return n=-e.a,t=W(V(Na,1),fd,30,15,[43,48,48,48,48]),n<0&&(t[0]=45,n=-n),t[1]=t[1]+((n/60|0)/10|0)&_r,t[2]=t[2]+(n/60|0)%10&_r,t[3]=t[3]+(n%60/10|0)&_r,t[4]=t[4]+n%10&_r,od(t,0,t.length)}function lve(e){var t,n,i,r;for(e.g=new yT(c(Rn($s),299)),i=0,n=(Je(),Kt),t=0;t<e.j.c.length;t++)r=c(Xe(e.j,t),12),r.j!=n&&(i!=t&&v5(e.g,n,new Ps(Pe(i),Pe(t))),n=r.j,i=t);v5(e.g,n,new Ps(Pe(i),Pe(t)))}function uve(e,t){var n,i,r;if(r=qx((Dl(),ps),e.Ah(),t),r)qs(),c(r,69).vk()||(r=S5(uo(ps,r))),i=(n=e.Fh(r),c(n>=0?e.Ih(n,!0,!0):ow(e,r,!0),164)),c(i,222).Xl(t);else throw J(new qt(V0+t.ve()+pE))}function ave(e){var t,n;return e>-0x800000000000&&e<0x800000000000?e==0?0:(t=e<0,t&&(e=-e),n=xs(p.Math.floor(p.Math.log(e)/.6931471805599453)),(!t||e!=p.Math.pow(2,n))&&++n,n):HWe(Zo(e))}function pGt(e){var t,n,i,r,o,a,d;for(o=new Ld,n=new G(e);n.a<n.c.c.length;)t=c(Q(n),135),a=t.a,d=t.b,!(o.a._b(a)||o.a._b(d))&&(r=a,i=d,a.e.b+a.j.b>2&&d.e.b+d.j.b<=2&&(r=d,i=a),o.a.yc(r,o),r.q=i);return o}function bGt(e,t,n){n.Tg("Eades radial",1),n.bh(t,kG),e.d=c(ke(t,(vx(),k3)),19),e.c=ue(he(ke(t,(F0(),AJ)))),e.e=ane(c(ke(t,yP),304)),e.a=rBt(c(ke(t,j8e),431)),e.b=wqt(c(ke(t,x8e),355)),nqt(e),n.bh(t,kG)}function mGt(e,t){if(t.Tg("Target Width Setter",1),ga(e,(Ah(),xue)))ii(e,(Gd(),Yv),he(ke(e,xue)));else throw J(new Wh("A target width has to be set if the TargetWidthWidthApproximator should be used."));t.Ug()}function $et(e,t){var n,i,r;return i=new Eh(e),ec(i,t),Ee(i,(De(),GU),t),Ee(i,(Ge(),cr),(Zr(),xc)),Ee(i,vd,(Hd(),qJ)),mu(i,(Jt(),Cr)),n=new bc,_o(n,i),$r(n,(Je(),Yt)),r=new bc,_o(r,i),$r(r,nn),i}function Bet(e,t){var n,i,r,o,a;for(e.c[t.p]=!0,qe(e.a,t),a=new G(t.j);a.a<a.c.c.length;)for(o=c(Q(a),12),i=new kh(o.b);No(i.a)||No(i.b);)n=c(No(i.a)?Q(i.a):Q(i.b),17),r=OBt(o,n).i,e.c[r.p]||Bet(e,r)}function zet(e){var t,n,i,r,o,a,d;for(a=0,n=new cn((!e.a&&(e.a=new Me(Mn,e,10,11)),e.a));n.e!=n.i.gc();)t=c(un(n),19),d=t.g,r=t.f,i=p.Math.sqrt(d*d+r*r),a=p.Math.max(i,a),o=zet(t),a=p.Math.max(o,a);return a}function Ql(){Ql=te,hp=new x7("OUTSIDE",0),eg=new x7("INSIDE",1),RP=new x7("NEXT_TO_PORT_IF_POSSIBLE",2),$C=new x7("ALWAYS_SAME_SIDE",3),RC=new x7("ALWAYS_OTHER_SAME_SIDE",4),Rk=new x7("SPACE_EFFICIENT",5)}function Fet(e,t,n){var i,r,o,a,d,b;return i=H_t(e,(r=(w0(),o=new Wj,o),n&&kQ(r,n),r),t),nS(i,M1(t,bd)),lQ(t,i),OUt(t,i),cve(t,i),a=t,d=Gm(a,"ports"),b=new GRe(e,i),ent(b.a,b.b,d),Tte(e,t,i),qIt(e,t,i),i}function wGt(e){var t,n;return n=-e.a,t=W(V(Na,1),fd,30,15,[43,48,48,58,48,48]),n<0&&(t[0]=45,n=-n),t[1]=t[1]+((n/60|0)/10|0)&_r,t[2]=t[2]+(n/60|0)%10&_r,t[4]=t[4]+(n%60/10|0)&_r,t[5]=t[5]+n%10&_r,od(t,0,t.length)}function vGt(e){var t,n,i,r,o;if(e==null)return pl;for(o=new ub(Jc,"[","]"),n=e,i=0,r=n.length;i<r;++i)t=n[i],o.a?Zn(o.a,o.b):o.a=new Lu(o.d),j7(o.a,""+R7(t));return o.a?o.e.length==0?o.a.a:o.a.a+(""+o.e):o.c}function fve(e,t){var n,i,r;for(r=di,i=new G(Ax(t));i.a<i.c.c.length;)n=c(Q(i),220),n.f&&!e.c[n.c]&&(e.c[n.c]=!0,r=p.Math.min(r,fve(e,DH(n,t))));return e.i[t.d]=e.j,e.g[t.d]=p.Math.min(r,e.j++),e.g[t.d]}function qet(e,t){var n,i,r;for(r=c(c(Si(e.r,t),24),85).Jc();r.Ob();)i=c(r.Pb(),116),i.e.b=(n=i.b,n.nf((Dn(),fu))?n.$f()==(Je(),Kt)?-n.Kf().b-ue(he(n.mf(fu))):ue(he(n.mf(fu))):n.$f()==(Je(),Kt)?-n.Kf().b:0)}function hve(e){var t,n,i,r,o;t=e.a,n=e.b,r=e.c,i=new $e(n.e.a+n.f.a/2,n.e.b+n.f.b/2),o=new $e(r.e.a+r.f.a/2,r.e.b+r.f.b/2),tr(t,i,t.a,t.a.a),tr(t,o,t.c.b,t.c),GZe(i,c(pc(t,1),8),e.b.f),GZe(o,c(pc(t,t.b-2),8),e.c.f)}function Het(e,t){var n,i,r,o;if(r=(!t.e&&(t.e=new Et(Ii,t,7,4)),t.e).i,r==0)return t.i;for(i=0,o=0,n=0;n<r;n++)o=Het(e,c(re(H6(c(re((!t.e&&(t.e=new Et(Ii,t,7,4)),t.e),n),74)),0),19)),i=o<i?o:i;return i+t.i}function G5(e){var t,n;if(n=!1,oe(e,213))return n=!0,c(e,213).a;if(!n&&oe(e,266)&&(t=c(e,266).a%1==0,t))return n=!0,Pe(z8t(c(e,266).a));throw J(new Kh("Id must be a string or an integer: '"+e+"'."))}function yGt(e,t){var n,i,r,o,a,d;for(o=null,r=new nqe((!e.a&&(e.a=new RK(e)),e.a));mve(r);)if(n=c(mQ(r),57),i=(a=n.Ah(),d=(Fx(a),a.o),!d||!n.Uh(d)?null:c0e(vte(d),n.Jh(d))),i!=null&&Ot(i,t)){o=n;break}return o}function Qet(e,t){var n;this.e=(Rn(e),Bwe(e)),this.c=(Rn(t),Bwe(t)),yge(this.e.Pd().dc()==this.c.Pd().dc()),this.d=sKe(this.e),this.b=sKe(this.c),n=H2(Br,[Be,Lt],[5,1],5,[this.e.Pd().gc(),this.c.Pd().gc()],2),this.a=n,FPt(this)}function Get(e,t,n){var i,r,o,a,d;if(zu(n,"occurrences"),n==0)return d=c(lv(k5(e.a),t),18),d?d.gc():0;if(a=c(lv(k5(e.a),t),18),!a)return 0;if(o=a.gc(),n>=o)a.$b();else for(r=a.Jc(),i=0;i<n;i++)r.Pb(),r.Qb();return o}function xGt(e,t,n){var i,r,o,a;return zu(n,"oldCount"),zu(0,"newCount"),i=c(lv(k5(e.a),t),18),(i?i.gc():0)==n?(zu(0,"count"),r=(o=c(lv(k5(e.a),t),18),o?o.gc():0),a=-r,a>0?Vde():a<0&&Get(e,t,-a),!0):!1}function kGt(e){var t;return t=W(V(Na,1),fd,30,15,[71,77,84,45,48,48,58,48,48]),e<=0&&(t[3]=43,e=-e),t[4]=t[4]+((e/60|0)/10|0)&_r,t[5]=t[5]+(e/60|0)%10&_r,t[7]=t[7]+(e%60/10|0)&_r,t[8]=t[8]+e%10&_r,od(t,0,t.length)}function _T(e){var t,n,i,r,o,a,d;if(d=0,e.b==0){for(a=mYe(e,!0),t=0,i=a,r=0,o=i.length;r<o;++r)n=i[r],n>0&&(d+=n,++t);t>1&&(d+=e.c*(t-1))}else d=aPe(gte(X2(pi(QZ(e.a),new qf),new Cp)));return d>0?d+e.n.d+e.n.a:0}function DT(e){var t,n,i,r,o,a,d;if(d=0,e.b==0)d=aPe(gte(X2(pi(QZ(e.a),new Ff),new lg)));else{for(a=wYe(e,!0),t=0,i=a,r=0,o=i.length;r<o;++r)n=i[r],n>0&&(d+=n,++t);t>1&&(d+=e.c*(t-1))}return d>0?d+e.n.b+e.n.c:0}function OGt(e){var t,n;if(e.c.length!=2)throw J(new oo("Order only allowed for two paths."));t=(ht(0,e.c.length),c(e.c[0],17)),n=(ht(1,e.c.length),c(e.c[1],17)),t.d.i!=n.c.i&&(e.c.length=0,It(e.c,n),It(e.c,t))}function Uet(e,t,n){var i;for(_m(n,t.g,t.f),aa(n,t.i,t.j),i=0;i<(!t.a&&(t.a=new Me(Mn,t,10,11)),t.a).i;i++)Uet(e,c(re((!t.a&&(t.a=new Me(Mn,t,10,11)),t.a),i),19),c(re((!n.a&&(n.a=new Me(Mn,n,10,11)),n.a),i),19))}function SGt(e,t){var n,i,r,o;for(o=c(Zs(e.b,t),129),n=o.a,r=c(c(Si(e.r,t),24),85).Jc();r.Ob();)i=c(r.Pb(),116),i.c&&(n.a=p.Math.max(n.a,P0e(i.c)));if(n.a>0)switch(t.g){case 2:o.n.c=e.s;break;case 4:o.n.b=e.s}}function jGt(e,t){var n,i,r;return n=c(R(t,(Sf(),dk)),15).a-c(R(e,dk),15).a,n==0?(i=Hr(Ms(c(R(e,(N0(),QL)),8)),c(R(e,DE),8)),r=Hr(Ms(c(R(t,QL),8)),c(R(t,DE),8)),ji(i.a*i.b,r.a*r.b)):n}function TGt(e,t){var n,i,r;return n=c(R(t,(Uo(),jJ)),15).a-c(R(e,jJ),15).a,n==0?(i=Hr(Ms(c(R(e,(Li(),mP)),8)),c(R(e,G9),8)),r=Hr(Ms(c(R(t,mP),8)),c(R(t,G9),8)),ji(i.a*i.b,r.a*r.b)):n}function Jet(e){var t,n;return n=new b0,n.a+="e_",t=IIt(e),t!=null&&(n.a+=""+t),e.c&&e.d&&(Zn((n.a+=" ",n),tQ(e.c)),Zn(Sc((n.a+="[",n),e.c.i),"]"),Zn((n.a+=jre,n),tQ(e.d)),Zn(Sc((n.a+="[",n),e.d.i),"]")),n.a}function Xet(e){switch(e.g){case 0:return new FB;case 1:return new jN;case 2:return new EN;case 3:return new gK;default:throw J(new qt("No implementation is available for the layout phase "+(e.f!=null?e.f:""+e.g)))}}function dve(e,t,n,i,r){var o;switch(o=0,r.g){case 1:o=p.Math.max(0,t.b+e.b-(n.b+i));break;case 3:o=p.Math.max(0,-e.b-i);break;case 2:o=p.Math.max(0,-e.a-i);break;case 4:o=p.Math.max(0,t.a+e.a-(n.a+i))}return o}function Vet(e,t,n){var i,r,o,a,d;if(n)for(r=n.a.length,i=new Xp(r),d=(i.b-i.a)*i.c<0?(x0(),wp):new S0(i);d.Ob();)a=c(d.Pb(),15),o=X6(n,a.a),h5e in o.a||Zse in o.a?DVt(e,o,t):itn(e,o,t),Bjt(c(Ut(e.c,kS(o)),74))}function gve(e){var t,n;switch(e.b){case-1:return!0;case 0:return n=e.t,n>1||n==-1?(e.b=-1,!0):(t=Qa(e),t&&(qs(),t.jk()==Iut)?(e.b=-1,!0):(e.b=1,!1));default:case 1:return!1}}function pve(e,t){var n,i,r,o;if(bi(e),e.c!=0||e.a!=123)throw J(new Qn(Vn((Bn(),rut))));if(o=t==112,i=e.d,n=A6(e.i,125,i),n<0)throw J(new Qn(Vn((Bn(),sut))));return r=Fa(e.i,i,n),e.d=n+1,XUe(r,o,(e.e&512)==512)}function EGt(e){var t,n,i,r,o,a,d;for(d=Pd(e.c.length),r=new G(e);r.a<r.c.c.length;){for(i=c(Q(r),9),a=new Or,o=$i(i),n=new Ht(Vt(o.a.Jc(),new U));hn(n);)t=c(sn(n),17),t.c.i==t.d.i||Sr(a,t.d.i);It(d.c,a)}return d}function CGt(e,t){var n,i,r;if(!t)ote(e,null),tS(e,null);else if((t.i&4)!=0)for(i="[]",n=t.c;;n=n.c){if((n.i&4)==0){r=Xde((j1(n),n.o+i)),ote(e,r),tS(e,r);break}i+="[]"}else r=Xde((j1(t),t.o)),ote(e,r),tS(e,r);e.fl(t)}function LT(e,t,n,i,r){var o,a,d,b;return b=fZ(e,c(r,57)),ve(b)!==ve(r)?(d=c(e.g[n],76),o=Fd(t,b),M7(e,n,Dne(e,n,o)),wu(e.e)&&(a=E0(e,9,o.Jk(),r,b,i,!1),T2e(a,new _1(e.e,9,e.c,d,o,i,!1)),Gee(a)),b):r}function Wet(e,t){var n,i,r;try{return r=f_t(e.a,t),r}catch(o){if(o=vr(o),oe(o,33)){try{if(i=Hu(t,ls,di),n=Jf(e.a),i>=0&&i<n.length)return n[i]}catch(a){if(a=vr(a),!oe(a,133))throw J(a)}return null}else throw J(o)}}function Xne(e,t){var n,i,r;if(r=qx((Dl(),ps),e.Ah(),t),r)return qs(),c(r,69).vk()||(r=S5(uo(ps,r))),i=(n=e.Fh(r),c(n>=0?e.Ih(n,!0,!0):ow(e,r,!0),164)),c(i,222).Ul(t);throw J(new qt(V0+t.ve()+Qse))}function MGt(){w1e();var e;return evt?c(NS((y0(),nf),Ja),2017):(li(Mb,new vm),jZt(),e=c(oe(Tc((y0(),nf),Ja),552)?Tc(nf,Ja):new $qe,552),evt=!0,Stn(e),Atn(e),oi((m1e(),ETe),e,new WO),lo(nf,Ja,e),e)}function AGt(e,t){var n,i,r,o;e.j=-1,wu(e.e)?(n=e.i,o=e.i!=0,U_(e,t),i=new _1(e.e,3,e.c,null,t,n,o),r=t.xl(e.e,e.c,null),r=yZe(e,t,r),r?(r.lj(i),r.mj()):vi(e.e,i)):(U_(e,t),r=t.xl(e.e,e.c,null),r&&r.mj())}function gQ(e,t){var n,i,r;if(r=0,i=t[0],i>=e.length)return-1;for(n=(en(i,e.length),e.charCodeAt(i));n>=48&&n<=57&&(r=r*10+(n-48),++i,!(i>=e.length));)n=(en(i,e.length),e.charCodeAt(i));return i>t[0]?t[0]=i:r=-1,r}function NGt(e,t,n){var i,r,o,a,d;a=e.c,d=e.d,o=Lo(W(V(Vr,1),Be,8,0,[a.i.n,a.n,a.a])).b,r=(o+Lo(W(V(Vr,1),Be,8,0,[d.i.n,d.n,d.a])).b)/2,i=null,a.j==(Je(),nn)?i=new $e(t+a.i.c.c.a+n,r):i=new $e(t-n,r),M6(e.a,0,i)}function sw(e){var t,n,i,r;for(t=null,i=Bd(ma(W(V(Ta,1),Lt,22,0,[(!e.b&&(e.b=new Et(vn,e,4,7)),e.b),(!e.c&&(e.c=new Et(vn,e,5,8)),e.c)])));hn(i);)if(n=c(sn(i),83),r=to(n),!t)t=r;else if(t!=r)return!1;return!0}function Vne(e,t,n){var i;if(++e.j,t>=e.i)throw J(new zc(toe+t+Tb+e.i));if(n>=e.i)throw J(new zc(noe+n+Tb+e.i));return i=e.g[n],t!=n&&(t<n?mc(e.g,t,e.g,t+1,n-t):mc(e.g,n+1,e.g,n,t-n),dr(e.g,t,i),e.Ni(t,i,n),e.Li()),i}function St(e,t,n){var i;if(i=c(e.c.xc(t),18),i)return i.Ec(n)?(++e.d,!0):!1;if(i=e.ic(t),i.Ec(n))return++e.d,e.c.yc(t,i),!0;throw J(new ube("New Collection violated the Collection spec"))}function qD(e){var t,n,i;return e<0?0:e==0?32:(i=-(e>>16),t=i>>16&16,n=16-t,e=e>>t,i=e-256,t=i>>16&8,n+=t,e<<=t,i=e-jv,t=i>>16&4,n+=t,e<<=t,i=e-ad,t=i>>16&2,n+=t,e<<=t,i=e>>14,t=i&~(i>>1),n+2-t)}function _Gt(e,t){var n,i,r;for(r=new Fe,i=_n(t.a,0);i.b!=i.d.c;)n=c(An(i),65),n.c.g==e.g&&ve(R(n.b,(Uo(),xd)))!==ve(R(n.c,xd))&&!Sx(new jt(null,new Tt(r,16)),new D_e(n))&&It(r.c,n);return Rr(r,new w2),r}function Ket(e,t,n){var i,r,o,a;return oe(t,156)&&oe(n,156)?(o=c(t,156),a=c(n,156),e.a[o.a][a.a]+e.a[a.a][o.a]):oe(t,254)&&oe(n,254)&&(i=c(t,254),r=c(n,254),i.a==r.a)?c(R(r.a,(Sf(),dk)),15).a:0}function Yet(e,t){var n,i,r,o,a,d,b,v;for(v=ue(he(R(t,(Ge(),tC)))),b=e[0].n.a+e[0].o.a+e[0].d.c+v,d=1;d<e.length;d++)i=e[d].n,r=e[d].o,n=e[d].d,o=i.a-n.b-b,o<0&&(i.a-=o),a=t.f,a.a=p.Math.max(a.a,i.a+r.a),b=i.a+r.a+n.c+v}function DGt(e,t){var n,i,r,o,a,d;return i=c(c(Ut(e.g,t.a),49).a,68),r=c(c(Ut(e.g,t.b),49).a,68),o=i.b,a=r.b,n=lYt(o,a),n>=0?n:(d=H7(Hr(new $e(a.c+a.b/2,a.d+a.a/2),new $e(o.c+o.b/2,o.d+o.a/2))),-(Nit(o,a)-1)*d)}function LGt(e,t,n){var i;lr(new jt(null,(!n.a&&(n.a=new Me(Hi,n,6,6)),new Tt(n.a,16))),new ARe(e,t)),lr(new jt(null,(!n.n&&(n.n=new Me(Bo,n,1,7)),new Tt(n.n,16))),new NRe(e,t)),i=c(ke(n,(Dn(),T3)),79),i&&wme(i,e,t)}function ow(e,t,n){var i,r,o;if(o=qx((Dl(),ps),e.Ah(),t),o)return qs(),c(o,69).vk()||(o=S5(uo(ps,o))),r=(i=e.Fh(o),c(i>=0?e.Ih(i,!0,!0):ow(e,o,!0),164)),c(r,222).Ql(t,n);throw J(new qt(V0+t.ve()+Qse))}function bve(e,t,n,i){var r,o,a,d,b;if(r=e.d[t],r){if(o=r.g,b=r.i,i!=null){for(d=0;d<b;++d)if(a=c(o[d],138),a.yi()==n&&yi(i,a.jd()))return a}else for(d=0;d<b;++d)if(a=c(o[d],138),ve(a.jd())===ve(i))return a}return null}function PGt(e,t){var n,i,r,o,a;for(i=(!t.s&&(t.s=new Me(xl,t,21,17)),t.s),o=null,r=0,a=i.i;r<a;++r)switch(n=c(re(i,r),182),zm(uo(e,n))){case 4:case 5:case 6:{!o&&(o=new Fe),It(o.c,n);break}}return o||(Ct(),Ct(),Rs)}function HD(e,t){var n;if(t<0)throw J(new Sz("Negative exponent"));if(t==0)return YG;if(t==1||Swe(e,YG)||Swe(e,ME))return e;if(!jtt(e,0)){for(n=1;!jtt(e,n);)++n;return Ox(tBt(n*t),HD(fbe(e,n),t))}return lHt(e,t)}function IGt(e,t){var n,i,r;if(ve(e)===ve(t))return!0;if(e==null||t==null||e.length!=t.length)return!1;for(n=0;n<e.length;++n)if(i=e[n],r=t[n],!(ve(i)===ve(r)||i!=null&&yi(i,r)))return!1;return!0}function Zet(e){g1e();var t,n,i;for(this.b=Mht,this.c=(Nr(),qh),this.f=(MIe(),Cht),this.a=e,e1e(this,new r2),OQ(this),i=new G(e.b);i.a<i.c.c.length;)n=c(Q(i),84),n.d||(t=new nne(W(V(Zoe,1),Lt,84,0,[n])),qe(e.a,t))}function ett(e){Cpe();var t,n;for(this.b=cft,this.c=uft,this.g=(AIe(),oft),this.d=(Nr(),qh),this.a=e,Hve(this),n=new G(e.b);n.a<n.c.c.length;)t=c(Q(n),60),!t.a&&yBe(TXe(new Nde,W(V(nU,1),Lt,60,0,[t])),e),t.e=new mq(t.d)}function RGt(e,t,n){var i,r,o,a,d,b;if(!e||e.c.length==0)return null;for(o=new MHe(t,!n),r=new G(e);r.a<r.c.c.length;)i=c(Q(r),70),X2e(o,(s7(),new hz(i)));return a=o.i,a.a=(b=o.n,o.e.b+b.d+b.a),a.b=(d=o.n,o.e.a+d.b+d.c),o}function ttt(e){var t,n,i,r,o,a,d;for(d=q_(e.a),rge(d,new q8),n=null,r=d,o=0,a=r.length;o<a&&(i=r[o],i.k==(Jt(),Cr));++o)t=c(R(i,(De(),Ko)),64),!(t!=(Je(),Yt)&&t!=nn)&&(n&&c(R(n,yk),16).Ec(i),n=i)}function $Gt(e,t,n){var i,r,o,a,d,b,v;b=(ht(t,e.c.length),c(e.c[t],341)),Mg(e,t),b.b/2>=n&&(i=t,v=(b.c+b.a)/2,a=v-n,b.c<=v-n&&(r=new OZ(b.c,a),Up(e,i++,r)),d=v+n,d<=b.a&&(o=new OZ(d,b.a),K2(i,e.c.length),h7(e.c,i,o)))}function ntt(e,t,n){var i,r,o,a,d,b;if(!t.dc()){for(r=new Ai,b=t.Jc();b.Ob();)for(d=c(b.Pb(),41),oi(e.a,Pe(d.g),Pe(n)),a=(i=_n(new k1(d).a.d,0),new ix(i));XN(a.a);)o=c(An(a.a),65).c,tr(r,o,r.c.b,r.c);ntt(e,r,n+1)}}function mve(e){var t;if(!e.c&&e.g==null)e.d=e._i(e.f),Nn(e,e.d),t=e.d;else{if(e.g==null)return!0;if(e.i==0)return!1;t=c(e.g[e.i-1],51)}return t==e.b&&null.Tm>=null.Sm()?(mQ(e),mve(e)):t.Ob()}function itt(e){if(this.a=e,e.c.i.k==(Jt(),Cr))this.c=e.c,this.d=c(R(e.c.i,(De(),Ko)),64);else if(e.d.i.k==Cr)this.c=e.d,this.d=c(R(e.d.i,(De(),Ko)),64);else throw J(new qt("Edge "+e+" is not an external edge."))}function rtt(e,t){var n,i,r;r=e.b,e.b=t,(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,3,r,e.b)),t?t!=e&&(Gc(e,t.zb),ite(e,t.d),n=(i=t.c,i??t.zb),ste(e,n==null||Ot(n,t.zb)?null:n)):(Gc(e,null),ite(e,0),ste(e,null))}function stt(e){!Moe&&(Moe=_en());var t=e.replace(/[\x00-\x1f\xad\u0600-\u0603\u06dd\u070f\u17b4\u17b5\u200b-\u200f\u2028-\u202e\u2060-\u2064\u206a-\u206f\ufeff\ufff9-\ufffb"\\]/g,function(n){return pNt(n)});return'"'+t+'"'}function wve(e,t,n,i,r,o){var a,d,b,v,x;if(r!=0)for(ve(e)===ve(n)&&(e=e.slice(t,t+r),t=0),b=n,d=t,v=t+r;d<v;)a=p.Math.min(d+1e4,v),r=a-d,x=e.slice(d,a),x.splice(0,0,i,o?r:0),Array.prototype.splice.apply(b,x),d=a,i+=r}function BGt(e){var t,n,i,r,o,a;for(r=e.e.c.length,i=ye(Ju,Tv,16,r,0,1),a=new G(e.e);a.a<a.c.c.length;)o=c(Q(a),156),i[o.a]=new Ai;for(n=new G(e.c);n.a<n.c.c.length;)t=c(Q(n),292),i[t.c.a].Ec(t),i[t.d.a].Ec(t);return i}function zGt(e,t){var n,i,r,o,a;if(n=c(Wt(e.a,4),131),a=n==null?0:n.length,t>=a)throw J(new F2(t,a));return r=n[t],a==1?i=null:(i=ye(Sae,coe,420,a-1,0,1),mc(n,0,i,0,t),o=a-t-1,o>0&&mc(n,t+1,i,t,o)),SS(e,i),jet(e,t,r),r}function ott(e){var t,n;if(e.f){for(;e.n<e.o;){if(t=c(e.j?e.j.Yi(e.n):e.k.Xb(e.n),76),n=t.Jk(),oe(n,104)&&(c(n,20).Bb&nc)!=0&&(!e.e||n.nk()!=o8||n.Jj()!=0)&&t.kd()!=null)return!0;++e.n}return!1}else return e.n<e.o}function U5(){U5=te,zk=c(re(Ne((s1e(),ic).qb),6),38),Bk=c(re(Ne(ic.qb),3),38),Aae=c(re(Ne(ic.qb),4),38),Nae=c(re(Ne(ic.qb),5),20),rQ(zk),rQ(Bk),rQ(Aae),rQ(Nae),rvt=new Ho(W(V(xl,1),Zx,182,0,[zk,Bk]))}function ctt(e,t){var n;this.d=new Vj,this.b=t,this.e=new Cs(t.Jf()),n=e.u.Gc((Ql(),RP)),e.u.Gc(eg)?e.F?this.a=n&&!t._f():this.a=!0:e.u.Gc(hp)?n?this.a=!(t.Sf().Jc().Ob()||t.Uf().Jc().Ob()):this.a=!1:this.a=!1}function ltt(e,t){var n,i,r,o;for(n=e.o.a,o=c(c(Si(e.r,t),24),85).Jc();o.Ob();)r=c(o.Pb(),116),r.e.a=(i=r.b,i.nf((Dn(),fu))?i.$f()==(Je(),Yt)?-i.Kf().a-ue(he(i.mf(fu))):n+ue(he(i.mf(fu))):i.$f()==(Je(),Yt)?-i.Kf().a:n)}function utt(e){var t,n,i,r,o,a,d;if(i=e.a.c.length,i>0)for(a=e.c.d,d=e.d.d,r=S1(Hr(new $e(d.a,d.b),a),1/(i+1)),o=new $e(a.a,a.b),n=new G(e.a);n.a<n.c.c.length;)t=c(Q(n),254),t.d.a=o.a+r.a,t.d.b=o.b+r.b,o.a+=r.a,o.b+=r.b}function att(e,t){var n,i,r,o;n=c(R(e,(Ge(),Xu)),87),o=c(ke(t,B9),64),r=c(R(e,cr),103),r!=(Zr(),Hh)&&r!=fp?o==(Je(),$o)&&(o=Sye(t,n),o==$o&&(o=I5(n))):(i=mrt(t),i>0?o=I5(n):o=jD(I5(n))),ii(t,B9,o)}function ftt(e,t){var n,i;if(e.c.length!=0){if(e.c.length==2)W5((ht(0,e.c.length),c(e.c[0],9)),(qu(),n1)),W5((ht(1,e.c.length),c(e.c[1],9)),up);else for(i=new G(e);i.a<i.c.c.length;)n=c(Q(i),9),W5(n,t);e.c.length=0}}function FGt(e,t){var n,i,r,o,a;for(a=e.j,t.a!=t.b&&Rr(a,new CR),r=a.c.length/2|0,i=0;i<r;i++)o=(ht(i,a.c.length),c(a.c[i],114)),o.c&&$r(o.d,t.a);for(n=r;n<a.c.length;n++)o=(ht(n,a.c.length),c(a.c[n],114)),o.c&&$r(o.d,t.b)}function J5(e,t,n,i){var r;switch(r=0,c(R(t,(Ge(),Ro)),166).g){case 2:r=2*-n+e.a,++e.a;break;case 1:r=-n;break;case 3:r=n;break;case 4:r=2*n+e.b,++e.b}return xi(t,(De(),Pi))&&(r+=c(R(t,zv),15).a*i+c(R(t,Pi),15).a),r}function qGt(e,t,n){var i,r,o;return i=e.c[t.c.p][t.p],r=e.c[n.c.p][n.p],i.a!=null&&r.a!=null?(o=BZ(i.a,r.a),o<0?VD(e,t,n):o>0&&VD(e,n,t),o):i.a!=null?(VD(e,t,n),-1):r.a!=null?(VD(e,n,t),1):0}function htt(e){mee();var t,n,i,r,o,a,d;for(n=new M0,r=new G(e.e.b);r.a<r.c.c.length;)for(i=c(Q(r),26),a=new G(i.a);a.a<a.c.c.length;)o=c(Q(a),9),d=e.g[o.p],t=c(Oh(n,d),16),t||(t=new Fe,gb(n,d,t)),t.Ec(o);return n}function HGt(e,t){var n,i,r,o,a;for(r=t.b.b,e.a=ye(Ju,Tv,16,r,0,1),e.b=ye(kl,eh,30,r,16,1),a=_n(t.b,0);a.b!=a.d.c;)o=c(An(a),41),e.a[o.g]=new Ai;for(i=_n(t.a,0);i.b!=i.d.c;)n=c(An(i),65),e.a[n.b.g].Ec(n),e.a[n.c.g].Ec(n)}function dtt(e,t){var n,i,r,o;e.Nj()?(n=e.Cj(),o=e.Oj(),++e.j,e.oj(n,e.Xi(n,t)),i=e.Gj(3,null,t,n,o),e.Kj()?(r=e.Lj(t,null),r?(r.lj(i),r.mj()):e.Hj(i)):e.Hj(i)):(Cqe(e,t),e.Kj()&&(r=e.Lj(t,null),r&&r.mj()))}function vve(e,t,n){var i,r,o;e.Nj()?(o=e.Oj(),kD(e,t,n),i=e.Gj(3,null,n,t,o),e.Kj()?(r=e.Lj(n,null),e.Rj()&&(r=e.Sj(n,r)),r?(r.lj(i),r.mj()):e.Hj(i)):e.Hj(i)):(kD(e,t,n),e.Kj()&&(r=e.Lj(n,null),r&&r.mj()))}function pQ(e,t){var n,i,r,o,a;for(a=nl(e.e.Ah(),t),r=new S4,n=c(e.g,123),o=e.i;--o>=0;)i=n[o],a.$l(i.Jk())&&Nn(r,i);!bst(e,r)&&wu(e.e)&&b6(e,t.Hk()?E0(e,6,t,(Ct(),Rs),null,-1,!1):E0(e,t.rk()?2:1,t,null,null,-1,!1))}function QGt(e,t){var n,i,r,o,a;return e.a==(MS(),BE)?!0:(o=t.a.c,n=t.a.c+t.a.b,!(t.j&&(i=t.A,a=i.c.c.a-i.o.a/2,r=o-(i.n.a+i.o.a),r>a)||t.q&&(i=t.C,a=i.c.c.a-i.o.a/2,r=i.n.a-n,r>a)))}function gtt(e,t,n){var i,r,o,a,d,b;for(i=0,b=n,t||(i=n*(e.c.length-1),b*=-1),o=new G(e);o.a<o.c.c.length;){for(r=c(Q(o),9),Ee(r,(Ge(),vd),(Hd(),qJ)),r.o.a=i,d=Bg(r,(Je(),nn)).Jc();d.Ob();)a=c(d.Pb(),12),a.n.a=i;i+=b}}function ptt(e){var t;return(e.Db&64)!=0?kf(e):(t=new Ba(kf(e)),t.a+=" (startX: ",rx(t,e.j),t.a+=", startY: ",rx(t,e.k),t.a+=", endX: ",rx(t,e.b),t.a+=", endY: ",rx(t,e.c),t.a+=", identifier: ",Ys(t,e.d),t.a+=")",t.a)}function yve(e){var t;return(e.Db&64)!=0?pT(e):(t=new Ba(pT(e)),t.a+=" (ordered: ",xg(t,(e.Bb&256)!=0),t.a+=", unique: ",xg(t,(e.Bb&512)!=0),t.a+=", lowerBound: ",oY(t,e.s),t.a+=", upperBound: ",oY(t,e.t),t.a+=")",t.a)}function btt(e,t,n,i,r,o,a,d){var b;return oe(e.Cb,89)&&bv(ru(c(e.Cb,89)),4),Gc(e,n),e.f=i,mS(e,r),vS(e,o),bS(e,a),wS(e,!1),Rg(e,!0),yS(e,d),Ig(e,!0),_g(e,0),e.b=0,iv(e,1),b=Ch(e,t,null),b&&b.mj(),Hte(e,!1),e}function mtt(e,t){var n,i,r,o;return n=c(Tc(e.a,t),515),n||(i=new _ee(t),r=(Iq(),Ph?null:i.c),o=Fa(r,0,p.Math.max(0,SF(r,dl(46)))),eTt(i,mtt(e,o)),(Ph?null:i.c).length==0&&JBe(i,new Gn),lo(e.a,Ph?null:i.c,i),i)}function GGt(e,t){var n,i;return xi(e,(De(),p3))?xi(t,p3)?(n=he(R(e,p3)),i=he(R(t,p3)),n!=null&&i!=null?ji((zt(n),n),(zt(i),i)):n!=null?-1:i!=null?1:0):-1:1}function wtt(){this.a=new X$,this.n=new KH,this.p=new KH,this.c=new wn,this.f=new KH,this.o=new KH,this.q=new wn,this.d=new wn,this.g=new wn,this.k=new wn,this.e=new wn,this.i=new wn,this.j=new wn,this.r=new wn,this.b=new wn}function X5(e,t,n){var i,r,o,a,d,b;return d=e.nl(n),d!=n?(a=e.g[t],b=d,M7(e,t,e.Xi(t,b)),o=a,e.Pi(t,b,o),e.$k()&&(i=n,r=e.Mj(i,null),!c(d,52).Mh()&&(r=e.Lj(b,r)),r&&r.mj()),wu(e.e)&&b6(e,e.Gj(9,n,d,t,!1)),d):n}function UGt(e,t){var n,i,r,o;for(i=new G(e.a.a);i.a<i.c.c.length;)n=c(Q(i),197),n.g=!0;for(o=new G(e.a.b);o.a<o.c.c.length;)r=c(Q(o),84),r.k=et(Ze(e.e.Kb(new Ps(r,t)))),r.d.g=r.d.g&et(Ze(e.e.Kb(new Ps(r,t))));return e}function vtt(e,t,n){var i,r,o,a,d;if(!e.d[n.p]){for(r=new Ht(Vt($i(n).a.Jc(),new U));hn(r);){for(i=c(sn(r),17),d=i.d.i,a=new Ht(Vt(pr(d).a.Jc(),new U));hn(a);)o=c(sn(a),17),o.c.i==t&&(e.a[o.p]=!0);vtt(e,t,d)}e.d[n.p]=!0}}function JGt(e,t){var n,i,r,o,a,d,b;if(i=VWe(e.Db&254),i==1)e.Eb=null;else if(o=N5(e.Eb),i==2)r=kne(e,t),e.Eb=o[r==0?1:0];else{for(a=ye(Br,Lt,1,i-1,5,1),n=2,d=0,b=0;n<=128;n<<=1)n==t?++d:(e.Db&n)!=0&&(a[b++]=o[d++]);e.Eb=a}e.Db&=~t}function xve(e){var t;switch(t=0,e){case 105:t=2;break;case 109:t=8;break;case 115:t=4;break;case 120:t=16;break;case 117:t=32;break;case 119:t=64;break;case 70:t=256;break;case 72:t=128;break;case 88:t=512;break;case 44:t=Ga}return t}function XGt(e,t,n,i,r){var o,a,d,b;if(ve(e)===ve(t)&&i==r){Oit(e,i,n);return}for(d=0;d<i;d++){for(a=0,o=e[d],b=0;b<r;b++)a=As(As(Ss(Yr(o,Us),Yr(t[b],Us)),Yr(n[d+b],Us)),Yr(Hn(a),Us)),n[d+b]=Hn(a),a=Vp(a,32);n[d+r]=Hn(a)}}function ytt(e){var t,n,i,r,o;if(n=(t=c(Jf($s),10),new ha(t,c(gf(t,t.length),10),0)),o=c(R(e,(De(),Ul)),9),o)for(r=new G(o.j);r.a<r.c.c.length;)i=c(Q(r),12),ve(R(i,Oi))===ve(e)&&N7(new kh(i.b))&&yf(n,i.j);return n}function VGt(e,t){var n,i,r;for(i=new G(e.i.d);i.a<i.c.c.length;)n=c(Q(i),70),Ee(n,(Ge(),b3),null);switch(t.g){case 2:case 4:r=e.a,e.c.d.n.b<r.d.n.b&&(r=e.c),Eg(e,t,(xf(),fce),r);break;case 1:case 3:Eg(e,t,(xf(),Iv),null)}}function xtt(e,t){t.b!=0&&(isNaN(e.s)?e.s=ue((dn(t.b!=0),he(t.a.a.c))):e.s=p.Math.min(e.s,ue((dn(t.b!=0),he(t.a.a.c)))),isNaN(e.c)?e.c=ue((dn(t.b!=0),he(t.c.b.c))):e.c=p.Math.max(e.c,ue((dn(t.b!=0),he(t.c.b.c)))))}function PT(e){var t,n,i,r;for(t=null,i=Bd(ma(W(V(Ta,1),Lt,22,0,[(!e.b&&(e.b=new Et(vn,e,4,7)),e.b),(!e.c&&(e.c=new Et(vn,e,5,8)),e.c)])));hn(i);)if(n=c(sn(i),83),r=to(n),!t)t=Xi(r);else if(t!=Xi(r))return!0;return!1}function Wne(e,t){var n,i,r,o;e.Nj()?(n=e.i,o=e.Oj(),U_(e,t),i=e.Gj(3,null,t,n,o),e.Kj()?(r=e.Lj(t,null),e.Rj()&&(r=e.Sj(t,r)),r?(r.lj(i),r.mj()):e.Hj(i)):e.Hj(i)):(U_(e,t),e.Kj()&&(r=e.Lj(t,null),r&&r.mj()))}function WGt(e,t){var n,i,r,o;if(o=L_(e.a,t.b),!o)throw J(new oo("Invalid hitboxes for scanline overlap calculation."));for(r=!1,i=e.a.a.ec().Jc();i.Ob();)if(n=c(i.Pb(),68),iRt(t.b,n))V9t(e.b.a,t.b,n),r=!0;else if(r)break}function KGt(e){var t;if(!e.a)throw J(new oo("IDataType class expected for layout option "+e.f));if(t=wDt(e.a),t==null)throw J(new oo("Couldn't create new instance of property '"+e.f+"'. "+Kct+(j1(KP),KP.k)+Z4e));return c(t,419)}function Kne(e){var t,n,i,r,o;return o=e.Mh(),o&&o.Sh()&&(r=I0(e,o),r!=o)?(n=e.Ch(),i=(t=e.Ch(),t>=0?e.xh(null):e.Mh().Qh(e,-1-t,null,null)),e.yh(c(r,52),n),i&&i.mj(),e.sh()&&e.th()&&n>-1&&vi(e,new Ur(e,9,n,o,r)),r):o}function kve(e,t){var n,i,r,o,a;for(o=e.b.Ae(t),i=(n=e.a.get(o),n??ye(Br,Lt,1,0,5,1)),a=0;a<i.length;a++)if(r=i[a],e.b.ze(t,r.jd()))return i.length==1?(i.length=0,$7t(e.a,o)):i.splice(a,1),--e.c,++e.b.g,r.kd();return null}function ktt(e){var t,n,i,r,o,a,d,b;for(a=0,o=e.f.e,i=0;i<o.c.length;++i)for(d=(ht(i,o.c.length),c(o.c[i],156)),r=i+1;r<o.c.length;++r)b=(ht(r,o.c.length),c(o.c[r],156)),n=A0(d.d,b.d),t=n-e.a[d.a][b.a],a+=e.i[d.a][b.a]*t*t;return a}function YGt(e,t){var n;if(!xi(t,(Ge(),Ro))&&(n=LFt(c(R(t,LOe),368),c(R(e,Ro),166)),Ee(t,LOe,n),!hn(new Ht(Vt(sd(t).a.Jc(),new U)))))switch(n.g){case 1:Ee(t,Ro,(Tu(),GE));break;case 2:Ee(t,Ro,(Tu(),UE))}}function ZGt(e,t){var n;dVt(e),e.a=(n=new tY,lr(new jt(null,new Tt(t.d,16)),new XNe(n)),n),EVt(e,c(R(t.b,(Ge(),ole)),349)),Ozt(e),cUt(e),$Ft(e),Szt(e),jYt(e,t),lr(So(new jt(null,IQe(RMt(e.b).a)),new nA),new TR),t.a=!1,e.a=null}function Ove(){Ove=te,qpt=new wt(s4e,(Bt(),!1)),Hpt=new wt(o4e,7),Pe(0),Jpt=new wt(c4e,Pe(0)),Gpt=new wt(l4e,Pe(-1)),X9e=(hT(),Yle),Xpt=new wt(u4e,X9e),U9e=(fT(),bP),Qpt=new wt(a4e,U9e),J9e=(jq(),Zle),Upt=new wt(f4e,J9e)}function Ott(){z2e.call(this,b9,(w0(),x2t)),this.p=null,this.a=null,this.f=null,this.n=null,this.g=null,this.c=null,this.i=null,this.j=null,this.d=null,this.b=null,this.e=null,this.k=null,this.o=null,this.s=null,this.q=!1,this.r=!1}function V5(){V5=te,kae=new s5(rct,0),oX=new s5("INSIDE_SELF_LOOPS",1),XP=new s5("MULTI_EDGES",2),JP=new s5("EDGE_LABELS",3),xae=new s5("PORTS",4),sX=new s5("COMPOUND",5),rX=new s5("CLUSTERS",6),yae=new s5("DISCONNECTED",7)}function Stt(e,t,n){var i,r,o;e.Nj()?(o=e.Oj(),++e.j,e.oj(t,e.Xi(t,n)),i=e.Gj(3,null,n,t,o),e.Kj()?(r=e.Lj(n,null),r?(r.lj(i),r.mj()):e.Hj(i)):e.Hj(i)):(++e.j,e.oj(t,e.Xi(t,n)),e.Kj()&&(r=e.Lj(n,null),r&&r.mj()))}function jtt(e,t){var n,i,r;if(t==0)return(e.a[0]&1)!=0;if(t<0)throw J(new Sz("Negative bit address"));if(r=t>>5,r>=e.d)return e.e<0;if(n=e.a[r],t=1<<(t&31),e.e<0){if(i=lVe(e),r<i)return!1;i==r?n=-n:n=~n}return(n&t)!=0}function Ttt(e){var t,n,i,r,o;if(r=new Fe,o=Eit(e,r),t=c(R(e,(De(),Ul)),9),t)for(i=new G(t.j);i.a<i.c.c.length;)n=c(Q(i),12),ve(R(n,Oi))===ve(e)&&(o=p.Math.max(o,Eit(n,r)));return r.c.length==0||Ee(e,f3,o),o!=-1?r:null}function eUt(e,t,n,i){var r;c(n.b,68),c(n.b,68),c(i.b,68),c(i.b,68),r=Hr(Ms(c(n.b,68).c),c(i.b,68).c),$F(r,Det(c(n.b,68),c(i.b,68),r)),c(i.b,68),c(i.b,68),c(i.b,68).c.a+r.a,c(i.b,68).c.b+r.b,c(i.b,68),Qc(i.a,new w0e(e,t,i))}function Sve(e,t){var n,i,r,o,a,d,b;if(o=t.e,o){for(n=Kne(o),i=c(e.g,686),a=0;a<e.i;++a)if(b=i[a],bne(b)==n&&(r=(!b.d&&(b.d=new Ar(Ks,b,1)),b.d),d=c(n.Jh(uie(o,o.Cb,o.Db>>16)),16).bd(o),d<r.i))return Sve(e,c(re(r,d),88))}return t}function T(e,t,n){var i=XG,r,o=i[e],a=o instanceof Array?o[0]:null;o&&!a?f=o:(f=(r=t&&t.prototype,!r&&(r=XG[t]),vNt(r)),f.Qm=n,!t&&(f.Rm=je),i[e]=f);for(var d=3;d<arguments.length;++d)arguments[d].prototype=f;a&&(f.Pm=a)}function hn(e){for(var t;!c(Rn(e.a),51).Ob();){if(e.d=vRt(e),!e.d)return!1;if(e.a=c(e.d.Pb(),51),oe(e.a,35)){if(t=c(e.a,35),e.a=t.a,!e.b&&(e.b=new bx),C0(e.b,e.d),t.b)for(;!e7(t.b);)C0(e.b,c(yMt(t.b),51));e.d=t.d}}return!0}function jve(e,t){var n,i,r,o;for(r=1,t.j=!0,o=null,i=new G(Ax(t));i.a<i.c.c.length;)n=c(Q(i),220),e.c[n.c]||(e.c[n.c]=!0,o=DH(n,t),n.f?r+=jve(e,o):!o.j&&n.a==n.e.e-n.d.e&&(n.f=!0,Sr(e.p,n),r+=jve(e,o)));return r}function tUt(e){var t,n,i;for(n=new G(e.a.a.b);n.a<n.c.c.length;)t=c(Q(n),84),i=(zt(0),0),i>0&&(!(O1(e.a.c)&&t.n.d)&&!(hx(e.a.c)&&t.n.b)&&(t.g.d+=p.Math.max(0,i/2-.5)),!(O1(e.a.c)&&t.n.a)&&!(hx(e.a.c)&&t.n.c)&&(t.g.a-=i-1))}function Ett(e,t,n){var i,r,o,a,d,b;o=c(Xe(t.e,0),17).c,i=o.i,r=i.k,b=c(Xe(n.g,0),17).d,a=b.i,d=a.k,r==(Jt(),jr)?Ee(e,(De(),sh),c(R(i,sh),12)):Ee(e,(De(),sh),o),d==jr?Ee(e,(De(),Wa),c(R(a,Wa),12)):Ee(e,(De(),Wa),b)}function Ctt(e,t){var n,i,r,o,a,d;for(o=new G(e.b);o.a<o.c.c.length;)for(r=c(Q(o),26),d=new G(r.a);d.a<d.c.c.length;)for(a=c(Q(d),9),a.k==(Jt(),lc)&&W5(a,t),i=new Ht(Vt($i(a).a.Jc(),new U));hn(i);)n=c(sn(i),17),LVe(n,t)}function nUt(e,t){var n,i,r;for(t.Tg("Layer constraint preprocessing",1),n=new Fe,r=new os(e.a,0);r.b<r.d.gc();)i=(dn(r.b<r.d.gc()),c(r.d.Xb(r.c=r.b++),9)),YIt(i)&&(Kqt(i),It(n.c,i),iu(r));n.c.length==0||Ee(e,(De(),Qce),n),t.Ug()}function Tve(e){var t,n,i;this.c=e,i=c(R(e,(Ge(),Xu)),87),t=ue(he(R(e,XU))),n=ue(he(R(e,QSe))),i==(Nr(),go)||i==yo||i==qh?this.b=t*n:this.b=1/(t*n),this.j=ue(he(R(e,Vv))),this.e=ue(he(R(e,$b))),this.f=e.b.c.length}function iUt(e){var t,n;for(e.e=ye(Fn,ci,30,e.p.c.length,15,1),e.k=ye(Fn,ci,30,e.p.c.length,15,1),n=new G(e.p);n.a<n.c.c.length;)t=c(Q(n),9),e.e[t.p]=Vf(new Ht(Vt(pr(t).a.Jc(),new U))),e.k[t.p]=Vf(new Ht(Vt($i(t).a.Jc(),new U)))}function rUt(e){var t,n,i,r,o,a;for(r=0,e.q=new Fe,t=new Or,a=new G(e.p);a.a<a.c.c.length;){for(o=c(Q(a),9),o.p=r,i=new Ht(Vt($i(o).a.Jc(),new U));hn(i);)n=c(sn(i),17),Sr(t,n.d.i);t.a.Ac(o)!=null,qe(e.q,new q2(t)),t.a.$b(),++r}}function Eve(e,t){var n,i,r,o,a;return t&=63,n=e.h,i=(n&aL)!=0,i&&(n|=-1048576),t<22?(a=n>>t,o=e.m>>t|n<<22-t,r=e.l>>t|e.m<<22-t):t<44?(a=i?Q1:0,o=n>>t-22,r=e.m>>t-22|n<<44-t):(a=i?Q1:0,o=i?au:0,r=n>>t-44),el(r&au,o&au,a&Q1)}function sUt(e,t){var n;switch(U7(e.a),Iu(e.a,(nQ(),Iue),($z(),que)),Iu(e.a,Rue,(Bz(),Hue)),Iu(e.a,$ue,(zz(),Que)),c(ke(t,(q5(),Fue)),389).g){case 1:n=(cD(),Gue);break;case 0:default:n=(cD(),Uue)}return Iu(e.a,Bue,n),VT(e.a,t)}function Mtt(e,t){var n,i,r,o,a,d,b,v,x;if(e.a.f>0&&oe(t,45)&&(e.a.Zj(),v=c(t,45),b=v.jd(),o=b==null?0:Ri(b),a=Xge(e.a,o),n=e.a.d[a],n)){for(i=c(n.g,375),x=n.i,d=0;d<x;++d)if(r=i[d],r.yi()==o&&r.Fb(v))return Mtt(e,v),!0}return!1}function oUt(e){var t,n,i,r,o,a,d;if(t=e.ni(Ja),t&&(d=zn(Zf((!t.b&&(t.b=new yu((Mt(),Bs),Yo,t)),t.b),"settingDelegates")),d!=null)){for(n=new Fe,r=xv(d,"\\w+"),o=0,a=r.length;o<a;++o)i=r[o],It(n.c,i);return n}return Ct(),Ct(),Rs}function cUt(e){var t,n,i,r;for(r=c(Si(e.a,(dv(),NU)),16).Jc();r.Ob();)i=c(r.Pb(),108),n=(t=b5(i.k),t.Gc((Je(),Kt))?t.Gc(nn)?t.Gc(bn)?t.Gc(Yt)?null:fdt:ddt:hdt:adt),B6(e,i,n[0],(Km(),Tw),0),B6(e,i,n[1],ep,1),B6(e,i,n[2],Ew,1)}function lUt(e,t){var n,i;n=FVt(t),AXt(e,t,n),SZe(e.a,c(R(Jr(t.b),(De(),kk)),237)),lWt(e),Qqt(e,t),i=ye(Fn,ci,30,t.b.j.c.length,15,1),Mie(e,t,(Je(),Kt),i,n),Mie(e,t,nn,i,n),Mie(e,t,bn,i,n),Mie(e,t,Yt,i,n),e.a=null,e.c=null,e.b=null}function Cve(e,t,n){switch(t){case 7:!e.e&&(e.e=new Et(Ii,e,7,4)),En(e.e),!e.e&&(e.e=new Et(Ii,e,7,4)),ur(e.e,c(n,18));return;case 8:!e.d&&(e.d=new Et(Ii,e,8,5)),En(e.d),!e.d&&(e.d=new Et(Ii,e,8,5)),ur(e.d,c(n,18));return}x2e(e,t,n)}function Mve(e,t){var n,i,r,o,a;if(ve(t)===ve(e))return!0;if(!oe(t,16)||(a=c(t,16),e.gc()!=a.gc()))return!1;for(o=a.Jc(),i=e.Jc();i.Ob();)if(n=i.Pb(),r=o.Pb(),!(ve(n)===ve(r)||n!=null&&yi(n,r)))return!1;return!0}function uUt(e,t){var n,i,r,o;for(o=c(ql(So(So(new jt(null,new Tt(t.b,16)),new SO),new G8),su(new Ls,new rs,new mo,W(V(ml,1),_e,132,0,[(va(),bl)]))),16),o.Ic(new YI),n=0,r=o.Jc();r.Ob();)i=c(r.Pb(),12),i.p==-1&&Nve(e,i,n++)}function aUt(e,t){var n,i,r,o,a;for(t.Tg("Port side processing",1),a=new G(e.a);a.a<a.c.c.length;)r=c(Q(a),9),Zit(r);for(i=new G(e.b);i.a<i.c.c.length;)for(n=c(Q(i),26),o=new G(n.a);o.a<o.c.c.length;)r=c(Q(o),9),Zit(r);t.Ug()}function fUt(e,t){var n,i,r,o,a,d;for(i=new M0,a=Dq(new Ho(e.g)),o=a.a.ec().Jc();o.Ob();){if(r=c(o.Pb(),9),!r){t.ah("There are no classes in a balanced layout.");break}d=e.j[r.p],n=c(Oh(i,d),16),n||(n=new Fe,gb(i,d,n)),n.Ec(r)}return i}function hUt(e,t){var n,i,r,o,a;i=new Ai,tr(i,t,i.c.b,i.c);do for(n=(dn(i.b!=0),c(ba(i,i.a.a),41)),e.b[n.g]=1,o=_n(n.d,0);o.b!=o.d.c;)r=c(An(o),65),a=r.c,e.b[a.g]==1?ei(e.a,r):e.b[a.g]==2?e.b[a.g]=1:tr(i,a,i.c.b,i.c);while(i.b!=0)}function Ave(e,t){if(oe(t,209))return Xi(c(t,19));if(oe(t,196))return yh(c(t,127));if(oe(t,363))return Rpe(c(t,158));if(oe(t,273))return b7t(e,c(t,74));throw J(new qt(m9+Mh(new Ho(W(V(Br,1),Lt,1,5,[t])))))}function dUt(e,t,n){var i;i=null,t&&(i=t.d),CT(e,new E6(t.n.a-i.b+n.a,t.n.b-i.d+n.b)),CT(e,new E6(t.n.a-i.b+n.a,t.n.b+t.o.b+i.a+n.b)),CT(e,new E6(t.n.a+t.o.a+i.c+n.a,t.n.b-i.d+n.b)),CT(e,new E6(t.n.a+t.o.a+i.c+n.a,t.n.b+t.o.b+i.a+n.b))}function Nve(e,t,n){var i,r,o;for(t.p=n,o=Bd(ma(W(V(Ta,1),Lt,22,0,[new p6(t),new Q4(t)])));hn(o);)i=c(sn(o),12),i.p==-1&&Nve(e,i,n);if(t.i.k==(Jt(),jr))for(r=new G(t.i.j);r.a<r.c.c.length;)i=c(Q(r),12),i!=t&&i.p==-1&&Nve(e,i,n)}function Att(e){var t,n,i,r,o;if(r=c(ql($pe(Fpe(e)),su(new Ls,new rs,new mo,W(V(ml,1),_e,132,0,[(va(),bl)]))),16),i=Vx,r.gc()>=2)for(n=r.Jc(),t=he(n.Pb());n.Ob();)o=t,t=he(n.Pb()),i=p.Math.min(i,(zt(t),t-(zt(o),o)));return i}function gUt(e,t){var n,i,r;for(r=new Fe,i=_n(t.a,0);i.b!=i.d.c;)n=c(An(i),65),n.b.g==e.g&&!Ot(n.b.c,yG)&&ve(R(n.b,(Uo(),xd)))!==ve(R(n.c,xd))&&!Sx(new jt(null,new Tt(r,16)),new L_e(n))&&It(r.c,n);return Rr(r,new hm),r}function pUt(e,t){var n,i,r;if(ve(t)===ve(Rn(e)))return!0;if(!oe(t,16)||(i=c(t,16),r=e.gc(),r!=i.gc()))return!1;if(oe(i,59)){for(n=0;n<r;n++)if(!T1(e.Xb(n),i.Xb(n)))return!1;return!0}else return Ezt(e.Jc(),i.Jc())}function bUt(e,t,n,i,r,o){var a,d,b,v;for(d=!k6(pi(e.Mc(),new d6(new ZV))).zd((Hp(),hk)),a=e,o==(Nr(),Ca)&&(a=Eu(a)),v=a.Jc();v.Ob();)b=c(v.Pb(),70),b.n.a=t.a,d?b.n.b=t.b+(i.b-b.o.b)/2:r?b.n.b=t.b:b.n.b=t.b+i.b-b.o.b,t.a+=b.o.a+n}function Ntt(e,t,n){var i,r,o,a,d,b,v;if(n)for(o=n.a.length,i=new Xp(o),d=(i.b-i.a)*i.c<0?(x0(),wp):new S0(i);d.Ob();)a=c(d.Pb(),15),b=X6(n,a.a),b&&(v=DPt(M1(b,Kse),t),oi(e.k,v,b),r=bd in b.a,r&&nS(v,M1(b,bd)),lQ(b,v),cve(b,v))}function mUt(e,t,n){var i,r,o,a,d;if(d=n,!d&&(d=A0e(new V4,0)),d.Tg(Rot,1),Irt(e.c,t),a=TZt(e.a,t),a.gc()==1)prt(c(a.Xb(0),37),d);else for(o=1/a.gc(),r=a.Jc();r.Ob();){if(i=c(r.Pb(),37),n.Zg())return;prt(i,d.dh(o))}S9t(e.a,a,t),KXt(t),d.Ug()}function _tt(e,t,n){var i,r,o,a,d;if(r=e.f,!r&&(r=c(e.a.a.ec().Jc().Pb(),60)),ET(r,t,n),e.a.a.gc()!=1)for(i=t*n,a=e.a.a.ec().Jc();a.Ob();)o=c(a.Pb(),60),o!=r&&(d=j5(o),d.f.d?(o.d.d+=i+_h,o.d.a-=i+_h):d.f.a&&(o.d.a-=i+_h))}function wUt(e,t,n,i){var r,o,a,d,b,v,x,S;r=n,x=t,o=x;do o=e.a[o.p],d=(S=e.g[o.p],ue(e.p[S.p])+ue(e.d[o.p])-o.d.d),b=IPt(o,i),b&&(a=(v=e.g[b.p],ue(e.p[v.p])+ue(e.d[b.p])+b.o.b+b.d.a),r=p.Math.min(r,d-(a+px(e.k,o,b))));while(x!=o);return r}function vUt(e,t,n,i){var r,o,a,d,b,v,x,S;r=n,x=t,o=x;do o=e.a[o.p],a=(S=e.g[o.p],ue(e.p[S.p])+ue(e.d[o.p])+o.o.b+o.d.a),b=GIt(o,i),b&&(d=(v=e.g[b.p],ue(e.p[v.p])+ue(e.d[b.p])-b.d.d),r=p.Math.min(r,d-(a+px(e.k,o,b))));while(x!=o);return r}function Dtt(e,t){var n;if(t.Tg("Equal Whitespace Eliminator",1),ga(e,(Gd(),DJ)))KRt(c(ke(e,DJ),16),ue(he(ke(e,Ck))),(n=ue(he(ke(e,wC))),ue(he(ke(e,(Ah(),xC)))),n));else throw J(new Wh("The graph does not contain rows."));t.Ug()}function ke(e,t){var n,i;return i=(!e.o&&(e.o=new Al((oc(),s1),e0,e,0)),Zf(e.o,t)),i??(n=t.Rg(),oe(n,4)&&(n==null?(!e.o&&(e.o=new Al((oc(),s1),e0,e,0)),zH(e.o,t)):(!e.o&&(e.o=new Al((oc(),s1),e0,e,0)),PD(e.o,t,n))),n)}function mv(){mv=te,Nf=new lx("H_LEFT",0),Z1=new lx("H_CENTER",1),_f=new lx("H_RIGHT",2),Lf=new lx("V_TOP",3),i1=new lx("V_CENTER",4),Ya=new lx("V_BOTTOM",5),Vu=new lx("INSIDE",6),Df=new lx("OUTSIDE",7),Ka=new lx("H_PRIORITY",8)}function yUt(e,t){var n,i,r,o,a,d,b;if(!t.f)throw J(new qt("The input edge is not a tree edge."));for(o=null,r=di,i=new G(e.d);i.a<i.c.c.length;)n=c(Q(i),220),d=n.d,b=n.e,Jne(e,d,t)&&!Jne(e,b,t)&&(a=b.e-d.e-n.a,a<r&&(r=a,o=n));return o}function xUt(e){var t,n,i,r,o,a;if(!(e.f.e.c.length<=1)){t=0,r=ktt(e),n=nr;do{for(t>0&&(r=n),a=new G(e.f.e);a.a<a.c.c.length;)o=c(Q(a),156),!et(Ze(R(o,(DD(),Rke))))&&(i=_Wt(e,o),ki(Xf(o.d),i));n=ktt(e)}while(!zMt(e,t++,r,n))}}function kUt(e,t){var n,i,r,o,a;for(o=e.g.a,a=e.g.b,i=new G(e.d);i.a<i.c.c.length;)n=c(Q(i),70),r=n.n,e.a==(xf(),E9)||e.i==(Je(),nn)?r.a=o:e.a==C9||e.i==(Je(),Yt)?r.a=o+e.j.a-n.o.a:r.a=o+(e.j.a-n.o.a)/2,r.b=a,ki(r,t),a+=n.o.b+e.e}function Ltt(e){var t,n,i,r;for(r=0,t=c(ke(e,(Dn(),Gwt)),15).a,i=new cn((!e.a&&(e.a=new Me(Mn,e,10,11)),e.a));i.e!=i.i.gc();)n=c(un(i),19),!n.a&&(n.a=new Me(Mn,n,10,11)),n.a&&(!n.a&&(n.a=new Me(Mn,n,10,11)),n.a).i>0?r+=t:r+=1;return r}function OUt(e,t){var n,i,r,o,a,d,b,v,x,S;v=e,b=K7(v,"individualSpacings"),b&&(i=ga(t,(Dn(),Lk)),a=!i,a&&(r=new O4,ii(t,Lk,r)),d=c(ke(t,Lk),380),S=b,o=null,S&&(o=(x=ate(S,ye(nt,Be,2,0,6,1)),new lY(S,x))),o&&(n=new KRe(S,d),ws(o,n)))}function SUt(e,t){var n,i,r,o,a,d,b,v,x,S,M;return b=null,S=e,x=null,(Hlt in S.a||Qlt in S.a||MG in S.a)&&(v=null,M=Cme(t),a=K7(S,Hlt),n=new wDe(M),uKe(n.a,a),d=K7(S,Qlt),i=new EDe(M),aKe(i.a,d),o=Gm(S,MG),r=new ADe(M),v=(wZe(r.a,o),o),x=v),b=x,b}function jUt(e,t){var n,i,r;if(t===e)return!0;if(oe(t,544)){if(r=c(t,841),e.a.d!=r.a.d||yx(e).gc()!=yx(r).gc())return!1;for(i=yx(r).Jc();i.Ob();)if(n=c(i.Pb(),421),uQe(e,n.a.jd())!=c(n.a.kd(),18).gc())return!1;return!0}return!1}function TUt(e,t){var n,i,r,o;for(o=new G(t.a);o.a<o.c.c.length;)for(r=c(Q(o),9),Ee(r,(De(),JU),(Bt(),!1)),Ee(r,Ok,Pe(-1)),Ee(r,QE,Pe(-1)),e.d.a.c.length=0,i=new Ht(Vt(sd(r).a.Jc(),new U));hn(i);)n=c(sn(i),17),Ee(n,Ldt,!1)}function EUt(e,t){return e.c<t.c?-1:e.c>t.c?1:e.b<t.b?-1:e.b>t.b?1:e.a!=t.a?Ri(e.a)-Ri(t.a):e.d==(Z7(),aC)&&t.d==uC?-1:e.d==uC&&t.d==aC?1:0}function Yne(e){var t,n,i,r,o,a,d,b;for(r=nr,i=Qr,n=new G(e.e.b);n.a<n.c.c.length;)for(t=c(Q(n),26),a=new G(t.a);a.a<a.c.c.length;)o=c(Q(a),9),b=ue(e.p[o.p]),d=b+ue(e.b[e.g[o.p].p]),r=p.Math.min(r,b),i=p.Math.max(i,d);return i-r}function Ptt(e,t){var n,i,r,o,a;return o=t.a,o.c.i==t.b?a=o.d:a=o.c,o.c.i==t.b?i=o.c:i=o.d,r=oBt(e.a,a,i),r>0&&r<Vx?(n=wUt(e.a,i.i,r,e.c),fXe(e.a,i.i,-n),n>0):r<0&&-r<Vx?(n=vUt(e.a,i.i,-r,e.c),fXe(e.a,i.i,n),n>0):!1}function CUt(e,t,n,i){var r,o,a,d,b,v,x,S;for(r=(t-e.d)/e.c.c.length,o=0,e.a+=n,e.d=t,S=new G(e.c);S.a<S.c.c.length;)x=c(Q(S),19),v=x.g,b=x.f,Cc(x,x.i+o*r),Nl(x,x.j+i*n),ob(x,x.g+r),sb(x,e.a),++o,d=x.g,a=x.f,rve(x,new $e(d,a),new $e(v,b))}function Itt(e,t){var n,i,r,o,a,d,b,v;for(i=new Ht(Vt(z1(t).a.Jc(),new U));hn(i);)n=c(sn(i),74),v=to(c(re((!n.c&&(n.c=new Et(vn,n,5,8)),n.c),0),83)),a=$T(n),d=t.i+t.g/2,b=t.j+t.f,r=v.i+v.g/2,o=v.j,Vm(a,d),Wm(a,b),Jm(a,r),Xm(a,o),Itt(e,v)}function MUt(e){var t,n,i,r,o,a,d;if(e==null)return null;for(d=e.length,r=(d+1)/2|0,a=ye(Rl,Yx,30,r,15,1),d%2!=0&&(a[--r]=tye((en(d-1,e.length),e.charCodeAt(d-1)))),n=0,i=0;n<r;++n)t=tye(ms(e,i++)),o=tye(ms(e,i++)),a[n]=(t<<4|o)<<24>>24;return a}function AUt(e){if(e.xe()){var t=e.c;t.ye()?e.o="["+t.n:t.xe()?e.o="["+t.ve():e.o="[L"+t.ve()+";",e.b=t.ue()+"[]",e.k=t.we()+"[]";return}var n=e.j,i=e.d;i=i.split("/"),e.o=tne(".",[n,tne("$",i)]),e.b=tne(".",[n,tne(".",i)]),e.k=i[i.length-1]}function NUt(e,t){var n,i,r,o,a;for(a=null,o=new G(e.e.a);o.a<o.c.c.length;)if(r=c(Q(o),126),r.b.a.c.length==r.g.a.c.length){for(i=r.e,a=xQt(r),n=r.e-c(a.a,15).a+1;n<r.e+c(a.b,15).a;n++)t[n]<t[i]&&(i=n);t[i]<t[r.e]&&(--t[r.e],++t[i],r.e=i)}}function _ve(e,t,n){var i,r,o,a,d,b,v,x;v=c(n,150),x=Ave(e,t),o=null,i=null,x&&(i=sQ(e,x,t.i)),i!=null?o=i:(d=t.i,o=d),Zp(v,"x",o),a=null,r=null,x&&(r=oQ(e,x,t.j)),r!=null?a=r:(b=t.j,a=b),Zp(v,"y",a),Zp(v,Vse,t.g),Zp(v,Xse,t.f)}function Rtt(e){jie();var t,n,i,r;return i=Zh(e,dl(35)),t=i==-1?e:(fs(0,i,e.length),e.substr(0,i)),n=i==-1?null:(en(i+1,e.length+1),e.substr(i+1)),r=CDt(TTe,t),r?n!=null&&(r=dWe(r,(zt(n),n))):(r=wtn(t),FDt(TTe,t,r),n!=null&&(r=dWe(r,n))),r}function Dve(e,t,n,i){var r,o,a,d,b;for(r=uye(e,t),d=0,b=r.gc();d<b;++d)if(o=c(r.Xb(d),182),Ot(i,Q6(uo(e,o)))){if(a=I_(uo(e,o)),n==null){if(a==null)return o}else if(Ot(n,a))return o}return null}function Lve(e,t,n,i){var r,o,a,d,b;for(r=aie(e,t),d=0,b=r.gc();d<b;++d)if(o=c(r.Xb(d),182),Ot(i,Q6(uo(e,o)))){if(a=I_(uo(e,o)),n==null){if(a==null)return o}else if(Ot(n,a))return o}return null}function _Ut(e,t,n){var i,r,o,a,d,b;if(a=new S4,d=nl(e.e.Ah(),t),i=c(e.g,123),qs(),c(t,69).vk())for(o=0;o<e.i;++o)r=i[o],d.$l(r.Jk())&&Nn(a,r);else for(o=0;o<e.i;++o)r=i[o],d.$l(r.Jk())&&(b=r.kd(),Nn(a,n?LT(e,t,o,a.i,b):b));return tbe(a)}function $tt(e){var t,n,i,r,o,a,d;if(e&&(t=e.ni(Ja),t&&(a=zn(Zf((!t.b&&(t.b=new yu((Mt(),Bs),Yo,t)),t.b),"conversionDelegates")),a!=null))){for(d=new Fe,i=xv(a,"\\w+"),r=0,o=i.length;r<o;++r)n=i[r],It(d.c,n);return d}return Ct(),Ct(),Rs}function Btt(e,t){var n,i,r,o,a,d,b,v;for(a=t==1?tce:ece,o=a.a.ec().Jc();o.Ob();)for(r=c(o.Pb(),87),b=c(Si(e.f.c,r),24).Jc();b.Ob();)switch(d=c(b.Pb(),49),i=c(d.b,84),v=c(d.a,197),n=v.c,r.g){case 2:case 1:i.g.d+=n;break;case 4:case 3:i.g.c+=n}}function DUt(e,t){var n,i,r,o,a;for(n=new yT(N9),r=(H5(),W(V(N9,1),_e,233,0,[A9,RE,M9,Rv,c3,o3])),o=0,a=r.length;o<a;++o)i=r[o],Wge(n,i,new Fe);return lr(qc(pi(So(new jt(null,new Tt(e.b,16)),new eW),new qM),new kNe(t)),new ONe(n)),n}function ztt(e,t){var n,i,r;for(n=1;n<e.c.length;n++){for(r=(ht(n,e.c.length),c(e.c[n],9)),i=n;i>0&&nL(t,(ht(i-1,e.c.length),c(e.c[i-1],9)),r)>0;)Su(e,i,(ht(i-1,e.c.length),c(e.c[i-1],9))),--i;ht(i,e.c.length),e.c[i]=r}t.b=new wn,t.g=new wn}function Ftt(e,t,n){var i,r,o;for(i=1;i<e.c.length;i++){for(o=(ht(i,e.c.length),c(e.c[i],9)),r=i;r>0&&t.Le((ht(r-1,e.c.length),c(e.c[r-1],9)),o)>0;)Su(e,r,(ht(r-1,e.c.length),c(e.c[r-1],9))),--r;ht(r,e.c.length),e.c[r]=o}n.a=new wn,n.b=new wn}function bQ(e,t,n){var i,r,o,a,d,b,v,x,S,M;for(o=t.Jc();o.Ob();)r=c(o.Pb(),19),x=r.i+r.g/2,M=r.j+r.f/2,b=e.f,a=b.i+b.g/2,d=b.j+b.f/2,v=x-a,S=M-d,i=p.Math.sqrt(v*v+S*S),v*=e.e/i,S*=e.e/i,n?(x-=v,M-=S):(x+=v,M+=S),Cc(r,x-r.g/2),Nl(r,M-r.f/2)}function $x(e){var t,n,i;if(!e.c&&e.b!=null){for(t=e.b.length-4;t>=0;t-=2)for(n=0;n<=t;n+=2)(e.b[n]>e.b[n+2]||e.b[n]===e.b[n+2]&&e.b[n+1]>e.b[n+3])&&(i=e.b[n+2],e.b[n+2]=e.b[n],e.b[n]=i,i=e.b[n+3],e.b[n+3]=e.b[n+1],e.b[n+1]=i);e.c=!0}}function kf(e){var t,n;return n=new Lu(qp(e.Pm)),n.a+="@",Zn(n,(t=Ri(e)>>>0,t.toString(16))),e.Sh()?(n.a+=" (eProxyURI: ",Sc(n,e.Yh()),e.Hh()&&(n.a+=" eClass: ",Sc(n,e.Hh())),n.a+=")"):e.Hh()&&(n.a+=" (eClass: ",Sc(n,e.Hh()),n.a+=")"),n.a}function IT(e){var t,n,i,r;if(e.e)throw J(new oo((j1(qoe),mre+qoe.k+wre)));for(e.d==(Nr(),qh)&&RQ(e,go),n=new G(e.a.a);n.a<n.c.c.length;)t=c(Q(n),321),t.g=t.i;for(r=new G(e.a.b);r.a<r.c.c.length;)i=c(Q(r),60),i.i=Qr;return e.b.af(e),e}function LUt(e,t){var n,i,r,o,a,d,b,v,x;for(b=Pd(e.c-e.b&e.a.length-1),v=null,x=null,o=new G7(e);o.a!=o.b;)r=c(EH(o),9),n=(d=c(R(r,(De(),sh)),12),d?d.i:null),i=(a=c(R(r,Wa),12),a?a.i:null),(v!=n||x!=i)&&(ftt(b,t),v=n,x=i),It(b.c,r);ftt(b,t)}function qtt(e){switch(e.g){case 0:return new Oz((hb(),gP));case 1:return new Oz((hb(),bJ));case 2:return new zB;case 3:return new TN;default:throw J(new qt("No implementation is available for the crossing minimizer "+(e.f!=null?e.f:""+e.g)))}}function PUt(e,t){var n,i,r,o,a;if(t<2*e.b)throw J(new qt("The knot vector must have at least two time the dimension elements."));for(e.f=1,r=0;r<e.b;r++)qe(e.e,0);for(a=t+1-2*e.b,n=a,o=1;o<a;o++)qe(e.e,o/n);if(e.d)for(i=0;i<e.b;i++)qe(e.e,1)}function Htt(e,t){var n,i,r,o,a,d,b,v,x;if(v=t,x=c(cH(KZ(e.o),v),19),!x)throw r=M1(v,bd),d="Unable to find elk node for json object '"+r,b=d+"' Panic!",J(new Kh(b));o=Gm(v,"edges"),n=new BRe(e,x),Vet(n.a,n.b,o),a=Gm(v,Yse),i=new aDe(e),ZYe(i.a,a)}function Qtt(e,t,n,i){var r,o,a,d,b;if(i!=null){if(r=e.d[t],r){for(o=r.g,b=r.i,d=0;d<b;++d)if(a=c(o[d],138),a.yi()==n&&yi(i,a.jd()))return d}}else if(r=e.d[t],r){for(o=r.g,b=r.i,d=0;d<b;++d)if(a=c(o[d],138),ve(a.jd())===ve(i))return d}return-1}function NS(e,t){var n,i,r;return n=t==null?Ao(co(e.f,null)):f7(e.i,t),oe(n,244)?(r=c(n,244),r.wi()==null,r):oe(n,496)?(i=c(n,2016),r=i.a,r&&(r.yb==null||(t==null?gl(e.f,null,r):Zm(e.i,t,r))),r):null}function IUt(e){Yve();var t,n,i,r,o,a,d;if(e==null||(r=e.length,r%2!=0))return null;for(t=Xq(e),o=r/2|0,n=ye(Rl,Yx,30,o,15,1),i=0;i<o;i++){if(a=VC[t[i*2]],a==-1||(d=VC[t[i*2+1]],d==-1))return null;n[i]=(a<<4|d)<<24>>24}return n}function RUt(e,t,n){var i,r,o;if(r=c(Zs(e.i,t),319),!r)if(r=new WJe(e.d,t,n),v5(e.i,t,r),Iwe(t))$jt(e.a,t.c,t.b,r);else switch(o=NQt(t),i=c(Zs(e.p,o),256),o.g){case 1:case 3:r.j=!0,WK(i,t.b,r);break;case 4:case 2:r.k=!0,WK(i,t.c,r)}return r}function $Ut(e,t,n,i){var r,o,a,d,b,v;if(d=new S4,b=nl(e.e.Ah(),t),r=c(e.g,123),qs(),c(t,69).vk())for(a=0;a<e.i;++a)o=r[a],b.$l(o.Jk())&&Nn(d,o);else for(a=0;a<e.i;++a)o=r[a],b.$l(o.Jk())&&(v=o.kd(),Nn(d,i?LT(e,t,a,d.i,v):v));return Nwe(d,n)}function Gtt(e,t){var n,i,r,o,a,d,b,v;if(r=e.b[t.p],r>=0)return r;for(o=1,d=new G(t.j);d.a<d.c.c.length;)for(a=c(Q(d),12),i=new G(a.g);i.a<i.c.c.length;)n=c(Q(i),17),v=n.d.i,t!=v&&(b=Gtt(e,v),o=p.Math.max(o,b+1));return V$t(e,t,o),o}function Utt(e,t){var n,i,r,o,a,d,b,v;if(r=e.b[t.p],r>=0)return r;for(o=1,d=new G(t.j);d.a<d.c.c.length;)for(a=c(Q(d),12),i=new G(a.e);i.a<i.c.c.length;)n=c(Q(i),17),v=n.c.i,t!=v&&(b=Utt(e,v),o=p.Math.max(o,b+1));return Mzt(e,t,o),o}function BUt(e){var t,n,i,r;for(r=e.length,t=null,i=0;i<r;i++)n=(en(i,e.length),e.charCodeAt(i)),Zh(".*+?{[()|\\^$",dl(n))>=0?(t||(t=new t7,i>0&&Ys(t,(fs(0,i,e.length),e.substr(0,i)))),t.a+="\\",z6(t,n&_r)):t&&z6(t,n&_r);return t?t.a:e}function zUt(e){var t,n,i;for(n=new G(e.a.a.b);n.a<n.c.c.length;)t=c(Q(n),84),i=(zt(0),0),i>0&&(!(O1(e.a.c)&&t.n.d)&&!(hx(e.a.c)&&t.n.b)&&(t.g.d-=p.Math.max(0,i/2-.5)),!(O1(e.a.c)&&t.n.a)&&!(hx(e.a.c)&&t.n.c)&&(t.g.a+=p.Math.max(0,i-1)))}function Jtt(e,t,n){var i,r;if((e.c-e.b&e.a.length-1)==2)t==(Je(),Kt)||t==nn?(Zq(c(aT(e),16),(qu(),n1)),Zq(c(aT(e),16),up)):(Zq(c(aT(e),16),(qu(),up)),Zq(c(aT(e),16),n1));else for(r=new G7(e);r.a!=r.b;)i=c(EH(r),16),Zq(i,n)}function FUt(e,t,n){var i,r,o,a,d,b,v,x,S;for(x=-1,S=0,d=t,b=0,v=d.length;b<v;++b){for(a=d[b],i=new Kqe(e,x==-1?t[0]:t[x],n,(gT(),hJ)),r=0;r<a.length;r++)for(o=r+1;o<a.length;o++)xi(a[r],(De(),Pi))&&xi(a[o],Pi)&&nL(i,a[r],a[o])>0&&++S;++x}return S}function qUt(e,t,n){var i;if(n.Tg("XPlacer",1),e.b=ue(he(ke(t,(Dn(),lh)))),e.a=et(Ze(ke(t,(q5(),zue)))),(!t.a&&(t.a=new Me(Mn,t,10,11)),t.a).i!=0)switch(i=c(ke(t,(Qd(),SC)),19),c(ke(t,Fue),389).g){case 0:Dst(e,i);break;case 1:_st(e,i)}n.Ug()}function HUt(e,t){var n,i,r,o,a,d,b;for(r=P6(new kde(e)),d=new os(r,r.c.length),o=P6(new kde(t)),b=new os(o,o.c.length),a=null;d.b>0&&b.b>0&&(n=(dn(d.b>0),c(d.a.Xb(d.c=--d.b),19)),i=(dn(b.b>0),c(b.a.Xb(b.c=--b.b),19)),n==i);)a=n;return a}function QUt(e,t){var n,i,r,o;for(t.Tg("Self-Loop pre-processing",1),i=new G(e.a);i.a<i.c.c.length;)n=c(Q(i),9),q$t(n)&&(r=(o=new UKe(n),Ee(n,(De(),Nw),o),hWt(o),o),lr(qc(So(new jt(null,new Tt(r.d,16)),new xW),new kW),new h1),lXt(r));t.Ug()}function Xtt(e,t,n){var i,r,o,a;vQe(e,t)>vQe(e,n)?(i=Po(n,(Je(),nn)),e.d=i.dc()?0:CZ(c(i.Xb(0),12)),a=Po(t,Yt),e.b=a.dc()?0:CZ(c(a.Xb(0),12))):(r=Po(n,(Je(),Yt)),e.d=r.dc()?0:CZ(c(r.Xb(0),12)),o=Po(t,nn),e.b=o.dc()?0:CZ(c(o.Xb(0),12)))}function GUt(e){var t,n,i,r,o,a,d,b;t=!0,r=null,o=null;e:for(b=new G(e.a);b.a<b.c.c.length;)for(d=c(Q(b),9),i=new Ht(Vt(pr(d).a.Jc(),new U));hn(i);){if(n=c(sn(i),17),r&&r!=d){t=!1;break e}if(r=d,a=n.c.i,o&&o!=a){t=!1;break e}o=a}return t}function UUt(e,t,n){var i,r,o,a,d,b,v,x;for(x=(i=c(t.e&&t.e(),10),new ha(i,c(gf(i,i.length),10),0)),b=xv(n,"[\\[\\]\\s,]+"),o=b,a=0,d=o.length;a<d;++a)if(r=o[a],pv(r).length!=0){if(v=Wet(e,r),v==null)return null;yf(x,c(v,23))}return x}function Vtt(e,t){var n,i,r,o;for(n=e.o.a,o=c(c(Si(e.r,t),24),85).Jc();o.Ob();)r=c(o.Pb(),116),r.e.a=n*ue(he(r.b.mf(rU))),r.e.b=(i=r.b,i.nf((Dn(),fu))?i.$f()==(Je(),Kt)?-i.Kf().b-ue(he(i.mf(fu))):ue(he(i.mf(fu))):i.$f()==(Je(),Kt)?-i.Kf().b:0)}function JUt(e,t,n){var i,r,o,a,d,b;for(o=-1,d=-1,a=0;a<t.c.length&&(r=(ht(a,t.c.length),c(t.c[a],341)),!(r.c>e.c));a++)r.a>=e.s&&(o<0&&(o=a),d=a);return b=(e.s+e.c)/2,o>=0&&(i=NVt(e,t,o,d),b=m8t((ht(i,t.c.length),c(t.c[i],341))),$Gt(t,i,n)),b}function In(e,t,n){var i,r,o,a,d,b,v;for(a=(o=new eN,o),cme(a,(zt(t),t)),v=(!a.b&&(a.b=new yu((Mt(),Bs),Yo,a)),a.b),b=1;b<n.length;b+=2)PD(v,n[b-1],n[b]);for(i=(!e.Ab&&(e.Ab=new Me(si,e,0,3)),e.Ab),d=0;d<0;++d)r=FMt(c(re(i,i.i-1),594)),i=r;Nn(i,a)}function Pve(e,t,n,i,r,o){var a,d,b;if(!r[t.a]){for(r[t.a]=!0,a=i,!a&&(a=new Rq),qe(a.e,t),b=o[t.a].Jc();b.Ob();)d=c(b.Pb(),292),!(d.d==n||d.c==n)&&(d.c!=t&&Pve(e,d.c,t,a,r,o),d.d!=t&&Pve(e,d.d,t,a,r,o),qe(a.c,d),yr(a.d,d.b));return a}return null}function XUt(e){var t,n,i,r,o,a,d;for(t=0,r=new G(e.e);r.a<r.c.c.length;)i=c(Q(r),17),n=Sx(new jt(null,new Tt(i.b,16)),new IM),n&&++t;for(a=new G(e.g);a.a<a.c.c.length;)o=c(Q(a),17),d=Sx(new jt(null,new Tt(o.b,16)),new VI),d&&++t;return t>=2}function VUt(e,t,n,i,r){var o,a,d,b,v,x;for(o=e.c.d.j,a=c(pc(n,0),8),x=1;x<n.b;x++)v=c(pc(n,x),8),tr(i,a,i.c.b,i.c),d=S1(ki(new Cs(a),v),.5),b=S1(new wee(qme(o)),r),ki(d,b),tr(i,d,i.c.b,i.c),a=v,o=t==0?AH(o):fwe(o);ei(i,(dn(n.b!=0),c(n.c.b.c,8)))}function WUt(e){mv();var t,n,i;return n=_i(Vu,W(V(Ws,1),_e,96,0,[Df])),!(hD(xq(n,e))>1||(t=_i(Nf,W(V(Ws,1),_e,96,0,[Z1,_f])),hD(xq(t,e))>1)||(i=_i(Lf,W(V(Ws,1),_e,96,0,[i1,Ya])),hD(xq(i,e))>1))}function Wtt(e){var t,n,i,r,o,a,d;for(t=0,i=new G(e.a);i.a<i.c.c.length;)for(n=c(Q(i),9),o=new Ht(Vt($i(n).a.Jc(),new U));hn(o);)r=c(sn(o),17),e==r.d.i.c&&r.c.j==(Je(),Yt)&&(a=xh(r.c).b,d=xh(r.d).b,t=p.Math.max(t,p.Math.abs(d-a)));return t}function Ive(e,t,n){var i,r,o;for(o=new G(e.t);o.a<o.c.c.length;)i=c(Q(o),275),i.b.s<0&&i.c>0&&(i.b.n-=i.c,i.b.n<=0&&i.b.u>0&&ei(t,i.b));for(r=new G(e.i);r.a<r.c.c.length;)i=c(Q(r),275),i.a.s<0&&i.c>0&&(i.a.u-=i.c,i.a.u<=0&&i.a.n>0&&ei(n,i.a))}function KUt(e){var t,n,i,r,o,a;for(a=c(ke(e,(Dn(),zh)),100),n=0,i=0,o=new cn((!e.a&&(e.a=new Me(Mn,e,10,11)),e.a));o.e!=o.i.gc();)r=c(un(o),19),t=c(ke(r,Y1),125),n<r.i+r.g+t.c&&(n=r.i+r.g+t.c),i<r.j+r.f+t.a&&(i=r.j+r.f+t.a);ob(e,n+a.c),sb(e,i+a.a)}function mQ(e){var t,n,i,r,o;if(e.g==null&&(e.d=e._i(e.f),Nn(e,e.d),e.c))return o=e.f,o;if(t=c(e.g[e.i-1],51),r=t.Pb(),e.e=t,n=e._i(r),n.Ob())e.d=n,Nn(e,n);else for(e.d=null;!t.Ob()&&(dr(e.g,--e.i,null),e.i!=0);)i=c(e.g[e.i-1],51),t=i;return r}function YUt(e,t){var n,i,r,o,a,d;if(i=t,r=i.Jk(),F1(e.e,r)){if(r.Qi()&&Mq(e,r,i.kd()))return!1}else for(d=nl(e.e.Ah(),r),n=c(e.g,123),o=0;o<e.i;++o)if(a=n[o],d.$l(a.Jk()))return yi(a,i)?!1:(c(Dx(e,o,t),76),!0);return Nn(e,t)}function Jt(){Jt=te,or=new i5("NORMAL",0),jr=new i5("LONG_EDGE",1),Cr=new i5("EXTERNAL_PORT",2),Dc=new i5("NORTH_SOUTH_PORT",3),lc=new i5("LABEL",4),Ih=new i5("BREAKING_POINT",5),UL=new i5("PLACEHOLDER",6),PE=new i5("NONSHIFTING_PLACEHOLDER",7)}function ZUt(e,t,n,i){var r,o,a,d;for(r=new Eh(e),mu(r,(Jt(),lc)),Ee(r,(De(),Oi),t),Ee(r,HE,i),Ee(r,(Ge(),cr),(Zr(),xc)),Ee(r,sh,t.c),Ee(r,Wa,t.d),tie(t,r),d=p.Math.floor(n/2),a=new G(r.j);a.a<a.c.c.length;)o=c(Q(a),12),o.n.b=d;return r}function QD(){QD=te,jce=new ox(_xe,0),UOe=new ox(nct,1),Ece=new ox(Mre,2),Cce=new ox(Sre,3),Tce=new ox("GREEDY_MODEL_ORDER",4),Mce=new ox("SCC_CONNECTIVITY",5),KL=new ox("SCC_NODE_TYPE",6),Sce=new ox("DFS_NODE_ORDER",7),Oce=new ox("BFS_NODE_ORDER",8)}function Ktt(e,t,n){var i,r,o,a,d;for(n.Tg("ELK Force",1),et(Ze(ke(t,(Sf(),Mke))))||J7((i=new g6((v0(),new wg(t))),i)),d=GVe(t),_Ft(d),gRt(e,c(R(d,Cke),429)),a=Xit(e.a,d),o=a.Jc();o.Ob();)r=c(o.Pb(),238),zWt(e.b,r,n.dh(1/a.gc()));d=ast(a),vst(d),n.Ug()}function Rve(e,t,n){switch(n.g){case 1:return new $e(t.a,p.Math.min(e.d.b,t.b));case 2:return new $e(p.Math.max(e.c.a,t.a),t.b);case 3:return new $e(t.a,p.Math.max(e.c.b,t.b));case 4:return new $e(p.Math.min(t.a,e.d.a),t.b)}return new $e(t.a,t.b)}function eJt(e,t){var n,i,r,o,a;if(t.Tg("Breaking Point Processor",1),BZt(e),et(Ze(R(e,(Ge(),VSe))))){for(r=new G(e.b);r.a<r.c.c.length;)for(i=c(Q(r),26),n=0,a=new G(i.a);a.a<a.c.c.length;)o=c(Q(a),9),o.p=n++;AKt(e),bnt(e,!0),bnt(e,!1)}t.Ug()}function wQ(e){var t,n,i;for(t=Pd(1+(!e.c&&(e.c=new Me(hu,e,9,9)),e.c).i),qe(t,(!e.d&&(e.d=new Et(Ii,e,8,5)),e.d)),i=new cn((!e.c&&(e.c=new Me(hu,e,9,9)),e.c));i.e!=i.i.gc();)n=c(un(i),127),qe(t,(!n.d&&(n.d=new Et(Ii,n,8,5)),n.d));return Rn(t),new T7(t)}function z1(e){var t,n,i;for(t=Pd(1+(!e.c&&(e.c=new Me(hu,e,9,9)),e.c).i),qe(t,(!e.e&&(e.e=new Et(Ii,e,7,4)),e.e)),i=new cn((!e.c&&(e.c=new Me(hu,e,9,9)),e.c));i.e!=i.i.gc();)n=c(un(i),127),qe(t,(!n.e&&(n.e=new Et(Ii,n,7,4)),n.e));return Rn(t),new T7(t)}function tJt(e){var t,n,i,r;if(e==null)return null;if(i=Nc(e,!0),r=BL.length,Ot(i.substr(i.length-r,r),BL)){if(n=i.length,n==4){if(t=(en(0,i.length),i.charCodeAt(0)),t==43)return UTe;if(t==45)return yvt}else if(n==3)return UTe}return gv(i)}function nJt(e,t,n,i){var r,o,a,d,b,v,x,S,M;for(S=i?(Je(),Yt):(Je(),nn),r=!1,b=t[n],v=0,x=b.length;v<x;++v)d=b[v],!d5(c(R(d,(Ge(),cr)),103))&&(a=d.e,M=!Po(d,S).dc()&&!!a,M&&(o=C2e(a),e.b=new A2e(o,i?0:o.length-1)),r=r|HXt(e,d,S,M));return r}function Ytt(e,t,n,i){var r,o,a;if(a=w2e(t,n),It(i.c,t),e.j[a.p]==-1||e.j[a.p]==2||e.a[t.p])return i;for(e.j[a.p]=-1,o=new Ht(Vt(sd(a).a.Jc(),new U));hn(o);)if(r=c(sn(o),17),!(!(!vs(r)&&!(!vs(r)&&r.c.i.c==r.d.i.c))||r==t))return Ytt(e,r,a,i);return i}function iJt(e){var t,n,i,r;for(t=0,n=0,r=new G(e.j);r.a<r.c.c.length;)if(i=c(Q(r),12),t=Hn(As(t,pUe(pi(new jt(null,new Tt(i.e,16)),new IO)))),n=Hn(As(n,pUe(pi(new jt(null,new Tt(i.g,16)),new nj)))),t>1||n>1)return 2;return t+n==1?2:0}function lu(e,t){var n,i,r,o,a,d;return o=e.a*dre+e.b*1502,d=e.b*dre+11,n=p.Math.floor(d*gL),o+=n,d-=n*axe,o%=axe,e.a=o,e.b=d,t<=24?p.Math.floor(e.a*bke[t]):(r=e.a*(1<<t-24),a=p.Math.floor(e.b*mke[t]),i=r+a,i>=2147483648&&(i-=4294967296),i)}function Ztt(e,t,n){var i,r,o,a,d,b,v;for(o=new Fe,v=new Ai,a=new Ai,vKt(e,v,a,t),eZt(e,v,a,t,n),b=new G(e);b.a<b.c.c.length;)for(d=c(Q(b),117),r=new G(d.k);r.a<r.c.c.length;)i=c(Q(r),135),(!t||i.c==(Wf(),sp))&&d.g>i.b.g&&It(o.c,i);return o}function rJt(e,t,n){var i,r,o,a,d,b;for(d=e.c,a=(n.q?n.q:(Ct(),Ct(),Yd)).vc().Jc();a.Ob();)o=c(a.Pb(),45),i=!k6(pi(new jt(null,new Tt(d,16)),new d6(new SRe(t,o)))).zd((Hp(),hk)),i&&(b=o.kd(),oe(b,4)&&(r=$we(b),r!=null&&(b=r)),t.of(c(o.jd(),149),b))}function sJt(e,t){var n,i,r,o;for(t.Tg("Resize child graph to fit parent.",1),i=new G(e.b);i.a<i.c.c.length;)n=c(Q(i),26),yr(e.a,n.a),n.a.c.length=0;for(o=new G(e.a);o.a<o.c.c.length;)r=c(Q(o),9),zr(r,null);e.b.c.length=0,jXt(e),e.e&&wWt(e.e,e),t.Ug()}function oJt(e,t){var n,i,r,o,a;for(t.Tg("Edge joining",1),n=et(Ze(R(e,(Ge(),ble)))),r=new G(e.b);r.a<r.c.c.length;)for(i=c(Q(r),26),a=new os(i.a,0);a.b<a.d.gc();)o=(dn(a.b<a.d.gc()),c(a.d.Xb(a.c=a.b++),9)),o.k==(Jt(),jr)&&(Cie(o,n),iu(a));t.Ug()}function cJt(e,t,n){var i,r;if(U7(e.b),Iu(e.b,(SD(),PJ),(c7(),SP)),Iu(e.b,IJ,t.g),Iu(e.b,RJ,t.a),e.a=VT(e.b,t),n.Tg("Compaction by shrinking a tree",e.a.c.length),t.i.c.length>1)for(r=new G(e.a);r.a<r.c.c.length;)i=c(Q(r),43),i.If(t,n.dh(1));n.Ug()}function $ve(e,t,n){var i,r,o;if(o=qx((Dl(),ps),e.Ah(),t),o){if(qs(),!c(o,69).vk()&&(o=S5(uo(ps,o)),!o))throw J(new qt(V0+t.ve()+pE));r=(i=e.Fh(o),c(i>=0?e.Ih(i,!0,!0):ow(e,o,!0),164)),c(r,222).Vl(t,n)}else throw J(new qt(V0+t.ve()+pE))}function lJt(e,t,n){var i,r,o,a,d,b;if(b=Qge(e,c(Ut(e.e,t),19)),d=null,b)switch(b.g){case 3:i=hge(e,V2(t)),d=(zt(n),n+(zt(i),i));break;case 2:r=hge(e,V2(t)),a=(zt(n),n+(zt(r),r)),o=hge(e,c(Ut(e.e,t),19)),d=a-(zt(o),o);break;default:d=n}else d=n;return d}function uJt(e,t,n){var i,r,o,a,d,b;if(b=Qge(e,c(Ut(e.e,t),19)),d=null,b)switch(b.g){case 3:i=dge(e,V2(t)),d=(zt(n),n+(zt(i),i));break;case 2:r=dge(e,V2(t)),a=(zt(n),n+(zt(r),r)),o=dge(e,c(Ut(e.e,t),19)),d=a-(zt(o),o);break;default:d=n}else d=n;return d}function vQ(e,t){var n,i,r,o,a;if(t){for(o=oe(e.Cb,89)||oe(e.Cb,104),a=!o&&oe(e.Cb,336),i=new cn((!t.a&&(t.a=new P7(t,Ks,t)),t.a));i.e!=i.i.gc();)if(n=c(un(i),88),r=AQ(n),o?oe(r,89):a?oe(r,160):r)return r;return o?(Mt(),rf):(Mt(),Gh)}else return null}function aJt(e,t){var n,i,r,o,a;for(n=new Fe,r=So(new jt(null,new Tt(e,16)),new v4),o=So(new jt(null,new Tt(e,16)),new rj),a=ULt(hLt(X2(xJt(W(V(Ftn,1),Lt,840,0,[r,o])),new FR))),i=1;i<a.length;i++)a[i]-a[i-1]>=2*t&&qe(n,new OZ(a[i-1]+t,a[i]-t));return n}function ent(e,t,n){var i,r,o,a,d,b,v,x;if(n)for(o=n.a.length,i=new Xp(o),d=(i.b-i.a)*i.c<0?(x0(),wp):new S0(i);d.Ob();)a=c(d.Pb(),15),r=X6(n,a.a),r&&(b=mDt(e,(v=(w0(),x=new Rde,x),t&&Bve(v,t),v),r),nS(b,M1(r,bd)),lQ(r,b),cve(r,b),Tte(e,r,b))}function yQ(e){var t,n,i,r,o,a;if(!e.j){if(a=new QW,t=GC,o=t.a.yc(e,t),o==null){for(i=new cn(vo(e));i.e!=i.i.gc();)n=c(un(i),29),r=yQ(n),ur(a,r),Nn(a,n);t.a.Ac(e)!=null}cv(a),e.j=new fx((c(re(Ne((j0(),Gt).o),11),20),a.i),a.g),ru(e).b&=-33}return e.j}function fJt(e){var t,n,i,r;if(e==null)return null;if(i=Nc(e,!0),r=BL.length,Ot(i.substr(i.length-r,r),BL)){if(n=i.length,n==4){if(t=(en(0,i.length),i.charCodeAt(0)),t==43)return JTe;if(t==45)return xvt}else if(n==3)return JTe}return new Mde(i)}function hJt(e){var t,n,i;return n=e.l,(n&n-1)!=0||(i=e.m,(i&i-1)!=0)||(t=e.h,(t&t-1)!=0)||t==0&&i==0&&n==0?-1:t==0&&i==0&&n!=0?eme(n):t==0&&i!=0&&n==0?eme(i)+22:t!=0&&i==0&&n==0?eme(t)+44:-1}function Bx(e,t){var n,i,r,o,a;for(r=t.a&e.f,o=null,i=e.b[r];;i=i.b){if(i==t){o?o.b=t.b:e.b[r]=t.b;break}o=i}for(a=t.f&e.f,o=null,n=e.c[a];;n=n.d){if(n==t){o?o.d=t.d:e.c[a]=t.d;break}o=n}t.e?t.e.c=t.c:e.a=t.c,t.c?t.c.e=t.e:e.e=t.e,--e.i,++e.g}function dJt(e,t){var n;t.d?t.d.b=t.b:e.a=t.b,t.b?t.b.d=t.d:e.e=t.d,!t.e&&!t.c?(n=c(za(c(E5(e.b,t.a),263)),263),n.a=0,++e.c):(n=c(za(c(Ut(e.b,t.a),263)),263),--n.a,t.e?t.e.c=t.c:n.b=c(za(t.c),501),t.c?t.c.e=t.e:n.c=c(za(t.e),501)),--e.d}function Zne(e,t){var n,i,r,o;for(o=new os(e,0),n=(dn(o.b<o.d.gc()),c(o.d.Xb(o.c=o.b++),148));o.b<o.d.gc();)i=(dn(o.b<o.d.gc()),c(o.d.Xb(o.c=o.b++),148)),r=new N0e(i.c,n.d,t),dn(o.b>0),o.a.Xb(o.c=--o.b),z2(o,r),dn(o.b<o.d.gc()),o.d.Xb(o.c=o.b++),r.a=!1,n=i}function tnt(e){var t,n,i,r,o,a;for(r=c(R(e,(De(),qU)),12),a=new G(e.j);a.a<a.c.c.length;){for(o=c(Q(a),12),i=new G(o.g);i.a<i.c.c.length;)return t=c(Q(i),17),ss(t,r),o;for(n=new G(o.e);n.a<n.c.c.length;)return t=c(Q(n),17),ks(t,r),o}return null}function nnt(e,t,n){var i,r,o,a,d,b;for(b=c(R2(e.a,t),15).a,n?M2e(e.a,Pe(b+1),t):M2e(e.a,Pe(b-1),t),a=new Ld,r=new Ht(Vt((n?$i(t):pr(t)).a.Jc(),new U));hn(r);)i=c(sn(r),17),n?o=i.d.i:o=i.c.i,ve(R2(e.a,o))===ve(R2(e.a,t))&&(d=a.a.yc(o,a),d==null);return a}function gJt(e,t,n){var i,r;i=Zo(n.q.getTime()),Mc(i,0)<0?(r=qg-Hn(Zte(Ng(i),qg)),r==qg&&(r=0)):r=Hn(Zte(i,qg)),t==1?(r=p.Math.min((r+50)/100|0,9),Kp(e,48+r&_r)):t==2?(r=p.Math.min((r+5)/10|0,99),qd(e,r,2)):(qd(e,r,3),t>3&&qd(e,0,t-3))}function pJt(e){var t,n,i,r;return ve(R(e,(Ge(),Fv)))===ve((R1(),Zg))?!e.e&&ve(R(e,oP))!==ve((cS(),YL)):(i=c(R(e,rle),303),r=et(Ze(R(e,sle)))||ve(R(e,KE))===ve((xT(),WL)),t=c(R(e,fSe),15).a,n=e.a.c.length,!r&&i!=(cS(),YL)&&(t==0||t>n))}function bJt(e,t){var n,i,r,o,a,d,b;for(r=e.Jc();r.Ob();)for(i=c(r.Pb(),9),d=new bc,_o(d,i),$r(d,(Je(),nn)),Ee(d,(De(),UU),(Bt(),!0)),a=t.Jc();a.Ob();)o=c(a.Pb(),9),b=new bc,_o(b,o),$r(b,Yt),Ee(b,UU,!0),n=new qm,Ee(n,UU,!0),ks(n,d),ss(n,b)}function mJt(e){var t,n;for(n=0;n<e.c.length&&!(dFe((ht(n,e.c.length),c(e.c[n],114)))>0);n++);if(n>0&&n<e.c.length-1)return n;for(t=0;t<e.c.length&&!(dFe((ht(t,e.c.length),c(e.c[t],114)))>0);t++);return t>0&&n<e.c.length-1?t:e.c.length/2|0}function int(e,t){var n,i,r,o,a,d,b;for(r=0,a=new G(t.a);a.a<a.c.c.length;)for(o=c(Q(a),9),r+=o.o.b+o.d.a+o.d.d+e.e,i=new Ht(Vt(pr(o).a.Jc(),new U));hn(i);)n=c(sn(i),17),n.c.i.k==(Jt(),Dc)&&(b=n.c.i,d=c(R(b,(De(),Oi)),9),r+=d.o.b+d.d.a+d.d.d);return r}function wJt(e,t){var n,i,r,o;t.Tg("Min Size Preprocessing",1),i=nve(e),Xi(e)&&(n=(v0(),new wg(Xi(e))),o=new EF(Xi(e)?new wg(Xi(e)):null,e),r=Hye(n,o,!1,!0),i.a=p.Math.max(i.a,r.a),i.b=p.Math.max(i.b,r.b)),ii(e,(Gd(),vC),i.a),ii(e,_J,i.b),t.Ug()}function rnt(e,t){var n,i;if(t!=e.Cb||e.Db>>16!=6&&t){if(jS(e,t))throw J(new qt(bE+ptt(e)));i=null,e.Cb&&(i=(n=e.Db>>16,n>=0?o2e(e,i):e.Cb.Qh(e,-1-n,null,i))),t&&(i=z5(t,e,6,i)),i=Uge(e,t,i),i&&i.mj()}else(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,6,t,t))}function xQ(e,t){var n,i;if(t!=e.Cb||e.Db>>16!=3&&t){if(jS(e,t))throw J(new qt(bE+urt(e)));i=null,e.Cb&&(i=(n=e.Db>>16,n>=0?a2e(e,i):e.Cb.Qh(e,-1-n,null,i))),t&&(i=z5(t,e,12,i)),i=Gge(e,t,i),i&&i.mj()}else(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,3,t,t))}function Bve(e,t){var n,i;if(t!=e.Cb||e.Db>>16!=9&&t){if(jS(e,t))throw J(new qt(bE+iit(e)));i=null,e.Cb&&(i=(n=e.Db>>16,n>=0?l2e(e,i):e.Cb.Qh(e,-1-n,null,i))),t&&(i=z5(t,e,9,i)),i=Jge(e,t,i),i&&i.mj()}else(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,9,t,t))}function _S(e){var t,n,i,r,o;if(i=Qa(e),o=e.j,o==null&&i)return e.Hk()?null:i.gk();if(oe(i,160)){if(n=i.hk(),n&&(r=n.ti(),r!=e.i)){if(t=c(i,160),t.lk())try{e.g=r.qi(t,o)}catch(a){if(a=vr(a),oe(a,81))e.g=null;else throw J(a)}e.i=r}return e.g}return null}function snt(e){var t;return t=new Fe,qe(t,new n5(new $e(e.c,e.d),new $e(e.c+e.b,e.d))),qe(t,new n5(new $e(e.c,e.d),new $e(e.c,e.d+e.a))),qe(t,new n5(new $e(e.c+e.b,e.d+e.a),new $e(e.c+e.b,e.d))),qe(t,new n5(new $e(e.c+e.b,e.d+e.a),new $e(e.c,e.d+e.a))),t}function vJt(e){var t,n,i,r;for(i=e.a.d.j,r=e.c.d.j,n=new G(e.i.d);n.a<n.c.c.length;)t=c(Q(n),70),Ee(t,(Ge(),b3),null);i==(Je(),Kt)?Eg(e,Kt,(xf(),E9),e.a):r==Kt?Eg(e,Kt,(xf(),C9),e.c):i==bn?Eg(e,bn,(xf(),C9),e.a):r==bn&&Eg(e,bn,(xf(),E9),e.c)}function yJt(e){var t,n,i;if(e==null)return pl;try{return jo(e)}catch(r){if(r=vr(r),oe(r,102))return t=r,i=qp(ju(e))+"@"+(n=(Og(),zwe(e)>>>0),n.toString(16)),FBt(QIt(),(T6(),"Exception during lenientFormat for "+i),t),"<"+i+" threw "+qp(t.Pm)+">";throw J(r)}}function xJt(e){var t,n,i,r,o,a,d,b,v;for(i=!1,t=336,n=0,o=new tze(e.length),d=e,b=0,v=d.length;b<v;++b)a=d[b],i=i|(R0(a),!1),r=(T0(a),a.a),qe(o.a,Rn(r)),t&=r.wd(),n=ARt(n,r.xd());return c(c(hqe(new jt(null,Rne(new Tt(Bwe(o.a),16),new D,t,n)),new sz(e)),684),840)}function kJt(e,t,n,i){var r,o,a,d;r=CKe(e,t,n),o=CKe(e,n,t),a=c(Ut(e.c,t),117),d=c(Ut(e.c,n),117),r<o?new eb((Wf(),Kv),a,d,o-r):o<r?new eb((Wf(),Kv),d,a,r-o):(r!=0||!(!t.i||!n.i)&&i[t.i.c][n.i.c])&&(new eb((Wf(),Kv),a,d,0),new eb(Kv,d,a,0))}function OJt(e,t,n){var i,r,o,a,d;for(n.Tg("Breaking Point Removing",1),e.a=c(R(t,(Ge(),W1)),225),o=new G(t.b);o.a<o.c.c.length;)for(r=c(Q(o),26),d=new G(tb(r.a));d.a<d.c.c.length;)a=c(Q(d),9),GJe(a)&&(i=c(R(a,(De(),Cw)),318),!i.d&&tst(e,i));n.Ug()}function RT(){RT=te,S3=new u_("CANDIDATE_POSITION_LAST_PLACED_RIGHT",0),Mk=new u_("CANDIDATE_POSITION_LAST_PLACED_BELOW",1),OC=new u_("CANDIDATE_POSITION_WHOLE_DRAWING_RIGHT",2),kC=new u_("CANDIDATE_POSITION_WHOLE_DRAWING_BELOW",3),OP=new u_("WHOLE_DRAWING",4)}function SJt(e){var t,n,i,r;for(i=new sv(new Bp(e.b).a);i.b;)n=Ex(i),r=c(n.jd(),12),t=c(n.kd(),9),Ee(t,(De(),Oi),r),Ee(r,Ul,t),Ee(r,nP,(Bt(),!0)),$r(r,c(R(t,Ko),64)),R(t,Ko),Ee(r.i,(Ge(),cr),(Zr(),r8)),c(R(Jr(r.i),Lc),24).Ec((Gs(),P9))}function jJt(e){var t,n,i,r,o,a,d;for(o=new Ai,r=new G(e.d.a);r.a<r.c.c.length;)i=c(Q(r),126),i.b.a.c.length==0&&tr(o,i,o.c.b,o.c);if(o.b>1)for(t=Dm((n=new Fp,++e.b,n),e.d),d=_n(o,0);d.b!=d.d.c;)a=c(An(d),126),Of(uf(ff(hf(af(new Ra,1),0),t),a))}function kQ(e,t){var n,i;if(t!=e.Cb||e.Db>>16!=11&&t){if(jS(e,t))throw J(new qt(bE+oye(e)));i=null,e.Cb&&(i=(n=e.Db>>16,n>=0?f2e(e,i):e.Cb.Qh(e,-1-n,null,i))),t&&(i=z5(t,e,10,i)),i=i0e(e,t,i),i&&i.mj()}else(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,11,t,t))}function TJt(e,t,n){var i,r,o,a,d,b;if(o=0,a=0,e.c)for(b=new G(e.d.i.j);b.a<b.c.c.length;)d=c(Q(b),12),o+=d.e.c.length;else o=1;if(e.d)for(b=new G(e.c.i.j);b.a<b.c.c.length;)d=c(Q(b),12),a+=d.g.c.length;else a=1;return r=xs(D_(a-o)),i=(n+t)/2+(n-t)*(.4*r),i}function EJt(e,t){var n,i,r,o,a,d;for(t.Tg("Partition postprocessing",1),i=new G(e.b);i.a<i.c.c.length;)for(n=c(Q(i),26),o=new G(n.a);o.a<o.c.c.length;)for(r=c(Q(o),9),d=new G(r.j);d.a<d.c.c.length;)a=c(Q(d),12),et(Ze(R(a,(De(),UU))))&&z7(d);t.Ug()}function CJt(e){dv();var t,n;if(e.Gc((Je(),$o)))throw J(new qt("Port sides must not contain UNDEFINED"));switch(e.gc()){case 1:return VL;case 2:return t=e.Gc(nn)&&e.Gc(Yt),n=e.Gc(Kt)&&e.Gc(bn),t||n?DU:_U;case 3:return NU;case 4:return AU;default:return null}}function ont(e,t,n){return LS(),bte(e,t)&&bte(e,n)?!1:Aie(new $e(e.c,e.d),new $e(e.c+e.b,e.d),t,n)||Aie(new $e(e.c+e.b,e.d),new $e(e.c+e.b,e.d+e.a),t,n)||Aie(new $e(e.c+e.b,e.d+e.a),new $e(e.c,e.d+e.a),t,n)||Aie(new $e(e.c,e.d+e.a),new $e(e.c,e.d),t,n)}function zve(e,t){var n,i,r,o;if(!e.dc()){for(n=0,i=e.gc();n<i;++n)if(o=zn(e.Xb(n)),o==null?t==null:Ot(o.substr(0,3),"!##")?t!=null&&(r=t.length,!Ot(o.substr(o.length-r,r),t)||o.length!=t.length+3)&&!Ot(Cb,t):Ot(o,hoe)&&!Ot(Cb,t)||Ot(o,t))return!0}return!1}function MJt(e,t,n,i){var r,o,a,d,b,v;for(a=e.j.c.length,b=ye(Qtn,mxe,319,a,0,1),d=0;d<a;d++)o=c(Xe(e.j,d),12),o.p=d,b[d]=RGt(Ttt(o),n,i);for(tXt(e,b,n,t,i),v=new wn,r=0;r<b.length;r++)b[r]&&oi(v,c(Xe(e.j,r),12),b[r]);v.f.c+v.i.c!=0&&(Ee(e,(De(),qE),v),cQt(e,b))}function AJt(e,t,n){var i,r,o;for(r=new G(e.a.b);r.a<r.c.c.length;)if(i=c(Q(r),60),o=kx(i),o&&o.k==(Jt(),Cr))switch(c(R(o,(De(),Ko)),64).g){case 4:o.n.a=t.a;break;case 2:o.n.a=n.a-(o.o.a+o.d.c);break;case 1:o.n.b=t.b;break;case 3:o.n.b=n.b-(o.o.b+o.d.a)}}function NJt(e,t,n){var i,r,o;for(n.Tg("Processor determine the height for each level",1),e.a=t.b.b==0?1:t.b.b,r=null,i=_n(t.b,0);!r&&i.b!=i.d.c;)o=c(An(i),41),et(Ze(R(o,(Li(),cp))))&&(r=o);r&&Yit(e,mf(W(V(kJ,1),xG,41,0,[r])),n,c(R(t,(Uo(),Iw)),87)),n.Ug()}function _Jt(e){var t,n,i,r,o,a;for(i=(w0(),o=new Wj,o),GD(i,e),n=new cn((!e.a&&(e.a=new Me(Mn,e,10,11)),e.a));n.e!=n.i.gc();)t=c(un(n),19),a=(r=new Wj,r),kQ(a,i),_m(a,t.g,t.f),nS(a,t.k),aa(a,t.i,t.j),Nn((!i.a&&(i.a=new Me(Mn,i,10,11)),i.a),a),GD(a,t);return i}function DJt(e,t,n){var i,r,o,a,d;return r=c(ke(t,(fQ(),Xje)),15),!r&&(r=Pe(0)),o=c(ke(n,Xje),15),!o&&(o=Pe(0)),r.a>o.a?-1:r.a<o.a?1:e.a&&(i=ji(t.j,n.j),i!=0||(i=ji(t.i,n.i),i!=0))?i:(a=t.g*t.f,d=n.g*n.f,ji(a,d))}function LJt(e,t){var n,i,r,o,a,d,b,v,x,S;if(++e.e,b=e.d==null?0:e.d.length,t>b){for(x=e.d,e.d=ye(wTe,T5e,67,2*b+4,0,1),o=0;o<b;++o)if(v=x[o],v)for(i=v.g,S=v.i,d=0;d<S;++d)r=c(i[d],138),a=Xge(e,r.yi()),n=e.d[a],!n&&(n=e.d[a]=e.bk()),n.Ec(r);return!0}else return!1}function PJt(e,t,n){var i,r,o,a,d,b;if(r=n,o=r.Jk(),F1(e.e,o)){if(o.Qi()){for(i=c(e.g,123),a=0;a<e.i;++a)if(d=i[a],yi(d,r)&&a!=t)throw J(new qt(DL))}}else for(b=nl(e.e.Ah(),o),i=c(e.g,123),a=0;a<e.i;++a)if(d=i[a],b.$l(d.Jk()))throw J(new qt($L));wT(e,t,n)}function cnt(e,t){var n,i,r,o,a,d;for(n=c(R(t,(De(),X1)),24),a=c(Si((Lie(),Ni),n),24),d=c(Si(ri,n),24),o=a.Jc();o.Ob();)if(i=c(o.Pb(),24),!c(Si(e.b,i),16).dc())return!1;for(r=d.Jc();r.Ob();)if(i=c(r.Pb(),24),!c(Si(e.b,i),16).dc())return!1;return!0}function IJt(e,t,n){e.d=0,e.b=0,t.k==(Jt(),Dc)&&n.k==Dc&&c(R(t,(De(),Oi)),9)==c(R(n,Oi),9)&&(Jee(t).j==(Je(),Kt)?Xtt(e,t,n):Xtt(e,n,t)),t.k==Dc&&n.k==jr?Jee(t).j==(Je(),Kt)?e.d=1:e.b=1:n.k==Dc&&t.k==jr&&(Jee(n).j==(Je(),Kt)?e.b=1:e.d=1),Rzt(e,t,n)}function Fve(e,t){var n,i,r,o,a,d,b,v,x;if(e.a.c.length==1)return tet(c(Xe(e.a,0),175),t);for(a=ZRt(e),b=0,v=e.d,o=a,x=e.d,d=(v-o)/2+o;o+1<v;){for(b=0,i=new G(e.a);i.a<i.c.c.length;)n=c(Q(i),175),b+=(r=UT(n,d,!1),r.a);b<t?(x=d,v=d):o=d,d=(v-o)/2+o}return x}function GD(e,t){var n,i,r,o,a;if(!t)return e;if(oe(t,344))for(r=c(t,344),o=(!e.o&&(e.o=new Al((oc(),s1),e0,e,0)),e.o),i=r.fh().c.Jc();i.e!=i.i.gc();)n=c(i.Wj(),45),a=n.kd(),PD(o,c(n.jd(),149),a);else!e.o&&(e.o=new Al((oc(),s1),e0,e,0)),GXe(e.o,t.lf());return e}function qve(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z;return x=null,P=Ave(e,t),b=null,P&&(b=xFt(e,P)),z=b,n=null,r=he(Ut(e.i,z)),r!=null?n=r:n=Pe(0),M=n,i=null,o=he(Ut(e.j,z)),o!=null?i=o:i=Pe(0),L=i,v=t.i,a=QBe(v,M),oi(e.i,t,a),S=t.j,d=QBe(S,L),x=he(oi(e.j,t,d)),x}function RJt(e){var t,n,i,r,o;return isNaN(e)?(Z6(),V5e):e<-9223372036854776e3?(Z6(),Iat):e>=9223372036854776e3?(Z6(),J5e):(r=!1,e<0&&(r=!0,e=-e),i=0,e>=yb&&(i=xs(e/yb),e-=i*yb),n=0,e>=tk&&(n=xs(e/tk),e-=n*tk),t=xs(e),o=el(t,n,i),r&&jte(o),o)}function $Jt(e){var t,n,i,r,o;if(o=new Fe,Qc(e.b,new WAe(o)),e.b.c.length=0,o.c.length!=0){for(t=(ht(0,o.c.length),c(o.c[0],81)),n=1,i=o.c.length;n<i;++n)r=(ht(n,o.c.length),c(o.c[n],81)),r!=t&&AZe(t,r);if(oe(t,63))throw J(c(t,63));if(oe(t,298))throw J(c(t,298))}}function BJt(e,t){var n,i,r,o;for(n=!t||!e.u.Gc((Ql(),eg)),o=0,r=new G(e.e.Vf());r.a<r.c.c.length;){if(i=c(Q(r),844),i.$f()==(Je(),$o))throw J(new qt("Label and node size calculator can only be used with ports that have port sides assigned."));i.Of(o++),QRt(e,i,n)}}function lnt(e,t,n){var i,r,o;for(ga(t,(q5(),W9))&&(n=ue(he(ke(t,W9)))),Nl(t,n),o=n+e.a+t.f+p.Math.max(c(ke(t,(Dn(),Y1)),125).a,e.b),r=0;r<(!t.e&&(t.e=new Et(Ii,t,7,4)),t.e).i;r++)i=c(re(H6(c(re((!t.e&&(t.e=new Et(Ii,t,7,4)),t.e),r),74)),0),19),lnt(e,i,o)}function Hve(e){var t,n,i,r,o;for(n=new G(e.a.a);n.a<n.c.c.length;){for(t=c(Q(n),321),t.j=null,o=t.a.a.ec().Jc();o.Ob();)i=c(o.Pb(),60),Xf(i.b),(!t.j||i.d.c<t.j.d.c)&&(t.j=i);for(r=t.a.a.ec().Jc();r.Ob();)i=c(r.Pb(),60),i.b.a=i.d.c-t.j.d.c,i.b.b=i.d.d-t.j.d.d}return e}function OQ(e){var t,n,i,r,o;for(n=new G(e.a.a);n.a<n.c.c.length;){for(t=c(Q(n),197),t.f=null,o=t.a.a.ec().Jc();o.Ob();)i=c(o.Pb(),84),Xf(i.e),(!t.f||i.g.c<t.f.g.c)&&(t.f=i);for(r=t.a.a.ec().Jc();r.Ob();)i=c(r.Pb(),84),i.e.a=i.g.c-t.f.g.c,i.e.b=i.g.d-t.f.g.d}return e}function zJt(e,t,n){var i,r,o,a,d;for(a=bT(e,n),d=ye(e1,Hg,9,t.length,0,1),i=0,o=a.Jc();o.Ob();)r=c(o.Pb(),12),et(Ze(R(r,(De(),nP))))&&(d[i++]=c(R(r,Ul),9));if(i<t.length)throw J(new oo("Expected "+t.length+" hierarchical ports, but found only "+i+"."));return d}function FJt(e){var t,n,i,r,o,a,d,b,v,x,S;return S=P2e(e),t=e.a,b=t!=null,b&&I6(S,"category",e.a),r=WN(new an(e.d)),a=!r,a&&(v=new mg,wf(S,"knownOptions",v),n=new NDe(v),ws(new an(e.d),n)),o=WN(e.g),d=!o,d&&(x=new mg,wf(S,"supportedFeatures",x),i=new _De(x),ws(e.g,i)),S}function qJt(e,t){var n;e.d&&(t.c!=e.e.c||oIt(e.e.b,t.b))&&(qe(e.f,e.d),e.a=e.d.c+e.d.b,e.d=null,e.e=null),H8t(t.b)?e.c=t:e.b=t,(t.b==(lS(),jw)&&!t.a||t.b==_v&&t.a||t.b==i3&&t.a||t.b==Dv&&!t.a)&&e.c&&e.b&&(n=new pf(e.a,e.c.d,t.c-e.a,e.b.d-e.c.d),e.d=n,e.e=t)}function Qd(){Qd=te,zb=new gi("LEFT_OUTLINE"),Zv=new gi("RIGHT_OUTLINE"),kd=new gi("OUTLINE_MAX_DEPTH"),V9=new gi("MIN_X"),X9=new gi("MAX_X"),Hmt=new gi("MIN_Y"),Pue=new gi("MAX_Y"),SC=new gi("root"),Rw=new gi("EDGE_BEND_HEIGHT"),jP=new gi("Node Model Order")}function Qve(e,t){var n,i;if(t!=e.Cb||e.Db>>16!=7&&t){if(jS(e,t))throw J(new qt(bE+cet(e)));i=null,e.Cb&&(i=(n=e.Db>>16,n>=0?c2e(e,i):e.Cb.Qh(e,-1-n,null,i))),t&&(i=c(t,52).Oh(e,1,QP,i)),i=U0e(e,t,i),i&&i.mj()}else(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,7,t,t))}function unt(e,t){var n,i;if(t!=e.Cb||e.Db>>16!=3&&t){if(jS(e,t))throw J(new qt(bE+UWe(e)));i=null,e.Cb&&(i=(n=e.Db>>16,n>=0?u2e(e,i):e.Cb.Qh(e,-1-n,null,i))),t&&(i=c(t,52).Oh(e,0,UP,i)),i=J0e(e,t,i),i&&i.mj()}else(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,3,t,t))}function eie(e,t){PS();var n,i,r,o,a,d,b,v,x;return t.d>e.d&&(d=e,e=t,t=d),t.d<63?CXt(e,t):(a=(e.d&-2)<<4,v=fbe(e,a),x=fbe(t,a),i=yie(e,T5(v,a)),r=yie(t,T5(x,a)),b=eie(v,x),n=eie(i,r),o=eie(yie(v,i),yie(r,x)),o=Eie(Eie(o,b),n),o=T5(o,a),b=T5(b,a<<1),Eie(Eie(b,o),n))}function UD(){UD=te,kle=new cx(bct,0),YSe=new cx("LONGEST_PATH",1),ZSe=new cx("LONGEST_PATH_SOURCE",2),yle=new cx("COFFMAN_GRAHAM",3),KSe=new cx(Mre,4),e9e=new cx("STRETCH_WIDTH",5),fJ=new cx("MIN_WIDTH",6),vle=new cx("BF_MODEL_ORDER",7),xle=new cx("DF_MODEL_ORDER",8)}function HJt(e,t){var n,i,r,o,a,d;if(!e.tb){for(o=(!e.rb&&(e.rb=new G2(e,ah,e)),e.rb),d=new e5(o.i),r=new cn(o);r.e!=r.i.gc();)i=c(un(r),146),a=i.ve(),n=c(a==null?gl(d.f,null,i):Zm(d.i,a,i),146),n&&(a==null?gl(d.f,null,n):Zm(d.i,a,n));e.tb=d}return c(Tc(e.tb,t),146)}function JD(e,t){var n,i,r,o,a;if((e.i==null&&ud(e),e.i).length,!e.p){for(a=new e5((3*e.g.i/2|0)+1),r=new a5(e.g);r.e!=r.i.gc();)i=c(lne(r),182),o=i.ve(),n=c(o==null?gl(a.f,null,i):Zm(a.i,o,i),182),n&&(o==null?gl(a.f,null,n):Zm(a.i,o,n));e.p=a}return c(Tc(e.p,t),182)}function Gve(e,t,n,i,r){var o,a,d,b,v;for(LBt(i+wq(n,n.ge()),r),Oqe(t,iBt(n)),o=n.f,o&&Gve(e,t,o,"Caused by: ",!1),d=(n.k==null&&(n.k=ye(Coe,Be,81,0,0,1)),n.k),b=0,v=d.length;b<v;++b)a=d[b],Gve(e,t,a,"Suppressed: ",!1);console.groupEnd!=null&&console.groupEnd.call(console)}function XD(e,t,n,i){var r,o,a,d,b;for(b=t.e,d=b.length,a=t.q.tg(b,n?0:d-1,n),r=b[n?0:d-1],a=a|Wnt(e,r,n,i),o=n?1:d-2;n?o<d:o>=0;o+=n?1:-1)a=a|t.c.jg(b,o,n,i&&!et(Ze(R(t.j,(De(),tp))))&&!et(Ze(R(t.j,(De(),h3))))),a=a|t.q.tg(b,o,n),a=a|Wnt(e,b[o],n,i);return Sr(e.c,t),a}function SQ(e,t,n){var i,r,o,a,d,b,v,x,S,M;for(x=YQe(e.j),S=0,M=x.length;S<M;++S){if(v=x[S],n==(Qs(),Jl)||n==oC)for(b=rd(v.g),r=b,o=0,a=r.length;o<a;++o)i=r[o],oQt(t,i)&&zg(i,!0);if(n==Wc||n==oC)for(d=rd(v.e),r=d,o=0,a=r.length;o<a;++o)i=r[o],sQt(t,i)&&zg(i,!0)}}function ant(){return cs(),W(V(Vtn,1),_e,80,0,[aOe,cOe,r3,cce,MOe,bU,TU,Pv,EOe,wOe,jOe,Lv,COe,pOe,AOe,tOe,yU,lce,gU,OU,_Oe,kU,nOe,TOe,DOe,SU,eOe,NOe,pU,hOe,OOe,kOe,EU,sOe,dU,wU,rOe,T9,yOe,bOe,SOe,IE,lOe,oOe,xOe,mOe,vU,jU,iOe,xU,vOe,mU,dOe,fOe,pk,hU,gOe,uOe])}function QJt(e){var t,n;switch(t=null,n=null,jqt(e).g){case 1:t=(Je(),nn),n=Yt;break;case 2:t=(Je(),bn),n=Kt;break;case 3:t=(Je(),Yt),n=nn;break;case 4:t=(Je(),Kt),n=bn}F4(e,c(vu(m5(c(Si(e.k,t),16).Mc(),s3)),114)),z4(e,c(vu(Q2(c(Si(e.k,n),16).Mc(),s3)),114))}function DS(e){var t;if(zLe.call(this),this.i=new N$,this.g=e,this.f=c(e.e&&e.e(),10).length,this.f==0)throw J(new qt("There must be at least one phase in the phase enumeration."));this.c=(t=c(Jf(this.g),10),new ha(t,c(gf(t,t.length),10),0)),this.a=new wr,this.b=new wn}function GJt(e){var t,n,i,r,o,a;if(r=c(Xe(e.j,0),12),r.e.c.length+r.g.c.length==0)e.n.a=0;else{for(a=0,i=Bd(ma(W(V(Ta,1),Lt,22,0,[new p6(r),new Q4(r)])));hn(i);)n=c(sn(i),12),a+=n.i.n.a+n.n.a+n.a.a;t=c(R(e,(Ge(),Lw)),8),o=t?t.a:0,e.n.a=a/(r.e.c.length+r.g.c.length)-o}}function fnt(e,t){var n,i,r;for(i=new G(t.a);i.a<i.c.c.length;)n=c(Q(i),227),IZ(c(n.b,68),Hr(Ms(c(t.b,68).c),c(t.b,68).a)),r=Nit(c(t.b,68).b,c(n.b,68).b),r>1&&(e.a=!0),nMt(c(n.b,68),ki(Ms(c(t.b,68).c),S1(Hr(Ms(c(n.b,68).a),c(t.b,68).a),r))),lQe(e,t),fnt(e,n)}function hnt(e){var t,n,i,r,o,a,d;for(o=new G(e.a.a);o.a<o.c.c.length;)i=c(Q(o),197),i.e=0,i.d.a.$b();for(r=new G(e.a.a);r.a<r.c.c.length;)for(i=c(Q(r),197),n=i.a.a.ec().Jc();n.Ob();)for(t=c(n.Pb(),84),d=t.f.Jc();d.Ob();)a=c(d.Pb(),84),a.d!=i&&(Sr(i.d,a),++a.d.e)}function UJt(e,t){var n,i,r,o,a,d,b;for(t.Tg("Constraints Postprocessor",1),a=0,o=new G(e.b);o.a<o.c.c.length;){for(r=c(Q(o),26),b=0,d=!1,i=new G(r.a);i.a<i.c.c.length;)n=c(Q(i),9),n.k==(Jt(),or)&&(d=!0,Ee(n,(Ge(),YE),Pe(a)),Ee(n,YU,Pe(b)),++b);d&&++a}t.Ug()}function JJt(e){var t,n,i,r,o,a,d,b;for(b=e.j.c.length,n=0,t=b,r=2*b,d=new G(e.j);d.a<d.c.c.length;)switch(a=c(Q(d),12),a.j.g){case 2:case 4:a.p=-1;break;case 1:case 3:i=a.e.c.length,o=a.g.c.length,i>0&&o>0?a.p=t++:i>0?a.p=n++:o>0?a.p=r++:a.p=n++}Ct(),Rr(e.j,new hW)}function XJt(e){var t,n;n=null,t=c(Xe(e.g,0),17);do{if(n=t.d.i,xi(n,(De(),Wa)))return c(R(n,Wa),12).i;if(n.k!=(Jt(),or)&&hn(new Ht(Vt($i(n).a.Jc(),new U))))t=c(sn(new Ht(Vt($i(n).a.Jc(),new U))),17);else if(n.k!=or)return null}while(n&&n.k!=(Jt(),or));return n}function VJt(e,t){var n,i,r,o,a,d,b,v,x;for(d=t.j,a=t.g,b=c(Xe(d,d.c.length-1),114),x=(ht(0,d.c.length),c(d.c[0],114)),v=One(e,a,b,x),o=1;o<d.c.length;o++)n=(ht(o-1,d.c.length),c(d.c[o-1],114)),r=(ht(o,d.c.length),c(d.c[o],114)),i=One(e,a,n,r),i>v&&(b=n,x=r,v=i);t.a=x,t.c=b}function cw(e,t,n,i){var r,o;if(r=ve(R(n,(Ge(),VE)))===ve((D0(),$v)),o=c(R(n,aSe),16),xi(e,(De(),Pi)))if(r){if(o.Gc(R(e,WE))&&o.Gc(R(t,WE)))return i*c(R(e,WE),15).a+c(R(e,Pi),15).a}else return c(R(e,Pi),15).a;else return-1;return c(R(e,Pi),15).a}function WJt(e,t,n){var i,r,o,a,d,b,v;for(v=new kg(new b_e(e)),a=W(V(qht,1),zot,12,0,[t,n]),d=0,b=a.length;d<b;++d)for(o=a[d],v.a.yc(o,(Bt(),K0))==null,r=new kh(o.b);No(r.a)||No(r.b);)i=c(No(r.a)?Q(r.a):Q(r.b),17),i.c==i.d||L_(v,o==i.c?i.d:i.c);return Rn(v),new Fl(v)}function Of(e){if(!e.a.d||!e.a.e)throw J(new oo((j1(aft),aft.k+" must have a source and target "+(j1(xke),xke.k)+" specified.")));if(e.a.d==e.a.e)throw J(new oo("Network simplex does not support self-loops: "+e.a+" "+e.a.d+" "+e.a.e));return jF(e.a.d.g,e.a),jF(e.a.e.b,e.a),e.a}function KJt(e,t,n){var i,r,o,a,d;for(n.Tg("Longest path layering",1),e.a=t,d=e.a.a,e.b=ye(Fn,ci,30,d.c.length,15,1),i=0,a=new G(d);a.a<a.c.c.length;)r=c(Q(a),9),r.p=i,e.b[i]=-1,++i;for(o=new G(d);o.a<o.c.c.length;)r=c(Q(o),9),Gtt(e,r);d.c.length=0,e.a=null,e.b=null,n.Ug()}function dnt(e,t,n){var i,r,o,a,d,b;if(i=0,t.b!=0&&n.b!=0){o=_n(t,0),a=_n(n,0),d=ue(he(An(o))),b=ue(he(An(a))),r=!0;do{if(d>b-e.b&&d<b+e.b)return-1;d>b-e.a&&d<b+e.a&&++i,d<=b&&o.b!=o.d.c?d=ue(he(An(o))):b<=d&&a.b!=a.d.c?b=ue(he(An(a))):r=!1}while(r)}return i}function gnt(e,t){var n,i;return U7(e.a),Iu(e.a,(hH(),EJ),EJ),Iu(e.a,O3,O3),i=new wr,Wn(i,O3,(cQ(),iue)),ve(ke(t,(F0(),cue)))!==ve((yD(),CJ))&&Wn(i,O3,eue),et(Ze(ke(t,k8e)))&&Wn(i,O3,rue),Wn(i,O3,tue),et(Ze(ke(t,S8e)))&&Fc(i,O3,nue),sge(e.a,i),n=VT(e.a,t),n}function YJt(e,t,n,i){var r,o,a,d,b,v,x,S,M;for(b=0,x=new G(e.a);x.a<x.c.c.length;){for(v=c(Q(x),9),d=0,o=new Ht(Vt(pr(v).a.Jc(),new U));hn(o);)r=c(sn(o),17),S=xh(r.c).b,M=xh(r.d).b,d=p.Math.max(d,p.Math.abs(M-S));b=p.Math.max(b,d)}return a=i*p.Math.min(1,t/n)*b,a}function ZJt(e){var t,n;for(n=new Ht(Vt($i(e).a.Jc(),new U));hn(n);)if(t=c(sn(n),17),t.d.i.k!=(Jt(),lc))throw J(new Wh(Cre+_D(e)+"' has its layer constraint set to LAST, but has at least one outgoing edge that  does not go to a LAST_SEPARATE node. That must not happen."))}function eXt(e,t){var n,i,r,o,a;for(a=c(R(t,(Uo(),n8e)),430),o=_n(t.b,0);o.b!=o.d.c;)if(r=c(An(o),41),e.b[r.g]==0){switch(a.g){case 0:bYe(e,r);break;case 1:hUt(e,r)}e.b[r.g]=2}for(i=_n(e.a,0);i.b!=i.d.c;)n=c(An(i),65),uv(n.b.d,n,!0),uv(n.c.b,n,!0);Ee(t,(Li(),G9e),e.a)}function Uve(e){var t;return t=new t7,(e&256)!=0&&(t.a+="F"),(e&128)!=0&&(t.a+="H"),(e&512)!=0&&(t.a+="X"),(e&2)!=0&&(t.a+="i"),(e&8)!=0&&(t.a+="m"),(e&4)!=0&&(t.a+="s"),(e&32)!=0&&(t.a+="u"),(e&64)!=0&&(t.a+="w"),(e&16)!=0&&(t.a+="x"),(e&Ga)!=0&&(t.a+=","),Xde(t.a)}function tXt(e,t,n,i,r){var o,a,d,b;for(b=(o=c(Jf($s),10),new ha(o,c(gf(o,o.length),10),0)),d=new G(e.j);d.a<d.c.c.length;)a=c(Q(d),12),t[a.p]&&(Sen(a,t[a.p],i),yf(b,a.j));r?(_ne(e,t,(Je(),nn),2*n,i),_ne(e,t,Yt,2*n,i)):(_ne(e,t,(Je(),Kt),2*n,i),_ne(e,t,bn,2*n,i))}function nXt(e,t){var n,i,r,o,a,d,b;for(r=new Fe,n=0;n<=e.j;n++)i=new hc(t),i.p=e.j-n,It(r.c,i);for(d=new G(e.p);d.a<d.c.c.length;)a=c(Q(d),9),zr(a,c(Xe(r,e.j-e.g[a.p]),26));for(o=new G(r);o.a<o.c.c.length;)b=c(Q(o),26),b.a.c.length==0&&z7(o);t.b.c.length=0,yr(t.b,r)}function iXt(e,t,n){var i,r,o,a,d,b;for(i=c(Si(e.c,t),16),r=c(Si(e.c,n),16),o=i.dd(i.gc()),a=r.dd(r.gc());o.Sb()&&a.Sb();)if(d=c(o.Ub(),15),b=c(a.Ub(),15),d!=b)return fc(d.a,b.a);return!o.Ob()&&!a.Ob()?t.p<n.p?-1:t.p>n.p?1:0:o.Ob()?1:-1}function rXt(e,t){var n,i,r,o,a,d;t.Tg(qct,1),r=c(ke(e,(Ah(),yC)),100),o=(!e.a&&(e.a=new Me(Mn,e,10,11)),e.a),a=vFt(o),d=p.Math.max(a.a,ue(he(ke(e,(Gd(),vC))))-(r.b+r.c)),i=p.Math.max(a.b,ue(he(ke(e,_J)))-(r.d+r.a)),n=i-a.b,ii(e,wC,n),ii(e,Ck,d),ii(e,J9,i+n),t.Ug()}function $T(e){var t,n;if((!e.a&&(e.a=new Me(Hi,e,6,6)),e.a).i==0)return Cme(e);for(t=c(re((!e.a&&(e.a=new Me(Hi,e,6,6)),e.a),0),171),En((!t.a&&(t.a=new Ar(Yu,t,5)),t.a)),Vm(t,0),Wm(t,0),Jm(t,0),Xm(t,0),n=(!e.a&&(e.a=new Me(Hi,e,6,6)),e.a);n.i>1;)vv(n,n.i-1);return t}function nl(e,t){qs();var n,i,r,o;return t?t==(Ci(),vvt)||(t==cvt||t==Gb||t==ovt)&&e!=GTe?new Qye(e,t):(i=c(t,689),n=i.Yk(),n||(Q6(uo((Dl(),ps),t)),n=i.Yk()),o=(!n.i&&(n.i=new wn),n.i),r=c(Ao(co(o.f,e)),2020),!r&&oi(o,e,r=new Qye(e,t)),r):ivt}function sXt(e,t){var n,i;if(i=L_(e.b,t.b),!i)throw J(new oo("Invalid hitboxes for scanline constraint calculation."));(DVe(t.b,c(s8t(e.b,t.b),60))||DVe(t.b,c(r8t(e.b,t.b),60)))&&Og(),e.a[t.b.f]=c(aY(e.b,t.b),60),n=c(uY(e.b,t.b),60),n&&(e.a[n.f]=t.b)}function oXt(e,t){var n,i,r,o,a,d,b,v,x;for(b=c(R(e,(De(),Oi)),12),v=Lo(W(V(Vr,1),Be,8,0,[b.i.n,b.n,b.a])).a,x=e.i.n.b,n=rd(e.e),r=n,o=0,a=r.length;o<a;++o)i=r[o],ss(i,b),Es(i.a,new $e(v,x)),t&&(d=c(R(i,(Ge(),ho)),79),d||(d=new nu,Ee(i,ho,d)),ei(d,new $e(v,x)))}function cXt(e,t){var n,i,r,o,a,d,b,v,x;for(r=c(R(e,(De(),Oi)),12),v=Lo(W(V(Vr,1),Be,8,0,[r.i.n,r.n,r.a])).a,x=e.i.n.b,n=rd(e.g),a=n,d=0,b=a.length;d<b;++d)o=a[d],ks(o,r),ax(o.a,new $e(v,x)),t&&(i=c(R(o,(Ge(),ho)),79),i||(i=new nu,Ee(o,ho,i)),ei(i,new $e(v,x)))}function lXt(e){var t,n,i,r,o,a,d,b,v;if(i=e.b,o=i.e,a=d5(c(R(i,(Ge(),cr)),103)),n=!!o&&c(R(o,(De(),Lc)),24).Gc((Gs(),Ea)),!(a||n))for(v=(d=new x1(e.e).a.vc().Jc(),new C2(d));v.a.Ob();)b=(t=c(v.a.Pb(),45),c(t.kd(),114)),b.a&&(r=b.d,_o(r,null),b.c=!0,e.a=!0)}function uXt(e,t){var n,i,r,o;for(t.Tg("Semi-Interactive Crossing Minimization Processor",1),n=!1,r=new G(e.b);r.a<r.c.c.length;)i=c(Q(r),26),o=OD(Yq(pi(pi(new jt(null,new Tt(i.a,16)),new JM),new OW),new o4),new XM),n=n|o.a!=null;n&&Ee(e,(De(),w6e),(Bt(),!0)),t.Ug()}function aXt(e,t){var n,i,r,o,a,d;for(e.b=new Fe,e.d=c(R(t,(De(),kk)),237),e.e=m_t(e.d),o=new Ai,r=mf(W(V(Bht,1),$ot,37,0,[t])),a=0;a<r.c.length;)i=(ht(a,r.c.length),c(r.c[a],37)),i.p=a++,n=new $rt(i,e.a,e.b),yr(r,n.b),qe(e.b,n),n.s&&(d=_n(o,0),oq(d,n));return e.c=new Or,o}function fXt(e,t){var n,i,r,o,a,d;for(a=c(c(Si(e.r,t),24),85).Jc();a.Ob();)o=c(a.Pb(),116),n=o.c?P0e(o.c):0,n>0?o.a?(d=o.b.Kf().a,n>d&&(r=(n-d)/2,o.d.b=r,o.d.c=r)):o.d.c=e.s+n:$7(e.u)&&(i=I2e(o.b),i.c<0&&(o.d.b=-i.c),i.c+i.b>o.b.Kf().a&&(o.d.c=i.c+i.b-o.b.Kf().a))}function hXt(e,t){var n,i,r,o,a;a=new Fe,n=t;do o=c(Ut(e.b,n),134),o.B=n.c,o.D=n.d,It(a.c,o),n=c(Ut(e.k,n),17);while(n);return i=(ht(0,a.c.length),c(a.c[0],134)),i.j=!0,i.A=c(i.d.a.ec().Jc().Pb(),17).c.i,r=c(Xe(a,a.c.length-1),134),r.q=!0,r.C=c(r.d.a.ec().Jc().Pb(),17).d.i,a}function dXt(e){var t,n;n=c(R(e,(Ge(),Ro)),166),t=c(R(e,(De(),Nb)),316),n==(Tu(),V1)?(Ee(e,Ro,rP),Ee(e,Nb,(D1(),a3))):n==Db?(Ee(e,Ro,rP),Ee(e,Nb,(D1(),bk))):t==(D1(),a3)?(Ee(e,Ro,V1),Ee(e,Nb,eP)):t==bk&&(Ee(e,Ro,Db),Ee(e,Nb,eP))}function jQ(){jQ=te,pP=new $O,Spt=Wn(new wr,(es(),vc),(cs(),gU)),Ept=Fc(Wn(new wr,vc,kU),Vs,xU),Cpt=cd(cd(u7(Fc(Wn(new wr,Cf,TU),Vs,jU),yc),SU),EU),jpt=Fc(Wn(Wn(Wn(new wr,Zd,bU),yc,wU),yc,T9),Vs,mU),Tpt=Fc(Wn(Wn(new wr,yc,T9),yc,dU),Vs,hU)}function BT(){BT=te,Npt=Wn(Fc(new wr,(es(),Vs),(cs(),dOe)),vc,gU),Ppt=cd(cd(u7(Fc(Wn(new wr,Cf,TU),Vs,jU),yc),SU),EU),_pt=Fc(Wn(Wn(Wn(new wr,Zd,bU),yc,wU),yc,T9),Vs,mU),Lpt=Wn(Wn(new wr,vc,kU),Vs,xU),Dpt=Fc(Wn(Wn(new wr,yc,T9),yc,dU),Vs,hU)}function gXt(e,t,n,i,r){var o,a;(!vs(t)&&t.c.i.c==t.d.i.c||!HXe(Lo(W(V(Vr,1),Be,8,0,[r.i.n,r.n,r.a])),n))&&!vs(t)&&(t.c==r?M6(t.a,0,new Cs(n)):ei(t.a,new Cs(n)),i&&!$a(e.a,n)&&(a=c(R(t,(Ge(),ho)),79),a||(a=new nu,Ee(t,ho,a)),o=new Cs(n),tr(a,o,a.c.b,a.c),Sr(e.a,o)))}function pnt(e,t){var n,i,r,o;for(o=Hn(Ss(Xd,zd(Hn(Ss(t==null?0:Ri(t),Vd)),15))),n=o&e.b.length-1,r=null,i=e.b[n];i;r=i,i=i.a)if(i.d==o&&T1(i.i,t))return r?r.a=i.a:e.b[n]=i.a,dPe(c(za(i.c),600),c(za(i.f),600)),QN(c(za(i.b),229),c(za(i.e),229)),--e.f,++e.e,!0;return!1}function pXt(e){var t,n;for(n=new Ht(Vt(pr(e).a.Jc(),new U));hn(n);)if(t=c(sn(n),17),t.c.i.k!=(Jt(),lc))throw J(new Wh(Cre+_D(e)+"' has its layer constraint set to FIRST, but has at least one incoming edge that  does not come from a FIRST_SEPARATE node. That must not happen."))}function bnt(e,t){var n,i,r,o,a,d,b,v,x,S,M;r=t?new oA:new cA,o=!1;do for(o=!1,v=t?Eu(e.b):e.b,b=v.Jc();b.Ob();)for(d=c(b.Pb(),26),M=tb(d.a),t||Eu(M),S=new G(M);S.a<S.c.c.length;)x=c(Q(S),9),r.Mb(x)&&(i=x,n=c(R(x,(De(),Cw)),318),a=t?n.b:n.k,o=qnt(i,a,t,!1));while(o)}function bXt(e,t,n){var i,r,o,a,d,b,v;if(r=VWe(e.Db&254),r==0)e.Eb=n;else{if(r==1)d=ye(Br,Lt,1,2,5,1),o=kne(e,t),o==0?(d[0]=n,d[1]=e.Eb):(d[0]=e.Eb,d[1]=n);else for(d=ye(Br,Lt,1,r+1,5,1),a=N5(e.Eb),i=2,b=0,v=0;i<=128;i<<=1)i==t?d[v++]=n:(e.Db&i)!=0&&(d[v++]=a[b++]);e.Eb=d}e.Db|=t}function mnt(e,t,n,i,r,o){var a,d,b,v,x,S,M,L,P,z,H,X;for(x=i,t.j&&t.o?(L=c(Ut(e.f,t.A),60),z=L.d.c+L.d.b,--x):z=t.a.c+t.a.b,S=r,n.q&&n.o?(L=c(Ut(e.f,n.C),60),v=L.d.c,++S):v=n.a.c,H=v-z,b=p.Math.max(2,S-x),d=H/b,P=z+d,M=x;M<S;++M)a=c(o.Xb(M),134),X=a.a.b,a.a.c=P-X/2,P+=d}function Jve(e,t,n,i,r,o){var a,d,b,v,x,S;for(v=n.c.length,o&&(e.c=ye(Fn,ci,30,t.length,15,1)),a=r?0:t.length-1;r?a<t.length:a>=0;a+=r?1:-1){for(d=t[a],b=i==(Je(),nn)?r?Po(d,i):Eu(Po(d,i)):r?Eu(Po(d,i)):Po(d,i),o&&(e.c[d.p]=b.gc()),S=b.Jc();S.Ob();)x=c(S.Pb(),12),e.d[x.p]=v++;yr(n,b)}}function wnt(e,t,n){var i,r,o,a,d,b,v,x;for(o=ue(he(e.b.Jc().Pb())),v=ue(he(FIt(t.b))),i=S1(Ms(e.a),v-n),r=S1(Ms(t.a),n-o),x=ki(i,r),S1(x,1/(v-o)),this.a=x,this.b=new Fe,d=!0,a=e.b.Jc(),a.Pb();a.Ob();)b=ue(he(a.Pb())),d&&b-n>yse&&(this.b.Ec(n),d=!1),this.b.Ec(b);d&&this.b.Ec(n)}function mXt(e){var t,n,i,r;if(LVt(e,e.n),e.d.c.length>0){for(Zj(e.c);jve(e,c(Q(new G(e.e.a)),126))<e.e.a.c.length;){for(t=wFt(e),r=t.e.e-t.d.e-t.a,t.e.j&&(r=-r),i=new G(e.e.a);i.a<i.c.c.length;)n=c(Q(i),126),n.j&&(n.e+=r);Zj(e.c)}Zj(e.c),fve(e,c(Q(new G(e.e.a)),126)),Trt(e)}}function wXt(e,t,n){var i,r,o,a,d;for(n.Tg("Longest path to source layering",1),e.a=t,d=e.a.a,e.b=ye(Fn,ci,30,d.c.length,15,1),i=0,a=new G(d);a.a<a.c.c.length;)r=c(Q(a),9),r.p=i,e.b[i]=-1,++i;for(o=new G(d);o.a<o.c.c.length;)r=c(Q(o),9),Utt(e,r);d.c.length=0,e.a=null,e.b=null,n.Ug()}function vXt(e,t){L5();var n,i;if(n=Dee(rT(),t.Og()),n){if(i=n.j,oe(e,209))return SNt(c(e,19))?Cl(i,(Th(),fr))||Cl(i,Nt):Cl(i,(Th(),fr));if(oe(e,273))return Cl(i,(Th(),ch));if(oe(e,196))return Cl(i,(Th(),Yg));if(oe(e,363))return Cl(i,(Th(),K1))}return!0}function yXt(e,t,n){var i,r,o,a,d,b;if(r=n,o=r.Jk(),F1(e.e,o)){if(o.Qi()){for(i=c(e.g,123),a=0;a<e.i;++a)if(d=i[a],yi(d,r)&&a!=t)throw J(new qt(DL))}}else for(b=nl(e.e.Ah(),o),i=c(e.g,123),a=0;a<e.i;++a)if(d=i[a],b.$l(d.Jk())&&a!=t)throw J(new qt($L));return c(Dx(e,t,n),76)}function vnt(e,t){if(t instanceof Object)try{if(t.__java$exception=e,navigator.userAgent.toLowerCase().indexOf("msie")!=-1&&$doc.documentMode<9)return;var n=e;Object.defineProperties(t,{cause:{get:function(){var i=n.fe();return i&&i.de()}},suppressed:{get:function(){return n.ee()}}})}catch{}}function ynt(e,t){var n,i,r,o,a;if(i=t>>5,t&=31,i>=e.d)return e.e<0?(ld(),Fat):(ld(),ME);if(o=e.d-i,r=ye(Fn,ci,30,o+1,15,1),mQt(r,o,e.a,i,t),e.e<0){for(n=0;n<i&&e.a[n]==0;n++);if(n<i||t>0&&e.a[n]<<32-t!=0){for(n=0;n<o&&r[n]==-1;n++)r[n]=0;n==o&&++o,++r[n]}}return a=new Wp(e.e,o,r),V7(a),a}function xXt(e,t,n,i){var r,o,a,d,b;return d=to(c(re((!t.b&&(t.b=new Et(vn,t,4,7)),t.b),0),83)),b=to(c(re((!t.c&&(t.c=new Et(vn,t,5,8)),t.c),0),83)),Xi(d)==Xi(b)||nv(b,d)?null:(a=V2(t),a==n?i:(o=c(Ut(e.a,a),9),o&&(r=o.e,r)?r:null))}function kXt(e,t){var n;switch(n=c(R(e,(Ge(),eJ)),286),t.Tg("Label side selection ("+n+")",1),n.g){case 0:Ctt(e,(qu(),n1));break;case 1:Ctt(e,(qu(),up));break;case 2:ert(e,(qu(),n1));break;case 3:ert(e,(qu(),up));break;case 4:Cnt(e,(qu(),n1));break;case 5:Cnt(e,(qu(),up))}t.Ug()}function F1(e,t){qs();var n,i,r;return t.Hk()?!0:t.Gk()==-2?t==(U5(),zk)||t==Bk||t==Aae||t==Nae?!0:(r=e.Ah(),Vi(r,t)>=0?!1:(n=qx((Dl(),ps),r,t),n?(i=n.Gk(),(i>1||i==-1)&&zm(uo(ps,n))!=3):!0)):!1}function OXt(e,t,n,i){var r,o,a,d,b,v,x,S,M,L;if(b=e.c.d,v=e.d.d,b.j!=v.j)for(L=e.b,x=null,d=null,a=ABt(e),a&&L.i&&(x=e.b.i.i,d=L.i.j),r=b.j,S=null;r!=v.j;)S=t==0?AH(r):fwe(r),o=Hwe(r,L.d[r.g],n),M=Hwe(S,L.d[S.g],n),a&&x&&d&&(r==x?iKe(o,x,d):S==x&&iKe(M,x,d)),ei(i,ki(o,M)),r=S}function Xve(e,t,n){var i,r,o,a,d,b;if(i=G9t(n,e.length),a=e[i],o=wPe(n,a.length),a[o].k==(Jt(),Cr))for(b=t.j,r=0;r<b.c.length;r++)d=(ht(r,b.c.length),c(b.c[r],12)),(n?d.j==(Je(),nn):d.j==(Je(),Yt))&&et(Ze(R(d,(De(),nP))))&&(Su(b,r,c(R(a[o],(De(),Oi)),12)),o+=n?1:-1)}function SXt(e,t){var n,i,r,o,a,d,b,v;t.Tg("Greedy Width Approximator",1),n=ue(he(ke(e,(Ah(),LJ)))),b=c(ke(e,yC),100),o=c(ke(e,W8e),388),a=et(Ze(ke(e,V8e))),d=ue(he(ke(e,xC))),v=(!e.a&&(e.a=new Me(Mn,e,10,11)),e.a),gme(v),r=new Qze(n,o,a),i=_Vt(r,v,d,b),ii(e,(Gd(),Yv),i.c),t.Ug()}function xnt(e){if(e.g==null)switch(e.p){case 0:e.g=jNt(e)?(Bt(),k9):(Bt(),K0);break;case 1:e.g=iD(yDt(e));break;case 2:e.g=dD(d_t(e));break;case 3:e.g=WMt(e);break;case 4:e.g=new Fs(KMt(e));break;case 6:e.g=fv(eAt(e));break;case 5:e.g=Pe(aNt(e));break;case 7:e.g=pS(ODt(e))}return e.g}function Vve(e){if(e.n==null)switch(e.p){case 0:e.n=TNt(e)?(Bt(),k9):(Bt(),K0);break;case 1:e.n=iD(xDt(e));break;case 2:e.n=dD(g_t(e));break;case 3:e.n=ZMt(e);break;case 4:e.n=new Fs(YMt(e));break;case 6:e.n=fv(tAt(e));break;case 5:e.n=Pe(fNt(e));break;case 7:e.n=pS(kDt(e))}return e.n}function knt(e,t,n,i){var r,o,a,d,b;if(d=(qs(),c(t,69).vk()),F1(e.e,t)){if(t.Qi()&&NQ(e,t,i,oe(t,104)&&(c(t,20).Bb&Is)!=0))throw J(new qt(DL))}else for(b=nl(e.e.Ah(),t),r=c(e.g,123),a=0;a<e.i;++a)if(o=r[a],b.$l(o.Jk()))throw J(new qt($L));wT(e,K2e(e,t,n),d?c(i,76):Fd(t,i))}function Ont(e){var t,n,i,r,o,a,d;for(o=new G(e.a.a);o.a<o.c.c.length;)i=c(Q(o),321),i.g=0,i.i=0,i.e.a.$b();for(r=new G(e.a.a);r.a<r.c.c.length;)for(i=c(Q(r),321),n=i.a.a.ec().Jc();n.Ob();)for(t=c(n.Pb(),60),d=t.c.Jc();d.Ob();)a=c(d.Pb(),60),a.a!=i&&(Sr(i.e,a),++a.a.g,++a.a.i)}function jXt(e){var t,n,i,r,o;r=c(R(e,(Ge(),Pb)),24),o=c(R(e,cJ),24),n=new $e(e.f.a+e.d.b+e.d.c,e.f.b+e.d.d+e.d.a),t=new Cs(n),r.Gc((Cu(),cy))&&(i=c(R(e,$9),8),o.Gc((uu(),s8))&&(i.a<=0&&(i.a=20),i.b<=0&&(i.b=20)),t.a=p.Math.max(n.a,i.a),t.b=p.Math.max(n.b,i.b)),TKt(e,n,t)}function TXt(e,t){var n,i,r;t.a?(L_(e.b,t.b),e.a[t.b.i]=c(aY(e.b,t.b),84),n=c(uY(e.b,t.b),84),n&&(e.a[n.i]=t.b)):(i=c(aY(e.b,t.b),84),i&&i==e.a[t.b.i]&&i.d&&i.d!=t.b.d&&i.f.Ec(t.b),r=c(uY(e.b,t.b),84),r&&e.a[r.i]==t.b&&r.d&&r.d!=t.b.d&&t.b.f.Ec(r),rZ(e.b,t.b))}function tie(e,t){var n,i,r,o,a,d;return o=e.d,d=ue(he(R(e,(Ge(),Xg)))),d<0&&(d=0,Ee(e,Xg,d)),t.o.b=d,a=p.Math.floor(d/2),i=new bc,$r(i,(Je(),Yt)),_o(i,t),i.n.b=a,r=new bc,$r(r,nn),_o(r,t),r.n.b=a,ss(e,i),n=new qm,ec(n,e),Ee(n,ho,null),ks(n,r),ss(n,o),RWt(t,e,n),QQt(e,n),n}function EXt(e){var t,n;return n=c(R(e,(De(),Lc)),24),t=new wr,n.Gc((Gs(),zE))&&(Fu(t,ypt),Fu(t,E9e)),(n.Gc(P9)||et(Ze(R(e,(Ge(),lle)))))&&(Fu(t,E9e),n.Gc(u3)&&Fu(t,kpt)),n.Gc(Ea)&&Fu(t,vpt),n.Gc(FE)&&Fu(t,Opt),n.Gc(zU)&&Fu(t,xpt),n.Gc(D9)&&Fu(t,mpt),n.Gc(L9)&&Fu(t,wpt),t}function CXt(e,t){var n,i,r,o,a,d,b,v,x,S,M;return i=e.d,o=t.d,d=i+o,b=e.e!=t.e?-1:1,d==2?(x=Ss(Yr(e.a[0],Us),Yr(t.a[0],Us)),M=Hn(x),S=Hn(Vp(x,32)),S==0?new A1(b,M):new Wp(b,2,W(V(Fn,1),ci,30,15,[M,S]))):(n=e.a,r=t.a,a=ye(Fn,ci,30,d,15,1),WRt(n,i,r,o,a),v=new Wp(b,d,a),V7(v),v)}function Snt(e,t,n,i){var r,o;if(t){if(r=e.a.Le(n.d,t.d),r==0)return i.d=Yge(t,n.e),i.b=!0,t;o=r<0?0:1,t.a[o]=Snt(e,t.a[o],n,i),A2(t.a[o])&&(A2(t.a[1-o])?(t.b=!0,t.a[0].b=!1,t.a[1].b=!1):A2(t.a[o].a[o])?t=fH(t,1-o):A2(t.a[o].a[1-o])&&(t=BQe(t,1-o)))}else return n;return t}function jnt(e,t,n){var i,r,o,a;r=e.i,i=e.n,pbe(e,(Yf(),Vo),r.c+i.b,n),pbe(e,Wo,r.c+r.b-i.c-n[2],n),a=r.b-i.b-i.c,n[0]>0&&(n[0]+=e.d,a-=n[0]),n[2]>0&&(n[2]+=e.d,a-=n[2]),o=p.Math.max(0,a),n[1]=p.Math.max(n[1],a),pbe(e,Vc,r.c+i.b+n[0]-(n[1]-a)/2,n),t==Vc&&(e.c.b=o,e.c.c=r.c+i.b+(o-a)/2)}function Tnt(){this.c=ye(ns,no,30,(Je(),W(V($s,1),cc,64,0,[$o,Kt,nn,bn,Yt])).length,15,1),this.b=ye(ns,no,30,W(V($s,1),cc,64,0,[$o,Kt,nn,bn,Yt]).length,15,1),this.a=ye(ns,no,30,W(V($s,1),cc,64,0,[$o,Kt,nn,bn,Yt]).length,15,1),S1e(this.c,nr),S1e(this.b,Qr),S1e(this.a,Qr)}function MXt(e,t,n,i){var r,o,a,d,b;for(b=t.i,d=n[b.g][e.d[b.g]],r=!1,a=new G(t.d);a.a<a.c.c.length;)if(o=c(Q(a),70),et(Ze(R(o,(Ge(),b3))))){r=!0;break}switch(r&&(i=0),b.g){case 1:d-=i+t.j.b,t.g.b=d;break;case 3:d+=i,t.g.b=d;break;case 4:d-=i+t.j.a,t.g.a=d;break;case 2:d+=i,t.g.a=d}}function Ac(e,t,n){var i,r,o,a;if(t<=n?(r=t,o=n):(r=n,o=t),i=0,e.b==null)e.b=ye(Fn,ci,30,2,15,1),e.b[0]=r,e.b[1]=o,e.c=!0;else{if(i=e.b.length,e.b[i-1]+1==r){e.b[i-1]=o;return}a=ye(Fn,ci,30,i+2,15,1),mc(e.b,0,a,0,i),e.b=a,e.b[i-1]>=r&&(e.c=!1,e.a=!1),e.b[i++]=r,e.b[i]=o,e.c||$x(e)}}function AXt(e,t,n){var i,r,o,a,d,b,v;for(v=t.d,e.a=new Hc(v.c.length),e.c=new wn,d=new G(v);d.a<d.c.c.length;)a=c(Q(d),108),o=new gD(null),qe(e.a,o),oi(e.c,a,o);for(e.b=new wn,UQt(e,t),i=0;i<v.c.length-1;i++)for(b=c(Xe(t.d,i),108),r=i+1;r<v.c.length;r++)kJt(e,b,c(Xe(t.d,r),108),n)}function NXt(e,t){var n,i,r,o,a,d,b;for(n=Qr,d=(Jt(),or),r=new G(t.a);r.a<r.c.c.length;)i=c(Q(r),9),o=i.k,o!=or&&(a=he(R(i,(De(),y6e))),a==null?(n=p.Math.max(n,0),i.n.b=n+Nge(e.a,o,d)):i.n.b=(zt(a),a)),b=Nge(e.a,o,d),i.n.b<n+b+i.d.d&&(i.n.b=n+b+i.d.d),n=i.n.b+i.o.b+i.d.a,d=o}function wv(e){var t,n,i,r,o;for(r=new Fe,t=new q2((!e.a&&(e.a=new Me(Mn,e,10,11)),e.a)),i=new Ht(Vt(z1(e).a.Jc(),new U));hn(i);)n=c(sn(i),74),oe(re((!n.b&&(n.b=new Et(vn,n,4,7)),n.b),0),196)||(o=to(c(re((!n.c&&(n.c=new Et(vn,n,5,8)),n.c),0),83)),t.a._b(o)||It(r.c,o));return r}function _Xt(e,t,n){var i,r,o;if(e.e=n,e.d=0,e.b=0,e.f=1,e.i=t,(e.e&16)==16&&(e.i=BVt(e.i)),e.j=e.i.length,bi(e),o=nw(e),e.d!=e.j)throw J(new Qn(Vn((Bn(),Vlt))));if(e.g){for(i=0;i<e.g.a.c.length;i++)if(r=c(Bm(e.g,i),587),e.f<=r.a)throw J(new Qn(Vn((Bn(),Wlt))));e.g.a.c.length=0}return o}function DXt(e,t){var n,i,r,o,a,d,b;for(t.Tg("Comment post-processing",1),o=new G(e.b);o.a<o.c.c.length;){for(r=c(Q(o),26),i=new Fe,d=new G(r.a);d.a<d.c.c.length;)a=c(Q(d),9),b=c(R(a,(De(),Sk)),16),n=c(R(a,mk),16),(b||n)&&(KZt(a,b,n),b&&yr(i,b),n&&yr(i,n));yr(r.a,i)}t.Ug()}function Ent(e,t,n,i,r){var o,a,d,b,v,x;if(e.d&&e.d.Fg(r),o=c(r.Xb(0),19),pYe(e,n,o,!1)||(a=c(r.Xb(r.gc()-1),19),pYe(e,i,a,!0))||q2e(e,r))return!0;for(x=r.Jc();x.Ob();)for(v=c(x.Pb(),19),b=t.Jc();b.Ob();)if(d=c(b.Pb(),19),TQ(e,v,d))return!0;return!1}function LXt(e,t,n){var i,r,o,a,d,b,v,x,S,M;M=t.c.length,S=(v=e.Fh(n),c(v>=0?e.Ih(v,!1,!0):ow(e,n,!1),61));e:for(o=S.Jc();o.Ob();){for(r=c(o.Pb(),57),x=0;x<M;++x)if(a=(ht(x,t.c.length),c(t.c[x],76)),b=a.kd(),d=a.Jk(),i=r.Kh(d,!1),b==null?i!=null:!yi(b,i))continue e;return r}return null}function PXt(e,t,n,i){var r,o,a,d;for(r=c(Bg(t,(Je(),Yt)).Jc().Pb(),12),o=c(Bg(t,nn).Jc().Pb(),12),d=new G(e.j);d.a<d.c.c.length;){for(a=c(Q(d),12);a.e.c.length!=0;)ss(c(Xe(a.e,0),17),r);for(;a.g.c.length!=0;)ks(c(Xe(a.g,0),17),o)}n||Ee(t,(De(),sh),null),i||Ee(t,(De(),Wa),null)}function Cnt(e,t){var n,i,r,o,a,d,b;for(n=new bx,o=new G(e.b);o.a<o.c.c.length;){for(r=c(Q(o),26),b=!0,i=0,d=new G(r.a);d.a<d.c.c.length;)switch(a=c(Q(d),9),a.k.g){case 4:++i;case 1:Zpe(n,a);break;case 0:HQt(a,t);default:n.b==n.c||vit(n,i,b,!1,t),b=!1,i=0}n.b==n.c||vit(n,i,b,!0,t)}}function IXt(e){var t,n,i,r,o,a,d,b,v;for(e.a=new n0e,v=0,r=0,i=new G(e.i.b);i.a<i.c.c.length;){for(t=c(Q(i),26),t.p=r,b=new G(t.a);b.a<b.c.c.length;)d=c(Q(b),9),d.p=v,++v;++r}for(o=e.r==(H0(),H9),a=o?Yht:Kht,n=new G(e.i.b);n.a<n.c.c.length;)t=c(Q(n),26),Rr(t.a,a),pPt(e.a,Pe(t.p),t.a)}function Wve(e,t){var n,i,r,o,a,d;for(n=0,d=new G(t);d.a<d.c.c.length;){for(a=c(Q(d),12),Ume(e.b,e.d[a.p]),r=new kh(a.b);No(r.a)||No(r.b);)i=c(No(r.a)?Q(r.a):Q(r.b),17),o=c1e(e,a==i.c?i.d:i.c),o>e.d[a.p]&&(n+=cbe(e.b,o),C0(e.a,Pe(o)));for(;!e7(e.a);)Fbe(e.b,c(w5(e.a),15).a)}return n}function Mnt(e,t,n){var i,r,o,a;for(o=(!t.a&&(t.a=new Me(Mn,t,10,11)),t.a).i,r=new cn((!t.a&&(t.a=new Me(Mn,t,10,11)),t.a));r.e!=r.i.gc();)i=c(un(r),19),(!i.a&&(i.a=new Me(Mn,i,10,11)),i.a).i==0||(o+=Mnt(e,i,!1));if(n)for(a=Xi(t);a;)o+=(!a.a&&(a.a=new Me(Mn,a,10,11)),a.a).i,a=Xi(a);return o}function vv(e,t){var n,i,r,o;return e.Nj()?(i=null,r=e.Oj(),e.Rj()&&(i=e.Tj(e.Yi(t),null)),n=e.Gj(4,o=F5(e,t),null,t,r),e.Kj()&&o!=null&&(i=e.Mj(o,i)),i?(i.lj(n),i.mj()):e.Hj(n),o):(o=F5(e,t),e.Kj()&&o!=null&&(i=e.Mj(o,null),i&&i.mj()),o)}function RXt(e){var t,n,i,r,o,a,d,b,v,x;for(v=e.a,t=new Or,b=0,i=new G(e.d);i.a<i.c.c.length;){for(n=c(Q(i),228),x=0,cb(n.b,new im),a=_n(n.b,0);a.b!=a.d.c;)o=c(An(a),228),t.a._b(o)&&(r=n.c,d=o.c,x<d.d+d.a+v&&x+r.a+v>d.d&&(x=d.d+d.a+v));n.c.d=x,t.a.yc(n,t),b=p.Math.max(b,n.c.d+n.c.a)}return b}function $Xt(e,t,n){var i,r,o,a,d,b;for(a=c(R(e,(De(),Qce)),16).Jc();a.Ob();){switch(o=c(a.Pb(),9),c(R(o,(Ge(),Ro)),166).g){case 2:zr(o,t);break;case 4:zr(o,n)}for(r=new Ht(Vt(sd(o).a.Jc(),new U));hn(r);)i=c(sn(r),17),!(i.c&&i.d)&&(d=!i.d,b=c(R(i,k6e),12),d?ss(i,b):ks(i,b))}}function Gs(){Gs=te,BU=new _2("COMMENTS",0),Ea=new _2("EXTERNAL_PORTS",1),zE=new _2("HYPEREDGES",2),zU=new _2("HYPERNODES",3),P9=new _2("NON_FREE_PORTS",4),u3=new _2("NORTH_SOUTH_PORTS",5),FE=new _2(rct,6),D9=new _2("CENTER_LABELS",7),L9=new _2("END_LABELS",8),FU=new _2("PARTITIONS",9)}function BXt(e,t,n,i,r){return i<0?(i=Rx(e,r,W(V(nt,1),Be,2,6,[Qie,Gie,Uie,Jie,Z5,Xie,Vie,Wie,Kie,Yie,Zie,ere]),t),i<0&&(i=Rx(e,r,W(V(nt,1),Be,2,6,["Jan","Feb","Mar","Apr",Z5,"Jun","Jul","Aug","Sep","Oct","Nov","Dec"]),t)),i<0?!1:(n.k=i,!0)):i>0?(n.k=i-1,!0):!1}function zXt(e,t,n,i,r){return i<0?(i=Rx(e,r,W(V(nt,1),Be,2,6,[Qie,Gie,Uie,Jie,Z5,Xie,Vie,Wie,Kie,Yie,Zie,ere]),t),i<0&&(i=Rx(e,r,W(V(nt,1),Be,2,6,["Jan","Feb","Mar","Apr",Z5,"Jun","Jul","Aug","Sep","Oct","Nov","Dec"]),t)),i<0?!1:(n.k=i,!0)):i>0?(n.k=i-1,!0):!1}function FXt(e,t,n,i,r,o){var a,d,b,v;if(d=32,i<0){if(t[0]>=e.length||(d=ms(e,t[0]),d!=43&&d!=45)||(++t[0],i=gQ(e,t),i<0))return!1;d==45&&(i=-i)}return d==32&&t[0]-n==2&&r.b==2&&(b=new _z,v=b.q.getFullYear()-G0+G0-80,a=v%100,o.a=i==a,i+=(v/100|0)*100+(i<a?100:0)),o.p=i,!0}function Ant(e,t){var n,i,r,o,a;Xi(e)&&(a=c(R(t,(Ge(),Pb)),185),ve(ke(e,cr))===ve((Zr(),fp))&&ii(e,cr,Hh),i=(v0(),new wg(Xi(e))),o=new EF(Xi(e)?new wg(Xi(e)):null,e),r=Hye(i,o,!1,!0),yf(a,(Cu(),cy)),n=c(R(t,$9),8),n.a=p.Math.max(r.a,n.a),n.b=p.Math.max(r.b,n.b))}function qXt(e){var t,n,i,r,o,a;for(o=new Or,t=new q2((!e.a&&(e.a=new Me(Mn,e,10,11)),e.a)),r=new Ht(Vt(z1(e).a.Jc(),new U));hn(r);)i=c(sn(r),74),oe(re((!i.b&&(i.b=new Et(vn,i,4,7)),i.b),0),196)||(a=to(c(re((!i.c&&(i.c=new Et(vn,i,5,8)),i.c),0),83)),t.a._b(a)||(n=o.a.yc(a,o),n==null));return o}function LS(){LS=te,zje=W(V(qw,1),tot,30,14,[1,1,2,6,24,120,720,5040,40320,362880,3628800,39916800,479001600,6227020800,87178291200,1307674368e3,{l:3506176,m:794077,h:1},{l:884736,m:916411,h:20},{l:3342336,m:3912489,h:363},{l:589824,m:3034138,h:6914},{l:3407872,m:1962506,h:138294}]),p.Math.pow(2,-65)}function PS(){PS=te;var e,t;for(fk=ye(t3,Be,92,32,0,1),AE=ye(t3,Be,92,32,0,1),e=1,t=0;t<=18;t++)fk[t]=(ld(),Mc(e,0)>=0?$0(e):F7($0(Ng(e)))),AE[t]=gF($d(e,t),0)?$0($d(e,t)):F7($0(Ng($d(e,t)))),e=Ss(e,5);for(;t<AE.length;t++)fk[t]=Ox(fk[t-1],fk[1]),AE[t]=Ox(AE[t-1],(ld(),Loe))}function Nnt(e,t){var n,i,r,o,a;if(e.c.length==0)return new Ps(Pe(0),Pe(0));for(n=(ht(0,e.c.length),c(e.c[0],12)).j,a=0,o=t.g,i=t.g+1;a<e.c.length-1&&n.g<o;)++a,n=(ht(a,e.c.length),c(e.c[a],12)).j;for(r=a;r<e.c.length-1&&n.g<i;)++r,n=(ht(a,e.c.length),c(e.c[a],12)).j;return new Ps(Pe(a),Pe(r))}function HXt(e,t,n,i){var r,o,a,d,b,v,x;b=Po(t,n),(n==(Je(),bn)||n==Yt)&&(b=Eu(b)),a=!1;do for(r=!1,o=0;o<b.gc()-1;o++)v=c(b.Xb(o),12),d=c(b.Xb(o+1),12),PHt(e,v,d,i)&&(a=!0,See(e.a,c(b.Xb(o),12),c(b.Xb(o+1),12)),x=c(b.Xb(o+1),12),b.fd(o+1,c(b.Xb(o),12)),b.fd(o,x),r=!0);while(r);return a}function QXt(e,t,n){var i,r,o,a;for(n.Tg(jct,1),r=c(ql(pi(new jt(null,new Tt(t.b,16)),new SA),su(new Ls,new rs,new mo,W(V(ml,1),_e,132,0,[(va(),bl)]))),16),ntt(e,r,0),a=_n(t.b,0);a.b!=a.d.c;)o=c(An(a),41),i=Ut(e.a,Pe(o.g))!=null?c(Ut(e.a,Pe(o.g)),15).a:0,Ee(o,(Uo(),xd),Pe(i));n.Ug()}function TQ(e,t,n){var i,r,o,a,d,b,v,x;return d=t.i-e.g/2,b=n.i-e.g/2,v=t.j-e.g/2,x=n.j-e.g/2,o=t.g+e.g,a=n.g+e.g,i=t.f+e.g,r=n.f+e.g,d<b+a&&b<d&&v<x+r&&x<v||b<d+o&&d<b&&x<v+i&&v<x||d<b+a&&b<d&&v<x&&x<v+i?!0:b<d+o&&d<b&&v<x+r&&x<v}function GXt(e,t,n){var i,r,o,a,d,b,v,x,S,M;for(o=t.c.length,a=(ht(n,t.c.length),c(t.c[n],295)),d=a.a.o.a,S=a.c,M=0,v=a.c;v<=a.f;v++){if(d<=e.a[v])return v;for(x=e.a[v],b=null,r=n+1;r<o;r++)i=(ht(r,t.c.length),c(t.c[r],295)),i.c<=v&&i.f>=v&&(b=i);b&&(x=p.Math.max(x,b.a.o.a)),x>M&&(S=v,M=x)}return S}function UXt(e){var t,n,i,r,o,a,d;for(o=new kg(c(Rn(new _y),50)),d=Qr,n=new G(e.d);n.a<n.c.c.length;){for(t=c(Q(n),228),d=t.c.c;o.a.gc()!=0&&(a=c(o.a.Rc(),228),a.c.c+a.c.b<d);)o.a.Ac(a)!=null;for(r=o.a.ec().Jc();r.Ob();)i=c(r.Pb(),228),ei(i.b,t),ei(t.b,i);o.a.yc(t,(Bt(),K0))==null}}function _nt(e,t,n){var i,r,o,a,d;if(!Y2(t)){for(d=n.dh((oe(t,18)?c(t,18).gc():Vf(t.Jc()))/e.a|0),d.Tg(Tct,1),a=new TA,o=null,r=t.Jc();r.Ob();)i=c(r.Pb(),41),a=ma(W(V(Ta,1),Lt,22,0,[a,new k1(i)])),o&&(Ee(o,(Li(),Fpt),i),Ee(i,Ule,o),$ee(i)==$ee(o)&&(Ee(o,Jle,i),Ee(i,OJ,o))),o=i;d.Ug(),_nt(e,a,n)}}function JXt(e,t){var n,i,r;if(t==null){for(i=(!e.a&&(e.a=new Me(tg,e,9,5)),new cn(e.a));i.e!=i.i.gc();)if(n=c(un(i),691),r=n.c,(r??n.zb)==null)return n}else for(i=(!e.a&&(e.a=new Me(tg,e,9,5)),new cn(e.a));i.e!=i.i.gc();)if(n=c(un(i),691),Ot(t,(r=n.c,r??n.zb)))return n;return null}function nie(e,t){var n;switch(n=null,t.g){case 1:e.e.nf((Dn(),rae))&&(n=c(e.e.mf(rae),260));break;case 3:e.e.nf((Dn(),sae))&&(n=c(e.e.mf(sae),260));break;case 2:e.e.nf((Dn(),iae))&&(n=c(e.e.mf(iae),260));break;case 4:e.e.nf((Dn(),oae))&&(n=c(e.e.mf(oae),260))}return!n&&(n=c(e.e.mf((Dn(),b7e)),260)),n}function Dnt(e,t,n){var i,r,o,a,d,b;for(r=n,o=0,d=new G(t);d.a<d.c.c.length;)a=c(Q(d),19),ii(a,(F0(),MJ),Pe(r++)),b=wv(a),i=p.Math.atan2(a.j+a.f/2,a.i+a.g/2),i+=i<0?Sb:0,i<.7853981633974483||i>Ict?Rr(b,e.b):i<=Ict&&i>Rct?Rr(b,e.d):i<=Rct&&i>$ct?Rr(b,e.c):i<=$ct&&Rr(b,e.a),o=Dnt(e,b,o);return r}function Lnt(e,t,n,i){var r,o,a,d,b,v;for(r=(i.c+i.a)/2,Ou(t.j),ei(t.j,r),Ou(n.e),ei(n.e,r),v=new bPe,d=new G(e.f);d.a<d.c.c.length;)o=c(Q(d),135),b=o.a,Ane(v,t,b),Ane(v,n,b);for(a=new G(e.k);a.a<a.c.c.length;)o=c(Q(a),135),b=o.b,Ane(v,t,b),Ane(v,n,b);return v.b+=2,v.a+=dHe(t,e.q),v.a+=dHe(e.q,n),v}function XXt(e,t,n){var i;n.Tg("Processor arrange node",1),et(Ze(R(t,(Uo(),W9e)))),i=c(vu(I1(pi(new jt(null,new Tt(t.b,16)),new UR))),41),e.a=c(R(t,s8e),354),e.a==(hT(),Kle)||e.a==TJ?Yrt(e,new Ho(W(V(kJ,1),xG,41,0,[i])),n.dh(1)):e.a==Wle&&jst(e,new Ho(W(V(kJ,1),xG,41,0,[i])),n.dh(1)),n.Ug()}function Pnt(e){var t,n,i,r,o,a,d;for(n=e.i,t=e.n,d=n.d,e.f==(hl(),Z0)?d+=(n.a-e.e.b)/2:e.f==Ef&&(d+=n.a-e.e.b),r=new G(e.d);r.a<r.c.c.length;){switch(i=c(Q(r),190),a=i.Kf(),o=new as,o.b=d,d+=a.b+e.a,e.b.g){case 0:o.a=n.c+t.b;break;case 1:o.a=n.c+t.b+(n.b-a.a)/2;break;case 2:o.a=n.c+n.b-t.c-a.a}i.Mf(o)}}function Int(e){var t,n,i,r,o,a,d;for(n=e.i,t=e.n,d=n.c,e.b==(Hl(),Y0)?d+=(n.b-e.e.a)/2:e.b==Tf&&(d+=n.b-e.e.a),r=new G(e.d);r.a<r.c.c.length;){switch(i=c(Q(r),190),a=i.Kf(),o=new as,o.a=d,d+=a.a+e.a,e.f.g){case 0:o.b=n.d+t.d;break;case 1:o.b=n.d+t.d+(n.a-a.b)/2;break;case 2:o.b=n.d+n.a-t.a-a.b}i.Mf(o)}}function VXt(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P;x=n.a.c,a=n.a.c+n.a.b,o=c(Ut(n.c,t),460),L=o.f,P=o.a,b=new $e(x,L),S=new $e(a,P),r=x,n.p||(r+=e.c),r+=n.F+n.v*e.b,v=new $e(r,L),M=new $e(r,P),sT(t.a,W(V(Vr,1),Be,8,0,[b,v])),d=n.d.a.gc()>1,d&&(i=new $e(r,n.b),ei(t.a,i)),sT(t.a,W(V(Vr,1),Be,8,0,[M,S]))}function Kve(e,t,n){var i,r;for(t<e.d.b.c.length?(e.b=c(Xe(e.d.b,t),26),e.a=c(Xe(e.d.b,t-1),26),e.c=t):(e.a=new hc(e.d),e.a.p=t-1,qe(e.d.b,e.a),e.b=new hc(e.d),e.b.p=t,qe(e.d.b,e.b),e.c=t),zr(n,e.b),r=new Ht(Vt(pr(n).a.Jc(),new U));hn(r);)i=c(sn(r),17),!i.c.i.c&&i.c.i.k==(Jt(),lc)&&zr(i.c.i,e.a)}function WXt(e,t){var n,i,r,o;for(o=Po(t,(Je(),bn)).Jc();o.Ob();)i=c(o.Pb(),12),n=c(R(i,(De(),Ul)),9),n&&Of(uf(ff(hf(af(new Ra,0),.1),e.i[t.p].d),e.i[n.p].a));for(r=Po(t,Kt).Jc();r.Ob();)i=c(r.Pb(),12),n=c(R(i,(De(),Ul)),9),n&&Of(uf(ff(hf(af(new Ra,0),.1),e.i[n.p].d),e.i[t.p].a))}function Rnt(e){Am(e,new mb(Em(Sm(Tm(jm(new b1,EG),"ELK Randomizer"),'Distributes the nodes randomly on the plane, leading to very obfuscating layouts. Can be useful to demonstrate the power of "real" layout algorithms.'),new UA))),Ie(e,EG,gw,W7e),Ie(e,EG,dw,15),Ie(e,EG,WQ,Pe(0)),Ie(e,EG,ZS,YS)}function Yve(){Yve=te;var e,t,n,i,r,o;for(VC=ye(Rl,Yx,30,255,15,1),gX=ye(Na,fd,30,16,15,1),t=0;t<255;t++)VC[t]=-1;for(n=57;n>=48;n--)VC[n]=n-48<<24>>24;for(i=70;i>=65;i--)VC[i]=i-65+10<<24>>24;for(r=102;r>=97;r--)VC[r]=r-97+10<<24>>24;for(o=0;o<10;o++)gX[o]=48+o&_r;for(e=10;e<=15;e++)gX[e]=65+e-10&_r}function $nt(e,t){t.Tg("Process graph bounds",1),Ee(e,(Li(),Qle),c_(pte(X2(new jt(null,new Tt(e.b,16)),new _W)))),Ee(e,Gle,c_(pte(X2(new jt(null,new Tt(e.b,16)),new pu)))),Ee(e,H9e,c_(gte(X2(new jt(null,new Tt(e.b,16)),new kA)))),Ee(e,Q9e,c_(gte(X2(new jt(null,new Tt(e.b,16)),new OA)))),t.Ug()}function KXt(e){var t,n,i,r,o;r=c(R(e,(Ge(),Pb)),24),o=c(R(e,cJ),24),n=new $e(e.f.a+e.d.b+e.d.c,e.f.b+e.d.d+e.d.a),t=new Cs(n),r.Gc((Cu(),cy))&&(i=c(R(e,$9),8),o.Gc((uu(),s8))&&(i.a<=0&&(i.a=20),i.b<=0&&(i.b=20)),t.a=p.Math.max(n.a,i.a),t.b=p.Math.max(n.b,i.b)),et(Ze(R(e,hle)))||jKt(e,n,t)}function YXt(e){var t,n,i,r,o,a,d;for(t=!1,n=0,r=new G(e.d.b);r.a<r.c.c.length;)for(i=c(Q(r),26),i.p=n++,a=new G(i.a);a.a<a.c.c.length;)o=c(Q(a),9),!t&&!Y2(sd(o))&&(t=!0);d=_i((Nr(),qh),W(V(_C,1),_e,87,0,[go,yo])),t||(yf(d,Ca),yf(d,Fh)),e.a=new VJe(d),sc(e.f),sc(e.b),sc(e.e),sc(e.g)}function iie(e){var t,n,i,r,o,a;if(!e.c){if(a=new zl,t=GC,o=t.a.yc(e,t),o==null){for(i=new cn(gc(e));i.e!=i.i.gc();)n=c(un(i),88),r=AQ(n),oe(r,89)&&ur(a,iie(c(r,29))),Nn(a,n);t.a.Ac(e)!=null,t.a.gc()==0}cBt(a),cv(a),e.c=new fx((c(re(Ne((j0(),Gt).o),15),20),a.i),a.g),ru(e).b&=-33}return e.c}function Zve(e){var t;if(e.c!=10)throw J(new Qn(Vn((Bn(),DG))));switch(t=e.a,t){case 110:t=10;break;case 114:t=13;break;case 116:t=9;break;case 92:case 124:case 46:case 94:case 45:case 63:case 42:case 43:case 123:case 125:case 40:case 41:case 91:case 93:break;default:throw J(new Qn(Vn((Bn(),ja))))}return t}function Bnt(e){var t,n,i,r,o;if(e.l==0&&e.m==0&&e.h==0)return"0";if(e.h==aL&&e.m==0&&e.l==0)return"-9223372036854775808";if(e.h>>19!=0)return"-"+Bnt(uS(e));for(n=e,i="";!(n.l==0&&n.m==0&&n.h==0);){if(r=Lee(QQ),n=Iye(n,r,!0),t=""+FPe(W0),!(n.l==0&&n.m==0&&n.h==0))for(o=9-t.length;o>0;o--)t="0"+t;i=t+i}return i}function ZXt(){if(!Object.create||!Object.getOwnPropertyNames)return!1;var e="__proto__",t=Object.create(null);if(t[e]!==void 0)return!1;var n=Object.getOwnPropertyNames(t);return!(n.length!=0||(t[e]=42,t[e]!==42)||Object.getOwnPropertyNames(t).length==0)}function eVt(e,t,n){var i,r,o,a,d,b,v,x,S;for(i=n.c,r=n.d,d=xh(t.c),b=xh(t.d),i==t.c?(d=Rve(e,d,r),b=LZe(t.d)):(d=LZe(t.c),b=Rve(e,b,r)),v=new Ez(t.a),tr(v,d,v.a,v.a.a),tr(v,b,v.c.b,v.c),a=t.c==i,S=new uLe,o=0;o<v.b-1;++o)x=new Ps(c(pc(v,o),8),c(pc(v,o+1),8)),a&&o==0||!a&&o==v.b-2?S.b=x:qe(S.a,x);return S}function tVt(e,t){var n,i,r,o;if(o=e.j.g-t.j.g,o!=0)return o;if(n=c(R(e,(Ge(),Vg)),15),i=c(R(t,Vg),15),n&&i&&(r=n.a-i.a,r!=0))return r;switch(e.j.g){case 1:return ji(e.n.a,t.n.a);case 2:return ji(e.n.b,t.n.b);case 3:return ji(t.n.a,e.n.a);case 4:return ji(t.n.b,e.n.b);default:throw J(new oo(Nxe))}}function eye(e,t,n,i){var r,o,a,d,b;if(Vf((C_(),new Ht(Vt(sd(t).a.Jc(),new U))))>=e.a||!_2e(t,n))return-1;if(Y2(c(i.Kb(t),22)))return 1;for(r=0,a=c(i.Kb(t),22).Jc();a.Ob();)if(o=c(a.Pb(),17),b=o.c.i==t?o.d.i:o.c.i,d=eye(e,b,n,i),d==-1||(r=p.Math.max(r,d),r>e.c-1))return-1;return r+1}function Ah(){Ah=te,LJ=new Gr((Dn(),K9),1.3),amt=new Gr(ny,(Bt(),!1)),U8e=new Qp(15),yC=new Gr(zh,U8e),xC=new Gr(lh,15),omt=CP,umt=qb,fmt=C3,hmt=lp,lmt=E3,vue=NC,dmt=iy,W8e=(vye(),imt),V8e=nmt,xue=smt,K8e=rmt,G8e=Zbt,yue=Ybt,Q8e=Kbt,X8e=tmt,q8e=AC,cmt=nae,xP=Xbt,F8e=Jbt,kP=Vbt,J8e=emt,H8e=Wbt}function znt(e,t){var n,i,r,o,a,d;if(ve(t)===ve(e))return!0;if(!oe(t,16)||(i=c(t,16),d=e.gc(),i.gc()!=d))return!1;if(a=i.Jc(),e.Wi()){for(n=0;n<d;++n)if(r=e.Ti(n),o=a.Pb(),r==null?o!=null:!yi(r,o))return!1}else for(n=0;n<d;++n)if(r=e.Ti(n),o=a.Pb(),ve(r)!==ve(o))return!1;return!0}function Fnt(e,t){var n,i,r,o,a,d;if(e.f>0){if(e.Zj(),t!=null){for(o=0;o<e.d.length;++o)if(n=e.d[o],n){for(i=c(n.g,375),d=n.i,a=0;a<d;++a)if(r=i[a],yi(t,r.kd()))return!0}}else for(o=0;o<e.d.length;++o)if(n=e.d[o],n){for(i=c(n.g,375),d=n.i,a=0;a<d;++a)if(r=i[a],ve(t)===ve(r.kd()))return!0}}return!1}function nVt(e,t){var n,i,r;return n=t.ni(e.a),n&&(r=zn(Zf((!n.b&&(n.b=new yu((Mt(),Bs),Yo,n)),n.b),"affiliation")),r!=null)?(i=SF(r,dl(35)),i==-1?zte(e,I7(e,Bu(t.ok())),r):i==0?zte(e,null,(en(1,r.length+1),r.substr(1))):zte(e,(fs(0,i,r.length),r.substr(0,i)),(en(i+1,r.length+1),r.substr(i+1)))):null}function EQ(){EQ=te,gce=new x5("NORTH",0,(Je(),Kt),Kt),mce=new x5("SOUTH",1,bn,bn),dce=new x5("EAST",2,nn,nn),yce=new x5("WEST",3,Yt,Yt),bce=new x5("NORTH_WEST_CORNER",4,Yt,Kt),pce=new x5("NORTH_EAST_CORNER",5,Kt,nn),vce=new x5("SOUTH_WEST_CORNER",6,bn,Yt),wce=new x5("SOUTH_EAST_CORNER",7,nn,bn)}function iVt(e,t,n){var i,r,o,a;n.Tg("Orthogonally routing hierarchical port edges",1),e.a=0,i=KKt(t),oZt(t,i),qYt(e,t,i),oen(t),r=c(R(t,(Ge(),cr)),103),o=t.b,Xrt((ht(0,o.c.length),c(o.c[0],26)),r,t),Xrt(c(Xe(o,o.c.length-1),26),r,t),a=t.b,irt((ht(0,a.c.length),c(a.c[0],26))),irt(c(Xe(a,a.c.length-1),26)),n.Ug()}function tye(e){switch(e){case 48:case 49:case 50:case 51:case 52:case 53:case 54:case 55:case 56:case 57:return e-48<<24>>24;case 97:case 98:case 99:case 100:case 101:case 102:return e-97+10<<24>>24;case 65:case 66:case 67:case 68:case 69:case 70:return e-65+10<<24>>24;default:throw J(new Yh("Invalid hexadecimal"))}}function qnt(e,t,n,i){var r,o,a,d,b,v;for(b=Mne(e,n),v=Mne(t,n),r=!1;b&&v&&(i||eFt(b,v,n));)a=Mne(b,n),d=Mne(v,n),eD(t),eD(e),o=b.c,Cie(b,!1),Cie(v,!1),n?(B0(t,v.p,o),t.p=v.p,B0(e,b.p+1,o),e.p=b.p):(B0(e,b.p,o),e.p=b.p,B0(t,v.p+1,o),t.p=v.p),zr(b,null),zr(v,null),b=a,v=d,r=!0;return r}function Hnt(e){switch(e.g){case 0:return new SN;case 1:return new IB;case 3:return new DIe;case 4:return new LO;case 5:return new aze;case 6:return new Pj;case 2:return new oK;case 7:return new kN;case 8:return new sK;default:throw J(new qt("No implementation is available for the layerer "+(e.f!=null?e.f:""+e.g)))}}function rVt(e,t,n,i){var r,o,a,d,b;for(r=!1,o=!1,d=new G(i.j);d.a<d.c.c.length;)a=c(Q(d),12),ve(R(a,(De(),Oi)))===ve(n)&&(a.g.c.length==0?a.e.c.length==0||(r=!0):o=!0);return b=0,r&&r^o?b=n.j==(Je(),Kt)?-e.e[i.c.p][i.p]:t-e.e[i.c.p][i.p]:o&&r^o?b=e.e[i.c.p][i.p]+1:r&&o&&(b=n.j==(Je(),Kt)?0:t/2),b}function rie(e,t,n,i,r,o,a,d){var b,v,x;for(b=0,t!=null&&(b^=Dg(t.toLowerCase())),n!=null&&(b^=Dg(n)),i!=null&&(b^=Dg(i)),a!=null&&(b^=Dg(a)),d!=null&&(b^=Dg(d)),v=0,x=o.length;v<x;v++)b^=Dg(o[v]);e?b|=256:b&=-257,r?b|=16:b&=-17,this.f=b,this.i=t==null?null:(zt(t),t),this.a=n,this.d=i,this.j=o,this.g=a,this.e=d}function nye(e,t,n){var i,r;switch(r=null,t.g){case 1:r=(_l(),Vke);break;case 2:r=(_l(),Kke)}switch(i=null,n.g){case 1:i=(_l(),Wke);break;case 2:i=(_l(),Xke);break;case 3:i=(_l(),Yke);break;case 4:i=(_l(),Zke)}return r&&i?g5(e.j,new mK(new Ho(W(V(Dtn,1),Lt,181,0,[c(Rn(r),181),c(Rn(i),181)])))):(Ct(),Ct(),Rs)}function sVt(e){var t,n,i;switch(t=c(R(e,(Ge(),$9)),8),Ee(e,$9,new $e(t.b,t.a)),c(R(e,vd),259).g){case 1:Ee(e,vd,(Hd(),HJ));break;case 2:Ee(e,vd,(Hd(),FJ));break;case 3:Ee(e,vd,(Hd(),TP));break;case 4:Ee(e,vd,(Hd(),EP))}(e.q?e.q:(Ct(),Ct(),Yd))._b(Uv)&&(n=c(R(e,Uv),8),i=n.a,n.a=n.b,n.b=i)}function Qnt(e,t,n,i,r,o){if(this.b=n,this.d=r,e>=t.length)throw J(new zc("Greedy SwitchDecider: Free layer not in graph."));this.c=t[e],this.e=new E_(i),ute(this.e,this.c,(Je(),Yt)),this.i=new E_(i),ute(this.i,this.c,nn),this.f=new LFe(this.c),this.a=!o&&r.i&&!r.s&&this.c[0].k==(Jt(),Cr),this.a&&OQt(this,e,t.length)}function Gnt(e,t){var n,i,r,o,a,d;o=!e.B.Gc((uu(),FP)),a=e.B.Gc(pae),e.a=new kKe(a,o,e.c),e.n&&jpe(e.a.n,e.n),WK(e.g,(Yf(),Vc),e.a),t||(i=new OT(1,o,e.c),i.n.a=e.k,v5(e.p,(Je(),Kt),i),r=new OT(1,o,e.c),r.n.d=e.k,v5(e.p,bn,r),d=new OT(0,o,e.c),d.n.c=e.k,v5(e.p,Yt,d),n=new OT(0,o,e.c),n.n.b=e.k,v5(e.p,nn,n))}function oVt(e){var t,n,i;switch(t=c(R(e.d,(Ge(),W1)),225),t.g){case 2:n=Ken(e);break;case 3:n=(i=new Fe,lr(pi(qc(So(So(new jt(null,new Tt(e.d.b,16)),new um),new SR),new K8),new g0),new UNe(i)),i);break;default:throw J(new oo("Compaction not supported for "+t+" edges."))}vYt(e,n),ws(new an(e.g),new qNe(e))}function cVt(e,t){var n,i,r,o,a,d,b;if(t.Tg("Process directions",1),n=c(R(e,(Uo(),Iw)),87),n!=(Nr(),Fh))for(r=_n(e.b,0);r.b!=r.d.c;){switch(i=c(An(r),41),d=c(R(i,(Li(),wP)),15).a,b=c(R(i,vP),15).a,n.g){case 4:b*=-1;break;case 1:o=d,d=b,b=o;break;case 2:a=d,d=-b,b=a}Ee(i,wP,Pe(d)),Ee(i,vP,Pe(b))}t.Ug()}function lVt(e){var t,n,i,r,o,a,d,b;for(b=new YGe,d=new G(e.a);d.a<d.c.c.length;)if(a=c(Q(d),9),a.k!=(Jt(),Cr)){for(dUt(b,a,new as),o=new Ht(Vt($i(a).a.Jc(),new U));hn(o);)if(r=c(sn(o),17),!(r.c.i.k==Cr||r.d.i.k==Cr))for(i=_n(r.a,0);i.b!=i.d.c;)n=c(An(i),8),t=n,CT(b,new E6(t.a,t.b))}return b}function sie(){sie=te,Oje=new gi(Nse),kje=(c7(),SP),xje=new wt(Lse,kje),yje=(pD(),zJ),Rmt=new wt(z4e,yje),vje=(BD(),Mue),Imt=new wt(F4e,vje),Dmt=new wt(_se,null),wje=(X_(),$J),Pmt=new wt(Dse,wje),mje=(Iz(),Tue),Mmt=new wt(q4e,mje),Amt=new wt(H4e,(Bt(),!1)),Nmt=new wt(Q4e,Pe(64)),_mt=new wt(G4e,!0),Lmt=Cue}function Unt(e,t){var n,i,r,o,a,d,b,v,x,S;for(e.p=1,r=e.c,S=new Ld,x=tw(e,(Qs(),Wc)).Jc();x.Ob();)for(v=c(x.Pb(),12),i=new G(v.g);i.a<i.c.c.length;)n=c(Q(i),17),b=n.d.i,e!=b&&(o=b.c,o.p<=r.p&&(a=r.p+1,a==t.b.c.length?(d=new hc(t),d.p=a,qe(t.b,d),zr(b,d)):(d=c(Xe(t.b,a),26),zr(b,d)),S.a.yc(b,S)));return S}function Jnt(e){switch(e.g){case 0:return new Q0e;case 1:return new BB;case 2:return new Bc;case 3:return new $B;case 4:return new LRe;case 5:return new IRe;case 6:return new PRe;case 7:return new Uf;case 8:return new lK;default:throw J(new qt("No implementation is available for the cycle breaker "+(e.f!=null?e.f:""+e.g)))}}function uVt(e,t){var n,i;if(n=c(R(e,(Li(),Fle)),16),!n||n.gc()<1)return null;if(n.gc()==1)return c(n.Xb(0),41);switch(i=null,t.g){case 2:i=c(vu(m5(n.Mc(),new cj)),41);break;case 1:i=c(vu(Q2(n.Mc(),new oa)),41);break;case 4:i=c(vu(m5(n.Mc(),new oj)),41);break;case 3:i=c(vu(Q2(n.Mc(),new y4)),41)}return i}function Xnt(e){var t,n,i,r,o,a;if(e.a==null)if(e.a=ye(kl,eh,30,e.c.b.c.length,16,1),e.a[0]=!1,xi(e.c,(Ge(),wle)))for(i=c(R(e.c,wle),16),n=i.Jc();n.Ob();)t=c(n.Pb(),15).a,t>0&&t<e.a.length&&(e.a[t]=!1);else for(a=new G(e.c.b),a.a<a.c.c.length&&Q(a),r=1;a.a<a.c.c.length;)o=c(Q(a),26),e.a[r++]=GUt(o)}function Gd(){Gd=te,wC=new gi("additionalHeight"),J9=new gi("drawingHeight"),Ck=new gi("drawingWidth"),_J=new gi("minHeight"),vC=new gi("minWidth"),DJ=new gi("rows"),Yv=new gi("targetWidth"),mue=new qi("minRowIncrease",0),Gbt=new qi("maxRowIncrease",0),bue=new qi("minRowDecrease",0),Qbt=new qi("maxRowDecrease",0)}function Vnt(e,t){var n,i,r,o;switch(r=e.b,t){case 1:{e.b|=1,e.b|=4,e.b|=8;break}case 2:{e.b|=2,e.b|=4,e.b|=8;break}case 4:{e.b|=1,e.b|=2,e.b|=4,e.b|=8;break}case 3:{e.b|=16,e.b|=8;break}case 0:{e.b|=32,e.b|=16,e.b|=8,e.b|=1,e.b|=2,e.b|=4;break}}if(e.b!=r&&e.c)for(i=new cn(e.c);i.e!=i.i.gc();)o=c(un(i),474),n=ru(o),bv(n,t)}function Wnt(e,t,n,i){var r,o,a,d,b,v,x,S,M,L,P;for(r=!1,a=t,d=0,b=a.length;d<b;++d)o=a[d],et((Bt(),!!o.e))&&!c(Xe(e.b,o.e.p),221).s&&(r=r|(v=o.e,x=c(Xe(e.b,v.p),221),S=x.e,M=wPe(n,S.length),L=S[M][0],L.k==(Jt(),Cr)?S[M]=zJt(o,S[M],n?(Je(),Yt):(Je(),nn)):x.c.kg(S,n),P=XD(e,x,n,i),Xve(x.e,x.o,n),P));return r}function Knt(e,t){var n,i,r,o,a;for(o=(!t.a&&(t.a=new Me(Mn,t,10,11)),t.a).i,r=new cn((!t.a&&(t.a=new Me(Mn,t,10,11)),t.a));r.e!=r.i.gc();)i=c(un(r),19),ve(ke(i,(Dn(),j3)))!==ve((R1(),LC))&&(a=c(ke(t,ry),144),n=c(ke(i,ry),144),(a==n||a&&abe(a,n))&&(!i.a&&(i.a=new Me(Mn,i,10,11)),i.a).i!=0&&(o+=Knt(e,i)));return o}function aVt(e){var t,n,i,r,o;for(o=new Hc(e.a.c.length),r=new G(e.a);r.a<r.c.c.length;){switch(i=c(Q(r),9),n=c(R(i,(Ge(),Ro)),166),t=null,n.g){case 1:case 2:t=(ab(),l3);break;case 3:case 4:t=(ab(),_9)}t?(Ee(i,(De(),QU),(ab(),l3)),t==_9?SQ(i,n,(Qs(),Jl)):t==l3&&SQ(i,n,(Qs(),Wc))):It(o.c,i)}return o}function fVt(e){var t,n,i,r,o,a,d;for(i=0,d=0,a=new G(e.d);a.a<a.c.c.length;)o=c(Q(a),108),r=c(ql(pi(new jt(null,new Tt(o.j,16)),new cf),su(new Ls,new rs,new mo,W(V(ml,1),_e,132,0,[(va(),bl)]))),16),n=null,i<=d?(n=(Je(),Kt),i+=r.gc()):d<i&&(n=(Je(),bn),d+=r.gc()),t=n,lr(qc(r.Mc(),new iA),new VNe(t))}function hVt(e,t){var n;return n=new Dy,t&&ec(n,c(Ut(e.a,QP),105)),oe(t,278)&&ec(n,c(Ut(e.a,GP),105)),oe(t,363)?(ec(n,c(Ut(e.a,Bo),105)),n):(oe(t,83)&&ec(n,c(Ut(e.a,vn),105)),oe(t,209)?(ec(n,c(Ut(e.a,Mn),105)),n):oe(t,196)?(ec(n,c(Ut(e.a,hu),105)),n):(oe(t,273)&&ec(n,c(Ut(e.a,Ii),105)),n))}function dVt(e){var t,n,i,r,o,a,d,b;for(e.b=new Qet(new Ho((Je(),W(V($s,1),cc,64,0,[$o,Kt,nn,bn,Yt]))),new Ho((Km(),W(V(hce,1),_e,369,0,[Ew,ep,Tw])))),a=W(V($s,1),cc,64,0,[$o,Kt,nn,bn,Yt]),d=0,b=a.length;d<b;++d)for(o=a[d],n=W(V(hce,1),_e,369,0,[Ew,ep,Tw]),i=0,r=n.length;i<r;++i)t=n[i],vqt(e.b,o,t,new Fe)}function Ynt(e,t){var n,i,r,o,a,d,b,v,x,S;if(a=c(c(Si(e.r,t),24),85),d=e.u.Gc((Ql(),hp)),n=e.u.Gc($C),i=e.u.Gc(RC),v=e.u.Gc(Rk),S=e.B.Gc((uu(),tX)),x=!n&&!i&&(v||a.gc()==2),fXt(e,t),r=null,b=null,d){for(o=a.Jc(),r=c(o.Pb(),116),b=r;o.Ob();)b=c(o.Pb(),116);r.d.b=0,b.d.c=0,x&&!r.a&&(r.d.c=0)}S&&(bHt(a),d&&(r.d.b=0,b.d.c=0))}function Znt(e,t){var n,i,r,o,a,d,b,v,x,S;if(a=c(c(Si(e.r,t),24),85),d=e.u.Gc((Ql(),hp)),n=e.u.Gc($C),i=e.u.Gc(RC),b=e.u.Gc(Rk),S=e.B.Gc((uu(),tX)),v=!n&&!i&&(b||a.gc()==2),MWt(e,t),x=null,r=null,d){for(o=a.Jc(),x=c(o.Pb(),116),r=x;o.Ob();)r=c(o.Pb(),116);x.d.d=0,r.d.a=0,v&&!x.a&&(x.d.a=0)}S&&(mHt(a),d&&(x.d.d=0,r.d.a=0))}function eit(e,t,n){var i,r,o,a,d,b,v,x;if(r=t.k,t.p>=0)return!1;if(t.p=n.b,qe(n.e,t),r==(Jt(),jr)||r==Dc){for(a=new G(t.j);a.a<a.c.c.length;)for(o=c(Q(a),12),x=(i=new G(new Q4(o).a.g),new vde(i));No(x.a);)if(v=c(Q(x.a),17).d,d=v.i,b=d.k,t.c!=d.c&&(b==jr||b==Dc)&&eit(e,d,n))return!0}return!0}function CQ(e){var t;return(e.Db&64)!=0?yve(e):(t=new Ba(yve(e)),t.a+=" (changeable: ",xg(t,(e.Bb&Ga)!=0),t.a+=", volatile: ",xg(t,(e.Bb&q1)!=0),t.a+=", transient: ",xg(t,(e.Bb&jv)!=0),t.a+=", defaultValueLiteral: ",Ys(t,e.j),t.a+=", unsettable: ",xg(t,(e.Bb&Pl)!=0),t.a+=", derived: ",xg(t,(e.Bb&ad)!=0),t.a+=")",t.a)}function gVt(e,t){var n,i,r,o,a;return r=t.ni(e.a),r&&(i=(!r.b&&(r.b=new yu((Mt(),Bs),Yo,r)),r.b),n=zn(Zf(i,ys)),n!=null&&(o=n.lastIndexOf("#"),a=o==-1?Bge(e,t.hk(),n):o==0?Y_(e,null,(en(1,n.length+1),n.substr(1))):Y_(e,(fs(0,o,n.length),n.substr(0,o)),(en(o+1,n.length+1),n.substr(o+1))),oe(a,160)))?c(a,160):null}function pVt(e,t){var n,i,r,o,a;return i=t.ni(e.a),i&&(n=(!i.b&&(i.b=new yu((Mt(),Bs),Yo,i)),i.b),o=zn(Zf(n,foe)),o!=null&&(r=o.lastIndexOf("#"),a=r==-1?Bge(e,t.hk(),o):r==0?Y_(e,null,(en(1,o.length+1),o.substr(1))):Y_(e,(fs(0,r,o.length),o.substr(0,r)),(en(r+1,o.length+1),o.substr(r+1))),oe(a,160)))?c(a,160):null}function bVt(e,t){var n,i,r,o,a,d,b,v,x,S,M;for(t.Tg("Restoring reversed edges",1),b=new G(e.b);b.a<b.c.c.length;)for(d=c(Q(b),26),x=new G(d.a);x.a<x.c.c.length;)for(v=c(Q(x),9),M=new G(v.j);M.a<M.c.c.length;)for(S=c(Q(M),12),a=rd(S.g),i=a,r=0,o=i.length;r<o;++r)n=i[r],et(Ze(R(n,(De(),Jg))))&&zg(n,!1);t.Ug()}function mVt(e,t,n,i){var r,o,a,d,b;for(b=ye(ns,Be,109,(Je(),W(V($s,1),cc,64,0,[$o,Kt,nn,bn,Yt])).length,0,2),o=W(V($s,1),cc,64,0,[$o,Kt,nn,bn,Yt]),a=0,d=o.length;a<d;++a)r=o[a],b[r.g]=ye(ns,no,30,e.c[r.g],15,1);return eZe(b,e,Kt),eZe(b,e,bn),xne(b,e,Kt,t,n,i),xne(b,e,nn,t,n,i),xne(b,e,bn,t,n,i),xne(b,e,Yt,t,n,i),b}function wVt(e,t,n){if(jc(e.a,t)){if($a(c(Ut(e.a,t),47),n))return 1}else oi(e.a,t,new Or);if(jc(e.a,n)){if($a(c(Ut(e.a,n),47),t))return-1}else oi(e.a,n,new Or);if(jc(e.b,t)){if($a(c(Ut(e.b,t),47),n))return-1}else oi(e.b,t,new Or);if(jc(e.b,n)){if($a(c(Ut(e.b,n),47),t))return 1}else oi(e.b,n,new Or);return 0}function vVt(e){var t,n,i,r,o,a;e.q==(Zr(),r1)||e.q==xc||(r=e.f.n.d+FF(c(Zs(e.b,(Je(),Kt)),129))+e.c,t=e.f.n.a+FF(c(Zs(e.b,bn),129))+e.c,i=c(Zs(e.b,nn),129),a=c(Zs(e.b,Yt),129),o=p.Math.max(0,i.n.d-r),o=p.Math.max(o,a.n.d-r),n=p.Math.max(0,i.n.a-t),n=p.Math.max(n,a.n.a-t),i.n.d=o,a.n.d=o,i.n.a=n,a.n.a=n)}function iye(e,t,n,i){var r,o,a,d,b,v;if(n==null){for(r=c(e.g,123),d=0;d<e.i;++d)if(a=r[d],a.Jk()==t)return Ns(e,a,i)}return o=(qs(),c(t,69).vk()?c(n,76):Fd(t,n)),wu(e.e)?(v=!ED(e,t),i=Uc(e,o,i),b=t.Hk()?E0(e,3,t,null,n,$S(e,t,n,oe(t,104)&&(c(t,20).Bb&Is)!=0),v):E0(e,1,t,t.gk(),n,-1,v),i?i.lj(b):i=b):i=Uc(e,o,i),i}function tit(){this.b=new M0,this.d=new M0,this.e=new M0,this.c=new M0,this.a=new wn,this.f=new wn,xx(Vr,new Qf,new D$),xx(Fje,new B$,new z$),xx(Uke,new F$,new FA),xx(Jke,new qA,new HA),xx(b2t,new q$,new QA),xx(Ltn,new L$,new P$),xx(Rtn,new I$,new UO),xx(Ptn,new R$,new mj),xx(Itn,new $$,new FW),xx(ztn,new wj,new zA)}function zT(e,t){var n,i,r,o,a;for(e=e==null?pl:(zt(e),e),r=0;r<t.length;r++)t[r]=yJt(t[r]);for(n=new Z4,a=0,i=0;i<t.length&&(o=e.indexOf("%s",a),o!=-1);)n.a+=""+Fa(e==null?pl:(zt(e),e),a,o),Sc(n,t[i++]),a=o+2;if(JQe(n,e,a,e.length),i<t.length){for(n.a+=" [",Sc(n,t[i++]);i<t.length;)n.a+=Jc,Sc(n,t[i++]);n.a+="]"}return n.a}function rye(e,t){var n,i,r,o,a,d,b;for(n=0,b=new G(t);b.a<b.c.c.length;){for(d=c(Q(b),12),Ume(e.b,e.d[d.p]),a=0,r=new kh(d.b);No(r.a)||No(r.b);)i=c(No(r.a)?Q(r.a):Q(r.b),17),Nqe(i)?(o=c1e(e,d==i.c?i.d:i.c),o>e.d[d.p]&&(n+=cbe(e.b,o),C0(e.a,Pe(o)))):++a;for(n+=e.b.d*a;!e7(e.a);)Fbe(e.b,c(w5(e.a),15).a)}return n}function nit(e){var t,n,i,r,o,a;return o=0,t=Qa(e),t.ik()&&(o|=4),(e.Bb&Pl)!=0&&(o|=2),oe(e,104)?(n=c(e,20),r=Hs(n),(n.Bb&nc)!=0&&(o|=32),r&&(pn(W2(r)),o|=8,a=r.t,(a>1||a==-1)&&(o|=16),(r.Bb&nc)!=0&&(o|=64)),(n.Bb&Is)!=0&&(o|=q1),o|=Ga):oe(t,462)?o|=512:(i=t.ik(),i&&(i.i&1)!=0&&(o|=256)),(e.Bb&512)!=0&&(o|=128),o}function yVt(e,t){var n;return e.f==Mae?(n=zm(uo((Dl(),ps),t)),e.e?n==4&&t!=(U5(),zk)&&t!=(U5(),Bk)&&t!=(U5(),Aae)&&t!=(U5(),Nae):n==2):e.d&&(e.d.Gc(t)||e.d.Gc(S5(uo((Dl(),ps),t)))||e.d.Gc(qx((Dl(),ps),e.b,t)))?!0:e.f&&zve((Dl(),e.f),I_(uo(ps,t)))?(n=zm(uo(ps,t)),e.e?n==4:n==2):!1}function xVt(e,t){var n,i,r,o,a,d,b,v;for(o=new Fe,t.b.c.length=0,n=c(ql(Fpe(new jt(null,new Tt(new an(e.a.b),1))),su(new Ls,new rs,new mo,W(V(ml,1),_e,132,0,[(va(),bl)]))),16),r=n.Jc();r.Ob();)if(i=c(r.Pb(),15),a=ebe(e.a,i),a.b!=0)for(d=new hc(t),It(o.c,d),d.p=i.a,v=_n(a,0);v.b!=v.d.c;)b=c(An(v),9),zr(b,d);yr(t.b,o)}function oie(e){var t,n,i,r,o,a,d;for(d=new wn,i=new G(e.a.b);i.a<i.c.c.length;)t=c(Q(i),60),oi(d,t,new Fe);for(r=new G(e.a.b);r.a<r.c.c.length;)for(t=c(Q(r),60),t.i=Qr,a=t.c.Jc();a.Ob();)o=c(a.Pb(),60),c(Ao(co(d.f,o)),16).Ec(t);for(n=new G(e.a.b);n.a<n.c.c.length;)t=c(Q(n),60),t.c.$b(),t.c=c(Ao(co(d.f,t)),16);Ont(e)}function cie(e){var t,n,i,r,o,a,d;for(d=new wn,i=new G(e.a.b);i.a<i.c.c.length;)t=c(Q(i),84),oi(d,t,new Fe);for(r=new G(e.a.b);r.a<r.c.c.length;)for(t=c(Q(r),84),t.o=Qr,a=t.f.Jc();a.Ob();)o=c(a.Pb(),84),c(Ao(co(d.f,o)),16).Ec(t);for(n=new G(e.a.b);n.a<n.c.c.length;)t=c(Q(n),84),t.f.$b(),t.f=c(Ao(co(d.f,t)),16);hnt(e)}function kVt(e,t){var n,i,r,o,a,d,b,v,x,S,M;for(b=Jr(t.a),r=ue(he(R(b,(Ge(),ip))))*2,x=ue(he(R(b,Vv))),v=p.Math.max(r,x),o=ye(ns,no,30,t.f-t.c+1,15,1),i=-v,n=0,d=t.b.Jc();d.Ob();)a=c(d.Pb(),9),i+=e.a[a.c.p]+v,o[n++]=i;for(i+=e.a[t.a.c.p]+v,o[n++]=i,M=new G(t.e);M.a<M.c.c.length;)S=c(Q(M),9),i+=e.a[S.c.p]+v,o[n++]=i;return o}function OVt(e,t,n,i){var r,o,a,d,b,v,x,S,M;for(M=new kg(new p_e(e)),d=W(V(e1,1),Hg,9,0,[t,n]),b=0,v=d.length;b<v;++b)for(a=d[b],S=bT(a,i).Jc();S.Ob();)for(x=c(S.Pb(),12),o=new kh(x.b);No(o.a)||No(o.b);)r=c(No(o.a)?Q(o.a):Q(o.b),17),vs(r)||(M.a.yc(x,(Bt(),K0))==null,Nqe(r)&&L_(M,x==r.c?r.d:r.c));return Rn(M),new Fl(M)}function SVt(e,t,n,i){var r,o,a,d,b,v,x,S;return a=c(ke(n,(Dn(),Dk)),8),b=a.a,x=a.b+e,r=p.Math.atan2(x,b),r<0&&(r+=Sb),r+=t,r>Sb&&(r-=Sb),d=c(ke(i,Dk),8),v=d.a,S=d.b+e,o=p.Math.atan2(S,v),o<0&&(o+=Sb),o+=t,o>Sb&&(o-=Sb),mh(),vf(1e-10),p.Math.abs(r-o)<=1e-10||r==o||isNaN(r)&&isNaN(o)?0:r<o?-1:r>o?1:Gp(isNaN(r),isNaN(o))}function sye(e,t,n,i){var r,o,a;t&&(o=ue(he(R(t,(Li(),Kg))))+i,a=n+ue(he(R(t,SJ)))/2,Ee(t,wP,Pe(Hn(Zo(p.Math.round(o))))),Ee(t,vP,Pe(Hn(Zo(p.Math.round(a))))),t.d.b==0||sye(e,c(kF((r=_n(new k1(t).a.d,0),new ix(r))),41),n+ue(he(R(t,SJ)))+e.b,i+ue(he(R(t,U9)))),R(t,Jle)!=null&&sye(e,c(R(t,Jle),41),n,i))}function jVt(e,t){var n,i,r,o;if(o=c(ke(e,(Dn(),M3)),64).g-c(ke(t,M3),64).g,o!=0)return o;if(n=c(ke(e,cae),15),i=c(ke(t,cae),15),n&&i&&(r=n.a-i.a,r!=0))return r;switch(c(ke(e,M3),64).g){case 1:return ji(e.i,t.i);case 2:return ji(e.j,t.j);case 3:return ji(t.i,e.i);case 4:return ji(t.j,e.j);default:throw J(new oo(Nxe))}}function oye(e){var t,n,i;return(e.Db&64)!=0?Fne(e):(t=new Lu(u5e),n=e.k,n?Zn(Zn((t.a+=' "',t),n),'"'):(!e.n&&(e.n=new Me(Bo,e,1,7)),e.n.i>0&&(i=(!e.n&&(e.n=new Me(Bo,e,1,7)),c(re(e.n,0),158)).a,!i||Zn(Zn((t.a+=' "',t),i),'"'))),Zn(Cm(Zn(Cm(Zn(Cm(Zn(Cm((t.a+=" (",t),e.i),","),e.j)," | "),e.g),","),e.f),")"),t.a)}function iit(e){var t,n,i;return(e.Db&64)!=0?Fne(e):(t=new Lu(a5e),n=e.k,n?Zn(Zn((t.a+=' "',t),n),'"'):(!e.n&&(e.n=new Me(Bo,e,1,7)),e.n.i>0&&(i=(!e.n&&(e.n=new Me(Bo,e,1,7)),c(re(e.n,0),158)).a,!i||Zn(Zn((t.a+=' "',t),i),'"'))),Zn(Cm(Zn(Cm(Zn(Cm(Zn(Cm((t.a+=" (",t),e.i),","),e.j)," | "),e.g),","),e.f),")"),t.a)}function TVt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P;for(L=-1,P=0,x=t,S=0,M=x.length;S<M;++S){for(v=x[S],a=v,d=0,b=a.length;d<b;++d)for(o=a[d],n=new Lbe(e,L==-1?t[0]:t[L],c(R(Jr(o),(Ge(),t1)),270),XYe(o),et(Ze(R(Jr(o),nle)))),i=0;i<o.j.c.length;i++)for(r=i+1;r<o.j.c.length;r++)ZFe(n,c(Xe(o.j,i),12),c(Xe(o.j,r),12))>0&&++P;++L}return P}function EVt(e,t){var n,i,r,o,a;for(t==(dT(),Dle)&&NT(c(Si(e.a,(dv(),VL)),16)),r=c(Si(e.a,(dv(),VL)),16).Jc();r.Ob();)switch(i=c(r.Pb(),108),n=c(Xe(i.j,0),114).d.j,o=new Fl(i.j),Rr(o,new f4),t.g){case 2:Lne(e,o,n,(Km(),ep),1);break;case 1:case 0:a=mJt(o),Lne(e,new nd(o,0,a),n,(Km(),ep),0),Lne(e,new nd(o,a,o.c.length),n,ep,1)}}function CVt(e){var t,n,i,r,o,a,d;for(r=c(R(e,(De(),Mw)),9),i=e.j,n=(ht(0,i.c.length),c(i.c[0],12)),a=new G(r.j);a.a<a.c.c.length;)if(o=c(Q(a),12),ve(o)===ve(R(n,Oi))){o.j==(Je(),Kt)&&e.p>r.p?($r(o,bn),o.d&&(d=o.o.b,t=o.a.b,o.a.b=d-t)):o.j==bn&&r.p>e.p&&($r(o,Kt),o.d&&(d=o.o.b,t=o.a.b,o.a.b=-(d-t)));break}return r}function cye(e,t){var n,i,r,o,a,d,b;if(t==null||t.length==0)return null;if(r=c(Tc(e.a,t),144),!r){for(i=(d=new x1(e.b).a.vc().Jc(),new C2(d));i.a.Ob();)if(n=(o=c(i.a.Pb(),45),c(o.kd(),144)),a=n.c,b=t.length,Ot(a.substr(a.length-b,b),t)&&(t.length==a.length||ms(a,a.length-t.length-1)==46)){if(r)return null;r=n}r&&lo(e.a,t,r)}return r}function IS(e,t,n){var i,r,o,a,d,b,v,x,S,M;for(o=new $e(t,n),x=new G(e.a);x.a<x.c.c.length;)for(v=c(Q(x),9),ki(v.n,o),M=new G(v.j);M.a<M.c.c.length;)for(S=c(Q(M),12),r=new G(S.g);r.a<r.c.c.length;)for(i=c(Q(r),17),rv(i.a,o),a=c(R(i,(Ge(),ho)),79),a&&rv(a,o),b=new G(i.b);b.a<b.c.c.length;)d=c(Q(b),70),ki(d.n,o)}function MVt(e,t,n){var i,r,o,a,d,b,v,x,S,M;for(o=new $e(t,n),x=new G(e.a);x.a<x.c.c.length;)for(v=c(Q(x),9),ki(v.n,o),M=new G(v.j);M.a<M.c.c.length;)for(S=c(Q(M),12),r=new G(S.g);r.a<r.c.c.length;)for(i=c(Q(r),17),rv(i.a,o),a=c(R(i,(Ge(),ho)),79),a&&rv(a,o),b=new G(i.b);b.a<b.c.c.length;)d=c(Q(b),70),ki(d.n,o)}function rit(e){if((!e.b&&(e.b=new Et(vn,e,4,7)),e.b).i==0)throw J(new Y4("Edges must have a source."));if((!e.c&&(e.c=new Et(vn,e,5,8)),e.c).i==0)throw J(new Y4("Edges must have a target."));if(!e.b&&(e.b=new Et(vn,e,4,7)),!(e.b.i<=1&&(!e.c&&(e.c=new Et(vn,e,5,8)),e.c.i<=1)))throw J(new Y4("Hyperedges are not supported."))}function AVt(e,t){var n,i;t.Tg("Partition preprocessing",1),i=c(ql(pi(new jt(null,new Tt(e.a,16)),new nR),su(new Ls,new rs,new mo,W(V(ml,1),_e,132,0,[(va(),bl)]))),16),n=c(ql(pi(So(pi(new jt(null,new Tt(e.a,16)),new iR),new rR),new ENe(i)),su(new Ls,new rs,new mo,W(V(ml,1),_e,132,0,[bl]))),16),lr(n.Mc(),new sR),t.Ug()}function sit(e){var t,n,i;xi(e,(Ge(),_w))&&(i=c(R(e,_w),24),!i.dc()&&(n=(t=c(Jf(Ws),10),new ha(t,c(gf(t,t.length),10),0)),i.Gc((mv(),Vu))?yf(n,Vu):yf(n,Df),i.Gc(Ka)||yf(n,Ka),i.Gc(Nf)?yf(n,Lf):i.Gc(Z1)?yf(n,i1):i.Gc(_f)&&yf(n,Ya),i.Gc(Lf)?yf(n,Nf):i.Gc(i1)?yf(n,Z1):i.Gc(Ya)&&yf(n,_f),Ee(e,_w,n)))}function oit(e,t){var n,i;for(this.b=new Fe,this.e=new Fe,this.a=e,this.d=t,hzt(this),vBt(this),this.b.dc()?this.c=e.c.p:this.c=c(this.b.Xb(0),9).c.p,this.e.c.length==0?this.f=e.c.p:this.f=c(Xe(this.e,this.e.c.length-1),9).c.p,i=c(R(e,(De(),HE)),16).Jc();i.Ob();)if(n=c(i.Pb(),70),xi(n,(Ge(),ZU))){this.d=c(R(n,ZU),233);break}}function Mu(e,t,n){var i,r,o,a,d,b,v,x;for(i=c(Ut(e.b,t),47),o=c(Ut(e.b,n),47),r=c(Ut(e.g,t),47),a=c(Ut(e.g,n),47),i.a.yc(n,i),a.a.yc(t,a),x=o.a.ec().Jc();x.Ob();)v=c(x.Pb(),9),i.a.yc(v,i),Sr(c(Ut(e.g,v),47),t),Os(c(Ut(e.g,v),47),r);for(b=r.a.ec().Jc();b.Ob();)d=c(b.Pb(),9),a.a.yc(d,a),Sr(c(Ut(e.b,d),47),n),Os(c(Ut(e.b,d),47),o)}function VD(e,t,n){var i,r,o,a,d,b,v,x;for(i=c(Ut(e.a,t),47),o=c(Ut(e.a,n),47),r=c(Ut(e.b,t),47),a=c(Ut(e.b,n),47),i.a.yc(n,i),a.a.yc(t,a),x=o.a.ec().Jc();x.Ob();)v=c(x.Pb(),9),i.a.yc(v,i),Sr(c(Ut(e.b,v),47),t),Os(c(Ut(e.b,v),47),r);for(b=r.a.ec().Jc();b.Ob();)d=c(b.Pb(),9),a.a.yc(d,a),Sr(c(Ut(e.a,d),47),n),Os(c(Ut(e.a,d),47),o)}function ld(){ld=te;var e;for(YG=new A1(1,1),Loe=new A1(1,10),ME=new A1(0,0),Fat=new A1(-1,1),qat=W(V(t3,1),Be,92,0,[ME,YG,new A1(1,2),new A1(1,3),new A1(1,4),new A1(1,5),new A1(1,6),new A1(1,7),new A1(1,8),new A1(1,9),Loe]),ZG=ye(t3,Be,92,32,0,1),e=0;e<ZG.length;e++)ZG[e]=gF($d(1,e),0)?$0($d(1,e)):F7($0(Ng($d(1,e))))}function cit(e,t){var n,i,r,o,a,d,b,v,x;for(r=new Ht(Vt(z1(t).a.Jc(),new U));hn(r);)i=c(sn(r),74),x=to(c(re((!i.c&&(i.c=new Et(vn,i,5,8)),i.c),0),83)),d=$T(i),b=t.i+t.g/2,v=t.j+t.f,o=x.i+x.g/2,a=x.j,Vm(d,b),Wm(d,v),Jm(d,o),Xm(d,a),n=ue(he(ke(x,(Qd(),Rw)))),p.Math.abs(n-(a-ue(he(ke(Xi(x),(Dn(),lh))))/2))>Fg&&Qte(d,o,n),cit(e,x)}function lit(e,t,n,i,r,o,a){if(e.c=i.Jf().a,e.d=i.Jf().b,r&&(e.c+=r.Jf().a,e.d+=r.Jf().b),e.b=t.Kf().a,e.a=t.Kf().b,!r)n?e.c-=a+t.Kf().a:e.c+=i.Kf().a+a;else switch(r.$f().g){case 0:case 2:e.c+=r.Kf().a+a+o.a+a;break;case 4:e.c-=a+o.a+a+t.Kf().a;break;case 1:e.c+=r.Kf().a+a,e.d-=a+o.b+a+t.Kf().b;break;case 3:e.c+=r.Kf().a+a,e.d+=r.Kf().b+a+o.b+a}}function NVt(e,t,n,i){var r,o,a,d,b,v,x,S,M,L,P;if(o=n,n<i)for(M=(L=new gD(e.p),P=new gD(e.p),Os(L.e,e.e),L.q=e.q,L.r=P,cq(L),Os(P.j,e.j),P.r=L,cq(P),new Ps(L,P)),S=c(M.a,117),x=c(M.b,117),r=(ht(o,t.c.length),c(t.c[o],341)),a=Lnt(e,S,x,r),v=n+1;v<=i;v++)d=(ht(v,t.c.length),c(t.c[v],341)),b=Lnt(e,S,x,d),fzt(d,b,r,a)&&(r=d,a=b,o=v);return o}function _Vt(e,t,n,i){var r,o,a,d,b,v,x,S,M,L,P;for(a=c(re(t,0),19),Cc(a,0),Nl(a,0),M=new Fe,It(M.c,a),d=a,o=new I0e(e.a,a.g,a.f,(RT(),OP)),L=1;L<t.i;L++)P=c(re(t,L),19),b=wie(e,S3,P,d,o,M,n),v=wie(e,Mk,P,d,o,M,n),x=wie(e,OC,P,d,o,M,n),S=wie(e,kC,P,d,o,M,n),r=aYt(e,b,v,x,S,P,d,i),Cc(P,r.d),Nl(P,r.e),FN(r,OP),o=r,d=P,It(M.c,P);return o}function DVt(e,t,n){var i,r,o,a,d,b,v,x,S,M;if(x=null,M=t,S=jXe(e,gGe(n),M),nS(S,M1(M,bd)),a=Gm(M,h5e),i=new zRe(e,S),Pet(i.a,i.b,a),d=Gm(M,Zse),r=new FRe(e,S),Iet(r.a,r.b,d),(!S.b&&(S.b=new Et(vn,S,4,7)),S.b).i==0||(!S.c&&(S.c=new Et(vn,S,5,8)),S.c).i==0)throw o=M1(M,bd),b=zlt+o,v=b+w9,J(new Kh(v));return lQ(M,S),Hen(e,M,S),x=Tte(e,M,S),x}function LVt(e,t){var n,i,r,o,a,d,b;for(r=ye(Fn,ci,30,e.e.a.c.length,15,1),a=new G(e.e.a);a.a<a.c.c.length;)o=c(Q(a),126),r[o.d]+=o.b.a.c.length;for(d=A_(t);d.b!=0;)for(o=c(d.b==0?null:(dn(d.b!=0),ba(d,d.a.a)),126),i=M5(new G(o.g.a));i.Ob();)n=c(i.Pb(),220),b=n.e,b.e=p.Math.max(b.e,o.e+n.a),--r[b.d],r[b.d]==0&&tr(d,b,d.c.b,d.c)}function uit(e){var t,n,i,r,o,a,d,b,v,x,S;for(n=ls,r=di,d=new G(e.e.a);d.a<d.c.c.length;)o=c(Q(d),126),r=p.Math.min(r,o.e),n=p.Math.max(n,o.e);for(t=ye(Fn,ci,30,n-r+1,15,1),a=new G(e.e.a);a.a<a.c.c.length;)o=c(Q(a),126),o.e-=r,++t[o.e];if(i=0,e.k!=null)for(v=e.k,x=0,S=v.length;x<S&&(b=v[x],t[i++]+=b,t.length!=i);++x);return t}function PVt(e,t){var n,i,r,o,a,d;if(t.Tg("Edge routing",1),r=c(R(e,(Uo(),Xle)),386),r==(fT(),zle))_Lt(e);else if(r==bP)for(c(vu(I1(pi(new jt(null,new Tt(e.b,16)),new sj))),41),o=ue(he(R(e,i8e))),a=ue(he(R(e,Y9e))),d=c(R(e,Iw),87),Gen(e,d,o),Otn(e,d,o,a),jtn(e,d,o,a),i=_n(e.a,0);i.b!=i.d.c;)n=c(An(i),65),n.a.b<2&&hve(n);t.Ug()}function ait(e){switch(e.d){case 9:case 8:return!0;case 3:case 5:case 4:case 6:return!1;case 7:return c(Vve(e),15).a==e.o;case 1:case 2:{if(e.o==-2)return!1;switch(e.p){case 0:case 1:case 2:case 6:case 5:case 7:return k7(e.k,e.f);case 3:case 4:return e.j==e.e;default:return e.n==null?e.g==null:yi(e.n,e.g)}}default:return!1}}function IVt(e){var t,n,i,r;for(r=e.b,t=!1,i=new G(e.i.d);i.a<i.c.c.length;)if(n=c(Q(i),70),et(Ze(R(n,(Ge(),b3))))){t=!0;break}Cl(r,(Je(),Kt))?Cl(r,bn)?Cl(r,Yt)?Cl(r,nn)||Eg(e,t?Yt:Kt,t?(xf(),Iv):(xf(),C9),t?null:e.c):Eg(e,t?nn:Kt,t?(xf(),Iv):(xf(),E9),t?null:e.a):Eg(e,Kt,(xf(),Iv),null):Eg(e,bn,(xf(),Iv),null)}function fit(e,t,n){var i,r,o,a,d,b,v,x,S;for(o=new Hc(t.c.length),v=new G(t);v.a<v.c.c.length;)a=c(Q(v),9),qe(o,e.b[a.c.p][a.p]);for(xYt(e,o,n),S=null;S=vZt(o);)tKt(e,c(S.a,242),c(S.b,242),o);for(t.c.length=0,r=new G(o);r.a<r.c.c.length;)for(i=c(Q(r),242),d=i.d,b=0,x=d.length;b<x;++b)a=d[b],It(t.c,a),e.a[a.c.p][a.p].a=wh(i.g,i.d[0]).a}function RVt(e,t){var n,i,r;switch(t.Tg("Breaking Point Insertion",1),i=new Tve(e),c(R(e,(Ge(),mle)),351).g){case 2:r=new _O;break;case 0:r=new Dp;break;default:r=new uA}if(n=r.mg(e,i),et(Ze(R(e,XSe)))&&(n=MYt(e,n)),!r.ng()&&xi(e,uJ))switch(c(R(e,uJ),352).g){case 2:n=Let(i,n);break;case 1:n=vZe(i,n)}if(n.dc()){t.Ug();return}Wen(e,n),t.Ug()}function hit(e){Am(e,new mb(Em(Sm(Tm(jm(new b1,g9),"ELK Fixed"),"Keeps the current layout as it is, without any automatic modification. Optional coordinates can be given for nodes and edge bend points."),new H$))),Ie(e,g9,gw,G7e),Ie(e,g9,mG,Ve(DC)),Ie(e,g9,n5e,Ve(F7e)),Ie(e,g9,Jx,Ve(q7e)),Ie(e,g9,ok,Ve(Q7e)),Ie(e,g9,n9,Ve(H7e))}function MQ(e,t,n){var i,r,o,a,d;if(i=Hn(Ss(Xd,zd(Hn(Ss(t==null?0:Ri(t),Vd)),15))),d=Hn(Ss(Xd,zd(Hn(Ss(n==null?0:Ri(n),Vd)),15))),o=oT(e,t,i),o&&d==o.f&&T1(n,o.i))return n;if(a=cT(e,n,d),a)throw J(new qt("value already present: "+n));return r=new aq(t,i,n,d),o?(Bx(e,o),FD(e,r,o),o.e=null,o.c=null,o.i):(FD(e,r,null),tZe(e),null)}function $Vt(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P;x=n.a.c,a=n.a.c+n.a.b,o=c(Ut(n.c,t),460),L=o.f,P=o.a,o.b?b=new $e(a,L):b=new $e(x,L),o.c?S=new $e(x,P):S=new $e(a,P),r=x,n.p||(r+=e.c),r+=n.F+n.v*e.b,v=new $e(r,L),M=new $e(r,P),sT(t.a,W(V(Vr,1),Be,8,0,[b,v])),d=n.d.a.gc()>1,d&&(i=new $e(r,n.b),ei(t.a,i)),sT(t.a,W(V(Vr,1),Be,8,0,[M,S]))}function H0(){H0=te,gJ=new D2(th,0),fP=new D2("NIKOLOV",1),hP=new D2("NIKOLOV_PIXEL",2),c9e=new D2("NIKOLOV_IMPROVED",3),l9e=new D2("NIKOLOV_IMPROVED_PIXEL",4),o9e=new D2("DUMMYNODE_PERCENTAGE",5),u9e=new D2("NODECOUNT_PERCENTAGE",6),pJ=new D2("NO_BOUNDARY",7),H9=new D2("MODEL_ORDER_LEFT_TO_RIGHT",8),sC=new D2("MODEL_ORDER_RIGHT_TO_LEFT",9)}function lie(e,t){var n,i,r,o,a,d,b,v,x,S,M,L;return x=null,M=Ave(e,t),i=null,d=c(ke(t,(Dn(),Mwt)),301),d?i=d:i=(iT(),$P),L=i,L==(iT(),$P)&&(r=null,v=c(Ut(e.r,M),301),v?r=v:r=gae,L=r),oi(e.r,t,L),o=null,b=c(ke(t,Cwt),280),b?o=b:o=(gS(),_P),S=o,S==(gS(),_P)&&(a=null,n=c(Ut(e.b,M),280),n?a=n:a=VJ,S=a),x=c(oi(e.b,t,S),280),x}function BVt(e){var t,n,i,r,o;for(i=e.length,t=new t7,o=0;o<i;)if(n=ms(e,o++),!(n==9||n==10||n==12||n==13||n==32)){if(n==35){for(;o<i&&(n=ms(e,o++),!(n==13||n==10)););continue}n==92&&o<i?(r=(en(o,e.length),e.charCodeAt(o)))==35||r==9||r==10||r==12||r==13||r==32?(z6(t,r&_r),++o):(t.a+="\\",z6(t,r&_r),++o):z6(t,n&_r)}return t.a}function lye(){lye=te,ybt=new wt(m4e,(Bt(),!1)),Sbt=new wt(w4e,Pe(0)),jbt=new wt(v4e,0),Tbt=new wt(OG,!1),p8e=(yD(),CJ),kbt=new wt(jse,p8e),Pe(0),xbt=new wt(Tse,Pe(1)),m8e=(mH(),aue),Abt=new wt(y4e,m8e),w8e=(Qq(),sue),Nbt=new wt(x4e,w8e),b8e=(YH(),uue),Obt=new wt(k4e,b8e),Mbt=new wt(Ese,0),Ebt=new wt(Cse,!1),Cbt=new wt(O4e,!1)}function zVt(e,t){var n,i,r;for(i=new G(t);i.a<i.c.c.length;)if(n=c(Q(i),19),St(e.a,n,n),St(e.b,n,n),r=wv(n),r.c.length!=0)for(e.d&&e.d.Fg(r),St(e.a,n,(ht(0,r.c.length),c(r.c[0],19))),St(e.b,n,c(Xe(r,r.c.length-1),19));kte(r).c.length!=0;)r=kte(r),e.d&&e.d.Fg(r),St(e.a,n,(ht(0,r.c.length),c(r.c[0],19))),St(e.b,n,c(Xe(r,r.c.length-1),19))}function uie(e,t,n){var i,r,o,a,d,b;if(t)if(n<=-1){if(i=_t(t.Ah(),-1-n),oe(i,104))return c(i,20);for(a=c(t.Jh(i),164),d=0,b=a.gc();d<b;++d)if(ve(a.Sl(d))===ve(e)&&(r=a.Rl(d),oe(r,104)&&(o=c(r,20),(o.Bb&nc)!=0)))return o;throw J(new oo("The containment feature could not be located"))}else return Hs(c(_t(e.Ah(),n),20));else return null}function FVt(e){var t,n,i,r,o,a,d,b,v,x;for(n=0,d=new G(e.d);d.a<d.c.c.length;)a=c(Q(d),108),a.i&&(a.i.c=n++);for(t=H2(kl,[Be,eh],[172,30],16,[n,n],2),x=e.d,r=0;r<x.c.length;r++)if(b=(ht(r,x.c.length),c(x.c[r],108)),b.i)for(o=r+1;o<x.c.length;o++)v=(ht(o,x.c.length),c(x.c[o],108)),v.i&&(i=jHt(b,v),t[b.i.c][v.i.c]=i,t[v.i.c][b.i.c]=i);return t}function FT(){FT=te,Ble=new Nm("ROOT_PROC",0),_9e=new Nm("FAN_PROC",1),I9e=new Nm("LEVEL_PROC",2),R9e=new Nm("NEIGHBORS_PROC",3),P9e=new Nm("LEVEL_HEIGHT",4),N9e=new Nm("DIRECTION_PROC",5),$9e=new Nm("NODE_POSITION_PROC",6),M9e=new Nm("COMPACTION_PROC",7),L9e=new Nm("LEVEL_COORDS",8),D9e=new Nm("GRAPH_BOUNDS_PROC",9),A9e=new Nm("DETREEIFYING_PROC",10)}function uye(e,t){var n,i,r,o,a,d,b,v,x,S;for(S=vo(t),v=null,r=!1,d=0,x=gc(S.a).i;d<x;++d)a=c(eL(S,d,(o=c(re(gc(S.a),d),88),b=o.c,oe(b,89)?c(b,29):(Mt(),rf))),29),n=uye(e,a),n.dc()||(v?(r||(r=!0,v=new VF(v)),v.Fc(n)):v=n);return i=uGt(e,t),i.dc()?v||(Ct(),Ct(),Rs):v?(r||(v=new VF(v)),v.Fc(i),v):i}function aie(e,t){var n,i,r,o,a,d,b,v,x,S;for(S=vo(t),v=null,i=!1,d=0,x=gc(S.a).i;d<x;++d)o=c(eL(S,d,(r=c(re(gc(S.a),d),88),b=r.c,oe(b,89)?c(b,29):(Mt(),rf))),29),n=aie(e,o),n.dc()||(v?(i||(i=!0,v=new VF(v)),v.Fc(n)):v=n);return a=PGt(e,t),a.dc()?v||(Ct(),Ct(),Rs):v?(i||(v=new VF(v)),v.Fc(a),v):a}function qVt(e,t){var n,i,r,o,a;for(e.c==null||e.c.length<t.c.length?e.c=ye(kl,eh,30,t.c.length,16,1):Zj(e.c),e.a=new Fe,i=0,a=new G(t);a.a<a.c.c.length;)r=c(Q(a),9),r.p=i++;for(n=new Ai,o=new G(t);o.a<o.c.c.length;)r=c(Q(o),9),e.c[r.p]||(Bet(e,r),n.b==0||(dn(n.b!=0),c(n.a.a.c,16)).gc()<e.a.c.length?ax(n,e.a):Es(n,e.a),e.a=new Fe);return n}function HVt(e,t,n,i){var r,o,a;R(i.d.i,(De(),Pi))==null?oi(t,Pe(di-(t.f.c+t.i.c)),new q2(new Ho(W(V(j9,1),s9,17,0,[i])))):(a=0,o=i.d.i,n?(r=c(R(e.c,np),15).a,a=r*c(R(o,(Ge(),zv)),15).a+c(R(o,Pi),15).a):a=c(R(i.d.i,Pi),15).a,jc(t,Pe(a))?Sr(c(Ut(t,Pe(a)),47),i):oi(t,Pe(a),new q2(new Ho(W(V(j9,1),s9,17,0,[i])))))}function WD(e,t,n){var i,r,o,a,d,b;if(oe(t,76))return Ns(e,t,n);for(d=null,o=null,i=c(e.g,123),a=0;a<e.i;++a)if(r=i[a],yi(t,r.kd())&&(o=r.Jk(),oe(o,104)&&(c(o,20).Bb&nc)!=0)){d=r;break}return d&&(wu(e.e)&&(b=o.Hk()?E0(e,4,o,t,null,$S(e,o,t,oe(o,104)&&(c(o,20).Bb&Is)!=0),!0):E0(e,o.rk()?2:1,o,t,o.gk(),-1,!0),n?n.lj(b):n=b),n=WD(e,d,n)),n}function QVt(e,t,n){var i,r,o,a;if(a=nl(e.e.Ah(),t),i=c(e.g,123),qs(),c(t,69).vk()){for(o=0;o<e.i;++o)if(r=i[o],a.$l(r.Jk())&&yi(r,n))return vv(e,o),!0}else if(n!=null){for(o=0;o<e.i;++o)if(r=i[o],a.$l(r.Jk())&&yi(n,r.kd()))return vv(e,o),!0}else for(o=0;o<e.i;++o)if(r=i[o],a.$l(r.Jk())&&r.kd()==null)return vv(e,o),!0;return!1}function dit(e,t,n,i){var r,o,a,d,b,v,x,S,M,L;for(a=$2(t.c,n,i),S=new G(t.a);S.a<S.c.c.length;){for(x=c(Q(S),9),ki(x.n,a),L=new G(x.j);L.a<L.c.c.length;)for(M=c(Q(L),12),o=new G(M.g);o.a<o.c.c.length;)for(r=c(Q(o),17),rv(r.a,a),d=c(R(r,(Ge(),ho)),79),d&&rv(d,a),v=new G(r.b);v.a<v.c.c.length;)b=c(Q(v),70),ki(b.n,a);qe(e.a,x),x.a=e}}function GVt(e,t){var n,i,r,o,a;if(t.Tg("Node and Port Label Placement and Node Sizing",1),L$e((s7(),new iee(e,!0,!0,new WV))),c(R(e,(De(),Lc)),24).Gc((Gs(),Ea)))for(o=c(R(e,(Ge(),Gv)),24),r=o.Gc((Ql(),RP)),a=et(Ze(R(e,$Se))),i=new G(e.b);i.a<i.c.c.length;)n=c(Q(i),26),lr(pi(new jt(null,new Tt(n.a,16)),new ZI),new Gze(o,r,a));t.Ug()}function git(e){Am(e,new mb(Em(Sm(Tm(jm(new b1,a9),"ELK SPOrE Overlap Removal"),'A node overlap removal algorithm proposed by Nachmanson et al. in "Node overlap removal by growing a tree".'),new gj))),Ie(e,a9,Nse,Ve(Eje)),Ie(e,a9,gw,Tje),Ie(e,a9,dw,8),Ie(e,a9,Lse,Ve(Bmt)),Ie(e,a9,Q4e,Ve(Sje)),Ie(e,a9,G4e,Ve(jje)),Ie(e,a9,AL,(Bt(),!1))}function UVt(e,t){var n,i,r,o,a,d,b;if(n=t.ni(e.a),n&&(b=zn(Zf((!n.b&&(n.b=new yu((Mt(),Bs),Yo,n)),n.b),_5e)),b!=null)){for(i=new Fe,o=xv(b,"\\w"),a=0,d=o.length;a<d;++a)r=o[a],Ot(r,"##other")?qe(i,"!##"+I7(e,Bu(t.ok()))):Ot(r,"##local")?i.c.push(null):Ot(r,RL)?qe(i,I7(e,Bu(t.ok()))):It(i.c,r);return i}return Ct(),Ct(),Rs}function zx(e,t,n,i){this.e=e,this.k=c(R(e,(De(),d3)),317),this.g=ye(e1,Hg,9,t,0,1),this.b=ye(kr,Be,347,t,7,1),this.a=ye(e1,Hg,9,t,0,1),this.d=ye(kr,Be,347,t,7,1),this.j=ye(e1,Hg,9,t,0,1),this.i=ye(kr,Be,347,t,7,1),this.p=ye(kr,Be,347,t,7,1),this.n=ye(ir,Be,476,t,8,1),n_(this.n,(Bt(),!1)),this.f=ye(ir,Be,476,t,8,1),n_(this.f,!0),this.o=n,this.c=i}function KD(e){var t,n,i,r,o,a,d,b;if(e.d)throw J(new oo((j1(nce),mre+nce.k+wre)));for(e.c==(Nr(),qh)&&Hx(e,go),n=new G(e.a.a);n.a<n.c.c.length;)t=c(Q(n),197),t.e=0;for(a=new G(e.a.b);a.a<a.c.c.length;)for(o=c(Q(a),84),o.o=Qr,r=o.f.Jc();r.Ob();)i=c(r.Pb(),84),++i.d.e;for(XZt(e),b=new G(e.a.b);b.a<b.c.c.length;)d=c(Q(b),84),d.k=!0;return e}function JVt(e,t){var n,i,r,o,a,d,b,v;for(d=new met(e),n=new Ai,tr(n,t,n.c.b,n.c);n.b!=0;){for(i=c(n.b==0?null:(dn(n.b!=0),ba(n,n.a.a)),114),i.d.p=1,a=new G(i.e);a.a<a.c.c.length;)r=c(Q(a),342),EZe(d,r),v=r.d,v.d.p==0&&tr(n,v,n.c.b,n.c);for(o=new G(i.b);o.a<o.c.c.length;)r=c(Q(o),342),EZe(d,r),b=r.c,b.d.p==0&&tr(n,b,n.c.b,n.c)}return d}function aye(e,t){var n,i,r,o,a,d,b;if(!e.e[t.p]){for(e.e[t.p]=!0,e.a[t.p]=!0,o=new wn,n=ve(R(e.c,(Ge(),jk)))===ve((D0(),$v)),ws($i(t),new zze(e,o,n)),a=new Mge(new an(o)),r=a.a.ec().Jc();r.Ob();)i=c(r.Pb(),15).a,d=c(c(Ut(o,Pe(i)),47).a.ec().Jc().Pb(),17),!vs(d)&&(b=d.d.i,e.a[b.p]?yr(e.b,c(Ut(o,Pe(i)),18)):aye(e,b));e.a[t.p]=!1}}function pit(e){var t,n,i,r,o;if(i=ue(he(ke(e,(Dn(),Dwt)))),i!=1)for(_m(e,i*e.g,i*e.f),n=F8t(bCt((!e.c&&(e.c=new Me(hu,e,9,9)),e.c),new XA)),o=Bd(ma(W(V(Ta,1),Lt,22,0,[(!e.n&&(e.n=new Me(Bo,e,1,7)),e.n),(!e.c&&(e.c=new Me(hu,e,9,9)),e.c),n])));hn(o);)r=c(sn(o),278),r.ph(i*r.mh(),i*r.nh()),r.oh(i*r.lh(),i*r.kh()),t=c(r.mf(w7e),8),t&&(t.a*=i,t.b*=i)}function fye(e,t,n){var i,r,o,a,d;if(a=(qs(),c(t,69).vk()),F1(e.e,t)){if(t.Qi()&&NQ(e,t,n,oe(t,104)&&(c(t,20).Bb&Is)!=0))return!1}else for(d=nl(e.e.Ah(),t),i=c(e.g,123),o=0;o<e.i;++o)if(r=i[o],d.$l(r.Jk()))return(a?yi(r,n):n==null?r.kd()==null:yi(n,r.kd()))?!1:(c(Dx(e,o,a?c(n,76):Fd(t,n)),76),!0);return Nn(e,a?c(n,76):Fd(t,n))}function XVt(e,t,n,i,r){var o,a,d,b,v,x,S,M;for(a=new G(e.b);a.a<a.c.c.length;)for(o=c(Q(a),26),M=q_(o.a),v=M,x=0,S=v.length;x<S;++x)switch(b=v[x],c(R(b,(Ge(),Ro)),166).g){case 1:pXt(b),zr(b,t),hYe(b,!0,i);break;case 3:ZJt(b),zr(b,n),hYe(b,!1,r)}for(d=new os(e.b,0);d.b<d.d.gc();)(dn(d.b<d.d.gc()),c(d.d.Xb(d.c=d.b++),26)).a.c.length==0&&iu(d)}function VVt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H;for(L=t.length,b=L,en(0,t.length),t.charCodeAt(0)==45?(S=-1,M=1,--L):(S=1,M=0),o=(vie(),Qat)[10],r=L/o|0,H=L%o,H!=0&&++r,d=ye(Fn,ci,30,r,15,1),n=Hat[8],a=0,P=M+(H==0?o:H),z=M;z<b;z=P,P=z+o)i=Hu((fs(z,P,t.length),t.substr(z,P-z)),ls,di),v=(PS(),Uwe(d,d,a,n)),v+=lBt(d,a,i),d[a++]=v;x=a,e.e=S,e.d=x,e.a=d,V7(e)}function WVt(e){var t,n,i,r,o,a,d,b,v,x,S,M;for(d=e.i,r=et(Ze(R(d,(Ge(),qv)))),x=0,i=0,v=new G(e.g);v.a<v.c.c.length;)b=c(Q(v),17),a=vs(b),o=a&&r&&et(Ze(R(b,Lb))),M=b.d.i,a&&o?++i:a&&!o?++x:Jr(M).e==d?++i:++x;for(n=new G(e.e);n.a<n.c.c.length;)t=c(Q(n),17),a=vs(t),o=a&&r&&et(Ze(R(t,Lb))),S=t.c.i,a&&o?++x:a&&!o?++i:Jr(S).e==d?++x:++i;return x-i}function bit(e,t){var n,i,r,o,a,d;if(!t.dc())if(c(t.Xb(0),295).d==(H5(),Rv))RFt(e,t);else for(i=t.Jc();i.Ob();){switch(n=c(i.Pb(),295),n.d.g){case 5:AS(e,n,Q$t(e,n));break;case 0:AS(e,n,(a=n.f-n.c+1,d=(a-1)/2|0,n.c+d));break;case 4:AS(e,n,iPt(e,n));break;case 2:wKe(n),AS(e,n,(o=j2e(n),o?n.c:n.f));break;case 1:wKe(n),AS(e,n,(r=j2e(n),r?n.f:n.c))}CHt(n.a)}}function hye(e,t,n,i){var r,o,a;return a=new gIe(t,n),e.a?i?(r=c(za(c(Ut(e.b,t),263)),263),++r.a,a.d=i.d,a.e=i.e,a.b=i,a.c=i,i.e?i.e.c=a:r.b=a,i.d?i.d.b=a:e.a=a,i.d=a,i.e=a):(c(za(e.e),501).b=a,a.d=e.e,e.e=a,r=c(Ut(e.b,t),263),r?(++r.a,o=r.c,o.c=a,a.e=o,r.c=a):(oi(e.b,t,r=new Mpe(a)),++e.c)):(e.a=e.e=a,oi(e.b,t,new Mpe(a)),++e.c),++e.d,a}function fie(e,t){var n,i,r,o,a;if(t.Tg("Network simplex",1),e.e.a.c.length<1){t.Ug();return}for(o=new G(e.e.a);o.a<o.c.c.length;)r=c(Q(o),126),r.e=0;for(a=e.e.a.c.length>=40,a&&$Wt(e),YKt(e),mXt(e),n=YWe(e),i=0;n&&i<e.f;)tWt(e,n,yUt(e,n)),n=YWe(e),++i;a&&Vqt(e),e.a?NUt(e,uit(e)):uit(e),e.b=null,e.d=null,e.p=null,e.c=null,e.g=null,e.i=null,e.n=null,e.o=null,t.Ug()}function KVt(e,t){var n,i,r,o,a,d,b;if(!t.e){for(t.e=!0,i=t.d.a.ec().Jc();i.Ob();){if(n=c(i.Pb(),17),t.o&&t.d.a.gc()<=1){a=t.a.c,d=t.a.c+t.a.b,b=new $e(a+(d-a)/2,t.b),ei(c(t.d.a.ec().Jc().Pb(),17).a,b);continue}if(r=c(Ut(t.c,n),460),r.b||r.c){$Vt(e,n,t);continue}o=e.d==(dS(),cC)&&(r.d||r.e)&&QGt(e,t)&&t.d.a.gc()<=1,o?DZt(n,t):VXt(e,n,t)}t.k&&ws(t.d,new $M)}}function dye(e,t,n,i,r,o){var a,d,b,v,x,S,M,L,P,z,H,X,ie,se;for(M=o,d=(i+r)/2+M,H=n*p.Math.cos(d),X=n*p.Math.sin(d),ie=H-t.g/2,se=X-t.f/2,Cc(t,ie),Nl(t,se),S=e.a.Dg(t),z=2*p.Math.acos(n/n+e.c),z<r-i?(L=z/S,a=(i+r-z)/2):(L=(r-i)/S,a=i),P=wv(t),e.e&&(e.e.Eg(e.d),e.e.Fg(P)),v=new G(P);v.a<v.c.c.length;)b=c(Q(v),19),x=e.a.Dg(b),dye(e,b,n+e.c,a,a+L*x,o),a+=L*x}function YVt(e,t,n){var i;switch(i=n.q.getMonth(),t){case 5:Zn(e,W(V(nt,1),Be,2,6,["J","F","M","A","M","J","J","A","S","O","N","D"])[i]);break;case 4:Zn(e,W(V(nt,1),Be,2,6,[Qie,Gie,Uie,Jie,Z5,Xie,Vie,Wie,Kie,Yie,Zie,ere])[i]);break;case 3:Zn(e,W(V(nt,1),Be,2,6,["Jan","Feb","Mar","Apr",Z5,"Jun","Jul","Aug","Sep","Oct","Nov","Dec"])[i]);break;default:qd(e,i+1,t)}}function ZVt(e,t,n,i){var r,o,a,d,b,v,x,S,M;for(b=new $e(n,i),Hr(b,c(R(t,(N0(),DE)),8)),M=new G(t.e);M.a<M.c.c.length;)S=c(Q(M),156),ki(S.d,b),qe(e.e,S);for(d=new G(t.c);d.a<d.c.c.length;){for(a=c(Q(d),292),o=new G(a.a);o.a<o.c.c.length;)r=c(Q(o),254),ki(r.d,b);qe(e.c,a)}for(x=new G(t.d);x.a<x.c.c.length;)v=c(Q(x),448),ki(v.d,b),qe(e.d,v)}function gye(e,t){var n,i,r,o,a,d,b,v;for(b=new G(t.j);b.a<b.c.c.length;)for(d=c(Q(b),12),r=new kh(d.b);No(r.a)||No(r.b);)i=c(No(r.a)?Q(r.a):Q(r.b),17),n=i.c==d?i.d:i.c,o=n.i,t!=o&&(v=c(R(i,(Ge(),z9)),15).a,v<0&&(v=0),a=o.p,e.c[a]==0&&(i.d==n?(e.a[a]-=v+1,e.a[a]<=0&&e.d[a]>0&&ei(e.g,o)):(e.d[a]-=v+1,e.d[a]<=0&&e.a[a]>0&&ei(e.f,o))))}function mit(e,t,n,i){var r,o,a,d,b,v,x;for(b=new $e(n,i),Hr(b,c(R(t,(Li(),G9)),8)),x=_n(t.b,0);x.b!=x.d.c;)v=c(An(x),41),ki(v.e,b),ei(e.b,v);for(d=c(ql($pe(new jt(null,new Tt(t.a,16))),su(new Ls,new rs,new mo,W(V(ml,1),_e,132,0,[(va(),bl)]))),16).Jc();d.Ob();){for(a=c(d.Pb(),65),o=_n(a.a,0);o.b!=o.d.c;)r=c(An(o),8),r.a+=b.a,r.b+=b.b;ei(e.a,a)}}function pye(e,t){var n,i,r,o;if(0<(oe(e,18)?c(e,18).gc():Vf(e.Jc()))){if(r=t,1<r){for(--r,o=new p1,i=e.Jc();i.Ob();)n=c(i.Pb(),41),o=ma(W(V(Ta,1),Lt,22,0,[o,new k1(n)]));return pye(o,r)}if(r<0){for(o=new Nu,i=e.Jc();i.Ob();)n=c(i.Pb(),41),o=ma(W(V(Ta,1),Lt,22,0,[o,new k1(n)]));if(0<(oe(o,18)?c(o,18).gc():Vf(o.Jc())))return pye(o,r)}}return c(kF(e.Jc()),41)}function eWt(e,t,n){var i,r,o,a;for(n.Tg("Processor order nodes",2),e.b=ue(he(R(t,(Uo(),Vle)))),e.a=c(R(t,Iw),87),e.a==(Nr(),qh)&&(e.a=Fh,Ee(t,Iw,e.a)),r=new Ai,a=_n(t.b,0);a.b!=a.d.c;)o=c(An(a),41),et(Ze(R(o,(Li(),cp))))&&tr(r,o,r.c.b,r.c);i=(dn(r.b!=0),c(r.a.a.c,41)),grt(e,i),n.eh(1),sye(e,i,0-ue(he(R(i,(Li(),SJ))))/2,0),n.eh(1),n.Ug()}function uu(){uu=te,s8=new ux("DEFAULT_MINIMUM_SIZE",0),qP=new ux("MINIMUM_SIZE_ACCOUNTS_FOR_PADDING",1),YJ=new ux("COMPUTE_PADDING",2),zC=new ux("OUTSIDE_NODE_LABELS_OVERHANG",3),ZJ=new ux("PORTS_OVERHANG",4),tX=new ux("UNIFORM_PORT_SPACING",5),eX=new ux("SPACE_EFFICIENT_PORT_LABELS",6),pae=new ux("FORCE_TABULAR_NODE_LABELS",7),FP=new ux("ASYMMETRICAL",8)}function hie(e,t){var n,i,r,o,a,d,b,v;if(t){if(n=(o=t.Ah(),o?Bu(o).ti().pi(o):null),n){for(gb(e,t,n),r=t.Ah(),b=0,v=(r.i==null&&ud(r),r.i).length;b<v;++b)d=(i=(r.i==null&&ud(r),r.i),b>=0&&b<i.length?i[b]:null),d.pk()&&!d.qk()&&(oe(d,336)?bzt(e,c(d,38),t,n):(a=c(d,20),(a.Bb&nc)!=0&&Tqt(e,a,t,n)));t.Sh()&&c(n,52).bi(c(t,52).Yh())}return n}else return null}function tWt(e,t,n){var i,r,o;if(!t.f)throw J(new qt("Given leave edge is no tree edge."));if(n.f)throw J(new qt("Given enter edge is a tree edge already."));for(t.f=!1,bge(e.p,t),n.f=!0,Sr(e.p,n),i=n.e.e-n.d.e-n.a,Jne(e,n.e,t)||(i=-i),o=new G(e.e.a);o.a<o.c.c.length;)r=c(Q(o),126),Jne(e,r,t)||(r.e+=i);e.j=1,Zj(e.c),fve(e,c(Q(new G(e.e.a)),126)),Trt(e)}function wit(e,t){var n,i,r,o,a,d;if(d=c(R(t,(Ge(),cr)),103),d==(Zr(),r1)||d==xc)for(r=new $e(t.f.a+t.d.b+t.d.c,t.f.b+t.d.d+t.d.a).b,a=new G(e.a);a.a<a.c.c.length;)o=c(Q(a),9),o.k==(Jt(),Cr)&&(n=c(R(o,(De(),Ko)),64),!(n!=(Je(),nn)&&n!=Yt)&&(i=ue(he(R(o,Aw))),d==r1&&(i*=r),o.n.b=i-c(R(o,Lw),8).b,xH(o,!1,!0)))}function vit(e,t,n,i,r){n&&(!i||(e.c-e.b&e.a.length-1)>1)&&t==1&&c(e.a[e.b],9).k==(Jt(),lc)?W5(c(e.a[e.b],9),(qu(),n1)):i&&(!n||(e.c-e.b&e.a.length-1)>1)&&t==1&&c(e.a[e.c-1&e.a.length-1],9).k==(Jt(),lc)?W5(c(e.a[e.c-1&e.a.length-1],9),(qu(),up)):(e.c-e.b&e.a.length-1)==2?(W5(c(aT(e),9),(qu(),n1)),W5(c(aT(e),9),up)):LUt(e,r),sbe(e)}function nWt(e){var t,n,i,r,o,a,d,b;for(b=new wn,t=new zK,a=e.Jc();a.Ob();)r=c(a.Pb(),9),d=Dm(ZN(new Fp,r),t),gl(b.f,r,d);for(o=e.Jc();o.Ob();)for(r=c(o.Pb(),9),i=new Ht(Vt($i(r).a.Jc(),new U));hn(i);)n=c(sn(i),17),!vs(n)&&Of(uf(ff(af(hf(new Ra,p.Math.max(1,c(R(n,(Ge(),zSe)),15).a)),1),c(Ut(b,n.c.i),126)),c(Ut(b,n.d.i),126)));return t}function yit(e,t,n,i){var r,o,a,d,b,v,x,S,M,L;if(TPt(e,t,n),o=t[n],L=i?(Je(),Yt):(Je(),nn),Ijt(t.length,n,i)){for(r=t[i?n-1:n+1],Obe(e,r,i?(Qs(),Wc):(Qs(),Jl)),b=o,x=0,M=b.length;x<M;++x)a=b[x],Wwe(e,a,L);for(Obe(e,o,i?(Qs(),Jl):(Qs(),Wc)),d=r,v=0,S=d.length;v<S;++v)a=d[v],a.e||Wwe(e,a,jD(L))}else for(d=o,v=0,S=d.length;v<S;++v)a=d[v],Wwe(e,a,L);return!1}function iWt(e,t,n,i,r){var o,a,d,b,v,x,S;for(Ct(),Rr(e,new qW),d=new os(e,0),S=new Fe,o=0;d.b<d.d.gc();)a=(dn(d.b<d.d.gc()),c(d.d.Xb(d.c=d.b++),168)),S.c.length!=0&&Ml(a)*ku(a)>o*2?(x=new eH(S),v=Ml(a)/ku(a),b=_ie(x,t,new X4,n,i,r,v),ki(Xf(x.e),b),S.c.length=0,o=0,It(S.c,x),It(S.c,a),o=Ml(x)*ku(x)+Ml(a)*ku(a)):(It(S.c,a),o+=Ml(a)*ku(a));return S}function rWt(e,t){var n,i,r,o,a,d,b;for(t.Tg("Port order processing",1),b=c(R(e,(Ge(),BSe)),426),i=new G(e.b);i.a<i.c.c.length;)for(n=c(Q(i),26),o=new G(n.a);o.a<o.c.c.length;)r=c(Q(o),9),a=c(R(r,cr),103),d=r.j,a==(Zr(),Hb)||a==r1||a==xc?(Ct(),Rr(d,POe)):a!=Hh&&a!=fp&&(Ct(),Rr(d,tdt),Czt(d),b==(rD(),Nle)&&Rr(d,edt)),r.i=!0,lve(r);t.Ug()}function sWt(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P;if(wu(e.e)){if(t!=n&&(r=c(e.g,123),L=r[n],a=L.Jk(),F1(e.e,a))){for(P=nl(e.e.Ah(),a),b=-1,d=-1,i=0,v=0,S=t>n?t:n;v<=S;++v)v==n?d=i++:(o=r[v],x=P.$l(o.Jk()),v==t&&(b=v==S&&!x?i-1:i),x&&++i);return M=c(vT(e,t,n),76),d!=b&&b6(e,new W_(e.e,7,a,Pe(d),L.kd(),b)),M}}else return c(Vne(e,t,n),76);return c(vT(e,t,n),76)}function bye(e,t){var n,i,r,o,a,d,b,v,x,S;for(S=0,o=new bx,C0(o,t);o.b!=o.c;)for(b=c(w5(o),221),v=0,x=c(R(t.j,(Ge(),t1)),270),c(R(t.j,VE),330),a=ue(he(R(t.j,sP))),d=ue(he(R(t.j,ele))),x!=(B1(),rp)&&(v+=a*FUt(t.j,b.e,x),v+=d*TVt(t.j,b.e)),S+=PYe(b.d,b.e)+v,r=new G(b.b);r.a<r.c.c.length;)i=c(Q(r),37),n=c(Xe(e.b,i.p),221),n.s||(S+=dQ(e,n));return S}function xit(){xit=te,ypt=Wn(new wr,(es(),yc),(cs(),yOe)),E9e=Wn(new wr,vc,gU),kpt=Fc(Wn(new wr,vc,kU),Vs,xU),vpt=Fc(Wn(Wn(new wr,vc,pOe),yc,bOe),Vs,mOe),Opt=cd(cd(u7(Fc(Wn(new wr,Cf,TU),Vs,jU),yc),SU),EU),xpt=Fc(new wr,Vs,xOe),mpt=Fc(Wn(Wn(Wn(new wr,Zd,bU),yc,wU),yc,T9),Vs,mU),wpt=Fc(Wn(Wn(new wr,yc,T9),yc,dU),Vs,hU)}function oWt(e,t,n,i,r,o){var a,d,b,v,x,S,M;for(v=KVe(t)-KVe(e),a=VZe(t,v),b=el(0,0,0);v>=0&&(d=dFt(e,a),!(d&&(v<22?b.l|=1<<v:v<44?b.m|=1<<v-22:b.h|=1<<v-44,e.l==0&&e.m==0&&e.h==0)));)x=a.m,S=a.h,M=a.l,a.h=S>>>1,a.m=x>>>1|(S&1)<<21,a.l=M>>>1|(x&1)<<21,--v;return n&&jte(b),o&&(i?(W0=uS(e),r&&(W0=AVe(W0,(Z6(),X5e)))):W0=el(e.l,e.m,e.h)),b}function cWt(e,t){var n,i,r,o,a,d,b,v,x,S;for(v=e.e[t.c.p][t.p]+1,b=t.c.a.c.length+1,d=new G(e.a);d.a<d.c.c.length;){for(a=c(Q(d),12),S=0,o=0,r=Bd(ma(W(V(Ta,1),Lt,22,0,[new p6(a),new Q4(a)])));hn(r);)i=c(sn(r),12),i.i.c==t.c&&(S+=Mjt(e,i.i)+1,++o);n=S/o,x=a.j,x==(Je(),nn)?n<v?e.f[a.p]=e.c-n:e.f[a.p]=e.b+(b-n):x==Yt&&(n<v?e.f[a.p]=e.b+n:e.f[a.p]=e.c-(b-n))}}function Hu(e,t,n){var i,r,o,a,d;if(e==null)throw J(new Yh(pl));for(o=e.length,a=o>0&&(en(0,e.length),e.charCodeAt(0)==45||(en(0,e.length),e.charCodeAt(0)==43))?1:0,i=a;i<o;i++)if(PKe((en(i,e.length),e.charCodeAt(i)))==-1)throw J(new Yh(hw+e+'"'));if(d=parseInt(e,10),r=d<t,isNaN(d))throw J(new Yh(hw+e+'"'));if(r||d>n)throw J(new Yh(hw+e+'"'));return d}function lWt(e){var t,n,i,r,o,a,d;for(a=new Ai,o=new G(e.a);o.a<o.c.c.length;)r=c(Q(o),117),BN(r,r.f.c.length),u6(r,r.k.c.length),r.i==0&&(r.o=0,tr(a,r,a.c.b,a.c));for(;a.b!=0;)for(r=c(a.b==0?null:(dn(a.b!=0),ba(a,a.a.a)),117),i=r.o+1,n=new G(r.f);n.a<n.c.c.length;)t=c(Q(n),135),d=t.a,a6(d,p.Math.max(d.o,i)),u6(d,d.i-1),d.i==0&&tr(a,d,a.c.b,a.c)}function uWt(e){var t,n,i,r,o,a,d,b;for(a=new G(e);a.a<a.c.c.length;){for(o=c(Q(a),74),i=to(c(re((!o.b&&(o.b=new Et(vn,o,4,7)),o.b),0),83)),d=i.i,b=i.j,r=c(re((!o.a&&(o.a=new Me(Hi,o,6,6)),o.a),0),171),m_(r,r.j+d,r.k+b),b_(r,r.b+d,r.c+b),n=new cn((!r.a&&(r.a=new Ar(Yu,r,5)),r.a));n.e!=n.i.gc();)t=c(un(n),373),YY(t,t.a+d,t.b+b);wme(c(ke(o,(Dn(),T3)),79),d,b)}}function RS(e){var t;switch(e){case 100:return Qx(TE,!0);case 68:return Qx(TE,!1);case 119:return Qx(poe,!0);case 87:return Qx(poe,!1);case 115:return Qx(boe,!0);case 83:return Qx(boe,!1);case 99:return Qx(moe,!0);case 67:return Qx(moe,!1);case 105:return Qx(woe,!0);case 73:return Qx(woe,!1);default:throw J(new Mo((t=e,gat+t.toString(16))))}}function aWt(e){var t,n,i,r,o;switch(r=c(Xe(e.a,0),9),t=new Eh(e),qe(e.a,t),t.o.a=p.Math.max(1,r.o.a),t.o.b=p.Math.max(1,r.o.b),t.n.a=r.n.a,t.n.b=r.n.b,c(R(r,(De(),Ko)),64).g){case 4:t.n.a+=2;break;case 1:t.n.b+=2;break;case 2:t.n.a-=2;break;case 3:t.n.b-=2}return i=new bc,_o(i,t),n=new qm,o=c(Xe(r.j,0),12),ks(n,o),ss(n,i),ki(Xf(i.n),o.n),ki(Xf(i.a),o.a),t}function ka(e,t,n,i){var r,o,a,d,b,v,x,S,M,L;for(r=t,d=n,i<0&&(r=n,d=t),o=c(Ut(e.a,r),47),b=c(Ut(e.a,d),47),a=c(Ut(e.e,r),47),v=c(Ut(e.e,d),47),o.a.yc(d,o),v.a.yc(r,v),L=b.a.ec().Jc();L.Ob();)M=c(L.Pb(),12),o.a.yc(M,o),Sr(c(Ut(e.e,M),47),r),Os(c(Ut(e.e,M),47),a);for(S=a.a.ec().Jc();S.Ob();)x=c(S.Pb(),12),v.a.yc(x,v),Sr(c(Ut(e.a,x),47),d),Os(c(Ut(e.a,x),47),b)}function fWt(e,t,n){var i,r,o,a,d;for(o=0,r=new cn((!e.a&&(e.a=new Me(Mn,e,10,11)),e.a));r.e!=r.i.gc();)i=c(un(r),19),a="",(!i.n&&(i.n=new Me(Bo,i,1,7)),i.n).i==0||(a=c(re((!i.n&&(i.n=new Me(Bo,i,1,7)),i.n),0),158).a),d=new Ete(o++,t,a),ec(d,i),Ee(d,(Li(),pC),i),d.e.b=i.j+i.f/2,d.f.a=p.Math.max(i.g,1),d.e.a=i.i+i.g/2,d.f.b=p.Math.max(i.f,1),ei(t.b,d),gl(n.f,i,d)}function mye(e,t,n){var i,r,o,a;if(t[0]>=e.length)return n.o=0,!0;switch(ms(e,t[0])){case 43:r=1;break;case 45:r=-1;break;default:return n.o=0,!0}if(++t[0],o=t[0],a=gQ(e,t),a==0&&t[0]==o)return!1;if(t[0]<e.length&&ms(e,t[0])==58){if(i=a*60,++t[0],o=t[0],a=gQ(e,t),a==0&&t[0]==o)return!1;i+=a}else i=a,i<24&&t[0]-o<=2?i*=60:i=i%100+(i/100|0)*60;return i*=r,n.o=-i,!0}function hWt(e){var t,n,i,r,o,a,d,b,v;for(a=new Fe,i=new Ht(Vt($i(e.b).a.Jc(),new U));hn(i);)n=c(sn(i),17),vs(n)&&qe(a,new uUe(n,VUe(e,n.c),VUe(e,n.d)));for(v=(o=new x1(e.e).a.vc().Jc(),new C2(o));v.a.Ob();)d=(t=c(v.a.Pb(),45),c(t.kd(),114)),d.d.p=0;for(b=(r=new x1(e.e).a.vc().Jc(),new C2(r));b.a.Ob();)d=(t=c(b.a.Pb(),45),c(t.kd(),114)),d.d.p==0&&qe(e.d,JVt(e,d))}function dWt(e,t){var n,i,r,o,a,d,b,v,x;for(a=new G(t.b);a.a<a.c.c.length;)for(o=c(Q(a),26),v=new G(o.a);v.a<v.c.c.length;){for(b=c(Q(v),9),x=new Fe,d=0,i=new Ht(Vt(pr(b).a.Jc(),new U));hn(i);)n=c(sn(i),17),!(vs(n)||!vs(n)&&n.c.i.c==n.d.i.c)&&(r=c(R(n,(Ge(),Ek)),15).a,r>d&&(d=r,x.c.length=0),r==d&&qe(x,new Ps(n.c.i,n)));Ct(),Rr(x,e.c),Up(e.b,b.p,x)}}function gWt(e,t){var n,i,r,o,a,d,b,v,x;for(a=new G(t.b);a.a<a.c.c.length;)for(o=c(Q(a),26),v=new G(o.a);v.a<v.c.c.length;){for(b=c(Q(v),9),x=new Fe,d=0,i=new Ht(Vt($i(b).a.Jc(),new U));hn(i);)n=c(sn(i),17),!(vs(n)||!vs(n)&&n.c.i.c==n.d.i.c)&&(r=c(R(n,(Ge(),Ek)),15).a,r>d&&(d=r,x.c.length=0),r==d&&qe(x,new Ps(n.d.i,n)));Ct(),Rr(x,e.c),Up(e.f,b.p,x)}}function pWt(e){var t,n,i,r,o,a,d;for(o=yh(e),r=new cn((!e.e&&(e.e=new Et(Ii,e,7,4)),e.e));r.e!=r.i.gc();)if(i=c(un(r),74),d=to(c(re((!i.c&&(i.c=new Et(vn,i,5,8)),i.c),0),83)),!nv(d,o))return!0;for(n=new cn((!e.d&&(e.d=new Et(Ii,e,8,5)),e.d));n.e!=n.i.gc();)if(t=c(un(n),74),a=to(c(re((!t.b&&(t.b=new Et(vn,t,4,7)),t.b),0),83)),!nv(a,o))return!0;return!1}function bWt(e){var t,n,i,r,o;i=c(R(e,(De(),Oi)),19),o=c(ke(i,(Ge(),Pb)),185).Gc((Cu(),Qb)),e.e||(r=c(R(e,Lc),24),t=new $e(e.f.a+e.d.b+e.d.c,e.f.b+e.d.d+e.d.a),r.Gc((Gs(),Ea))?(ii(i,cr,(Zr(),xc)),uw(i,t.a,t.b,!1,!0)):et(Ze(ke(i,hle)))||uw(i,t.a,t.b,!0,!0)),o?ii(i,Pb,gt(Qb)):ii(i,Pb,(n=c(Jf(BC),10),new ha(n,c(gf(n,n.length),10),0)))}function mWt(e,t){var n,i,r,o,a,d,b,v;if(v=Ze(R(t,(Uo(),rbt))),v==null||(zt(v),v)){for(HGt(e,t),r=new Fe,b=_n(t.b,0);b.b!=b.d.c;)a=c(An(b),41),n=eve(e,a,null),n&&(ec(n,t),It(r.c,n));if(e.a=null,e.b=null,r.c.length>1)for(i=new G(r);i.a<i.c.c.length;)for(n=c(Q(i),121),o=0,d=_n(n.b,0);d.b!=d.d.c;)a=c(An(d),41),a.g=o++;return r}return mf(W(V(Ztn,1),Mot,121,0,[t]))}function wWt(e,t){var n,i,r,o,a,d;for(r=new G(t.a);r.a<r.c.c.length;)i=c(Q(r),9),o=R(i,(De(),Oi)),oe(o,12)&&(a=c(o,12),d=Fit(t,i,a.o.a,a.o.b),a.n.a=d.a,a.n.b=d.b,$r(a,c(R(i,Ko),64)));n=new $e(t.f.a+t.d.b+t.d.c,t.f.b+t.d.d+t.d.a),c(R(t,(De(),Lc)),24).Gc((Gs(),Ea))?(Ee(e,(Ge(),cr),(Zr(),xc)),c(R(Jr(e),Lc),24).Ec(P9),Nrt(e,n,!1)):Nrt(e,n,!0)}function vWt(e){var t,n,i,r,o,a,d,b;for(b=new nu,t=_n(e,0),d=null,n=c(An(t),8),r=c(An(t),8);t.b!=t.d.c;)d=n,n=r,r=c(An(t),8),o=uXe(Hr(new $e(d.a,d.b),n)),a=uXe(Hr(new $e(r.a,r.b),n)),i=10,i=p.Math.min(i,p.Math.abs(o.a+o.b)/2),i=p.Math.min(i,p.Math.abs(a.a+a.b)/2),o.a=D_(o.a)*i,o.b=D_(o.b)*i,a.a=D_(a.a)*i,a.b=D_(a.b)*i,ei(b,ki(o,n)),ei(b,ki(a,n));return b}function yWt(e,t,n){var i,r,o,a,d,b;if(n.Tg("Minimize Crossings "+e.a,1),i=t.b.c.length==0||!k6(pi(new jt(null,new Tt(t.b,16)),new d6(new fA))).zd((Hp(),hk)),b=t.b.c.length==1&&c(Xe(t.b,0),26).a.c.length==1,o=ve(R(t,(Ge(),Fv)))===ve((R1(),Zg)),i||b&&!o){n.Ug();return}r=aXt(e,t),a=(d=c(pc(r,0),221),d.c.ig()?d.c.cg()?new a_e(e):new f_e(e):new u_e(e)),kRt(r,a),YRt(e),n.Ug()}function Qu(e,t,n,i){var r,o,a,d,b;return a=e.Mh(),b=e.Gh(),r=null,b?t&&(uie(e,t,n).Bb&Is)==0?(i=Ns(b.Cl(),e,i),e.ai(null),r=t.Nh()):b=null:(a&&(b=a.Nh()),t&&(r=t.Nh())),b!=r&&b&&b.Gl(e),d=e.Ch(),e.yh(t,n),b!=r&&r&&r.Fl(e),e.sh()&&e.th()&&(a&&d>=0&&d!=n&&(o=new Ur(e,1,d,a,null),i?i.lj(o):i=o),n>=0&&(o=new Ur(e,1,n,d==n?a:null,t),i?i.lj(o):i=o)),i}function kit(e){var t,n,i;if(e.b==null){if(i=new yg,e.i!=null&&(Ys(i,e.i),i.a+=":"),(e.f&256)!=0){for((e.f&256)!=0&&e.a!=null&&(gAt(e.i)||(i.a+="//"),Ys(i,e.a)),e.d!=null&&(i.a+="/",Ys(i,e.d)),(e.f&16)!=0&&(i.a+="/"),t=0,n=e.j.length;t<n;t++)t!=0&&(i.a+="/"),Ys(i,e.j[t]);e.g!=null&&(i.a+="?",Ys(i,e.g))}else Ys(i,e.a);e.e!=null&&(i.a+="#",Ys(i,e.e)),e.b=i.a}return e.b}function xWt(e,t,n,i,r){var o,a,d,b;o=new Eh(e),mu(o,(Jt(),Dc)),Ee(o,(Ge(),cr),(Zr(),xc)),Ee(o,(De(),Oi),t.c.i),a=new bc,Ee(a,Oi,t.c),$r(a,r),_o(a,o),Ee(t.c,Ul,o),d=new Eh(e),mu(d,Dc),Ee(d,cr,xc),Ee(d,Oi,t.d.i),b=new bc,Ee(b,Oi,t.d),$r(b,r),_o(b,d),Ee(t.d,Ul,d),ks(t,a),ss(t,b),K2(0,n.c.length),h7(n.c,0,o),It(i.c,d),Ee(o,HU,Pe(1)),Ee(d,HU,Pe(1))}function kWt(e,t,n,i){var r,o,a,d,b;if(b=Hn(Ss(Xd,zd(Hn(Ss(t==null?0:Ri(t),Vd)),15))),r=Hn(Ss(Xd,zd(Hn(Ss(n==null?0:Ri(n),Vd)),15))),d=cT(e,t,b),a=oT(e,n,r),d&&r==d.a&&T1(n,d.g))return n;if(a)throw J(new qt("key already present: "+n));return d&&Bx(e,d),a&&Bx(e,a),o=new aq(n,r,t,b),FD(e,o,a),a&&(a.e=null,a.c=null),d&&(d.e=null,d.c=null),tZe(e),d?d.g:null}function Oit(e,t,n){var i,r,o,a,d;for(o=0;o<t;o++){for(i=0,d=o+1;d<t;d++)i=As(As(Ss(Yr(e[o],Us),Yr(e[d],Us)),Yr(n[o+d],Us)),Yr(Hn(i),Us)),n[o+d]=Hn(i),i=Vp(i,32);n[o+t]=Hn(i)}for(cIt(n,n,t<<1),i=0,r=0,a=0;r<t;++r,a++)i=As(As(Ss(Yr(e[r],Us),Yr(e[r],Us)),Yr(n[a],Us)),Yr(Hn(i),Us)),n[a]=Hn(i),i=Vp(i,32),++a,i=As(i,Yr(n[a],Us)),n[a]=Hn(i),i=Vp(i,32);return n}function Sit(e,t,n){var i,r,o,a,d,b,v,x;if(!Y2(t)){for(b=ue(he(av(n.c,(Ge(),tC)))),v=c(av(n.c,aP),125),!v&&(v=new Vj),i=n.a,r=null,d=t.Jc();d.Ob();)a=c(d.Pb(),12),x=0,r?(x=b,x+=r.o.b):x=v.d,o=Dm(ZN(new Fp,a),e.f),oi(e.k,a,o),Of(uf(ff(af(hf(new Ra,0),xs(p.Math.ceil(x))),i),o)),r=a,i=o;Of(uf(ff(af(hf(new Ra,0),xs(p.Math.ceil(v.a+r.o.b))),i),n.d))}}function OWt(e,t,n,i,r,o,a,d){var b,v,x,S,M,L;return L=!1,M=o-n.s,x=n.t-t.f+(v=UT(n,M,!1),v.a),i.g+d>M?!1:(S=(b=UT(i,M,!1),b.a),x+d+S<=t.b&&(K_(n,o-n.s),n.c=!0,K_(i,o-n.s),AD(i,n.s,n.t+n.d+d),i.k=!0,yme(n.q,i),L=!0,r&&(oH(t,i),i.j=t,e.c.length>a&&(LD((ht(a,e.c.length),c(e.c[a],189)),i),(ht(a,e.c.length),c(e.c[a],189)).a.c.length==0&&Mg(e,a)))),L)}function SWt(e,t){var n,i,r,o,a,d;if(t.Tg("Partition midprocessing",1),r=new Qm,lr(pi(new jt(null,new Tt(e.a,16)),new jO),new TNe(r)),r.d!=0){for(d=c(ql(Fpe((o=r.i,new jt(null,(o||(r.i=new wx(r,r.c))).Lc()))),su(new Ls,new rs,new mo,W(V(ml,1),_e,132,0,[(va(),bl)]))),16),i=d.Jc(),n=c(i.Pb(),15);i.Ob();)a=c(i.Pb(),15),bJt(c(Si(r,n),24),c(Si(r,a),24)),n=a;t.Ug()}}function qT(e,t){var n,i,r,o,a;if(e.Ab){if(e.Ab){if(a=e.Ab.i,a>0){if(r=c(e.Ab.g,2012),t==null){for(o=0;o<a;++o)if(n=r[o],n.d==null)return n}else for(o=0;o<a;++o)if(n=r[o],Ot(t,n.d))return n}}else if(t==null){for(i=new cn(e.Ab);i.e!=i.i.gc();)if(n=c(un(i),594),n.d==null)return n}else for(i=new cn(e.Ab);i.e!=i.i.gc();)if(n=c(un(i),594),Ot(t,n.d))return n}return null}function jit(e,t,n,i,r){var o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de;L=bDt(e,Cme(t),r),fme(L,M1(r,bd)),k=null,P=r,z=K7(P,Blt),H=new uDe(L),JZe(H.a,z),X=K7(P,"endPoint"),ie=new dDe(L),UZe(ie.a,X),se=Gm(P,MG),de=new bDe(L),mZe(de.a,se),S=M1(r,g5e),o=new qRe(e,L),pze(o.a,o.b,S),M=M1(r,d5e),a=new HRe(e,L),bze(a.a,a.b,M),v=Gm(r,b5e),d=new XRe(n,L),FYe(d.b,d.a,v),x=Gm(r,p5e),b=new VRe(i,L),qYe(b.b,b.a,x)}function Tit(e,t,n){var i,r,o,a,d,b,v,x;if(t.p==0){for(t.p=1,a=n,a||(r=new Fe,o=(i=c(Jf($s),10),new ha(i,c(gf(i,i.length),10),0)),a=new Ps(r,o)),c(a.a,16).Ec(t),t.k==(Jt(),Cr)&&c(a.b,24).Ec(c(R(t,(De(),Ko)),64)),b=new G(t.j);b.a<b.c.c.length;)for(d=c(Q(b),12),x=Bd(ma(W(V(Ta,1),Lt,22,0,[new p6(d),new Q4(d)])));hn(x);)v=c(sn(x),12),Tit(e,v.i,a);return a}return null}function wye(e,t,n){var i,r,o,a,d;switch(d=null,t.g){case 1:for(r=new G(e.j);r.a<r.c.c.length;)if(i=c(Q(r),12),et(Ze(R(i,(De(),Gce)))))return i;d=new bc,Ee(d,(De(),Gce),(Bt(),!0));break;case 2:for(a=new G(e.j);a.a<a.c.c.length;)if(o=c(Q(a),12),et(Ze(R(o,(De(),Jce)))))return o;d=new bc,Ee(d,(De(),Jce),(Bt(),!0))}return d&&(_o(d,e),$r(d,n),kzt(d.n,e.o,n)),d}function Eit(e,t){var n,i,r,o,a,d;for(d=-1,a=new Ai,i=new kh(e.b);No(i.a)||No(i.b);){for(n=c(No(i.a)?Q(i.a):Q(i.b),17),d=p.Math.max(d,ue(he(R(n,(Ge(),Xg))))),n.c==e?lr(pi(new jt(null,new Tt(n.b,16)),new cm),new pNe(a)):lr(pi(new jt(null,new Tt(n.b,16)),new LM),new bNe(a)),o=_n(a,0);o.b!=o.d.c;)r=c(An(o),70),xi(r,(De(),vk))||Ee(r,vk,n);yr(t,a),Ou(a)}return d}function lw(e,t,n,i,r){var o,a,d,b,v;d=r?i.b:i.a,!$a(e.a,i)&&(v=d>n.s&&d<n.c,b=!1,n.e.b!=0&&n.j.b!=0&&(b=b|(p.Math.abs(d-ue(he(N6(n.e))))<dd&&p.Math.abs(d-ue(he(N6(n.j))))<dd),b=b|(p.Math.abs(d-ue(he(df(n.e))))<dd&&p.Math.abs(d-ue(he(df(n.j))))<dd)),(v||b)&&(a=c(R(t,(Ge(),ho)),79),a||(a=new nu,Ee(t,ho,a)),o=new Cs(i),tr(a,o,a.c.b,a.c),Sr(e.a,o)))}function jWt(e,t,n){var i,r,o,a,d,b,v,x,S;for(n.Tg("Processor set coordinates",1),e.a=t.b.b==0?1:t.b.b,v=null,i=_n(t.b,0);!v&&i.b!=i.d.c;)S=c(An(i),41),et(Ze(R(S,(Li(),cp))))&&(v=S,b=S.e,b.a=c(R(S,wP),15).a,b.b=c(R(S,vP),15).a);d=xte(v),x=1;do d=HHt((r=d,n.dh(x),r)),x=d.b/e.a|0;while(d.b!=0);for(a=_n(t.b,0);a.b!=a.d.c;)o=c(An(a),41),Hr(o.e,new $e(o.f.a/2,o.f.b/2));n.Ug()}function TWt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z;for(n=!1,x=ue(he(R(t,(Ge(),$b)))),P=Fg*x,r=new G(t.b);r.a<r.c.c.length;)for(i=c(Q(r),26),v=new G(i.a),o=c(Q(v),9),S=Z0e(e.a[o.p]);v.a<v.c.c.length;)d=c(Q(v),9),M=Z0e(e.a[d.p]),S!=M&&(L=px(e.b,o,d),a=o.n.b+o.o.b+o.d.a+S.a+L,b=d.n.b-d.d.d+M.a,a>b+P&&(z=S.g+M.g,M.a=(M.g*M.a+S.g*S.a)/z,M.g=z,S.f=M,n=!0)),o=d,S=M;return n}function EWt(e,t,n){var i,r,o,a,d,b,v,x;for(n.Tg(jct,1),sc(e.b),sc(e.a),d=null,o=_n(t.b,0);!d&&o.b!=o.d.c;)v=c(An(o),41),et(Ze(R(v,(Li(),cp))))&&(d=v);for(b=new Ai,tr(b,d,b.c.b,b.c),ost(e,b),x=_n(t.b,0);x.b!=x.d.c;)v=c(An(x),41),a=zn(R(v,(Li(),gC))),r=Tc(e.b,a)!=null?c(Tc(e.b,a),15).a:0,Ee(v,Hle,Pe(r)),i=1+(Tc(e.a,a)!=null?c(Tc(e.a,a),15).a:0),Ee(v,q9e,Pe(i));n.Ug()}function Cit(e){Am(e,new mb(Em(Sm(Tm(jm(new b1,yw),"ELK Box"),"Algorithm for packing of unconnected boxes, i.e. graphs without edges."),new GA))),Ie(e,yw,gw,Jje),Ie(e,yw,dw,15),Ie(e,yw,wL,Pe(0)),Ie(e,yw,e5e,Ve(Qje)),Ie(e,yw,Jx,Ve(bwt)),Ie(e,yw,sk,Ve(mwt)),Ie(e,yw,ZS,Zct),Ie(e,yw,e9,Ve(Gje)),Ie(e,yw,ok,Ve(Uje)),Ie(e,yw,t5e,Ve(Wue)),Ie(e,yw,bG,Ve(pwt))}function Mit(e,t){var n,i,r,o,a,d,b,v,x;if(r=e.i,a=r.o.a,o=r.o.b,a<=0&&o<=0)return Je(),$o;switch(v=e.n.a,x=e.n.b,d=e.o.a,n=e.o.b,t.g){case 2:case 1:if(v<0)return Je(),Yt;if(v+d>a)return Je(),nn;break;case 4:case 3:if(x<0)return Je(),Kt;if(x+n>o)return Je(),bn}return b=(v+d/2)/a,i=(x+n/2)/o,b+i<=1&&b-i<=0?(Je(),Yt):b+i>=1&&b-i>=0?(Je(),nn):i<.5?(Je(),Kt):(Je(),bn)}function Ait(e,t,n,i,r,o,a){var d,b,v,x,S,M;for(M=new c5,v=t.Jc();v.Ob();)for(d=c(v.Pb(),845),S=new G(d.Pf());S.a<S.c.c.length;)x=c(Q(S),190),ve(x.mf((Dn(),eae)))===ve((Sh(),n8))&&(lit(M,x,!1,i,r,o,a),AT(e,M));for(b=n.Jc();b.Ob();)for(d=c(b.Pb(),845),S=new G(d.Pf());S.a<S.c.c.length;)x=c(Q(S),190),ve(x.mf((Dn(),eae)))===ve((Sh(),oy))&&(lit(M,x,!0,i,r,o,a),AT(e,M))}function CWt(e,t,n){var i,r,o,a,d,b,v;for(a=new cn((!e.a&&(e.a=new Me(Mn,e,10,11)),e.a));a.e!=a.i.gc();)for(o=c(un(a),19),r=new Ht(Vt(z1(o).a.Jc(),new U));hn(r);)i=c(sn(r),74),!PT(i)&&!PT(i)&&!sw(i)&&(b=c(Ao(co(n.f,o)),41),v=c(Ut(n,to(c(re((!i.c&&(i.c=new Et(vn,i,5,8)),i.c),0),83))),41),b&&v&&(d=new Epe(b,v),Ee(d,(Li(),pC),i),ec(d,i),ei(b.d,d),ei(v.b,d),ei(t.a,d)))}function MWt(e,t){var n,i,r,o,a,d,b,v;for(b=c(c(Si(e.r,t),24),85).Jc();b.Ob();)d=c(b.Pb(),116),r=d.c?lFe(d.c):0,r>0?d.a?(v=d.b.Kf().b,r>v&&(e.v||d.c.d.c.length==1?(a=(r-v)/2,d.d.d=a,d.d.a=a):(n=c(Xe(d.c.d,0),190).Kf().b,i=(n-v)/2,d.d.d=p.Math.max(0,i),d.d.a=r-i-v))):d.d.a=e.t+r:$7(e.u)&&(o=I2e(d.b),o.d<0&&(d.d.d=-o.d),o.d+o.a>d.b.Kf().b&&(d.d.a=o.d+o.a-d.b.Kf().b))}function Sf(){Sf=te,dk=new Gr((Dn(),NP),Pe(1)),cU=new Gr(lh,80),cht=new Gr(O7e,5),Kft=new Gr(K9,YS),sht=new Gr(uae,Pe(1)),oht=new Gr(aae,(Bt(),!0)),Ake=new Qp(50),iht=new Gr(zh,Ake),Eke=AC,Nke=Y9,Yft=new Gr(QJ,!1),Mke=NC,tht=ny,nht=lp,eht=qb,Zft=E3,rht=iy,Cke=(U2e(),Qft),Voe=Xft,oU=Hft,Xoe=Gft,_ke=Jft,aht=e8,fht=JJ,uht=sy,lht=Z9,Dke=(P5(),ly),new Gr(Pk,Dke)}function AWt(e,t){var n;switch(sD(e)){case 6:return Kr(t);case 7:return P2(t);case 8:return L2(t);case 3:return Array.isArray(t)&&(n=sD(t),!(n>=14&&n<=16));case 11:return t!=null&&typeof t===Rie;case 12:return t!=null&&(typeof t===iL||typeof t==Rie);case 0:return une(t,e.__elementTypeId$);case 2:return HZ(t)&&t.Rm!==je;case 1:return HZ(t)&&t.Rm!==je||une(t,e.__elementTypeId$);default:return!0}}function NWt(e){var t,n,i,r;i=e.o,B2(),e.A.dc()||yi(e.A,kke)?r=i.a:(e.D?r=p.Math.max(i.a,DT(e.f)):r=DT(e.f),e.A.Gc((Cu(),BP))&&!e.B.Gc((uu(),zC))&&(r=p.Math.max(r,DT(c(Zs(e.p,(Je(),Kt)),256))),r=p.Math.max(r,DT(c(Zs(e.p,bn),256)))),t=mVe(e),t&&(r=p.Math.max(r,t.a))),et(Ze(e.e.Rf().mf((Dn(),ny))))?i.a=p.Math.max(i.a,r):i.a=r,n=e.f.i,n.c=0,n.b=r,pie(e.f)}function Nit(e,t){var n,i,r,o;return i=p.Math.min(p.Math.abs(e.c-(t.c+t.b)),p.Math.abs(e.c+e.b-t.c)),o=p.Math.min(p.Math.abs(e.d-(t.d+t.a)),p.Math.abs(e.d+e.a-t.d)),n=p.Math.abs(e.c+e.b/2-(t.c+t.b/2)),n>e.b/2+t.b/2||(r=p.Math.abs(e.d+e.a/2-(t.d+t.a/2)),r>e.a/2+t.a/2)?1:n==0&&r==0?0:n==0?o/r+1:r==0?i/n+1:p.Math.min(i/n,o/r)+1}function _Wt(e,t){var n,i,r,o,a,d,b;for(o=0,d=0,b=0,r=new G(e.f.e);r.a<r.c.c.length;)i=c(Q(r),156),t!=i&&(a=e.i[t.a][i.a],o+=a,n=A0(t.d,i.d),n>0&&e.d!=(tT(),Yoe)&&(d+=a*(i.d.a+e.a[t.a][i.a]*(t.d.a-i.d.a)/n)),n>0&&e.d!=(tT(),Woe)&&(b+=a*(i.d.b+e.a[t.a][i.a]*(t.d.b-i.d.b)/n)));switch(e.d.g){case 1:return new $e(d/o,t.d.b);case 2:return new $e(t.d.a,b/o);default:return new $e(d/o,b/o)}}function _it(e){var t,n,i,r,o,a;for(n=(!e.a&&(e.a=new Ar(Yu,e,5)),e.a).i+2,a=new Hc(n),qe(a,new $e(e.j,e.k)),lr(new jt(null,(!e.a&&(e.a=new Ar(Yu,e,5)),new Tt(e.a,16))),new sDe(a)),qe(a,new $e(e.b,e.c)),t=1;t<a.c.length-1;)i=(ht(t-1,a.c.length),c(a.c[t-1],8)),r=(ht(t,a.c.length),c(a.c[t],8)),o=(ht(t+1,a.c.length),c(a.c[t+1],8)),i.a==r.a&&r.a==o.a||i.b==r.b&&r.b==o.b?Mg(a,t):++t;return a}function Dit(e,t){aS();var n,i,r,o,a;if(a=c(R(e.i,(Ge(),cr)),103),o=e.j.g-t.j.g,o!=0||!(a==(Zr(),Hb)||a==r1||a==xc))return 0;if(a==(Zr(),Hb)&&(n=c(R(e,Vg),15),i=c(R(t,Vg),15),n&&i&&(r=n.a-i.a,r!=0)))return r;switch(e.j.g){case 1:return ji(e.n.a,t.n.a);case 2:return ji(e.n.b,t.n.b);case 3:return ji(t.n.a,e.n.a);case 4:return ji(t.n.b,e.n.b);default:throw J(new oo(Nxe))}}function Lit(e,t){var n,i,r,o,a,d,b;for(n=xBe(CIe(TIe(EIe(new _de,t),new mq(t.e)),rdt),e.a),t.j.c.length==0||tJe(c(Xe(t.j,0),60).a,n),b=new $K,oi(e.e,n,b),a=new Or,d=new Or,o=new G(t.k);o.a<o.c.c.length;)r=c(Q(o),17),Sr(a,r.c),Sr(d,r.d);i=a.a.gc()-d.a.gc(),i<0?(vD(b,!0,(Nr(),go)),vD(b,!1,yo)):i>0&&(vD(b,!1,(Nr(),go)),vD(b,!0,yo)),Qc(t.g,new iRe(e,n)),oi(e.g,t,n)}function vye(){vye=te,emt=new wt(T4e,(Bt(),!1)),Pe(-1),Jbt=new wt(E4e,Pe(-1)),Pe(-1),Xbt=new wt(C4e,Pe(-1)),Vbt=new wt(M4e,!1),Wbt=new wt(A4e,!1),z8e=(Pq(),kue),rmt=new wt(N4e,z8e),smt=new wt(_4e,-1),B8e=(LH(),wue),imt=new wt(D4e,B8e),nmt=new wt(L4e,!0),R8e=(Gq(),Oue),Zbt=new wt(P4e,R8e),Ybt=new wt(I4e,!1),Pe(1),Kbt=new wt(R4e,Pe(1)),$8e=(CH(),Sue),tmt=new wt($4e,$8e)}function Pit(){Pit=te;var e;for(nke=W(V(Fn,1),ci,30,15,[-1,-1,30,19,15,13,11,11,10,9,9,8,8,8,8,7,7,7,7,7,7,7,6,6,6,6,6,6,6,6,6,6,6,6,6,6,5]),_oe=ye(Fn,ci,30,37,15,1),$at=W(V(Fn,1),ci,30,15,[-1,-1,63,40,32,28,25,23,21,20,19,19,18,18,17,17,16,16,16,15,15,15,15,14,14,14,14,14,14,13,13,13,13,13,13,13,13]),ike=ye(qw,tot,30,37,14,1),e=2;e<=36;e++)_oe[e]=xs(p.Math.pow(e,nke[e])),ike[e]=ID(cL,_oe[e])}function DWt(e){var t;if((!e.a&&(e.a=new Me(Hi,e,6,6)),e.a).i!=1)throw J(new qt(Olt+(!e.a&&(e.a=new Me(Hi,e,6,6)),e.a).i));return t=new nu,yte(c(re((!e.b&&(e.b=new Et(vn,e,4,7)),e.b),0),83))&&Os(t,Sst(e,yte(c(re((!e.b&&(e.b=new Et(vn,e,4,7)),e.b),0),83)),!1)),yte(c(re((!e.c&&(e.c=new Et(vn,e,5,8)),e.c),0),83))&&Os(t,Sst(e,yte(c(re((!e.c&&(e.c=new Et(vn,e,5,8)),e.c),0),83)),!0)),t}function Iit(e,t){var n,i,r,o,a;for(t.d?r=e.a.c==(td(),Pw)?pr(t.b):$i(t.b):r=e.a.c==(td(),Wg)?pr(t.b):$i(t.b),o=!1,i=new Ht(Vt(r.a.Jc(),new U));hn(i);)if(n=c(sn(i),17),a=et(e.a.f[e.a.g[t.b.p].p]),!(!a&&!vs(n)&&n.c.i.c==n.d.i.c)&&!(et(e.a.n[e.a.g[t.b.p].p])||et(e.a.n[e.a.g[t.b.p].p]))&&(o=!0,$a(e.b,e.a.g[Vzt(n,t.b).p])))return t.c=!0,t.a=n,t;return t.c=o,t.a=null,t}function yye(e,t,n){var i,r,o,a,d,b,v;if(i=n.gc(),i==0)return!1;if(e.Nj())if(b=e.Oj(),Twe(e,t,n),a=i==1?e.Gj(3,null,n.Jc().Pb(),t,b):e.Gj(5,null,n,t,b),e.Kj()){for(d=i<100?null:new m0(i),o=t+i,r=t;r<o;++r)v=e.vj(r),d=e.Lj(v,d),d=d;d?(d.lj(a),d.mj()):e.Hj(a)}else e.Hj(a);else if(Twe(e,t,n),e.Kj()){for(d=i<100?null:new m0(i),o=t+i,r=t;r<o;++r)d=e.Lj(e.vj(r),d);d&&d.mj()}return!0}function Rit(e,t,n){var i,r,o,a,d;return e.Nj()?(r=null,o=e.Oj(),i=e.Gj(1,d=(a=e.Bj(t,e.Xi(t,n)),a),n,t,o),e.Kj()&&!(e.Wi()&&d?yi(d,n):ve(d)===ve(n))&&(d&&(r=e.Mj(d,r)),r=e.Lj(n,r)),r?(r.lj(i),r.mj()):e.Hj(i),d):(d=(a=e.Bj(t,e.Xi(t,n)),a),e.Kj()&&!(e.Wi()&&d?yi(d,n):ve(d)===ve(n))&&(r=null,d&&(r=e.Mj(d,null)),r=e.Lj(n,r),r&&r.mj()),d)}function xye(e,t){var n,i,r,o,a,d,b,v,x;if(e.e=t,e.f=c(R(t,(N0(),lU)),237),yHt(t),e.d=p.Math.max(t.e.c.length*16+t.c.c.length,256),!et(Ze(R(t,(Sf(),Eke)))))for(x=e.e.e.c.length,b=new G(t.e);b.a<b.c.c.length;)d=c(Q(b),156),v=d.d,v.a=RZ(e.f)*x,v.b=RZ(e.f)*x;for(n=t.b,o=new G(t.c);o.a<o.c.c.length;)if(r=c(Q(o),292),i=c(R(r,_ke),15).a,i>0){for(a=0;a<i;a++)qe(n,new pqe(r));utt(r)}}function LWt(e,t){var n,i,r,o,a,d,b,v,x,S;for(t.Tg("Hypernodes processing",1),r=new G(e.b);r.a<r.c.c.length;)for(i=c(Q(r),26),d=new G(i.a);d.a<d.c.c.length;)if(a=c(Q(d),9),et(Ze(R(a,(Ge(),tJ))))&&a.j.c.length<=2){for(S=0,x=0,n=0,o=0,v=new G(a.j);v.a<v.c.c.length;)switch(b=c(Q(v),12),b.j.g){case 1:++S;break;case 2:++x;break;case 3:++n;break;case 4:++o}S==0&&n==0&&Qen(e,a,o<=x)}t.Ug()}function $it(e,t,n,i){var r,o,a,d,b,v,x,S,M,L,P;if(M=new J2(e.Yg()),wf(t,hi,M),n&&!e.Wg().a.dc())for(x=new mg,wf(t,"logs",x),d=0,P=new nx(e.Wg().b.Jc());P.b.Ob();)L=zn(P.b.Pb()),S=new J2(L),tv(x,d),Eee(x,d,S),++d;if(i&&(v=new c6(e.Vg()),wf(t,"executionTime",v)),!e.Xg().a.dc())for(a=new mg,wf(t,Yse,a),d=0,o=new nx(e.Xg().b.Jc());o.b.Ob();)r=c(o.b.Pb(),861),b=new W4,tv(a,d),Eee(a,d,b),$it(r,b,n,i),++d}function kye(){kye=te,fY(),Nvt=new bN,W(V($k,2),Be,377,0,[W(V($k,1),JG,596,0,[new VN(rat)])]),W(V($k,2),Be,377,0,[W(V($k,1),JG,596,0,[new VN(I5e)])]),W(V($k,2),Be,377,0,[W(V($k,1),JG,596,0,[new VN(sat)]),W(V($k,1),JG,596,0,[new VN(I5e)])]),new O0("-1"),W(V($k,2),Be,377,0,[W(V($k,1),JG,596,0,[new VN("\\c+")])]),new O0("0"),new O0("0"),new O0("1"),new O0("0"),new O0(fat)}function PWt(e,t,n){var i,r,o,a,d,b,v,x,S;for(n.Tg("Hyperedge merging",1),uUt(e,t),b=new os(t.b,0);b.b<b.d.gc();)if(d=(dn(b.b<b.d.gc()),c(b.d.Xb(b.c=b.b++),26)),x=d.a,x.c.length!=0)for(i=null,r=null,o=null,a=null,v=0;v<x.c.length;v++)i=(ht(v,x.c.length),c(x.c[v],9)),r=i.k,r==(Jt(),jr)&&a==jr&&(S=DKt(i,o),S.a&&(PXt(i,o,S.b,S.c),ht(v,x.c.length),l1e(x.c,v,1),--v,i=o,r=a)),o=i,a=r;n.Ug()}function IWt(e,t,n,i,r){var o,a,d,b,v,x,S;for(a=new G(t);a.a<a.c.c.length;){if(o=c(Q(a),17),b=o.c,n.a._b(b))v=(Hm(),op);else if(i.a._b(b))v=(Hm(),y3);else throw J(new qt("Source port must be in one of the port sets."));if(x=o.d,n.a._b(x))S=(Hm(),op);else if(i.a._b(x))S=(Hm(),y3);else throw J(new qt("Target port must be in one of the port sets."));d=new Oet(o,v,S),oi(e.b,o,d),It(r.c,d)}}function AQ(e){var t,n;return e.c&&e.c.Sh()&&(n=c(e.c,52),e.c=c(I0(e,n),146),e.c!=n&&((e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,9,2,n,e.c)),oe(e.Cb,408)?e.Db>>16==-15&&e.Cb.Vh()&&Gee(new Hee(e.Cb,9,13,n,e.c,$g(ou(c(e.Cb,62)),e))):oe(e.Cb,89)&&e.Db>>16==-23&&e.Cb.Vh()&&(t=e.c,oe(t,89)||(t=(Mt(),rf)),oe(n,89)||(n=(Mt(),rf)),Gee(new Hee(e.Cb,9,10,n,t,$g(gc(c(e.Cb,29)),e)))))),e.c}function Bit(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P;if(t==n)return!0;if(t=Sve(e,t),n=Sve(e,n),i=bne(t),i){if(x=bne(n),x!=i)return x?(b=i.kk(),P=x.kk(),b==P&&b!=null):!1;if(a=(!t.d&&(t.d=new Ar(Ks,t,1)),t.d),o=a.i,M=(!n.d&&(n.d=new Ar(Ks,n,1)),n.d),o==M.i){for(v=0;v<o;++v)if(r=c(re(a,v),88),S=c(re(M,v),88),!Bit(e,r,S))return!1}return!0}else return d=t.e,L=n.e,d==L}function zit(e,t,n,i){var r,o,a,d,b,v,x,S;if(F1(e.e,t)){for(S=nl(e.e.Ah(),t),o=c(e.g,123),x=null,b=-1,d=-1,r=0,v=0;v<e.i;++v)a=o[v],S.$l(a.Jk())&&(r==n&&(b=v),r==i&&(d=v,x=a.kd()),++r);if(b==-1)throw J(new zc(toe+n+Tb+r));if(d==-1)throw J(new zc(noe+i+Tb+r));return vT(e,b,d),wu(e.e)&&b6(e,E0(e,7,t,Pe(i),x,n,!0)),x}else throw J(new qt("The feature must be many-valued to support move"))}function Fit(e,t,n,i){var r,o,a,d,b;switch(b=new Cs(t.n),b.a+=t.o.a/2,b.b+=t.o.b/2,d=ue(he(R(t,(Ge(),Qv)))),o=e.f,a=e.d,r=e.c,c(R(t,(De(),Ko)),64).g){case 1:b.a+=a.b+r.a-n/2,b.b=-i-d,t.n.b=-(a.d+d+r.b);break;case 2:b.a=o.a+a.b+a.c+d,b.b+=a.d+r.b-i/2,t.n.a=o.a+a.c+d-r.a;break;case 3:b.a+=a.b+r.a-n/2,b.b=o.b+a.d+a.a+d,t.n.b=o.b+a.a+d-r.b;break;case 4:b.a=-n-d,b.b+=a.d+r.b-i/2,t.n.a=-(a.b+d+r.a)}return b}function RWt(e,t,n){var i,r;i=t.c.i,r=n.d.i,i.k==(Jt(),jr)?(Ee(e,(De(),sh),c(R(i,sh),12)),Ee(e,Wa,c(R(i,Wa),12)),Ee(e,Bv,Ze(R(i,Bv)))):i.k==lc?(Ee(e,(De(),sh),c(R(i,sh),12)),Ee(e,Wa,c(R(i,Wa),12)),Ee(e,Bv,(Bt(),!0))):r.k==lc?(Ee(e,(De(),sh),c(R(r,sh),12)),Ee(e,Wa,c(R(r,Wa),12)),Ee(e,Bv,(Bt(),!0))):(Ee(e,(De(),sh),t.c),Ee(e,Wa,n.d))}function $Wt(e){var t,n,i,r,o,a,d;for(e.o=new bx,i=new Ai,a=new G(e.e.a);a.a<a.c.c.length;)o=c(Q(a),126),Ax(o).c.length==1&&tr(i,o,i.c.b,i.c);for(;i.b!=0;)o=c(i.b==0?null:(dn(i.b!=0),ba(i,i.a.a)),126),Ax(o).c.length!=0&&(t=c(Xe(Ax(o),0),220),n=o.g.a.c.length>0,d=DH(t,o),Tge(n?d.b:d.g,t),Ax(d).c.length==1&&tr(i,d,i.c.b,i.c),r=new Ps(o,t),C0(e.o,r),fl(e.e.a,o))}function qit(e,t){var n,i,r,o,a,d,b;return i=p.Math.abs(iq(e.b).a-iq(t.b).a),d=p.Math.abs(iq(e.b).b-iq(t.b).b),r=0,b=0,n=1,a=1,i>e.b.b/2+t.b.b/2&&(r=p.Math.min(p.Math.abs(e.b.c-(t.b.c+t.b.b)),p.Math.abs(e.b.c+e.b.b-t.b.c)),n=1-r/i),d>e.b.a/2+t.b.a/2&&(b=p.Math.min(p.Math.abs(e.b.d-(t.b.d+t.b.a)),p.Math.abs(e.b.d+e.b.a-t.b.d)),a=1-b/d),o=p.Math.min(n,a),(1-o)*p.Math.sqrt(i*i+d*d)}function BWt(e){var t,n,i,r;for(Nie(e,e.e,e.f,(Hm(),op),!0,e.c,e.i),Nie(e,e.e,e.f,op,!1,e.c,e.i),Nie(e,e.e,e.f,y3,!0,e.c,e.i),Nie(e,e.e,e.f,y3,!1,e.c,e.i),IWt(e,e.c,e.e,e.f,e.i),i=new os(e.i,0);i.b<i.d.gc();)for(t=(dn(i.b<i.d.gc()),c(i.d.Xb(i.c=i.b++),134)),r=new os(e.i,i.b);r.b<r.d.gc();)n=(dn(r.b<r.d.gc()),c(r.d.Xb(r.c=r.b++),134)),AYt(t,n);etn(e.i,c(R(e.d,(De(),kk)),237)),mZt(e.i)}function die(e,t){var n,i;if(t!=null){if(i=rw(e),i)if((i.i&1)!=0){if(i==kl)return L2(t);if(i==Fn)return oe(t,15);if(i==py)return oe(t,165);if(i==Rl)return oe(t,224);if(i==Na)return oe(t,183);if(i==ns)return P2(t);if(i==L3)return oe(t,193);if(i==qw)return oe(t,192)}else return Fz(),n=c(Ut(cX,i),58),!n||n.dk(t);else if(oe(t,57))return e.bl(c(t,57))}return!1}function Oye(){Oye=te;var e,t,n,i,r,o,a,d,b;for(Uh=ye(Rl,Yx,30,255,15,1),s0=ye(Na,fd,30,64,15,1),t=0;t<255;t++)Uh[t]=-1;for(n=90;n>=65;n--)Uh[n]=n-65<<24>>24;for(i=122;i>=97;i--)Uh[i]=i-97+26<<24>>24;for(r=57;r>=48;r--)Uh[r]=r-48+52<<24>>24;for(Uh[43]=62,Uh[47]=63,o=0;o<=25;o++)s0[o]=65+o&_r;for(a=26,b=0;a<=51;++a,b++)s0[a]=97+b&_r;for(e=52,d=0;e<=61;++e,d++)s0[e]=48+d&_r;s0[62]=43,s0[63]=47}function Hit(e,t){var n,i,r,o,a,d;return r=bme(e),d=bme(t),r==d?e.e==t.e&&e.a<54&&t.a<54?e.f<t.f?-1:e.f>t.f?1:0:(i=e.e-t.e,n=(e.d>0?e.d:p.Math.floor((e.a-1)*not)+1)-(t.d>0?t.d:p.Math.floor((t.a-1)*not)+1),n>i+1?r:n<i-1?-r:(o=(!e.c&&(e.c=F_(Zo(e.f))),e.c),a=(!t.c&&(t.c=F_(Zo(t.f))),t.c),i<0?o=Ox(o,nrt(-i)):i>0&&(a=Ox(a,nrt(i))),LKe(o,a))):r<d?-1:1}function Qit(e){var t,n,i,r,o,a;return i=new tme,ec(i,e),ve(R(i,(Ge(),Xu)))===ve((Nr(),qh))&&Ee(i,Xu,NH(i)),R(i,(Bq(),jC))==null&&(a=c(BZe(e),176),Ee(i,jC,bF(a.mf(jC)))),Ee(i,(De(),Oi),e),Ee(i,Lc,(t=c(Jf(Rce),10),new ha(t,c(gf(t,t.length),10),0))),r=qZt((Xi(e)&&(v0(),new wg(Xi(e))),v0(),new EF(Xi(e)?new wg(Xi(e)):null,e)),yo),o=c(R(i,LSe),100),n=i.d,FHe(n,o),FHe(n,r),i}function zWt(e,t,n){var i,r,o,a,d,b,v,x;for(n.Tg(_ot,1),e.qf(t),o=0;e.sf(o)&&!n.Zg();){for(e.rf(),x=Bd(ma(W(V(Ta,1),Lt,22,0,[t.e,t.d,t.b])));hn(x);)for(b=c(sn(x),314),d=Bd(ma(W(V(Ta,1),Lt,22,0,[t.e,t.d,t.b])));hn(d);)a=c(sn(d),314),a!=b&&(r=e.pf(a,b),r&&ki(b.c,r));for(v=Bd(ma(W(V(Ta,1),Lt,22,0,[t.e,t.d,t.b])));hn(v);)b=c(sn(v),314),i=b.c,ret(i,-e.d,-e.d,e.d,e.d),ki(b.d,i),i.a=0,i.b=0;++o}n.Ug()}function FWt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L;if(e.dc())return new as;for(v=0,S=0,r=e.Jc();r.Ob();)i=c(r.Pb(),37),o=i.f,v=p.Math.max(v,o.a),S+=o.a*o.b;for(v=p.Math.max(v,p.Math.sqrt(S)*ue(he(R(c(e.Jc().Pb(),37),(Ge(),XU))))),M=0,L=0,b=0,n=t,d=e.Jc();d.Ob();)a=c(d.Pb(),37),x=a.f,M+x.a>v&&(M=0,L+=b+t,b=0),IS(a,M,L),n=p.Math.max(n,M+x.a),b=p.Math.max(b,x.b),M+=x.a+t;return new $e(n+t,L+b+t)}function Sye(e,t){var n,i,r,o,a,d,b;if(!yh(e))throw J(new oo(klt));if(i=yh(e),o=i.g,r=i.f,o<=0&&r<=0)return Je(),$o;switch(d=e.i,b=e.j,t.g){case 2:case 1:if(d<0)return Je(),Yt;if(d+e.g>o)return Je(),nn;break;case 4:case 3:if(b<0)return Je(),Kt;if(b+e.f>r)return Je(),bn}return a=(d+e.g/2)/o,n=(b+e.f/2)/r,a+n<=1&&a-n<=0?(Je(),Yt):a+n>=1&&a-n>=0?(Je(),nn):n<.5?(Je(),Kt):(Je(),bn)}function qWt(e,t,n,i,r){var o,a;if(o=As(Yr(t[0],Us),Yr(i[0],Us)),e[0]=Hn(o),o=Im(o,32),n>=r){for(a=1;a<r;a++)o=As(o,As(Yr(t[a],Us),Yr(i[a],Us))),e[a]=Hn(o),o=Im(o,32);for(;a<n;a++)o=As(o,Yr(t[a],Us)),e[a]=Hn(o),o=Im(o,32)}else{for(a=1;a<n;a++)o=As(o,As(Yr(t[a],Us),Yr(i[a],Us))),e[a]=Hn(o),o=Im(o,32);for(;a<r;a++)o=As(o,Yr(i[a],Us)),e[a]=Hn(o),o=Im(o,32)}Mc(o,0)!=0&&(e[a]=Hn(o))}function HWt(e,t){var n,i,r,o,a,d,b,v,x;for(t.Tg("Layer constraint edge reversal",1),a=new G(e.b);a.a<a.c.c.length;){for(o=c(Q(a),26),x=-1,n=new Fe,v=q_(o.a),r=0;r<v.length;r++)i=c(R(v[r],(De(),Nb)),316),x==-1?i!=(D1(),a3)&&(x=r):i==(D1(),a3)&&(zr(v[r],null),B0(v[r],x++,o)),i==(D1(),bk)&&It(n.c,v[r]);for(b=new G(n);b.a<b.c.c.length;)d=c(Q(b),9),zr(d,null),zr(d,o)}t.Ug()}function yv(e){wi();var t,n,i,r,o,a;if(e.e!=4&&e.e!=5)throw J(new qt("Token#complementRanges(): must be RANGE: "+e.e));for(o=e,$x(o),JT(o),i=o.b.length+2,o.b[0]==0&&(i-=2),n=o.b[o.b.length-1],n==y9&&(i-=2),r=new $u(4),r.b=ye(Fn,ci,30,i,15,1),a=0,o.b[0]>0&&(r.b[a++]=0,r.b[a++]=o.b[0]-1),t=1;t<o.b.length-2;t+=2)r.b[a++]=o.b[t]+1,r.b[a++]=o.b[t+1]-1;return n!=y9&&(r.b[a++]=n+1,r.b[a]=y9),r.a=!0,r}function QWt(e,t){var n,i,r,o,a,d,b,v,x;for(t.Tg("Hierarchical port dummy size processing",1),b=new Fe,x=new Fe,i=ue(he(R(e,(Ge(),Jv)))),n=i*2,o=new G(e.b);o.a<o.c.c.length;){for(r=c(Q(o),26),b.c.length=0,x.c.length=0,d=new G(r.a);d.a<d.c.c.length;)a=c(Q(d),9),a.k==(Jt(),Cr)&&(v=c(R(a,(De(),Ko)),64),v==(Je(),Kt)?It(b.c,a):v==bn&&It(x.c,a));gtt(b,!0,n),gtt(x,!1,n)}t.Ug()}function Git(e,t){var n,i,r,o,a,d,b,v,x,S,M,L;if(e.c.length==1)return 0;for(M=ue(he(t.a)),L=ue(he(t.b)),x=0,b=new G(e);b.a<b.c.c.length;)d=c(Q(b),19),x+=d.g;for(n=(x-M+L)/2,o=0;n<o&&0<e.c.length;)o+=(ht(0,e.c.length),c(e.c[0],19)).lh();for(i=o-n,S=n-(o-(ht(0,e.c.length),c(e.c[0],19)).lh()),i>S?v=0:v=-1,t.a=M+i,a=0,r=v+1;r<e.c.length;r++)a+=(ht(r,e.c.length),c(e.c[r],19)).lh();return t.b=L+a,v}function gie(e,t,n){var i,r,o,a,d,b,v,x;if(i=n.gc(),i==0)return!1;if(e.Nj())if(v=e.Oj(),Ine(e,t,n),a=i==1?e.Gj(3,null,n.Jc().Pb(),t,v):e.Gj(5,null,n,t,v),e.Kj()){for(d=i<100?null:new m0(i),o=t+i,r=t;r<o;++r)x=e.g[r],d=e.Lj(x,d),d=e.Sj(x,d);d?(d.lj(a),d.mj()):e.Hj(a)}else e.Hj(a);else if(Ine(e,t,n),e.Kj()){for(d=i<100?null:new m0(i),o=t+i,r=t;r<o;++r)b=e.g[r],d=e.Lj(b,d);d&&d.mj()}return!0}function jye(e,t,n,i){var r,o,a,d,b;for(a=new G(e.k);a.a<a.c.c.length;)r=c(Q(a),135),(!i||r.c==(Wf(),sp))&&(b=r.b,b.g<0&&r.d>0&&(BN(b,b.d-r.d),r.c==(Wf(),sp)&&MK(b,b.a-r.d),b.d<=0&&b.i>0&&tr(t,b,t.c.b,t.c)));for(o=new G(e.f);o.a<o.c.c.length;)r=c(Q(o),135),(!i||r.c==(Wf(),sp))&&(d=r.a,d.g<0&&r.d>0&&(u6(d,d.i-r.d),r.c==(Wf(),sp)&&Hj(d,d.b-r.d),d.i<=0&&d.d>0&&tr(n,d,n.c.b,n.c)))}function GWt(e,t,n,i,r){var o,a,d,b,v,x,S,M,L;for(Ct(),Rr(e,new gm),a=A_(e),L=new Fe,M=new Fe,d=null,b=0;a.b!=0;)o=c(a.b==0?null:(dn(a.b!=0),ba(a,a.a.a)),168),!d||Ml(d)*ku(d)/2<Ml(o)*ku(o)?(d=o,It(L.c,o)):(b+=Ml(o)*ku(o),It(M.c,o),M.c.length>1&&(b>Ml(d)*ku(d)/2||a.b==0)&&(S=new eH(M),x=Ml(d)/ku(d),v=_ie(S,t,new X4,n,i,r,x),ki(Xf(S.e),v),d=S,It(L.c,S),b=0,M.c.length=0));return yr(L,M),L}function mc(e,t,n,i,r){Og();var o,a,d,b,v,x,S;if(ipe(e,"src"),ipe(n,"dest"),S=ju(e),b=ju(n),T0e((S.i&4)!=0,"srcType is not an array"),T0e((b.i&4)!=0,"destType is not an array"),x=S.c,a=b.c,T0e((x.i&1)!=0?x==a:(a.i&1)==0,"Array types don't match"),dRt(e,t,n,i,r),(x.i&1)==0&&S!=b)if(v=N5(e),o=N5(n),ve(e)===ve(n)&&t<i)for(t+=r,d=i+r;d-- >i;)dr(o,d,v[--t]);else for(d=i+r;i<d;)dr(o,i++,v[t++]);else wve(e,t,n,i,r,!0)}function Uit(e,t){var n,i,r,o,a,d,b,v,x;switch(t.Tg("Box layout",2),r=UN(he(ke(e,(fQ(),vwt)))),o=c(ke(e,wwt),100),n=et(Ze(ke(e,Qje))),i=et(Ze(ke(e,Gje))),c(ke(e,Wue),327).g){case 0:a=(x=new Fl((!e.a&&(e.a=new Me(Mn,e,10,11)),e.a)),Ct(),Rr(x,new nDe(i)),x),d=nve(e),b=he(ke(e,Hje)),(b==null||(zt(b),b<=0))&&(b=1.3),v=Ren(a,r,o,d.a,d.b,n,(zt(b),b)),uw(e,v.a,v.b,!1,!0);break;default:kYt(e,r,o,n)}t.Ug()}function UWt(e,t,n,i,r){var o,a,d,b,v,x,S,M,L,P;for(M=Pqt(e,n),b=0;b<t;b++){for(z2(r,n),L=new Fe,P=(dn(i.b<i.d.gc()),c(i.d.Xb(i.c=i.b++),415)),x=M+b;x<e.b;x++)d=P,P=(dn(i.b<i.d.gc()),c(i.d.Xb(i.c=i.b++),415)),qe(L,new wnt(d,P,n));for(S=M+b;S<e.b;S++)dn(i.b>0),i.a.Xb(i.c=--i.b),S>M+b&&iu(i);for(a=new G(L);a.a<a.c.c.length;)o=c(Q(a),415),z2(i,o);if(b<t-1)for(v=M+b;v<e.b;v++)dn(i.b>0),i.a.Xb(i.c=--i.b)}}function JWt(){wi();var e,t,n,i,r,o;if(Dae)return Dae;for(e=new $u(4),kv(e,Q0(voe,!0)),WT(e,Q0("M",!0)),WT(e,Q0("C",!0)),o=new $u(4),i=0;i<11;i++)Ac(o,i,i);return t=new $u(4),kv(t,Q0("M",!0)),Ac(t,4448,4607),Ac(t,65438,65439),r=new E7(2),wb(r,e),wb(r,KC),n=new E7(2),n.Hm(KF(o,Q0("L",!0))),n.Hm(t),n=new Z2(3,n),n=new spe(r,n),Dae=n,Dae}function xv(e,t){var n,i,r,o,a,d,b,v;for(n=new RegExp(t,"g"),b=ye(nt,Be,2,0,6,1),i=0,v=e,o=null;;)if(d=n.exec(v),d==null||v==""){b[i]=v;break}else a=d.index,b[i]=(fs(0,a,v.length),v.substr(0,a)),v=Fa(v,a+d[0].length,v.length),n.lastIndex=0,o==v&&(b[i]=(fs(0,1,v.length),v.substr(0,1)),v=(en(1,v.length+1),v.substr(1))),o=v,++i;if(e.length>0){for(r=b.length;r>0&&b[r-1]=="";)--r;r<b.length&&(b.length=r)}return b}function Uo(){Uo=te,t8e=new Qp(20),e8e=new Gr((Dn(),zh),t8e),Vle=new Gr(lh,20),i8e=new Gr(S7e,3),Vpt=new Gr(K9,YS),jJ=new Gr(NP,Pe(1)),rbt=new Gr(aae,(Bt(),!0)),W9e=MP,K9e=(Nr(),qh),Iw=new Gr(Fb,K9e),Wpt=AC,Kpt=nae,Zpt=qb,ebt=ny,tbt=C3,nbt=lp,Ypt=E3,Z9e=NC,ibt=iy,s8e=(Ove(),Xpt),n8e=Upt,cbt=e8,lbt=JJ,obt=sy,sbt=Z9,r8e=(P5(),ly),new Gr(Pk,r8e),x3=Gpt,Xle=Qpt,xd=Jpt,V9e=qpt,Y9e=Hpt}function XWt(e){var t,n,i,r,o,a,d,b,v,x,S,M;if(d=Xi(e),S=Ltt(e),t=c(ke(e,(Dn(),Hwt)),15).a,d){for(x=ls,i=new cn((!d.a&&(d.a=new Me(Mn,d,10,11)),d.a));i.e!=i.i.gc();)n=c(un(i),19),b=Ltt(n),b>x&&(x=b);for(v=p.Math.pow(4,t),x>v&&(v=x),M=(p.Math.log(v)-p.Math.log(1))/t,o=p.Math.exp(M),r=o,a=0;a<t;a++){if(S<r)return p.Math.pow(2,a);r*=o}return p.Math.pow(2,t-1)}else return 1}function VWt(e){var t,n,i,r,o,a,d,b,v,x,S;for(S=new bA,S.d=0,a=new G(e.b);a.a<a.c.c.length;)o=c(Q(a),26),S.d+=o.a.c.length;for(i=0,r=0,S.a=ye(Fn,ci,30,e.b.c.length,15,1),v=0,x=0,S.e=ye(Fn,ci,30,S.d,15,1),n=new G(e.b);n.a<n.c.c.length;)for(t=c(Q(n),26),t.p=i++,S.a[t.p]=r++,x=0,b=new G(t.a);b.a<b.c.c.length;)d=c(Q(b),9),d.p=v++,S.e[d.p]=x++;return S.c=new M_e(S),S.b=Pd(S.d),dWt(S,e),S.f=Pd(S.d),gWt(S,e),S}function WWt(e){var t,n;if(t=zn(ke(e,(Dn(),_k))),!wVe(t,e)&&!ga(e,ry)&&((!e.a&&(e.a=new Me(Mn,e,10,11)),e.a).i!=0||et(Ze(ke(e,AP)))))if(t==null||pv(t).length==0){if(!wVe(Qt,e))throw n=Zn(Zn(new Lu("Unable to load default layout algorithm "),Qt)," for unconfigured node "),$Q(e,n),J(new Wh(n.a))}else throw n=Zn(Zn(new Lu("Layout algorithm '"),t),"' not found for "),$Q(e,n),J(new Wh(n.a))}function pie(e){var t,n,i,r,o,a,d,b,v,x,S,M,L;if(n=e.i,t=e.n,e.b==0)for(L=n.c+t.b,M=n.b-t.b-t.c,a=e.a,b=0,x=a.length;b<x;++b)r=a[b],ZF(r,L,M);else i=wYe(e,!1),ZF(e.a[0],n.c+t.b,i[0]),ZF(e.a[2],n.c+n.b-t.c-i[2],i[2]),S=n.b-t.b-t.c,i[0]>0&&(S-=i[0]+e.c,i[0]+=e.c),i[2]>0&&(S-=i[2]+e.c),i[1]=p.Math.max(i[1],S),ZF(e.a[1],n.c+t.b+i[0]-(i[1]-S)/2,i[1]);for(o=e.a,d=0,v=o.length;d<v;++d)r=o[d],oe(r,338)&&c(r,338).hf()}function KWt(e){var t,n,i,r,o,a,d,b,v,x;for(x=ye(Fn,ci,30,e.b.c.length+1,15,1),v=new Or,i=0,o=new G(e.b);o.a<o.c.c.length;){for(r=c(Q(o),26),x[i++]=v.a.gc(),b=new G(r.a);b.a<b.c.c.length;)for(a=c(Q(b),9),n=new Ht(Vt($i(a).a.Jc(),new U));hn(n);)t=c(sn(n),17),v.a.yc(t,v);for(d=new G(r.a);d.a<d.c.c.length;)for(a=c(Q(d),9),n=new Ht(Vt(pr(a).a.Jc(),new U));hn(n);)t=c(sn(n),17),v.a.Ac(t)!=null}return x}function Jit(e,t){var n,i,r,o;for(o=c(Xe(e.n,e.n.c.length-1),211).d,e.p=p.Math.min(e.p,t.g),e.r=p.Math.max(e.r,o),e.g=p.Math.max(e.g,t.g+(e.b.c.length==1?0:e.i)),e.o=p.Math.min(e.o,t.f),e.e+=t.f+(e.b.c.length==1?0:e.i),e.f=p.Math.max(e.f,t.f),r=e.n.c.length>0?(e.n.c.length-1)*e.i:0,i=new G(e.n);i.a<i.c.c.length;)n=c(Q(i),211),r+=n.a;e.d=r,e.a=e.e/e.b.c.length-e.i*((e.b.c.length-1)/e.b.c.length),e2e(e.j)}function Xit(e,t){var n,i,r,o,a,d,b,v,x,S;if(x=Ze(R(t,(Sf(),oht))),x==null||(zt(x),x)){for(S=ye(kl,eh,30,t.e.c.length,16,1),a=BGt(t),r=new Ai,v=new G(t.e);v.a<v.c.c.length;)d=c(Q(v),156),n=Pve(e,d,null,null,S,a),n&&(ec(n,t),tr(r,n,r.c.b,r.c));if(r.b>1)for(i=_n(r,0);i.b!=i.d.c;)for(n=c(An(i),238),o=0,b=new G(n.e);b.a<b.c.c.length;)d=c(Q(b),156),d.a=o++;return r}return mf(W(V(Utn,1),Mot,238,0,[t]))}function ud(e){var t,n,i,r,o,a,d;if(!e.g){if(d=new bh,t=GC,a=t.a.yc(e,t),a==null){for(i=new cn(vo(e));i.e!=i.i.gc();)n=c(un(i),29),ur(d,ud(n));t.a.Ac(e)!=null,t.a.gc()==0}for(r=d.i,o=(!e.s&&(e.s=new Me(xl,e,21,17)),new cn(e.s));o.e!=o.i.gc();++r)m(c(un(o),454),r);ur(d,(!e.s&&(e.s=new Me(xl,e,21,17)),e.s)),cv(d),e.g=new JVe(e,d),e.i=c(d.g,258),e.i==null&&(e.i=Tae),e.p=null,ru(e).b&=-5}return e.g}function YWt(e,t){var n,i,r,o,a,d,b,v,x;if(n=t.ni(e.a),n&&(b=zn(Zf((!n.b&&(n.b=new yu((Mt(),Bs),Yo,n)),n.b),"memberTypes")),b!=null)){for(v=new Fe,o=xv(b,"\\w"),a=0,d=o.length;a<d;++a)r=o[a],i=r.lastIndexOf("#"),x=i==-1?Bge(e,t.hk(),r):i==0?Y_(e,null,(en(1,r.length+1),r.substr(1))):Y_(e,(fs(0,i,r.length),r.substr(0,i)),(en(i+1,r.length+1),r.substr(i+1))),oe(x,160)&&qe(v,c(x,160));return v}return Ct(),Ct(),Rs}function bie(e){var t,n,i,r,o,a,d,b,v,x,S,M,L,P;if(i=e.i,n=e.n,e.b==0)t=mYe(e,!1),eq(e.a[0],i.d+n.d,t[0]),eq(e.a[2],i.d+i.a-n.a-t[2],t[2]),M=i.a-n.d-n.a,S=M,t[0]>0&&(t[0]+=e.c,S-=t[0]),t[2]>0&&(S-=t[2]+e.c),t[1]=p.Math.max(t[1],S),eq(e.a[1],i.d+n.d+t[0]-(t[1]-S)/2,t[1]);else for(P=i.d+n.d,L=i.a-n.d-n.a,a=e.a,b=0,x=a.length;b<x;++b)r=a[b],eq(r,P,L);for(o=e.a,d=0,v=o.length;d<v;++d)r=o[d],oe(r,338)&&c(r,338).jf()}function ZWt(e,t,n,i,r){var o,a,d;if(n.f>=t.o&&n.f<=t.f||t.a*.5<=n.f&&t.a*1.5>=n.f){if(a=c(Xe(t.n,t.n.c.length-1),211),a.e+a.d+n.g+r<=i&&(o=c(Xe(t.n,t.n.c.length-1),211),o.f-e.f+n.f<=e.b||e.a.c.length==1))return mwe(t,n),!0;if(t.s+n.g<=i&&t.t+t.d+n.f+r<=e.f+e.b)return qe(t.b,n),d=c(Xe(t.n,t.n.c.length-1),211),qe(t.n,new kq(t.s,d.f+d.a+t.i,t.i)),Kwe(c(Xe(t.n,t.n.c.length-1),211),n),Jit(t,n),!0}return!1}function NQ(e,t,n,i){var r,o,a,d,b;if(b=nl(e.e.Ah(),t),r=c(e.g,123),qs(),c(t,69).vk()){for(a=0;a<e.i;++a)if(o=r[a],b.$l(o.Jk())&&yi(o,n))return!0}else if(n!=null){for(d=0;d<e.i;++d)if(o=r[d],b.$l(o.Jk())&&yi(n,o.kd()))return!0;if(i){for(a=0;a<e.i;++a)if(o=r[a],b.$l(o.Jk())&&ve(n)===ve(fZ(e,c(o.kd(),57))))return!0}}else for(a=0;a<e.i;++a)if(o=r[a],b.$l(o.Jk())&&o.kd()==null)return!1;return!1}function eKt(e,t){var n,i,r,o,a,d;if(n=t.ni(e.a),n&&(d=zn(Zf((!n.b&&(n.b=new yu((Mt(),Bs),Yo,n)),n.b),AG)),d!=null))switch(r=SF(d,dl(35)),i=t.ok(),r==-1?(a=I7(e,Bu(i)),o=d):r==0?(a=null,o=(en(1,d.length+1),d.substr(1))):(a=(fs(0,r,d.length),d.substr(0,r)),o=(en(r+1,d.length+1),d.substr(r+1))),zm(uo(e,t))){case 2:case 3:return lRt(e,i,a,o);case 0:case 4:case 5:case 6:return uRt(e,i,a,o)}return null}function Vit(e,t,n,i){var r,o,a,d;for(d=n,a=new G(t.a);a.a<a.c.c.length;){if(o=c(Q(a),227),r=c(o.b,68),ew(e.b.c,r.b.c+r.b.b)<=0&&ew(r.b.c,e.b.c+e.b.b)<=0&&ew(e.b.d,r.b.d+r.b.a)<=0&&ew(r.b.d,e.b.d+e.b.a)<=0){if(ew(r.b.c,e.b.c+e.b.b)==0&&i.a<0||ew(r.b.c+r.b.b,e.b.c)==0&&i.a>0||ew(r.b.d,e.b.d+e.b.a)==0&&i.b<0||ew(r.b.d+r.b.a,e.b.d)==0&&i.b>0){d=0;break}}else d=p.Math.min(d,Det(e,r,i));d=p.Math.min(d,Vit(e,o,d,i))}return d}function Tye(e,t){var n,i,r,o,a,d,b;if(e.b<2)throw J(new qt("The vector chain must contain at least a source and a target point."));for(r=(dn(e.b!=0),c(e.a.a.c,8)),m_(t,r.a,r.b),b=new f5((!t.a&&(t.a=new Ar(Yu,t,5)),t.a)),a=_n(e,1);a.a<e.b-1;)d=c(An(a),8),b.e!=b.i.gc()?n=c(un(b),373):(n=(w0(),i=new y2,i),jKe(b,n)),YY(n,d.a,d.b);for(;b.e!=b.i.gc();)un(b),MT(b);o=(dn(e.b!=0),c(e.c.b.c,8)),b_(t,o.a,o.b)}function Wit(e,t,n,i){var r,o,a,d,b,v;if(v=nl(e.e.Ah(),t),a=c(e.g,123),F1(e.e,t)){if(t.Qi()&&(o=$S(e,t,i,oe(t,104)&&(c(t,20).Bb&Is)!=0),o>=0&&o!=n))throw J(new qt(DL));for(r=0,b=0;b<e.i;++b)if(d=a[b],v.$l(d.Jk())){if(r==n)return c(Dx(e,b,(qs(),c(t,69).vk()?c(i,76):Fd(t,i))),76);++r}throw J(new zc(wE+n+Tb+r))}else{for(b=0;b<e.i;++b)if(d=a[b],v.$l(d.Jk()))return qs(),c(t,69).vk()?d:d.kd();return null}}function Kit(e,t){var n,i,r,o,a,d,b,v,x;for(n=0,r=new G((ht(0,e.c.length),c(e.c[0],108)).g.b.j);r.a<r.c.c.length;)i=c(Q(r),12),i.p=n++;for(t==(Je(),Kt)?Rr(e,new Sl):Rr(e,new ko),d=0,x=e.c.length-1;d<x;)a=(ht(d,e.c.length),c(e.c[d],108)),v=(ht(x,e.c.length),c(e.c[x],108)),o=t==Kt?a.c:a.a,b=t==Kt?v.a:v.c,Eg(a,t,(xf(),C9),o),Eg(v,t,E9,b),++d,--x;d==x&&Eg((ht(d,e.c.length),c(e.c[d],108)),t,(xf(),Iv),null)}function tKt(e,t,n,i){var r,o,a,d,b,v;for(a=new Mrt(e,t,n),b=new os(i,0),r=!1;b.b<b.d.gc();)d=(dn(b.b<b.d.gc()),c(b.d.Xb(b.c=b.b++),242)),d==t||d==n?iu(b):!r&&ue(wh(d.g,d.d[0]).a)>ue(wh(a.g,a.d[0]).a)?(dn(b.b>0),b.a.Xb(b.c=--b.b),z2(b,a),r=!0):d.e&&d.e.gc()>0&&(o=(!d.e&&(d.e=new Fe),d.e).Kc(t),v=(!d.e&&(d.e=new Fe),d.e).Kc(n),(o||v)&&((!d.e&&(d.e=new Fe),d.e).Ec(a),++a.c));r||It(i.c,a)}function nKt(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X;return S=e.a.i+e.a.g/2,M=e.a.i+e.a.g/2,P=t.i+t.g/2,H=t.j+t.f/2,d=new $e(P,H),v=c(ke(t,(Dn(),Dk)),8),v.a=v.a+S,v.b=v.b+M,o=(d.b-v.b)/(d.a-v.a),i=d.b-o*d.a,z=n.i+n.g/2,X=n.j+n.f/2,b=new $e(z,X),x=c(ke(n,Dk),8),x.a=x.a+S,x.b=x.b+M,a=(b.b-x.b)/(b.a-x.a),r=b.b-a*b.a,L=(i-r)/(a-o),v.a<L&&d.a<L||L<v.a&&L<d.a?!1:!(x.a<L&&b.a<L||L<x.a&&L<b.a)}function iKt(e,t,n){var i,r,o,a;for(n.Tg(wct,1),e.a=t,e.c=new Fe,o=p.Math.max(t.a.c.length,c(R(t,(De(),np)),15).a);a=new UUe(e.c,e.d,e.b),TUt(a,t),jFt(a,t),e.d.b!=0;){for(e.rg(o,o*c(R(t,tP),15).a),r=new G(e.c);r.a<r.c.c.length;)i=c(Q(r),17),zg(i,!1),Ee(i.c.i,(Ge(),YE),Pe(c(R(i.c.i,YE),15).a+1)),Ee(t,wk,(Bt(),!0));Ou(e.d),sc(e.b),e.c.c.length=0}n.Ug(),n.ah("Execution Time: "+n.Vg())}function Yit(e,t,n,i){var r,o,a,d,b,v;if(!Y2(t)){if(v=n.dh((oe(t,18)?c(t,18).gc():Vf(t.Jc()))/e.a|0),v.Tg(Tct,1),b=new DW,d=0,i==(Nr(),go)||i==yo)for(a=t.Jc();a.Ob();)r=c(a.Pb(),41),b=ma(W(V(Ta,1),Lt,22,0,[b,new k1(r)])),d<r.f.a&&(d=r.f.a);else for(a=t.Jc();a.Ob();)r=c(a.Pb(),41),b=ma(W(V(Ta,1),Lt,22,0,[b,new k1(r)])),d<r.f.b&&(d=r.f.b);for(o=t.Jc();o.Ob();)r=c(o.Pb(),41),Ee(r,(Li(),SJ),d);v.Ug(),Yit(e,b,n,i)}}function Eye(e,t,n){var i,r,o,a,d,b,v,x;this.a=e,this.b=t,this.c=n,this.e=mf(W(V(Htn,1),Lt,180,0,[new n5(e,t),new n5(t,n),new n5(n,e)])),this.f=mf(W(V(Vr,1),Be,8,0,[e,t,n])),this.d=(i=Hr(Ms(this.b),this.a),r=Hr(Ms(this.c),this.a),o=Hr(Ms(this.c),this.b),a=i.a*(this.a.a+this.b.a)+i.b*(this.a.b+this.b.b),d=r.a*(this.a.a+this.c.a)+r.b*(this.a.b+this.c.b),b=2*(i.a*o.b-i.b*o.a),v=(r.b*a-i.b*d)/b,x=(i.a*d-r.a*a)/b,new $e(v,x))}function zg(e,t){var n,i,r,o,a,d;for(o=e.c,a=e.d,ks(e,null),ss(e,null),t&&et(Ze(R(a,(De(),Gce))))?ks(e,wye(a.i,(Qs(),Wc),(Je(),nn))):ks(e,a),t&&et(Ze(R(o,(De(),Jce))))?ss(e,wye(o.i,(Qs(),Jl),(Je(),Yt))):ss(e,o),i=new G(e.b);i.a<i.c.c.length;)n=c(Q(i),70),r=c(R(n,(Ge(),yd)),281),r==(Sh(),n8)?Ee(n,yd,oy):r==oy&&Ee(n,yd,n8);d=et(Ze(R(e,(De(),Jg)))),Ee(e,Jg,(Bt(),!d)),e.a=Fme(e.a)}function rKt(e,t){var n,i,r,o,a;return n=OS(c(R(t,(Uo(),Iw)),87)),e.b.b==0?null:(a=c(ql(qc(new jt(null,new Tt(e.b,16)),new Ts),su(new Ls,new rs,new mo,W(V(ml,1),_e,132,0,[(va(),bl)]))),16),o=c(ql(pi(new jt(null,new Tt(t.b,16)),new N_e(a)),su(new Ls,new rs,new mo,W(V(ml,1),_e,132,0,[bl]))),16),r=he(vu(Q2(qc(o.Mc(),new __e(n)),(Fm(),Fm(),Poe)))),i=c(vu(I1(pi(o.Mc(),new mRe(n,r)))),41),i)}function sKt(e,t){var n,i,r,o,a,d;if(Ct(),Rr(t,new xde(!1)),n=new Fe,i=new Fe,e.a)pZt(t,n,i);else{for(qe(n,c(Xe(t,t.c.length-1),19)),a=0,d=0,o=1;o<t.c.length;o++)a<=d?(qe(n,c(Xe(t,t.c.length-1-o),19)),a+=c(Xe(t,t.c.length-1-o),19).lh()):(qe(i,c(Xe(t,t.c.length-1-o),19)),d+=c(Xe(t,t.c.length-1-o),19).lh());NT(n)}for(Rr(i,new xde(!0)),yr(n,i),r=0;r<t.c.length;r++)Su(t,r,(ht(r,n.c.length),c(n.c[r],19)))}function oKt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H;n=Dm(new Fp,e.f),v=e.i[t.c.i.p],L=e.i[t.d.i.p],b=t.c,M=t.d,d=b.a.b,S=M.a.b,v.b||(d+=b.n.b),L.b||(S+=M.n.b),x=xs(p.Math.max(0,d-S)),a=xs(p.Math.max(0,S-d)),P=(z=p.Math.max(1,c(R(t,(Ge(),Ek)),15).a),H=nbe(t.c.i.k,t.d.i.k),z*H),r=Of(uf(ff(af(hf(new Ra,P),a),n),c(Ut(e.k,t.c),126))),o=Of(uf(ff(af(hf(new Ra,P),x),n),c(Ut(e.k,t.d),126))),i=new aRe(r,o),e.c[t.p]=i}function cKt(e,t){var n,i,r,o,a,d,b,v,x,S;for(n=new xu(e.c,-100,new xu(0,e.a,e.b)),i=new xu(t.c,-100,new xu(0,t.a,t.b)),a=n.c-i.c,b=n,v=i,x=b.c,S=v.c;b&&v.b;)v.b.a>b.a?(r=v.b.c,o=v.b.a-v.a,d=x-S-(b.a-v.a)*r/o,a=p.Math.max(a,d),b=b.b,b&&(x+=b.c)):(v=v.b,S+=v.c);for(b=n,v=i,x=b.c,S=v.c;v&&b.b;)b.b.a>v.a?(r=b.b.c,o=b.b.a-b.a,d=x-S+(v.a-b.a)*r/o,a=p.Math.max(a,d),v=v.b,v&&(S+=v.c)):(b=b.b,x+=b.c);return a}function lKt(e,t,n){var i,r,o,a,d,b;for(i=0,o=new cn((!e.a&&(e.a=new Me(Mn,e,10,11)),e.a));o.e!=o.i.gc();)r=c(un(o),19),a="",(!r.n&&(r.n=new Me(Bo,r,1,7)),r.n).i==0||(a=c(re((!r.n&&(r.n=new Me(Bo,r,1,7)),r.n),0),158).a),d=new F$e(a),ec(d,r),Ee(d,(N0(),gk),r),d.a=i++,d.d.a=r.i+r.g/2,d.d.b=r.j+r.f/2,d.e.a=p.Math.max(r.g,1),d.e.b=p.Math.max(r.f,1),qe(t.e,d),gl(n.f,r,d),b=c(ke(r,(Sf(),Nke)),103),b==(Zr(),fp)&&(b=Hh)}function Zit(e){var t,n,i;if(dx(c(R(e,(Ge(),cr)),103)))for(n=new G(e.j);n.a<n.c.c.length;)t=c(Q(n),12),t.j==(Je(),$o)&&(i=c(R(t,(De(),Ul)),9),i?$r(t,c(R(i,Ko),64)):t.e.c.length-t.g.c.length<0?$r(t,nn):$r(t,Yt));else{for(n=new G(e.j);n.a<n.c.c.length;)t=c(Q(n),12),i=c(R(t,(De(),Ul)),9),i?$r(t,c(R(i,Ko),64)):t.e.c.length-t.g.c.length<0?$r(t,(Je(),nn)):$r(t,(Je(),Yt));Ee(e,cr,(Zr(),r8))}}function uKt(e,t){var n,i,r,o,a,d,b;t.Tg("Layer constraint postprocessing",1),b=e.b,b.c.length!=0&&(i=(ht(0,b.c.length),c(b.c[0],26)),a=c(Xe(b,b.c.length-1),26),n=new hc(e),o=new hc(e),XVt(e,i,a,n,o),n.a.c.length==0||(K2(0,b.c.length),h7(b.c,0,n)),o.a.c.length==0||It(b.c,o)),xi(e,(De(),Qce))&&(r=new hc(e),d=new hc(e),$Xt(e,r,d),r.a.c.length==0||(K2(0,b.c.length),h7(b.c,0,r)),d.a.c.length==0||It(b.c,d)),t.Ug()}function YD(e){var t,n,i;switch(e){case 91:case 93:case 45:case 94:case 44:case 92:i="\\"+String.fromCharCode(e&_r);break;case 12:i="\\f";break;case 10:i="\\n";break;case 13:i="\\r";break;case 9:i="\\t";break;case 27:i="\\e";break;default:e<32?(n=(t=e>>>0,"0"+t.toString(16)),i="\\x"+Fa(n,n.length-2,n.length)):e>=Is?(n=(t=e>>>0,"0"+t.toString(16)),i="\\v"+Fa(n,n.length-6,n.length)):i=""+String.fromCharCode(e&_r)}return i}function ert(e,t){var n,i,r,o,a,d,b,v,x;for(o=new G(e.b);o.a<o.c.c.length;)for(r=c(Q(o),26),d=new G(r.a);d.a<d.c.c.length;)for(a=c(Q(d),9),a.k==(Jt(),lc)&&(b=(v=c(sn(new Ht(Vt(pr(a).a.Jc(),new U))),17),x=c(sn(new Ht(Vt($i(a).a.Jc(),new U))),17),!et(Ze(R(v,(De(),Jg))))||!et(Ze(R(x,Jg)))?t:zVe(t)),W5(a,b)),i=new Ht(Vt($i(a).a.Jc(),new U));hn(i);)n=c(sn(i),17),b=et(Ze(R(n,(De(),Jg))))?zVe(t):t,LVe(n,b)}function Cye(e){var t,n,i,r,o,a;for(this.e=new Fe,this.a=new Fe,n=e.b-1;n<3;n++)M6(e,0,c(pc(e,0),8));if(e.b<4)throw J(new qt("At (least dimension + 1) control points are necessary!"));for(this.b=3,this.d=!0,this.c=!1,PUt(this,e.b+this.b-1),a=new Fe,o=new G(this.e),t=0;t<this.b-1;t++)qe(a,he(Q(o)));for(r=_n(e,0);r.b!=r.d.c;)i=c(An(r),8),qe(a,he(Q(o))),qe(this.a,new NHe(i,a)),ht(0,a.c.length),a.c.splice(0,1)}function trt(e,t,n){var i,r,o,a;return e.Nj()?(r=null,o=e.Oj(),i=e.Gj(1,a=Wee(e,t,n),n,t,o),e.Kj()&&!(e.Wi()&&a!=null?yi(a,n):ve(a)===ve(n))?(a!=null&&(r=e.Mj(a,r)),r=e.Lj(n,r),e.Rj()&&(r=e.Uj(a,n,r)),r?(r.lj(i),r.mj()):e.Hj(i)):(e.Rj()&&(r=e.Uj(a,n,r)),r?(r.lj(i),r.mj()):e.Hj(i)),a):(a=Wee(e,t,n),e.Kj()&&!(e.Wi()&&a!=null?yi(a,n):ve(a)===ve(n))&&(r=null,a!=null&&(r=e.Mj(a,null)),r=e.Lj(n,r),r&&r.mj()),a)}function aKt(e,t){var n,i,r,o,a;if(t.Tg("Path-Like Graph Wrapping",1),e.b.c.length==0){t.Ug();return}if(r=new Tve(e),a=(r.i==null&&(r.i=mme(r,new NO)),ue(r.i)*r.f),n=a/(r.i==null&&(r.i=mme(r,new NO)),ue(r.i)),r.b>n){t.Ug();return}switch(c(R(e,(Ge(),mle)),351).g){case 2:o=new _O;break;case 0:o=new Dp;break;default:o=new uA}if(i=o.mg(e,r),!o.ng())switch(c(R(e,uJ),352).g){case 2:i=Let(r,i);break;case 1:i=vZe(r,i)}sYt(e,r,i),t.Ug()}function HT(e,t){var n,i,r,o,a,d,b,v;t%=24,e.q.getHours()!=t&&(i=new p.Date(e.q.getTime()),i.setDate(i.getDate()+1),d=e.q.getTimezoneOffset()-i.getTimezoneOffset(),d>0&&(b=d/60|0,v=d%60,r=e.q.getDate(),n=e.q.getHours(),n+b>=24&&++r,o=new p.Date(e.q.getFullYear(),e.q.getMonth(),r,t+b,e.q.getMinutes()+v,e.q.getSeconds(),e.q.getMilliseconds()),e.q.setTime(o.getTime()))),a=e.q.getTime(),e.q.setTime(a+36e5),e.q.getHours()!=t&&e.q.setTime(a)}function fKt(e,t){var n,i,r,o;if(RNt(e.d,e.e),e.c.a.$b(),ue(he(R(t.j,(Ge(),sP))))!=0||ue(he(R(t.j,sP)))!=0)for(n=Vx,ve(R(t.j,t1))!==ve((B1(),rp))&&Ee(t.j,(De(),tp),(Bt(),!0)),o=c(R(t.j,nC),15).a,r=0;r<o&&(i=SKt(e,t),!(i<n&&(n=i,KXe(e),n==0)));r++);else for(n=di,ve(R(t.j,t1))!==ve((B1(),rp))&&Ee(t.j,(De(),tp),(Bt(),!0)),o=c(R(t.j,nC),15).a,r=0;r<o&&(i=ort(e,t),!(i<n&&(n=i,KXe(e),n==0)));r++);}function hKt(e,t){var n,i,r,o,a,d,b,v;for(a=new Fe,d=0,n=0,b=0;d<t.c.length-1&&n<e.gc();){for(i=c(e.Xb(n),15).a+b;(ht(d+1,t.c.length),c(t.c[d+1],15)).a<i;)++d;for(v=0,o=i-(ht(d,t.c.length),c(t.c[d],15)).a,r=(ht(d+1,t.c.length),c(t.c[d+1],15)).a-i,o>r&&++v,qe(a,(ht(d+v,t.c.length),c(t.c[d+v],15))),b+=(ht(d+v,t.c.length),c(t.c[d+v],15)).a-i,++n;n<e.gc()&&c(e.Xb(n),15).a+b<=(ht(d+v,t.c.length),c(t.c[d+v],15)).a;)++n;d+=1+v}return a}function dKt(e,t){var n,i,r,o,a;for(a=new Ht(Vt(pr(t).a.Jc(),new U));hn(a);)if(o=c(sn(a),17),e.f.b==0?(r=o.c.i.k==(Jt(),or)&&!!o.c.i.c&&o.c.i.c.p==e.c,hn(new Ht(Vt(pr(o.c.i).a.Jc(),new U)))?(n=c(sn(new Ht(Vt(pr(o.c.i).a.Jc(),new U))),17).c.i.c,i=o.c.i.k==lc&&!!n&&n.p==e.c):i=!1):(r=o.c.i.k==(Jt(),or)&&o.c.i.p==e.c,i=o.c.i.k==lc&&c(sn(new Ht(Vt(pr(o.c.i).a.Jc(),new U))),17).c.i.p==e.c),r||i)return!0;return!1}function gKt(e,t,n,i,r){var o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se;for(M=new Fe,X=Dq(i),H=t*e.a,S=0,P=0,o=new Or,a=new Or,d=new Fe,ie=0,se=0,L=0,z=0,v=0,x=0;X.a.gc()!=0;)b=x$t(X,r,a),b&&(X.a.Ac(b)!=null,It(d.c,b),o.a.yc(b,o),P=e.f[b.p],ie+=e.e[b.p]-P*e.b,S=e.c[b.p],se+=S*e.b,x+=P*e.b,z+=e.e[b.p]),(!b||X.a.gc()==0||ie>=H&&e.e[b.p]>P*e.b||se>=n*H)&&(It(M.c,d),d=new Fe,Os(a,o),o.a.$b(),v-=x,L=p.Math.max(L,v*e.b+z),v+=se,ie=se,se=0,x=0,z=0);return new Ps(L,M)}function mie(e){var t,n,i,r,o,a,d;if(!e.d){if(d=new Z$,t=GC,o=t.a.yc(e,t),o==null){for(i=new cn(vo(e));i.e!=i.i.gc();)n=c(un(i),29),ur(d,mie(n));t.a.Ac(e)!=null,t.a.gc()==0}for(a=d.i,r=(!e.q&&(e.q=new Me(tf,e,11,10)),new cn(e.q));r.e!=r.i.gc();++a)c(un(r),408);ur(d,(!e.q&&(e.q=new Me(tf,e,11,10)),e.q)),cv(d),e.d=new fx((c(re(Ne((j0(),Gt).o),9),20),d.i),d.g),e.e=c(d.g,685),e.e==null&&(e.e=Y2t),ru(e).b&=-17}return e.d}function $S(e,t,n,i){var r,o,a,d,b,v;if(v=nl(e.e.Ah(),t),b=0,r=c(e.g,123),qs(),c(t,69).vk()){for(a=0;a<e.i;++a)if(o=r[a],v.$l(o.Jk())){if(yi(o,n))return b;++b}}else if(n!=null){for(d=0;d<e.i;++d)if(o=r[d],v.$l(o.Jk())){if(yi(n,o.kd()))return b;++b}if(i){for(b=0,a=0;a<e.i;++a)if(o=r[a],v.$l(o.Jk())){if(ve(n)===ve(fZ(e,c(o.kd(),57))))return b;++b}}}else for(a=0;a<e.i;++a)if(o=r[a],v.$l(o.Jk())){if(o.kd()==null)return b;++b}return-1}function pKt(e,t,n,i){var r,o,a,d,b,v,x,S,M,L,P,z;if(n.Uh(t)&&(x=(L=t,L?c(i,52).di(L):null),x))if(z=n.Kh(t,e.a),P=t.t,P>1||P==-1)if(S=c(z,72),M=c(x,72),S.dc())M.$b();else for(a=!!Hs(t),o=0,d=e.a?S.Jc():S.Gi();d.Ob();)v=c(d.Pb(),57),r=c(Oh(e,v),57),r?(a?(b=M.bd(r),b==-1?M.Ei(o,r):o!=b&&M.Si(o,r)):M.Ei(o,r),++o):e.b&&!a&&(M.Ei(o,v),++o);else z==null?x.Wb(null):(r=Oh(e,z),r==null?e.b&&!Hs(t)&&x.Wb(z):x.Wb(r))}function bKt(e,t){var n,i,r,o,a,d,b,v;for(n=new OO,r=new Ht(Vt(pr(t).a.Jc(),new U));hn(r);)if(i=c(sn(r),17),!vs(i)&&(d=i.c.i,_2e(d,fU))){if(v=eye(e,d,fU,aU),v==-1)continue;n.b=p.Math.max(n.b,v),!n.a&&(n.a=new Fe),qe(n.a,d)}for(a=new Ht(Vt($i(t).a.Jc(),new U));hn(a);)if(o=c(sn(a),17),!vs(o)&&(b=o.d.i,_2e(b,aU))){if(v=eye(e,b,aU,fU),v==-1)continue;n.d=p.Math.max(n.d,v),!n.c&&(n.c=new Fe),qe(n.c,b)}return n}function mKt(e,t,n,i){var r,o,a,d,b,v,x;if(n.d.i!=t.i){for(r=new Eh(e),mu(r,(Jt(),jr)),Ee(r,(De(),Oi),n),Ee(r,(Ge(),cr),(Zr(),xc)),It(i.c,r),a=new bc,_o(a,r),$r(a,(Je(),Yt)),d=new bc,_o(d,r),$r(d,nn),x=n.d,ss(n,a),o=new qm,ec(o,n),Ee(o,ho,null),ks(o,d),ss(o,x),v=new os(n.b,0);v.b<v.d.gc();)b=(dn(v.b<v.d.gc()),c(v.d.Xb(v.c=v.b++),70)),ve(R(b,yd))===ve((Sh(),oy))&&(Ee(b,vk,n),iu(v),qe(o.b,b));Ett(r,a,d)}}function wKt(e,t,n,i){var r,o,a,d,b,v,x;if(n.c.i!=t.i)for(r=new Eh(e),mu(r,(Jt(),jr)),Ee(r,(De(),Oi),n),Ee(r,(Ge(),cr),(Zr(),xc)),It(i.c,r),a=new bc,_o(a,r),$r(a,(Je(),Yt)),d=new bc,_o(d,r),$r(d,nn),ss(n,a),o=new qm,ec(o,n),Ee(o,ho,null),ks(o,d),ss(o,t),Ett(r,a,d),v=new os(n.b,0);v.b<v.d.gc();)b=(dn(v.b<v.d.gc()),c(v.d.Xb(v.c=v.b++),70)),x=c(R(b,yd),281),x==(Sh(),oy)&&(xi(b,vk)||Ee(b,vk,n),iu(v),qe(o.b,b))}function nrt(e){PS();var t,n,i,r;if(t=xs(e),e<AE.length)return AE[t];if(e<=50)return HD((ld(),Loe),t);if(e<=qg)return T5(HD(fk[1],t),t);if(e>1e6)throw J(new Sz("power of ten too big"));if(e<=di)return T5(HD(fk[1],t),t);for(i=HD(fk[1],di),r=i,n=Zo(e-di),t=xs(e%di);Mc(n,di)>0;)r=Ox(r,i),n=Ha(n,di);for(r=Ox(r,HD(fk[1],t)),r=T5(r,di),n=Zo(e-di);Mc(n,di)>0;)r=T5(r,di),n=Ha(n,di);return r=T5(r,t),r}function irt(e){var t,n,i,r,o,a,d,b,v,x;for(b=new G(e.a);b.a<b.c.c.length;)if(d=c(Q(b),9),d.k==(Jt(),Cr)&&(r=c(R(d,(De(),Ko)),64),r==(Je(),nn)||r==Yt))for(i=new Ht(Vt(sd(d).a.Jc(),new U));hn(i);)n=c(sn(i),17),t=n.a,t.b!=0&&(v=n.c,v.i==d&&(o=(dn(t.b!=0),c(t.a.a.c,8)),o.b=Lo(W(V(Vr,1),Be,8,0,[v.i.n,v.n,v.a])).b),x=n.d,x.i==d&&(a=(dn(t.b!=0),c(t.c.b.c,8)),a.b=Lo(W(V(Vr,1),Be,8,0,[x.i.n,x.n,x.a])).b))}function QT(e,t,n,i){var r,o,a;if(this.j=new Fe,this.k=new Fe,this.b=new Fe,this.c=new Fe,this.e=new c5,this.i=new nu,this.f=new $K,this.d=new Fe,this.g=new Fe,qe(this.b,e),qe(this.b,t),this.e.c=p.Math.min(e.a,t.a),this.e.d=p.Math.min(e.b,t.b),this.e.b=p.Math.abs(e.a-t.a),this.e.a=p.Math.abs(e.b-t.b),r=c(R(i,(Ge(),ho)),79),r)for(a=_n(r,0);a.b!=a.d.c;)o=c(An(a),8),Gbe(o.a,e.a)&&ei(this.i,o);n&&qe(this.j,n),qe(this.k,i)}function vKt(e,t,n,i){var r,o,a,d,b,v,x;for(d=-1,x=new G(e);x.a<x.c.c.length;)v=c(Q(x),117),v.g=d--,r=Hn(Eq(fq(pi(new jt(null,new Tt(v.f,16)),new mA),new wA)).d),o=Hn(Eq(fq(pi(new jt(null,new Tt(v.k,16)),new BO),new zO)).d),a=r,b=o,i||(a=Hn(Eq(fq(new jt(null,new Tt(v.f,16)),new BR)).d),b=Hn(Eq(fq(new jt(null,new Tt(v.k,16)),new b2)).d)),v.d=a,v.a=r,v.i=b,v.b=o,b==0?tr(n,v,n.c.b,n.c):a==0&&tr(t,v,t.c.b,t.c)}function W5(e,t){var n,i,r,o,a,d;if(e.k==(Jt(),lc)&&(n=e.k==lc&&!k6(pi(c(R(e,(De(),HE)),16).Mc(),new d6(new Py))).zd((Hp(),hk))?(qu(),LP):t,Ee(e,(De(),xk),n),n!=(qu(),up)))for(i=c(R(e,Oi),17),d=ue(he(R(i,(Ge(),Xg)))),a=0,n==n1?a=e.o.b-p.Math.ceil(d/2):n==LP&&(a=p.Math.ceil(e.o.b-ue(he(R(Jr(e),m3)))-d)/2,e.o.b-=ue(he(R(Jr(e),m3))),e.o.b-=d),o=new G(e.j);o.a<o.c.c.length;)r=c(Q(o),12),r.n.b=a}function rrt(e,t,n){var i,r,o,a,d,b,v,x,S;for(r=!0,a=new G(e.b);a.a<a.c.c.length;){for(o=c(Q(a),26),v=Qr,x=null,b=new G(o.a);b.a<b.c.c.length;)if(d=c(Q(b),9),S=ue(t.p[d.p])+ue(t.d[d.p])-d.d.d,i=ue(t.p[d.p])+ue(t.d[d.p])+d.o.b+d.d.a,S>v&&i>v)x=d,v=ue(t.p[d.p])+ue(t.d[d.p])+d.o.b+d.d.a;else{r=!1,n.$g()&&n.ah("bk node placement breaks on "+d+" which should have been after "+x);break}if(!r)break}return n.$g()&&n.ah(t+" is feasible: "+r),r}function srt(e,t){var n,i;i=c(ke(t,(Dn(),Y1)),125),n=new xu(0,t.j+t.f+i.a+e.b/2,new xu(t.g/2,t.j+t.f+i.a+e.b/2,null)),ii(t,(Qd(),zb),new xu(-i.b-e.b/2+t.g/2,t.j-i.d-e.b/2,new xu(-t.g/2,t.j-i.d,n))),n=new xu(0,t.j+t.f+i.a,new xu(-t.g/2,t.j+t.f+i.a+e.b/2,null)),ii(t,Zv,new xu(t.g/2+i.c+e.b/2,t.j-i.d,new xu(t.g/2,t.j-i.d-e.b/2,n))),ii(t,V9,t.i-i.b),ii(t,X9,t.i+i.c+t.g),ii(t,Hmt,t.j-i.d),ii(t,Pue,t.j+i.a+t.f),ii(t,kd,c(ke(t,zb),107).b.b.a)}function Mye(e,t,n,i){var r,o,a,d,b,v,x,S,M;if(o=new Eh(e),mu(o,(Jt(),Dc)),Ee(o,(Ge(),cr),(Zr(),xc)),r=0,t){for(a=new bc,Ee(a,(De(),Oi),t),Ee(o,Oi,t.i),$r(a,(Je(),Yt)),_o(a,o),M=rd(t.e),v=M,x=0,S=v.length;x<S;++x)b=v[x],ss(b,a);Ee(t,Ul,o),++r}if(n){for(d=new bc,Ee(o,(De(),Oi),n.i),Ee(d,Oi,n),$r(d,(Je(),nn)),_o(d,o),M=rd(n.g),v=M,x=0,S=v.length;x<S;++x)b=v[x],ks(b,d);Ee(n,Ul,o),++r}return Ee(o,(De(),HU),Pe(r)),It(i.c,o),o}function yKt(e){var t,n,i,r,o,a,d,b,v,x,S,M,L;for(n=(v=new x1(e.c.b).a.vc().Jc(),new C2(v));n.a.Ob();)t=(d=c(n.a.Pb(),45),c(d.kd(),144)),r=t.a,r==null&&(r=""),i=N7t(e.c,r),!i&&r.length==0&&(i=t$t(e)),i&&!uv(i.c,t,!1)&&ei(i.c,t);for(a=_n(e.a,0);a.b!=a.d.c;)o=c(An(a),478),x=Dee(e.c,o.a),L=Dee(e.c,o.b),x&&L&&ei(x.c,new Ps(L,o.c));for(Ou(e.a),M=_n(e.b,0);M.b!=M.d.c;)S=c(An(M),478),t=A7t(e.c,S.a),b=Dee(e.c,S.b),t&&b&&g8t(t,b,S.c);Ou(e.b)}function xKt(e,t,n){var i,r,o,a,d,b,v,x,S;for(a=new nZe,v=W(V(Fn,1),ci,30,15,[0]),r=-1,o=0,i=0,b=0;b<e.b.c.length;++b)if(x=c(Xe(e.b,b),439),x.b>0){if(r<0&&x.a&&(r=b,o=v[0],i=0),r>=0){if(d=x.b,b==r&&(d-=i++,d==0))return 0;if(!ust(t,v,x,d,a)){b=r-1,v[0]=o;continue}}else if(r=-1,!ust(t,v,x,0,a))return 0}else{if(r=-1,ms(x.c,0)==32){if(S=v[0],MJe(t,v),v[0]>S)continue}else if(FAt(t,x.c,v[0])){v[0]+=x.c.length;continue}return 0}return fen(a,n)?v[0]:0}function kKt(e,t,n){var i,r,o,a,d,b,v,x,S,M;for(x=new nq(new iNe(n)),d=ye(kl,eh,30,e.f.e.c.length,16,1),npe(d,d.length),n[t.a]=0,v=new G(e.f.e);v.a<v.c.c.length;)b=c(Q(v),156),b.a!=t.a&&(n[b.a]=di),p5(CS(x,b),XS);for(;x.b.c.length!=0;)for(S=c(Zee(x),156),d[S.a]=!0,o=dBe(new cY(e.b,S),0);o.c;)r=c(qbe(o),292),M=Xzt(r,S),!d[M.a]&&(xi(r,(DD(),uU))?a=ue(he(R(r,uU))):a=e.c,i=n[S.a]+a,i<n[M.a]&&(n[M.a]=i,UXe(x,M),p5(CS(x,M),XS)))}function Aye(e){var t,n,i,r,o,a,d,b;n=et(Ze(R(e,(Sf(),Yft)))),o=e.a.c.d,d=e.a.d.d,n?(a=S1(Hr(new $e(d.a,d.b),o),.5),b=S1(Ms(e.e),.5),t=Hr(ki(new $e(o.a,o.b),a),b),Pge(e.d,t)):(r=ue(he(R(e.a,cht))),i=e.d,o.a>=d.a?o.b>=d.b?(i.a=d.a+(o.a-d.a)/2+r,i.b=d.b+(o.b-d.b)/2-r-e.e.b):(i.a=d.a+(o.a-d.a)/2+r,i.b=o.b+(d.b-o.b)/2+r):o.b>=d.b?(i.a=o.a+(d.a-o.a)/2+r,i.b=d.b+(o.b-d.b)/2+r):(i.a=o.a+(d.a-o.a)/2+r,i.b=o.b+(d.b-o.b)/2-r-e.e.b))}function GT(e){var t,n,i,r,o,a,d,b;if(!e.f){if(b=new Ip,d=new Ip,t=GC,a=t.a.yc(e,t),a==null){for(o=new cn(vo(e));o.e!=o.i.gc();)r=c(un(o),29),ur(b,GT(r));t.a.Ac(e)!=null,t.a.gc()==0}for(i=(!e.s&&(e.s=new Me(xl,e,21,17)),new cn(e.s));i.e!=i.i.gc();)n=c(un(i),182),oe(n,104)&&Nn(d,c(n,20));cv(d),e.r=new iFe(e,(c(re(Ne((j0(),Gt).o),6),20),d.i),d.g),ur(b,e.r),cv(b),e.f=new fx((c(re(Ne(Gt.o),5),20),b.i),b.g),ru(e).b&=-3}return e.f}function _Q(){_Q=te,bTe=W(V(Na,1),fd,30,15,[48,49,50,51,52,53,54,55,56,57,65,66,67,68,69,70]),C2t=new RegExp(`[ 	
\r\f]+`);try{qC=W(V(lnn,1),Lt,2093,0,[new HN((cge(),$H("yyyy-MM-dd'T'HH:mm:ss'.'SSSZ",T_((xz(),xz(),EE))))),new HN($H("yyyy-MM-dd'T'HH:mm:ss'.'SSS",T_(EE))),new HN($H("yyyy-MM-dd'T'HH:mm:ss",T_(EE))),new HN($H("yyyy-MM-dd'T'HH:mm",T_(EE))),new HN($H("yyyy-MM-dd",T_(EE)))])}catch(e){if(e=vr(e),!oe(e,81))throw J(e)}}function OKt(e){var t,n,i,r,o,a,d;for(n=null,d=null,i=c(R(e.b,(Ge(),ole)),349),i==(dT(),dP)&&(n=new Fe,d=new Fe),a=new G(e.d);a.a<a.c.c.length;)if(o=c(Q(a),108),r=o.i,!!r)switch(o.e.g){case 0:t=c(Y7(new t5(o.b)),64),i==dP&&t==(Je(),Kt)?It(n.c,o):i==dP&&t==(Je(),bn)?It(d.c,o):VGt(o,t);break;case 1:vJt(o);break;case 2:case 3:IVt(o);break;case 4:MQt(o)}n&&(n.c.length==0||Kit(n,(Je(),Kt)),d.c.length==0||Kit(d,(Je(),bn)))}function SKt(e,t){var n,i,r,o;if(r=lu(e.d,1)!=0,i=bye(e,t),i==0&&et(Ze(R(t.j,(De(),tp)))))return 0;!et(Ze(R(t.j,(De(),tp))))&&!et(Ze(R(t.j,h3)))||ve(R(t.j,(Ge(),t1)))===ve((B1(),rp))?t.c.kg(t.e,r):r=et(Ze(R(t.j,tp))),XD(e,t,r,!0),et(Ze(R(t.j,h3)))&&Ee(t.j,h3,(Bt(),!1)),et(Ze(R(t.j,tp)))&&(Ee(t.j,tp,(Bt(),!1)),Ee(t.j,h3,!0)),n=bye(e,t);do{if(pme(e),n==0)return 0;r=!r,o=n,XD(e,t,r,!1),n=bye(e,t)}while(o>n);return o}function ort(e,t){var n,i,r,o;if(r=lu(e.d,1)!=0,i=dQ(e,t),i==0&&et(Ze(R(t.j,(De(),tp)))))return 0;!et(Ze(R(t.j,(De(),tp))))&&!et(Ze(R(t.j,h3)))||ve(R(t.j,(Ge(),t1)))===ve((B1(),rp))?t.c.kg(t.e,r):r=et(Ze(R(t.j,tp))),XD(e,t,r,!0),et(Ze(R(t.j,h3)))&&Ee(t.j,h3,(Bt(),!1)),et(Ze(R(t.j,tp)))&&(Ee(t.j,tp,(Bt(),!1)),Ee(t.j,h3,!0)),n=dQ(e,t);do{if(pme(e),n==0)return 0;r=!r,o=n,XD(e,t,r,!1),n=dQ(e,t)}while(o>n);return o}function jKt(e,t,n){var i,r,o,a,d;if(i=c(R(e,(Ge(),ile)),24),n.a>t.a&&(i.Gc((bb(),TC))?e.c.a+=(n.a-t.a)/2:i.Gc(EC)&&(e.c.a+=n.a-t.a)),n.b>t.b&&(i.Gc((bb(),MC))?e.c.b+=(n.b-t.b)/2:i.Gc(CC)&&(e.c.b+=n.b-t.b)),c(R(e,(De(),Lc)),24).Gc((Gs(),Ea))&&(n.a>t.a||n.b>t.b))for(d=new G(e.a);d.a<d.c.c.length;)a=c(Q(d),9),a.k==(Jt(),Cr)&&(r=c(R(a,Ko),64),r==(Je(),nn)?a.n.a+=n.a-t.a:r==bn&&(a.n.b+=n.b-t.b));o=e.d,e.f.a=n.a-o.b-o.c,e.f.b=n.b-o.d-o.a}function TKt(e,t,n){var i,r,o,a,d;if(i=c(R(e,(Ge(),ile)),24),n.a>t.a&&(i.Gc((bb(),TC))?e.c.a+=(n.a-t.a)/2:i.Gc(EC)&&(e.c.a+=n.a-t.a)),n.b>t.b&&(i.Gc((bb(),MC))?e.c.b+=(n.b-t.b)/2:i.Gc(CC)&&(e.c.b+=n.b-t.b)),c(R(e,(De(),Lc)),24).Gc((Gs(),Ea))&&(n.a>t.a||n.b>t.b))for(a=new G(e.a);a.a<a.c.c.length;)o=c(Q(a),9),o.k==(Jt(),Cr)&&(r=c(R(o,Ko),64),r==(Je(),nn)?o.n.a+=n.a-t.a:r==bn&&(o.n.b+=n.b-t.b));d=e.d,e.f.a=n.a-d.b-d.c,e.f.b=n.b-d.d-d.a}function EKt(e){var t,n,i,r,o,a,d,b,v,x,S,M;for(t=htt(e),x=(d=new an(t).a.vc().Jc(),new mr(d));x.a.Ob();){for(v=(r=c(x.a.Pb(),45),c(r.jd(),9)),S=0,M=0,S=v.d.d,M=v.o.b+v.d.a,e.d[v.p]=0,n=v;(o=e.a[n.p])!=v;)i=NBt(n,o),b=0,e.c==(td(),Wg)?b=i.d.n.b+i.d.a.b-i.c.n.b-i.c.a.b:b=i.c.n.b+i.c.a.b-i.d.n.b-i.d.a.b,a=ue(e.d[n.p])+b,e.d[o.p]=a,S=p.Math.max(S,o.d.d-a),M=p.Math.max(M,a+o.o.b+o.d.a),n=o;n=v;do e.d[n.p]=ue(e.d[n.p])+S,n=e.a[n.p];while(n!=v);e.b[v.p]=S+M}}function Nye(e,t,n,i){var r,o,a,d,b,v,x,S,M;return b=Hr(new $e(n.a,n.b),e),v=b.a*t.b-b.b*t.a,x=t.a*i.b-t.b*i.a,S=(b.a*i.b-b.b*i.a)/x,M=v/x,x==0?v==0?(r=ki(new $e(n.a,n.b),S1(new $e(i.a,i.b),.5)),o=A0(e,r),a=A0(ki(new $e(e.a,e.b),t),r),d=p.Math.sqrt(i.a*i.a+i.b*i.b)*.5,o<a&&o<=d?new $e(e.a,e.b):a<=d?ki(new $e(e.a,e.b),t):null):null:S>=0&&S<=1&&M>=0&&M<=1?ki(new $e(e.a,e.b),S1(new $e(t.a,t.b),S)):null}function UT(e,t,n){var i,r,o,a,d,b,v,x,S,M;for(o=0,a=e.t,r=0,i=0,b=0,M=0,S=0,n&&(e.n.c.length=0,qe(e.n,new kq(e.s,e.t,e.i))),d=0,x=new G(e.b);x.a<x.c.c.length;)v=c(Q(x),19),o+v.g+(d>0?e.i:0)>t&&b>0&&(o=0,a+=b+e.i,r=p.Math.max(r,M),i+=b+e.i,b=0,M=0,n&&(++S,qe(e.n,new kq(e.s,a,e.i))),d=0),M+=v.g+(d>0?e.i:0),b=p.Math.max(b,v.f),n&&Kwe(c(Xe(e.n,S),211),v),o+=v.g+(d>0?e.i:0),++d;return r=p.Math.max(r,M),i+=b,n&&(e.r=r,e.d=i,e2e(e.j)),new pf(e.s,e.t,r,i)}function DQ(e){var t,n,i;return n=ve(ke(e,(Ge(),Tk)))===ve((QD(),Cce))||ve(ke(e,Tk))===ve(Oce)||ve(ke(e,Tk))===ve(Sce)||ve(ke(e,Tk))===ve(Tce)||ve(ke(e,Tk))===ve(Mce)||ve(ke(e,Tk))===ve(KL),i=ve(ke(e,nJ))===ve((UD(),vle))||ve(ke(e,nJ))===ve(xle)||ve(ke(e,cP))===ve((H0(),H9))||ve(ke(e,cP))===ve((H0(),sC)),t=ve(ke(e,t1))!==ve((B1(),rp))||et(Ze(ke(e,R9)))||ve(ke(e,XE))!==ve(($5(),LE))||ue(he(ke(e,sP)))!=0||ue(he(ke(e,ele)))!=0,n||i||t}function Fx(e){var t,n,i,r,o,a,d,b;if(!e.a){if(e.o=null,b=new FDe(e),t=new Y$,n=GC,d=n.a.yc(e,n),d==null){for(a=new cn(vo(e));a.e!=a.i.gc();)o=c(un(a),29),ur(b,Fx(o));n.a.Ac(e)!=null,n.a.gc()==0}for(r=(!e.s&&(e.s=new Me(xl,e,21,17)),new cn(e.s));r.e!=r.i.gc();)i=c(un(r),182),oe(i,336)&&Nn(t,c(i,38));cv(t),e.k=new nFe(e,(c(re(Ne((j0(),Gt).o),7),20),t.i),t.g),ur(b,e.k),cv(b),e.a=new fx((c(re(Ne(Gt.o),4),20),b.i),b.g),ru(e).b&=-2}return e.a}function CKt(e){var t,n,i,r,o,a,d,b,v,x,S,M;if(d=e.d,S=c(R(e,(De(),Sk)),16),t=c(R(e,mk),16),!(!S&&!t)){if(o=ue(he(av(e,(Ge(),dle)))),a=ue(he(av(e,FSe))),M=0,S){for(v=0,r=S.Jc();r.Ob();)i=c(r.Pb(),9),v=p.Math.max(v,i.o.b),M+=i.o.a;M+=o*(S.gc()-1),d.d+=v+a}if(n=0,t){for(v=0,r=t.Jc();r.Ob();)i=c(r.Pb(),9),v=p.Math.max(v,i.o.b),n+=i.o.a;n+=o*(t.gc()-1),d.a+=v+a}b=p.Math.max(M,n),b>e.o.a&&(x=(b-e.o.a)/2,d.b=p.Math.max(d.b,x),d.c=p.Math.max(d.c,x))}}function _ye(e,t,n,i){var r,o,a,d,b,v,x;if(x=nl(e.e.Ah(),t),r=0,o=c(e.g,123),b=null,qs(),c(t,69).vk()){for(d=0;d<e.i;++d)if(a=o[d],x.$l(a.Jk())){if(yi(a,n)){b=a;break}++r}}else if(n!=null){for(d=0;d<e.i;++d)if(a=o[d],x.$l(a.Jk())){if(yi(n,a.kd())){b=a;break}++r}}else for(d=0;d<e.i;++d)if(a=o[d],x.$l(a.Jk())){if(a.kd()==null){b=a;break}++r}return b&&(wu(e.e)&&(v=t.Hk()?new Aee(e.e,4,t,n,null,r,!0):E0(e,t.rk()?2:1,t,n,t.gk(),-1,!0),i?i.lj(v):i=v),i=WD(e,b,i)),i}function wie(e,t,n,i,r,o,a){var d,b,v,x,S,M,L,P,z;switch(P=0,z=0,b=r.c,d=r.b,x=n.f,L=n.g,t.g){case 0:P=i.i+i.g+a,e.c?z=sHt(P,o,i,a):z=i.j,M=p.Math.max(b,P+L),v=p.Math.max(d,z+x);break;case 1:z=i.j+i.f+a,e.c?P=rHt(z,o,i,a):P=i.i,M=p.Math.max(b,P+L),v=p.Math.max(d,z+x);break;case 2:P=b+a,z=0,M=b+a+L,v=p.Math.max(d,x);break;case 3:P=0,z=d+a,M=p.Math.max(b,L),v=d+a+x;break;default:throw J(new qt("IllegalPlacementOption."))}return S=new Rwe(e.a,M,v,t,P,z),S}function MKt(e){var t,n,i,r,o,a,d,b;for(o=new kQe,V8t(o,(L5(),owt)),i=(r=ate(e,ye(nt,Be,2,0,6,1)),new Gj(new Ho(new lY(e,r).b)));i.b<i.d.gc();)n=(dn(i.b<i.d.gc()),zn(i.d.Xb(i.c=i.b++))),a=Bye(gp,n),a&&(t=C1(e,n),t.re()?d=t.re().a:t.oe()?d=""+t.oe().a:t.pe()?d=""+t.pe().a:d=t.Ib(),b=Rye(a,d),b!=null&&((Cl(a.j,(Th(),fr))||Cl(a.j,Nt))&&wD(ete(o,Mn),a,b),Cl(a.j,ch)&&wD(ete(o,Ii),a,b),Cl(a.j,Yg)&&wD(ete(o,hu),a,b),Cl(a.j,K1)&&wD(ete(o,Bo),a,b)));return o}function ZD(e,t,n){var i,r,o,a,d,b,v,x;if(r=c(e.g,123),F1(e.e,t))return qs(),c(t,69).vk()?new HF(t,e):new p_(t,e);for(v=nl(e.e.Ah(),t),i=0,d=0;d<e.i;++d){if(o=r[d],a=o.Jk(),v.$l(a)){if(qs(),c(t,69).vk())return o;if(a==(U5(),zk)||a==Bk){for(b=new Lu(jo(o.kd()));++d<e.i;)o=r[d],a=o.Jk(),(a==zk||a==Bk)&&Zn(b,jo(o.kd()));return l0e(c(t.Fk(),160),b.a)}else return x=o.kd(),x!=null&&n&&oe(t,104)&&(c(t,20).Bb&Is)!=0&&(x=LT(e,t,d,i,x)),x}++i}return t.gk()}function AKt(e){var t,n,i,r,o,a,d,b;for(r=new G(e.b);r.a<r.c.c.length;)for(i=c(Q(r),26),a=new G(tb(i.a));a.a<a.c.c.length;)if(o=c(Q(a),9),UJe(o)&&(n=c(R(o,(De(),Cw)),318),!n.g&&n.d))for(t=n,b=n.d;b;)qnt(b.i,b.k,!1,!0),eD(t.a),eD(b.i),eD(b.k),eD(b.b),ss(b.c,t.c.d),ss(t.c,null),zr(t.a,null),zr(b.i,null),zr(b.k,null),zr(b.b,null),d=new ibe(t.i,b.a,t.e,b.j,b.f),d.k=t.k,d.n=t.n,d.b=t.b,d.c=b.c,d.g=t.g,d.d=b.d,Ee(t.i,Cw,d),Ee(b.a,Cw,d),b=b.d,t=d}function LQ(e,t,n,i){var r,o,a,d,b,v;if(b=nl(e.e.Ah(),t),o=c(e.g,123),F1(e.e,t)){for(r=0,d=0;d<e.i;++d)if(a=o[d],b.$l(a.Jk())){if(r==n)return qs(),c(t,69).vk()?a:(v=a.kd(),v!=null&&i&&oe(t,104)&&(c(t,20).Bb&Is)!=0&&(v=LT(e,t,d,r,v)),v);++r}throw J(new zc(wE+n+Tb+r))}else{for(r=0,d=0;d<e.i;++d){if(a=o[d],b.$l(a.Jk()))return qs(),c(t,69).vk()?a:(v=a.kd(),v!=null&&i&&oe(t,104)&&(c(t,20).Bb&Is)!=0&&(v=LT(e,t,d,r,v)),v);++r}return t.gk()}}function vie(){vie=te,Hat=W(V(Fn,1),ci,30,15,[ls,1162261467,KT,1220703125,362797056,1977326743,KT,387420489,QQ,214358881,429981696,815730721,1475789056,170859375,268435456,410338673,612220032,893871739,128e7,1801088541,113379904,148035889,191102976,244140625,308915776,387420489,481890304,594823321,729e6,887503681,KT,1291467969,1544804416,1838265625,60466176]),Qat=W(V(Fn,1),ci,30,15,[-1,-1,31,19,15,13,11,11,10,9,9,8,8,8,8,7,7,7,7,7,7,7,6,6,6,6,6,6,6,6,6,6,6,6,6,6,5])}function yie(e,t){var n,i,r,o,a,d,b,v,x,S;if(a=e.e,b=t.e,b==0)return e;if(a==0)return t.e==0?t:new Wp(-t.e,t.d,t.a);if(o=e.d,d=t.d,o+d==2)return n=Yr(e.a[0],Us),i=Yr(t.a[0],Us),a<0&&(n=Ng(n)),b<0&&(i=Ng(i)),ld(),gF(Ha(n,i),0)?$0(Ha(n,i)):F7($0(Ng(Ha(n,i))));if(r=o!=d?o>d?1:-1:Gme(e.a,t.a,o),r==-1)S=-b,x=a==b?Ree(t.a,d,e.a,o):Bee(t.a,d,e.a,o);else if(S=a,a==b){if(r==0)return ld(),ME;x=Ree(e.a,o,t.a,d)}else x=Bee(e.a,o,t.a,d);return v=new Wp(S,x.length,x),V7(v),v}function NKt(e,t){var n,i,r,o;if(o=Qit(t),!t.c&&(t.c=new Me(hu,t,9,9)),lr(new jt(null,(!t.c&&(t.c=new Me(hu,t,9,9)),new Tt(t.c,16))),new cNe(o)),r=c(R(o,(De(),Lc)),24),CZt(t,r),r.Gc((Gs(),Ea)))for(i=new cn((!t.c&&(t.c=new Me(hu,t,9,9)),t.c));i.e!=i.i.gc();)n=c(un(i),127),ZZt(e,t,o,n);return c(ke(t,(Ge(),Pb)),185).gc()!=0&&Ant(t,o),et(Ze(R(o,ISe)))&&r.Ec(FU),xi(o,lP)&&ePe(new ywe(ue(he(R(o,lP)))),o),ve(ke(t,Fv))===ve((R1(),Zg))?xtn(e,t,o):sen(e,t,o),o}function Nc(e,t){var n,i,r,o,a,d,b;if(e==null)return null;if(o=e.length,o==0)return"";for(b=ye(Na,fd,30,o,15,1),fs(0,o,e.length),fs(0,o,b.length),dqe(e,0,o,b,0),n=null,d=t,r=0,a=0;r<o;r++)i=b[r],Ist(),i<=32&&(ne[i]&2)!=0?d?(!n&&(n=new Ba(e)),n7t(n,r-a++)):(d=t,i!=32&&(!n&&(n=new Ba(e)),mte(n,r-a,r-a+1," "))):d=!1;return d?n?(o=n.a.length,o>0?Fa(n.a,0,o-1):""):(fs(0,o-1,e.length),e.substr(0,o-1)):n?n.a:e}function _Kt(e,t,n){var i,r,o;if(xi(t,(Ge(),Ro))&&(ve(R(t,Ro))===ve((Tu(),V1))||ve(R(t,Ro))===ve(Db))||xi(n,Ro)&&(ve(R(n,Ro))===ve((Tu(),V1))||ve(R(n,Ro))===ve(Db)))return 0;if(i=Jr(t),r=wVt(e,t,n),r!=0)return r;if(xi(t,(De(),Pi))&&xi(n,Pi)){if(o=fc(cw(t,n,i,c(R(i,np),15).a),cw(n,t,i,c(R(i,np),15).a)),ve(R(i,VE))===ve((D0(),ZL))&&ve(R(t,WE))!==ve(R(n,WE))&&(o=0),o<0)return VD(e,t,n),o;if(o>0)return VD(e,n,t),o}return qGt(e,t,n)}function crt(e,t){var n,i,r,o,a,d,b,v,x,S,M;for(i=new Ht(Vt(z1(t).a.Jc(),new U));hn(i);)n=c(sn(i),74),oe(re((!n.b&&(n.b=new Et(vn,n,4,7)),n.b),0),196)||(b=to(c(re((!n.c&&(n.c=new Et(vn,n,5,8)),n.c),0),83)),PT(n)||(a=t.i+t.g/2,d=t.j+t.f/2,x=b.i+b.g/2,S=b.j+b.f/2,M=new as,M.a=x-a,M.b=S-d,o=new $e(M.a,M.b),TS(o,t.g,t.f),M.a-=o.a,M.b-=o.b,a=x-M.a,d=S-M.b,v=new $e(M.a,M.b),TS(v,b.g,b.f),M.a-=v.a,M.b-=v.b,x=a+M.a,S=d+M.b,r=$T(n),Vm(r,a),Wm(r,d),Jm(r,x),Xm(r,S),crt(e,b)))}function kv(e,t){var n,i,r,o,a;if(a=c(t,140),$x(e),$x(a),a.b!=null){if(e.c=!0,e.b==null){e.b=ye(Fn,ci,30,a.b.length,15,1),mc(a.b,0,e.b,0,a.b.length);return}for(o=ye(Fn,ci,30,e.b.length+a.b.length,15,1),n=0,i=0,r=0;n<e.b.length||i<a.b.length;)n>=e.b.length?(o[r++]=a.b[i++],o[r++]=a.b[i++]):i>=a.b.length?(o[r++]=e.b[n++],o[r++]=e.b[n++]):a.b[i]<e.b[n]||a.b[i]===e.b[n]&&a.b[i+1]<e.b[n+1]?(o[r++]=a.b[i++],o[r++]=a.b[i++]):(o[r++]=e.b[n++],o[r++]=e.b[n++]);e.b=o}}function DKt(e,t){var n,i,r,o,a,d,b,v,x,S;return n=et(Ze(R(e,(De(),Bv)))),d=et(Ze(R(t,Bv))),i=c(R(e,sh),12),b=c(R(t,sh),12),r=c(R(e,Wa),12),v=c(R(t,Wa),12),x=!!i&&i==b,S=!!r&&r==v,!n&&!d?new v0e(c(Q(new G(e.j)),12).p==c(Q(new G(t.j)),12).p,x,S):(o=(!et(Ze(R(e,Bv)))||et(Ze(R(e,iP))))&&(!et(Ze(R(t,Bv)))||et(Ze(R(t,iP)))),a=(!et(Ze(R(e,Bv)))||!et(Ze(R(e,iP))))&&(!et(Ze(R(t,Bv)))||!et(Ze(R(t,iP)))),new v0e(x&&o||S&&a,x,S))}function lrt(e){var t,n,i,r,o,a,d,b;for(i=0,n=0,b=new Ai,t=0,d=new G(e.n);d.a<d.c.c.length;)a=c(Q(d),211),a.c.c.length==0?tr(b,a,b.c.b,b.c):(i=p.Math.max(i,a.d),n+=a.a+(t>0?e.i:0)),++t;for(hwe(e.n,b),e.d=n,e.r=i,e.g=0,e.f=0,e.e=0,e.o=nr,e.p=nr,o=new G(e.b);o.a<o.c.c.length;)r=c(Q(o),19),e.p=p.Math.min(e.p,r.g),e.g=p.Math.max(e.g,r.g),e.f=p.Math.max(e.f,r.f),e.o=p.Math.min(e.o,r.f),e.e+=r.f+e.i;e.a=e.e/e.b.c.length-e.i*((e.b.c.length-1)/e.b.c.length),e2e(e.j)}function urt(e){var t,n,i,r;return(e.Db&64)!=0?Gte(e):(t=new Lu(c5e),i=e.k,i?Zn(Zn((t.a+=' "',t),i),'"'):(!e.n&&(e.n=new Me(Bo,e,1,7)),e.n.i>0&&(r=(!e.n&&(e.n=new Me(Bo,e,1,7)),c(re(e.n,0),158)).a,!r||Zn(Zn((t.a+=' "',t),r),'"'))),n=(!e.b&&(e.b=new Et(vn,e,4,7)),!(e.b.i<=1&&(!e.c&&(e.c=new Et(vn,e,5,8)),e.c.i<=1))),n?t.a+=" [":t.a+=" ",Zn(t,kge(new nY,new cn(e.b))),n&&(t.a+="]"),t.a+=jre,n&&(t.a+="["),Zn(t,kge(new nY,new cn(e.c))),n&&(t.a+="]"),t.a)}function LKt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt;for(Se=e.c,xe=t.c,n=Do(Se.a,e,0),i=Do(xe.a,t,0),se=c(tw(e,(Qs(),Jl)).Jc().Pb(),12),bt=c(tw(e,Wc).Jc().Pb(),12),de=c(tw(t,Jl).Jc().Pb(),12),Dt=c(tw(t,Wc).Jc().Pb(),12),X=rd(se.e),We=rd(bt.g),ie=rd(de.e),pt=rd(Dt.g),B0(e,i,xe),a=ie,x=0,P=a.length;x<P;++x)r=a[x],ss(r,se);for(d=pt,S=0,z=d.length;S<z;++S)r=d[S],ks(r,bt);for(B0(t,n,Se),b=X,M=0,H=b.length;M<H;++M)r=b[M],ss(r,de);for(o=We,v=0,L=o.length;v<L;++v)r=o[v],ks(r,Dt)}function PKt(e){var t,n,i,r,o,a,d;for(a=c(ke(e,(vx(),k3)),19),i=new cn((!a.e&&(a.e=new Et(Ii,a,7,4)),a.e));i.e!=i.i.gc();)n=c(un(i),74),d=new $e(c(re((!n.a&&(n.a=new Me(Hi,n,6,6)),n.a),0),171).j,c(re((!n.a&&(n.a=new Me(Hi,n,6,6)),n.a),0),171).k),o=new $e(c(re((!n.a&&(n.a=new Me(Hi,n,6,6)),n.a),0),171).b,c(re((!n.a&&(n.a=new Me(Hi,n,6,6)),n.a),0),171).c),r=new $e(o.a-d.a,o.b-d.b),t=p.Math.atan2(r.b,r.a),c(re((!n.c&&(n.c=new Et(vn,n,5,8)),n.c),0),83).of((F0(),lue),t)}function IKt(e,t){var n,i,r,o,a,d,b,v,x;for(t.Tg("Interactive Node Reorderer",1),x=(!e.a&&(e.a=new Me(Mn,e,10,11)),e.a),d=new Fe,r=new cn(x);r.e!=r.i.gc();)n=c(un(r),19),ga(n,(Ah(),xP))&&It(d.c,n);for(o=new G(d);o.a<o.c.c.length;)n=c(Q(o),19),Vq(x,n);for(Ct(),Rr(d,new _A),a=new G(d);a.a<a.c.c.length;)n=c(Q(a),19),v=c(ke(n,(Ah(),xP)),15).a,v=p.Math.min(v,x.i),wT(x,v,n);for(b=0,i=new cn(x);i.e!=i.i.gc();)n=c(un(i),19),ii(n,(Ah(),F8e),Pe(b)),++b;t.Ug()}function RKt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z;for(d=ye(Fn,ci,30,t.b.c.length,15,1),v=ye(sce,_e,252,t.b.c.length,0,1),b=ye(e1,Hg,9,t.b.c.length,0,1),S=e.a,M=0,L=S.length;M<L;++M){for(x=S[M],z=0,a=new G(x.e);a.a<a.c.c.length;)r=c(Q(a),9),i=ige(r.c),++d[i],P=ue(he(R(t,(Ge(),Mf)))),d[i]>0&&b[i]&&(P=px(e.b,b[i],r)),z=p.Math.max(z,r.c.c.b+P);for(o=new G(x.e);o.a<o.c.c.length;)r=c(Q(o),9),r.n.b=z+r.d.d,n=r.c,n.c.b=z+r.d.d+r.o.b+r.d.a,v[Do(n.b.b,n,0)]=r.k,b[Do(n.b.b,n,0)]=r}}function Dye(e,t,n){var i,r,o,a,d,b,v,x;return p.Math.abs(t.s-t.c)<dd||p.Math.abs(n.s-n.c)<dd?0:(i=dnt(e,t.j,n.e),r=dnt(e,n.j,t.e),o=i==-1||r==-1,a=0,o?(i==-1&&(new eb((Wf(),sp),n,t,1),++a),r==-1&&(new eb((Wf(),sp),t,n,1),++a)):(d=Nx(t.j,n.s,n.c),d+=Nx(n.e,t.s,t.c),b=Nx(n.j,t.s,t.c),b+=Nx(t.e,n.s,n.c),v=i+16*d,x=r+16*b,v<x?new eb((Wf(),Kv),t,n,x-v):v>x?new eb((Wf(),Kv),n,t,v-x):v>0&&x>0&&(new eb((Wf(),Kv),t,n,0),new eb(Kv,n,t,0))),a)}function $Kt(e,t,n){var i,r,o;for(e.a=new Fe,o=_n(t.b,0);o.b!=o.d.c;){for(r=c(An(o),41);c(R(r,(Uo(),xd)),15).a>e.a.c.length-1;)qe(e.a,new Ps(Vx,r4e));i=c(R(r,xd),15).a,n==(Nr(),go)||n==yo?(r.e.a<ue(he(c(Xe(e.a,i),49).a))&&H4(c(Xe(e.a,i),49),r.e.a),r.e.a+r.f.a>ue(he(c(Xe(e.a,i),49).b))&&qN(c(Xe(e.a,i),49),r.e.a+r.f.a)):(r.e.b<ue(he(c(Xe(e.a,i),49).a))&&H4(c(Xe(e.a,i),49),r.e.b),r.e.b+r.f.b>ue(he(c(Xe(e.a,i),49).b))&&qN(c(Xe(e.a,i),49),r.e.b+r.f.b))}}function art(e,t,n,i){var r,o,a,d,b,v,x;if(o=NH(i),d=et(Ze(R(i,(Ge(),ASe)))),(d||et(Ze(R(e,tJ))))&&!dx(c(R(e,cr),103)))r=I5(o),b=wye(e,n,n==(Qs(),Wc)?r:jD(r));else switch(b=new bc,_o(b,e),t?(x=b.n,x.a=t.a-e.n.a,x.b=t.b-e.n.b,ret(x,0,0,e.o.a,e.o.b),$r(b,Mit(b,o))):(r=I5(o),$r(b,n==(Qs(),Wc)?r:jD(r))),a=c(R(i,(De(),Lc)),24),v=b.j,o.g){case 2:case 1:(v==(Je(),Kt)||v==bn)&&a.Ec((Gs(),u3));break;case 4:case 3:(v==(Je(),nn)||v==Yt)&&a.Ec((Gs(),u3))}return b}function frt(e,t){var n,i,r,o,a,d;for(a=new sv(new Bp(e.f.b).a);a.b;){if(o=Ex(a),r=c(o.jd(),598),t==1){if(r.yf()!=(Nr(),Ca)&&r.yf()!=Fh)continue}else if(r.yf()!=(Nr(),go)&&r.yf()!=yo)continue;switch(i=c(c(o.kd(),49).b,84),d=c(c(o.kd(),49).a,197),n=d.c,r.yf().g){case 2:i.g.c=e.e.a,i.g.b=p.Math.max(1,i.g.b+n);break;case 1:i.g.c=i.g.c+n,i.g.b=p.Math.max(1,i.g.b-n);break;case 4:i.g.d=e.e.b,i.g.a=p.Math.max(1,i.g.a+n);break;case 3:i.g.d=i.g.d+n,i.g.a=p.Math.max(1,i.g.a-n)}}}function BKt(e,t){var n,i,r,o,a,d,b,v,x,S;for(t.Tg("Simple node placement",1),S=c(R(e,(De(),d3)),317),d=0,o=new G(e.b);o.a<o.c.c.length;){for(i=c(Q(o),26),a=i.c,a.b=0,n=null,v=new G(i.a);v.a<v.c.c.length;)b=c(Q(v),9),n&&(a.b+=Dwe(b,n,S.c)),a.b+=b.d.d+b.o.b+b.d.a,n=b;d=p.Math.max(d,a.b)}for(r=new G(e.b);r.a<r.c.c.length;)for(i=c(Q(r),26),a=i.c,x=(d-a.b)/2,n=null,v=new G(i.a);v.a<v.c.c.length;)b=c(Q(v),9),n&&(x+=Dwe(b,n,S.c)),x+=b.d.d,b.n.b=x,x+=b.o.b+b.d.a,n=b;t.Ug()}function hrt(e){Am(e,new mb(Em(Sm(Tm(jm(new b1,mw),"ELK SPOrE Compaction"),"ShrinkTree is a compaction algorithm that maintains the topology of a layout. The relocation of diagram elements is based on contracting a spanning tree."),new IA))),Ie(e,mw,Nse,Ve(BJ)),Ie(e,mw,z4e,Ve(Due)),Ie(e,mw,F4e,Ve(_ue)),Ie(e,mw,_se,Ve(bje)),Ie(e,mw,Dse,Ve(Nue)),Ie(e,mw,gw,pje),Ie(e,mw,dw,8),Ie(e,mw,Lse,Ve(Cmt)),Ie(e,mw,q4e,Ve(dje)),Ie(e,mw,H4e,Ve(gje)),Ie(e,mw,AL,(Bt(),!1))}function zKt(e,t){var n,i,r,o;for(jPt(t.b.j),lr(qc(new jt(null,new Tt(t.d,16)),new a2),new MR),o=new G(t.d);o.a<o.c.c.length;){switch(r=c(Q(o),108),r.e.g){case 0:n=c(Xe(r.j,0),114).d.j,F4(r,c(vu(m5(c(Si(r.k,n),16).Mc(),s3)),114)),z4(r,c(vu(Q2(c(Si(r.k,n),16).Mc(),s3)),114));break;case 1:i=i2e(r),F4(r,c(vu(m5(c(Si(r.k,i[0]),16).Mc(),s3)),114)),z4(r,c(vu(Q2(c(Si(r.k,i[1]),16).Mc(),s3)),114));break;case 2:RQt(e,r);break;case 3:QJt(r);break;case 4:VJt(e,r)}SPt(r)}e.a=null}function xie(e,t,n){var i,r,o,a,d,b,v,x;return i=e.a.o==(vh(),Rh)?nr:Qr,d=Iit(e,new wRe(t,n)),!d.a&&d.c?(ei(e.d,d),i):d.a?(r=d.a.c,b=d.a.d,n?(v=e.a.c==(td(),Pw)?b:r,o=e.a.c==Pw?r:b,a=e.a.g[o.i.p],x=ue(e.a.p[a.p])+ue(e.a.d[o.i.p])+o.n.b+o.a.b-ue(e.a.d[v.i.p])-v.n.b-v.a.b):(v=e.a.c==(td(),Wg)?b:r,o=e.a.c==Wg?r:b,x=ue(e.a.p[e.a.g[o.i.p].p])+ue(e.a.d[o.i.p])+o.n.b+o.a.b-ue(e.a.d[v.i.p])-v.n.b-v.a.b),e.a.n[e.a.g[r.i.p].p]=(Bt(),!0),e.a.n[e.a.g[b.i.p].p]=!0,x):i}function FKt(e,t,n,i){var r,o,a,d,b,v,x,S;if(i.gc()==0)return!1;if(b=(qs(),c(t,69).vk()),a=b?i:new Um(i.gc()),F1(e.e,t)){if(t.Qi())for(x=i.Jc();x.Ob();)v=x.Pb(),NQ(e,t,v,oe(t,104)&&(c(t,20).Bb&Is)!=0)||(o=Fd(t,v),a.Ec(o));else if(!b)for(x=i.Jc();x.Ob();)v=x.Pb(),o=Fd(t,v),a.Ec(o)}else{for(S=nl(e.e.Ah(),t),r=c(e.g,123),d=0;d<e.i;++d)if(o=r[d],S.$l(o.Jk()))throw J(new qt($L));if(i.gc()>1)throw J(new qt($L));b||(o=Fd(t,i.Jc().Pb()),a.Ec(o))}return Nme(e,K2e(e,t,n),a)}function PQ(e,t,n){var i,r,o,a,d,b,v,x;if(F1(e.e,t))b=(qs(),c(t,69).vk()?new HF(t,e):new p_(t,e)),pQ(b.c,b.b),C7(b,c(n,18));else{for(x=nl(e.e.Ah(),t),i=c(e.g,123),a=0;a<e.i;++a)if(r=i[a],o=r.Jk(),x.$l(o)){if(o==(U5(),zk)||o==Bk){for(v=Xwe(e,t,n),d=a,v?vv(e,a):++a;a<e.i;)r=i[a],o=r.Jk(),o==zk||o==Bk?vv(e,a):++a;v||c(Dx(e,d,Fd(t,n)),76)}else Xwe(e,t,n)?vv(e,a):c(Dx(e,a,(qs(),c(t,69).vk()?c(n,76):Fd(t,n))),76);return}Xwe(e,t,n)||Nn(e,(qs(),c(t,69).vk()?c(n,76):Fd(t,n)))}}function drt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z;for(S=0;S<t.length;S++){for(d=e.Jc();d.Ob();)o=c(d.Pb(),223),o.fg(S,t);for(M=0;M<t[S].length;M++){for(b=e.Jc();b.Ob();)o=c(b.Pb(),223),o.gg(S,M,t);for(z=t[S][M].j,L=0;L<z.c.length;L++){for(v=e.Jc();v.Ob();)o=c(v.Pb(),223),o.hg(S,M,L,t);for(P=(ht(L,z.c.length),c(z.c[L],12)),n=0,r=new kh(P.b);No(r.a)||No(r.b);)for(i=c(No(r.a)?Q(r.a):Q(r.b),17),x=e.Jc();x.Ob();)o=c(x.Pb(),223),o.eg(S,M,L,n++,i,t)}}}for(a=e.Jc();a.Ob();)o=c(a.Pb(),223),o.dg()}function qKt(e,t,n){var i,r,o,a,d,b,v,x,S,M,L;for(n.Tg(mct,1),S=t.a,x=S.c.length,e.c=new Fe,e.d=ye(kl,eh,30,x,16,1),e.a=ye(kl,eh,30,x,16,1),e.b=new Fe,a=0,v=new G(S);v.a<v.c.c.length;)b=c(Q(v),9),b.p=a,Y2(pr(b))&&qe(e.c,b),++a;for(L=new G(e.c);L.a<L.c.c.length;)M=c(Q(L),9),tve(e,M);for(o=0;o<x;o++)e.d[o]||(d=(ht(o,S.c.length),c(S.c[o],9)),tve(e,d));for(r=new G(e.b);r.a<r.c.c.length;)i=c(Q(r),17),zg(i,!0),Ee(t,(De(),wk),(Bt(),!0));e.c=null,e.d=null,e.a=null,e.b=null,n.Ug()}function HKt(e,t,n){var i,r,o,a,d,b,v,x,S,M,L;for(n.Tg(mct,1),e.c=t,S=t.a,x=S.c.length,e.d=new Fe,e.e=ye(kl,eh,30,x,16,1),e.a=ye(kl,eh,30,x,16,1),e.b=new Fe,a=0,v=new G(S);v.a<v.c.c.length;)b=c(Q(v),9),b.p=a,Y2(pr(b))&&qe(e.d,b),++a;for(L=new G(e.d);L.a<L.c.c.length;)M=c(Q(L),9),aye(e,M);for(o=0;o<x;o++)e.e[o]||(d=(ht(o,S.c.length),c(S.c[o],9)),aye(e,d));for(r=new G(e.b);r.a<r.c.c.length;)i=c(Q(r),17),zg(i,!0),Ee(t,(De(),wk),(Bt(),!0));e.d=null,e.e=null,e.a=null,e.b=null,n.Ug()}function QKt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z;if(P=c(Ut(e.d,t),150),!P)throw J(new Kh("Edge did not exist in input."));return lie(e,t),S=kS(P),a=WN((!t.a&&(t.a=new Me(Hi,t,6,6)),t.a)),b=!a,b&&(z=new mg,i=new nHe(e,S,z,t),I8t((!t.a&&(t.a=new Me(Hi,t,6,6)),t.a),i),wf(P,eoe,null),wf(P,eoe,z)),o=ga(t,(Dn(),T3)),o&&(M=c(ke(t,T3),79),d=!M||Aqe(M),v=!d,v&&(L=new mg,r=new qze(e,t,L),ws(M,r),wf(P,"junctionPoints",L))),n=Qge(e,c(Ut(e.e,t),19)),x=n==(gS(),VJ),x&&I6(P,"container",V2(t).k),null}function GKt(e,t){var n,i,r,o,a,d,b;for(e.b=ue(he(R(t,(Ge(),Jv)))),e.c=ue(he(R(t,ip))),e.d=c(R(t,cle),350),e.a=c(R(t,WU),285),Lzt(t),d=c(ql(pi(pi(So(So(new jt(null,new Tt(t.b,16)),new lm),new RM),new kO),new c2),su(new Ls,new rs,new mo,W(V(ml,1),_e,132,0,[(va(),bl)]))),16),r=d.Jc();r.Ob();)n=c(r.Pb(),17),a=c(R(n,(De(),_b)),16),a.Ic(new mNe(e)),Ee(n,_b,null);for(i=d.Jc();i.Ob();)n=c(i.Pb(),17),b=c(R(n,(De(),S6e)),17),o=c(R(n,g3),16),ltn(e,o,b),Ee(n,g3,null)}function kie(e,t){var n,i,r,o,a,d,b;if(e.a){if(d=e.a.ve(),b=null,d!=null?t.a+=""+d:(a=e.a.kk(),a!=null&&(o=Zh(a,dl(91)),o!=-1?(b=(en(o,a.length+1),a.substr(o)),t.a+=""+Fa(a==null?pl:(zt(a),a),0,o)):t.a+=""+a)),e.d&&e.d.i!=0){for(r=!0,t.a+="<",i=new cn(e.d);i.e!=i.i.gc();)n=c(un(i),88),r?r=!1:t.a+=Jc,kie(n,t);t.a+=">"}b!=null&&(t.a+=""+b)}else e.e?(d=e.e.zb,d!=null&&(t.a+=""+d)):(t.a+="?",e.b?(t.a+=" super ",kie(e.b,t)):e.f&&(t.a+=" extends ",kie(e.f,t)))}function UKt(e){e.b=null,e.a=null,e.o=null,e.q=null,e.v=null,e.w=null,e.B=null,e.p=null,e.Q=null,e.R=null,e.S=null,e.T=null,e.U=null,e.V=null,e.W=null,e.bb=null,e.eb=null,e.ab=null,e.H=null,e.db=null,e.c=null,e.d=null,e.f=null,e.n=null,e.r=null,e.s=null,e.u=null,e.G=null,e.J=null,e.e=null,e.j=null,e.i=null,e.g=null,e.k=null,e.t=null,e.F=null,e.I=null,e.L=null,e.M=null,e.O=null,e.P=null,e.$=null,e.N=null,e.Z=null,e.cb=null,e.K=null,e.D=null,e.A=null,e.C=null,e._=null,e.fb=null,e.X=null,e.Y=null,e.gb=!1,e.hb=!1}function JKt(e){var t,n,i,r;if(i=Pie((!e.c&&(e.c=F_(Zo(e.f))),e.c),0),e.e==0||e.a==0&&e.f!=-1&&e.e<0)return i;if(t=bme(e)<0?1:0,n=e.e,r=(i.length+1+p.Math.abs(xs(e.e)),new Z4),t==1&&(r.a+="-"),e.e>0)if(n-=i.length-t,n>=0){for(r.a+="0.";n>Ab.length;n-=Ab.length)EFe(r,Ab);sze(r,Ab,xs(n)),Zn(r,(en(t,i.length+1),i.substr(t)))}else n=t-n,Zn(r,Fa(i,t,xs(n))),r.a+=".",Zn(r,hpe(i,xs(n)));else{for(Zn(r,(en(t,i.length+1),i.substr(t)));n<-Ab.length;n+=Ab.length)EFe(r,Ab);sze(r,Ab,xs(-n))}return r.a}function Oie(e){var t,n,i,r,o,a,d,b,v;return!(e.k!=(Jt(),or)||e.j.c.length<=1||(o=c(R(e,(Ge(),cr)),103),o==(Zr(),xc))||(r=(hv(),(e.q?e.q:(Ct(),Ct(),Yd))._b(Dw)?i=c(R(e,Dw),205):i=c(R(Jr(e),eC),205),i),r==dJ)||!(r==v3||r==w3)&&(a=ue(he(av(e,tC))),t=c(R(e,aP),125),!t&&(t=new Zge(a,a,a,a)),v=Po(e,(Je(),Yt)),b=t.d+t.a+(v.gc()-1)*a,b>e.o.b||(n=Po(e,nn),d=t.d+t.a+(n.gc()-1)*a,d>e.o.b)))}function XKt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H;t.Tg("Orthogonal edge routing",1),v=ue(he(R(e,(Ge(),Vv)))),n=ue(he(R(e,Jv))),i=ue(he(R(e,ip))),M=new XZ(0,n),H=0,a=new os(e.b,0),d=null,x=null,b=null,S=null;do x=a.b<a.d.gc()?(dn(a.b<a.d.gc()),c(a.d.Xb(a.c=a.b++),26)):null,S=x?x.a:null,d&&(Pye(d,H),H+=d.c.a),z=d?H+i:H,P=zye(M,e,b,S,z),r=!d||pF(b,(jQ(),pP)),o=!x||pF(S,(jQ(),pP)),P>0?(L=(P-1)*n,d&&(L+=i),x&&(L+=i),L<v&&!r&&!o&&(L=v),H+=L):!r&&!o&&(H+=v),d=x,b=S;while(x);e.f.a=H,t.Ug()}function IQ(e,t){var n,i,r,o,a,d,b,v,x,S;if(x=null,e.d&&(x=c(Tc(e.d,t),146)),!x){if(o=e.a.si(),S=o.i,!e.d||r7(e.d)!=S){for(b=new wn,e.d&&lT(b,e.d),v=b.f.c+b.i.c,d=v;d<S;++d)i=c(re(o,d),146),r=Pg(e.e,i).ve(),n=c(r==null?gl(b.f,null,i):Zm(b.i,r,i),146),n&&n!=i&&(r==null?gl(b.f,null,n):Zm(b.i,r,n));if(b.f.c+b.i.c!=S)for(a=0;a<v;++a)i=c(re(o,a),146),r=Pg(e.e,i).ve(),n=c(r==null?gl(b.f,null,i):Zm(b.i,r,i),146),n&&n!=i&&(r==null?gl(b.f,null,n):Zm(b.i,r,n));e.d=b}x=c(Tc(e.d,t),146)}return x}function Sie(e,t,n,i,r,o,a){var d,b,v,x,S,M,L;return S=et(Ze(R(t,(Ge(),NSe)))),M=null,o==(Qs(),Jl)&&i.c.i==n?M=i.c:o==Wc&&i.d.i==n&&(M=i.d),v=a,!v||!S||M?(x=(Je(),$o),M?x=M.j:dx(c(R(n,cr),103))&&(x=o==Jl?Yt:nn),b=VKt(e,t,n,o,x,i),d=Iee((Jr(n),i)),o==Jl?(ks(d,c(Xe(b.j,0),12)),ss(d,r)):(ks(d,r),ss(d,c(Xe(b.j,0),12))),v=new eKe(i,d,b,c(R(b,(De(),Oi)),12),o,!M)):(qe(v.e,i),L=p.Math.max(ue(he(R(v.d,Xg))),ue(he(R(i,Xg)))),Ee(v.d,Xg,L)),St(e.a,i,new PF(v.d,t,o)),v}function jie(){jie=te;var e;TTe=new MLe,R2t=ye(nt,Be,2,0,6,1),P2t=id(D5(33,58),D5(1,26)),I2t=id(D5(97,122),D5(65,90)),xTe=D5(48,57),D2t=id(P2t,0),L2t=id(I2t,xTe),kTe=id(id(0,D5(1,6)),D5(33,38)),OTe=id(id(xTe,D5(65,70)),D5(97,102)),$2t=id(D2t,QH("-_.!~*'()")),B2t=id(L2t,RH("-_.!~*'()")),QH(Out),RH(Out),id($2t,QH(";:@&=+$,")),id(B2t,RH(";:@&=+$,")),STe=QH(":/?#"),jTe=RH(":/?#"),HC=QH("/?#"),QC=RH("/?#"),e=new Or,e.a.yc("jar",e),e.a.yc("zip",e),e.a.yc("archive",e),lX=(Ct(),new w6(e))}function VKt(e,t,n,i,r,o){var a,d,b,v,x,S;return a=null,v=i==(Qs(),Jl)?o.c:o.d,b=NH(t),v.i==n?(a=c(Ut(e.b,v),9),a||(a=tL(v,c(R(n,(Ge(),cr)),103),r,WVt(v),null,v.n,v.o,b,t),Ee(a,(De(),Oi),v),oi(e.b,v,a))):(a=tL((x=new Dy,S=ue(he(R(t,(Ge(),Mf))))/2,wD(x,Qv,S),x),c(R(n,cr),103),r,i==Jl?-1:1,null,new as,new $e(0,0),b,t),d=zqt(a,n,i),Ee(a,(De(),Oi),d),oi(e.b,d,a)),c(R(t,(De(),Lc)),24).Ec((Gs(),Ea)),dx(c(R(t,(Ge(),cr)),103))?Ee(t,cr,(Zr(),r8)):Ee(t,cr,(Zr(),Hh)),a}function BS(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P;d=0,P=0,b=yq(e.g,e.g.length),o=e.e,a=e.j,i=e.b,r=e.c;do{for(L=0,x=new G(e.q);x.a<x.c.c.length;)v=c(Q(x),9),M=Prt(e,v),n=!0,(e.r==(H0(),fP)||e.r==hP)&&(n=et(Ze(M.b))),c(M.a,15).a<0&&n?(++L,b=yq(e.g,e.g.length),e.e=e.e+c(M.a,15).a,P+=o-e.e,o=e.e+c(M.a,15).a,a=e.j,i=tb(e.b),r=tb(e.c)):(e.g=yq(b,b.length),e.e=o,e.b=(Rn(i),i?new Fl(i):P6(new G(i))),e.c=(Rn(r),r?new Fl(r):P6(new G(r))),e.j=a);++d,S=L!=0&&et(Ze(t.Kb(new Ps(Pe(P),Pe(d)))))}while(S)}function WKt(e,t,n,i){var r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt;return a=e.f,M=t.f,d=a==(RT(),Mk)||a==kC,L=M==Mk||M==kC,b=a==S3||a==OC,P=M==S3||M==OC,v=a==S3||a==Mk,z=M==S3||M==Mk,d&&L?e.f==kC?e:t:b&&P?e.f==OC?e:t:v&&z?(a==S3?(S=e,x=t):(S=t,x=e),o=(H=n.j+n.f,X=S.e+i.f,ie=p.Math.max(H,X),se=ie-p.Math.min(n.j,S.e),de=S.d+i.g-n.i,de*se),r=(Se=n.i+n.g,xe=x.d+i.g,We=p.Math.max(Se,xe),pt=We-p.Math.min(n.i,x.d),bt=x.e+i.f-n.j,pt*bt),o<=r?e.f==S3?e:t:e.f==Mk?e:t):e}function grt(e,t){var n,i,r,o,a,d,b,v,x,S;if(Ee(t,(Li(),U9),0),b=c(R(t,OJ),41),t.d.b==0)b?(x=ue(he(R(b,Kg)))+e.b+bwe(e,b,t),Ee(t,Kg,x)):Ee(t,Kg,0);else{for(i=(o=_n(new k1(t).a.d,0),new ix(o));XN(i.a);)n=c(An(i.a),65).c,grt(e,n);d=c(kF((a=_n(new k1(t).a.d,0),new ix(a))),41),S=c(zjt((r=_n(new k1(t).a.d,0),new ix(r))),41),v=(ue(he(R(S,Kg)))+ue(he(R(d,Kg))))/2,b?(x=ue(he(R(b,Kg)))+e.b+bwe(e,b,t),Ee(t,Kg,x),Ee(t,U9,ue(he(R(t,Kg)))-v),hZt(e,t)):Ee(t,Kg,v)}}function KKt(e){var t,n,i,r,o,a,d,b,v,x,S,M,L;if(v=new Fe,!xi(e,(De(),Hce)))return v;for(i=c(R(e,Hce),16).Jc();i.Ob();)t=c(i.Pb(),9),wYt(t,e),It(v.c,t);for(o=new G(e.b);o.a<o.c.c.length;)for(r=c(Q(o),26),d=new G(r.a);d.a<d.c.c.length;)a=c(Q(d),9),a.k==(Jt(),Cr)&&(b=c(R(a,GU),9),b&&(x=new bc,_o(x,a),S=c(R(a,Ko),64),$r(x,S),M=c(Xe(b.j,0),12),L=new qm,ks(L,x),ss(L,M)));for(n=new G(v);n.a<n.c.c.length;)t=c(Q(n),9),zr(t,c(Xe(e.b,e.b.c.length-1),26));return v}function YKt(e){var t,n,i,r,o,a,d,b,v,x,S;for(x=e.e.a.c.length,a=new G(e.e.a);a.a<a.c.c.length;)o=c(Q(a),126),o.j=!1;for(e.i=ye(Fn,ci,30,x,15,1),e.g=ye(Fn,ci,30,x,15,1),e.n=new Fe,r=0,S=new Fe,b=new G(e.e.a);b.a<b.c.c.length;)d=c(Q(b),126),d.d=r++,d.b.a.c.length==0&&qe(e.n,d),yr(S,d.g);for(t=0,i=new G(S);i.a<i.c.c.length;)n=c(Q(i),220),n.c=t++,n.f=!1;v=S.c.length,e.b==null||e.b.length<v?(e.b=ye(ns,no,30,v,15,1),e.c=ye(kl,eh,30,v,16,1)):Zj(e.c),e.d=S,e.p=new oZ(ov(e.d.c.length)),e.j=1}function ZKt(e,t){var n,i,r,o,a,d,b,v,x;if(!(t.e.c.length<=1)){for(e.f=t,e.d=c(R(e.f,(DD(),Pke)),385),e.g=c(R(e.f,Bke),15).a,e.e=ue(he(R(e.f,Ike))),e.c=ue(he(R(e.f,uU))),aqe(e.b),r=new G(e.f.c);r.a<r.c.c.length;)i=c(Q(r),292),hye(e.b,i.c,i,null),hye(e.b,i.d,i,null);for(d=e.f.e.c.length,e.a=H2(ns,[Be,no],[109,30],15,[d,d],2),v=new G(e.f.e);v.a<v.c.c.length;)b=c(Q(v),156),kKt(e,b,e.a[b.a]);for(e.i=H2(ns,[Be,no],[109,30],15,[d,d],2),o=0;o<d;++o)for(a=0;a<d;++a)n=e.a[o][a],x=1/(n*n),e.i[o][a]=x}}function prt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L;if(d=t._g(),d||t.Tg(_ot,1),n=c(R(e,(De(),Xce)),16),a=1/n.gc(),t.$g())for(t.ah("ELK Layered uses the following "+n.gc()+" modules:"),L=0,M=n.Jc();M.Ob();)x=c(M.Pb(),43),i=(L<10?"0":"")+L++,t.ah("   Slot "+i+": "+qp(ju(x)));for(S=n.Jc();S.Ob();){if(x=c(S.Pb(),43),t.Zg())return;x.If(e,t.dh(a))}for(o=new G(e.b);o.a<o.c.c.length;)r=c(Q(o),26),yr(e.a,r.a),r.a.c.length=0;for(v=new G(e.a);v.a<v.c.c.length;)b=c(Q(v),9),zr(b,null);e.b.c.length=0,d||t.Ug()}function eYt(e,t){var n,i,r,o,a,d,b,v,x;if(xi(e.d.i,(Ge(),Hv)))return d=c(R(e.c.i,Hv),15),v=c(R(e.d.i,Hv),15),fc(d.a,v.a)>0;for(d=c(R(e.c.i,Hv),15).a,o=c(ql(pi(t.Mc(),new CNe(d)),su(new Ls,new rs,new mo,W(V(ml,1),_e,132,0,[(va(),bl)]))),16),a=new Ai,x=new Or,ei(a,e.c.i),Sr(x,e.c.i);a.b!=0;){if(n=c(a.b==0?null:(dn(a.b!=0),ba(a,a.a.a)),9),o.Gc(n))return!0;for(r=new Ht(Vt($i(n).a.Jc(),new U));hn(r);)i=c(sn(r),17),b=i.d.i,x.a._b(b)||(x.a.yc(b,x),tr(a,b,a.c.b,a.c))}return!1}function brt(e,t,n){var i,r,o,a,d,b,v,x,S;for(S=new Fe,x=new Jpe(0,n),o=0,oH(x,new Cte(0,0,x,n)),r=0,v=new cn(e);v.e!=v.i.gc();)b=c(un(v),19),i=c(Xe(x.a,x.a.c.length-1),175),d=r+b.g+(c(Xe(x.a,0),175).b.c.length==0?0:n),(d>t||et(Ze(ke(b,(Ah(),kP)))))&&(r=0,o+=x.b+n,It(S.c,x),x=new Jpe(o,n),i=new Cte(0,x.f,x,n),oH(x,i),r=0),i.b.c.length==0||!et(Ze(ke(Xi(b),(Ah(),yue))))&&(b.f>=i.o&&b.f<=i.f||i.a*.5<=b.f&&i.a*1.5>=b.f)?mwe(i,b):(a=new Cte(i.s+i.r+n,x.f,x,n),oH(x,a),mwe(a,b)),r=b.i+b.g;return It(S.c,x),S}function JT(e){var t,n,i,r;if(!(e.b==null||e.b.length<=2)&&!e.a){for(t=0,r=0;r<e.b.length;){for(t!=r?(e.b[t]=e.b[r++],e.b[t+1]=e.b[r++]):r+=2,n=e.b[t+1];r<e.b.length&&!(n+1<e.b[r]);)if(n+1==e.b[r])e.b[t+1]=e.b[r+1],n=e.b[t+1],r+=2;else if(n>=e.b[r+1])r+=2;else if(n<e.b[r+1])e.b[t+1]=e.b[r+1],n=e.b[t+1],r+=2;else throw J(new Mo("Token#compactRanges(): Internel Error: ["+e.b[t]+","+e.b[t+1]+"] ["+e.b[r]+","+e.b[r+1]+"]"));t+=2}t!=e.b.length&&(i=ye(Fn,ci,30,t,15,1),mc(e.b,0,i,0,t),e.b=i),e.a=!0}}function tYt(e,t){var n,i,r,o,a,d,b;for(a=b5(e.a).Jc();a.Ob();){if(o=c(a.Pb(),17),o.b.c.length>0)for(i=new Fl(c(Si(e.a,o),24)),Ct(),Rr(i,new wde(t)),r=new os(o.b,0);r.b<r.d.gc();){switch(n=(dn(r.b<r.d.gc()),c(r.d.Xb(r.c=r.b++),70)),d=-1,c(R(n,(Ge(),yd)),281).g){case 1:d=i.c.length-1;break;case 0:d=Oqt(i);break;case 2:d=0}d!=-1&&(b=(ht(d,i.c.length),c(i.c[d],253)),qe(b.b.b,n),c(R(Jr(b.b.c.i),(De(),Lc)),24).Ec((Gs(),L9)),c(R(Jr(b.b.c.i),Lc),24).Ec(D9),iu(r),Ee(n,x6e,o))}ks(o,null),ss(o,null)}}function nYt(e,t){var n,i,r,o,a,d,b,v,x,S,M;for(x=new Fe,M=new Or,a=t.b,r=0;r<a.c.length;r++){for(v=(ht(r,a.c.length),c(a.c[r],26)).a,x.c.length=0,o=0;o<v.c.length;o++)d=e.a[r][o],d.p=o,d.k==(Jt(),Dc)&&It(x.c,d),Su(c(Xe(t.b,r),26).a,o,d),d.j.c.length=0,yr(d.j,c(c(Xe(e.b,r),16).Xb(o),18)),d5(c(R(d,(Ge(),cr)),103))||Ee(d,cr,(Zr(),Hb));for(i=new G(x);i.a<i.c.c.length;)n=c(Q(i),9),S=CVt(n),M.a.yc(S,M),M.a.yc(n,M)}for(b=M.a.ec().Jc();b.Ob();)d=c(b.Pb(),9),Ct(),Rr(d.j,(aS(),POe)),d.i=!0,lve(d)}function iYt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L;if(t.Tg("Edge splitting",1),e.b.c.length<=2){t.Ug();return}for(o=new os(e.b,0),a=(dn(o.b<o.d.gc()),c(o.d.Xb(o.c=o.b++),26));o.b<o.d.gc();)for(r=a,a=(dn(o.b<o.d.gc()),c(o.d.Xb(o.c=o.b++),26)),b=new G(r.a);b.a<b.c.c.length;)for(d=c(Q(b),9),x=new G(d.j);x.a<x.c.c.length;)for(v=c(Q(x),12),i=new G(v.g);i.a<i.c.c.length;)n=c(Q(i),17),M=n.d,S=M.i.c,S!=r&&S!=a&&tie(n,(L=new Eh(e),mu(L,(Jt(),jr)),Ee(L,(De(),Oi),n),Ee(L,(Ge(),cr),(Zr(),xc)),zr(L,a),L));t.Ug()}function mrt(e){var t,n,i,r,o,a,d,b,v,x,S,M;for(t=yh(e),o=et(Ze(ke(t,(Ge(),qv)))),x=0,r=0,v=new cn((!e.e&&(e.e=new Et(Ii,e,7,4)),e.e));v.e!=v.i.gc();)b=c(un(v),74),d=sw(b),a=d&&o&&et(Ze(ke(b,Lb))),M=to(c(re((!b.c&&(b.c=new Et(vn,b,5,8)),b.c),0),83)),d&&a?++r:d&&!a?++x:Xi(M)==t||M==t?++r:++x;for(i=new cn((!e.d&&(e.d=new Et(Ii,e,8,5)),e.d));i.e!=i.i.gc();)n=c(un(i),74),d=sw(n),a=d&&o&&et(Ze(ke(n,Lb))),S=to(c(re((!n.b&&(n.b=new Et(vn,n,4,7)),n.b),0),83)),d&&a?++x:d&&!a?++r:Xi(S)==t||S==t?++x:++r;return x-r}function wrt(e){var t,n,i,r,o;return e.g!=null?e.g:e.a<32?(e.g=ken(Zo(e.f),xs(e.e)),e.g):(r=Pie((!e.c&&(e.c=F_(Zo(e.f))),e.c),0),e.e==0?r:(t=(!e.c&&(e.c=F_(Zo(e.f))),e.c).e<0?2:1,n=r.length,i=-e.e+n-t,o=new b0,o.a+=""+r,e.e>0&&i>=-6?i>=0?w_(o,n-xs(e.e),"."):(mte(o,t-1,t-1,"0."),w_(o,t+1,od(Ab,0,-xs(i)-1))):(n-t>=1&&(w_(o,t,"."),++n),w_(o,n,"E"),i>0&&w_(o,++n,"+"),w_(o,++n,""+R7(Zo(i)))),e.g=o.a,e.g))}function rYt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We;i=ue(he(R(t,(Ge(),DSe)))),Se=c(R(t,nC),15).a,M=4,r=3,xe=20/Se,L=!1,b=0,a=di;do{for(o=b!=1,S=b!=0,We=0,H=e.a,ie=0,de=H.length;ie<de;++ie)P=H[ie],P.f=null,JZt(e,P,o,S,i),We+=p.Math.abs(P.a);do d=TWt(e,t);while(d);for(z=e.a,X=0,se=z.length;X<se;++X)if(P=z[X],n=Z0e(P).a,n!=0)for(x=new G(P.e);x.a<x.c.c.length;)v=c(Q(x),9),v.n.b+=n;b==0||b==1?(--M,M<=0&&(We<a||-M>Se)?(b=2,a=di):b==0?(b=1,a=We):(b=0,a=We)):(L=We>=a||a-We<xe,a=We,L&&--r)}while(!(L&&r<=0))}function Tie(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P;for(P=new wn,o=e.a.ec().Jc();o.Ob();)i=c(o.Pb(),180),oi(P,i,n.$e(i));for(a=(Rn(e),e?new Fl(e):P6(e.a.ec().Jc())),Rr(a,new YAe(P)),d=Dq(a),b=new yF(t),L=new wn,gl(L.f,t,b);d.a.gc()!=0;){for(v=null,x=null,S=null,r=d.a.ec().Jc();r.Ob();)if(i=c(r.Pb(),180),ue(he(Ao(co(P.f,i))))<=nr){if(jc(L,i.a)&&!jc(L,i.b)){x=i.b,S=i.a,v=i;break}if(jc(L,i.b)&&!jc(L,i.a)){x=i.a,S=i.b,v=i;break}}if(!v)break;M=new yF(x),qe(c(Ao(co(L.f,S)),227).a,M),gl(L.f,x,M),d.a.Ac(v)!=null}return b}function wb(e,t){var n,i,r,o,a,d;if(t){if(!e.a&&(e.a=new vz),e.e==2){wz(e.a,t);return}if(t.e==1){for(r=0;r<t.Nm();r++)wb(e,t.Jm(r));return}if(d=e.a.a.c.length,d==0){wz(e.a,t);return}if(a=c(Bm(e.a,d-1),122),!((a.e==0||a.e==10)&&(t.e==0||t.e==10))){wz(e.a,t);return}o=t.e==0?2:t.Km().length,a.e==0?(n=new t7,i=a.Im(),i>=Is?Ys(n,dwe(i)):z6(n,i&_r),a=new gee(10,null,0),kMt(e.a,a,d-1)):(n=(a.Km().length+o,new t7),Ys(n,a.Km())),t.e==0?(i=t.Im(),i>=Is?Ys(n,dwe(i)):z6(n,i&_r)):Ys(n,t.Km()),c(a,521).b=n.a}}function sYt(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H;if(!n.dc()){for(d=0,M=0,i=n.Jc(),P=c(i.Pb(),15).a;d<t.f;){if(d==P&&(M=0,i.Ob()?P=c(i.Pb(),15).a:P=t.f+1),d!=M){for(H=c(Xe(e.b,d),26),L=c(Xe(e.b,M),26),z=tb(H.a),S=new G(z);S.a<S.c.c.length;)if(x=c(Q(S),9),B0(x,L.a.c.length,L),M==0)for(a=tb(pr(x)),o=new G(a);o.a<o.c.c.length;)r=c(Q(o),17),zg(r,!0),Ee(e,(De(),wk),(Bt(),!0)),jrt(e,r,1)}++M,++d}for(b=new os(e.b,0);b.b<b.d.gc();)v=(dn(b.b<b.d.gc()),c(b.d.Xb(b.c=b.b++),26)),v.a.c.length==0&&iu(b)}}function oYt(e,t,n){var i,r,o;if(r=c(R(t,(Ge(),WU)),285),r!=(MS(),BE)){switch(n.Tg("Horizontal Compaction",1),e.a=t,o=new EJe,i=new ett((o.d=t,o.c=c(R(o.d,W1),225),YXt(o),aZt(o),oVt(o),o.a)),D9t(i,e.b),c(R(t,cSe),427).g){case 1:hPe(i,new VXe(e.a));break;default:hPe(i,(Cpe(),lft))}switch(r.g){case 1:IT(i);break;case 2:IT(RQ(i,(Nr(),yo)));break;case 3:IT(fPe(RQ(IT(i),(Nr(),yo)),new KM));break;case 4:IT(fPe(RQ(IT(i),(Nr(),yo)),new RNe(o)));break;case 5:IT(_9t(i,ndt))}RQ(i,(Nr(),go)),i.e=!0,ren(o),n.Ug()}}function cYt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se;for(a=t.b,x=a.o,b=a.d,i=ue(he(GH(a,(Ge(),Mf)))),r=ue(he(GH(a,m3))),v=ue(he(GH(a,ple))),d=new qK,M0e(d,b.d,b.c,b.a,b.b),M=mVt(t,i,r,v),X=new G(t.d);X.a<X.c.c.length;){for(H=c(Q(X),108),P=H.f.a.ec().Jc();P.Ob();)L=c(P.Pb(),342),o=L.a,S=aHt(L),n=(ie=new nu,YZe(L,L.c,M,ie),OXt(L,S,M,ie),YZe(L,L.d,M,ie),ie),n=e.lg(L,S,n),Ou(o.a),Os(o.a,n),lr(new jt(null,new Tt(n,16)),new cRe(x,d));z=H.i,z&&(MXt(H,z,M,r),se=new Cs(z.g),Fwe(x,d,se),ki(se,z.j),Fwe(x,d,se))}M0e(b,d.d,d.c,d.a,d.b)}function lYt(e,t){LS();var n,i,r,o,a,d;return o=t.c-(e.c+e.b),r=e.c-(t.c+t.b),a=e.d-(t.d+t.a),n=t.d-(e.d+e.a),i=p.Math.max(r,o),d=p.Math.max(a,n),mh(),vf(pd),(p.Math.abs(i)<=pd||i==0||isNaN(i)&&isNaN(0)?0:i<0?-1:i>0?1:Gp(isNaN(i),isNaN(0)))>=0^(vf(pd),(p.Math.abs(d)<=pd||d==0||isNaN(d)&&isNaN(0)?0:d<0?-1:d>0?1:Gp(isNaN(d),isNaN(0)))>=0)?p.Math.max(d,i):(vf(pd),(p.Math.abs(i)<=pd||i==0||isNaN(i)&&isNaN(0)?0:i<0?-1:i>0?1:Gp(isNaN(i),isNaN(0)))>0?p.Math.sqrt(d*d+i*i):-p.Math.sqrt(d*d+i*i))}function uYt(e){var t,n,i,r;r=e.o,B2(),e.A.dc()||yi(e.A,kke)?t=r.b:(e.D?t=p.Math.max(r.b,_T(e.f)):t=_T(e.f),e.A.Gc((Cu(),BP))&&!e.B.Gc((uu(),zC))&&(t=p.Math.max(t,_T(c(Zs(e.p,(Je(),nn)),256))),t=p.Math.max(t,_T(c(Zs(e.p,Yt),256)))),n=mVe(e),n&&(t=p.Math.max(t,n.b)),e.A.Gc(zP)&&(e.q==(Zr(),r1)||e.q==xc)&&(t=p.Math.max(t,FF(c(Zs(e.b,(Je(),nn)),129))),t=p.Math.max(t,FF(c(Zs(e.b,Yt),129))))),et(Ze(e.e.Rf().mf((Dn(),ny))))?r.b=p.Math.max(r.b,t):r.b=t,i=e.f.i,i.d=0,i.a=t,bie(e.f)}function aYt(e,t,n,i,r,o,a,d){var b,v,x,S;switch(b=mf(W(V(nnn,1),Lt,241,0,[t,n,i,r])),S=null,e.b.g){case 1:S=mf(W(V(Y8e,1),Lt,527,0,[new dj,new LA,new HO]));break;case 0:S=mf(W(V(Y8e,1),Lt,527,0,[new HO,new LA,new dj]));break;case 2:S=mf(W(V(Y8e,1),Lt,527,0,[new LA,new dj,new HO]))}for(x=new G(S);x.a<x.c.c.length;)v=c(Q(x),527),b.c.length>1&&(b=v.Gg(b,e.a,d));return b.c.length==1?c(Xe(b,b.c.length-1),241):b.c.length==2?WKt((ht(0,b.c.length),c(b.c[0],241)),(ht(1,b.c.length),c(b.c[1],241)),a,o):null}function fYt(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P;r=new B4(e),o=new wtt,i=(G_(o.n),G_(o.p),sc(o.c),G_(o.f),G_(o.o),sc(o.q),sc(o.d),sc(o.g),sc(o.k),sc(o.e),sc(o.i),sc(o.j),sc(o.r),sc(o.b),M=Fet(o,r,null),Htt(o,r),M),t&&(b=new B4(t),a=MKt(b),G2e(i,W(V($je,1),Lt,528,0,[a]))),S=!1,x=!1,n&&(b=new B4(n),_G in b.a&&(S=C1(b,_G).oe().a),Xlt in b.a&&(x=C1(b,Xlt).oe().a)),v=vPe(SXe(new V4,S),x),hQt(new M$,i,v),_G in r.a&&wf(r,_G,null),(S||x)&&(d=new W4,$it(v,d,S,x),wf(r,_G,d)),L=new ODe(o),XVe(new WY(i),L),P=new SDe(o),XVe(new WY(i),P)}function hYt(e,t,n){var i,r,o,a,d,b,v;for(n.Tg("Find roots",1),e.a.c.length=0,r=_n(t.b,0);r.b!=r.d.c;)i=c(An(r),41),i.b.b==0&&(Ee(i,(Li(),cp),(Bt(),!0)),qe(e.a,i));switch(e.a.c.length){case 0:o=new Ete(0,t,"DUMMY_ROOT"),Ee(o,(Li(),cp),(Bt(),!0)),Ee(o,qle,!0),ei(t.b,o);break;case 1:break;default:for(a=new Ete(0,t,yG),b=new G(e.a);b.a<b.c.c.length;)d=c(Q(b),41),v=new Epe(a,d),Ee(v,(Li(),qle),(Bt(),!0)),ei(a.a.a,v),ei(a.d,v),ei(d.b,v),Ee(d,cp,!1);Ee(a,(Li(),cp),(Bt(),!0)),Ee(a,qle,!0),ei(t.b,a)}n.Ug()}function vrt(e){var t,n,i,r,o,a;for(Qc(e.a,new Ti),n=new G(e.a);n.a<n.c.c.length;)t=c(Q(n),227),i=Hr(Ms(c(e.b,68).c),c(t.b,68).c),qft?(a=c(e.b,68).b,o=c(t.b,68).b,p.Math.abs(i.a)>=p.Math.abs(i.b)?(i.b=0,o.d+o.a>a.d&&o.d<a.d+a.a&&$F(i,p.Math.max(a.c-(o.c+o.b),o.c-(a.c+a.b)))):(i.a=0,o.c+o.b>a.c&&o.c<a.c+a.b&&$F(i,p.Math.max(a.d-(o.d+o.a),o.d-(a.d+a.a))))):$F(i,qit(c(e.b,68),c(t.b,68))),r=p.Math.sqrt(i.a*i.a+i.b*i.b),r=xZe(NE,t,r,i),$F(i,r),IZ(c(t.b,68),i),Qc(t.a,new pde(i)),c(NE.b,68),Tbe(NE,Oke,t)}function dYt(e){var t,n,i,r,o,a,d,b,v,x,S,M,L,P;for(e.f=new zK,v=0,r=0,a=new G(e.e.b);a.a<a.c.c.length;)for(o=c(Q(a),26),b=new G(o.a);b.a<b.c.c.length;){for(d=c(Q(b),9),d.p=v++,i=new Ht(Vt($i(d).a.Jc(),new U));hn(i);)n=c(sn(i),17),n.p=r++;for(t=Oie(d),M=new G(d.j);M.a<M.c.c.length;)S=c(Q(M),12),t&&(P=S.a.b,P!=p.Math.floor(P)&&(x=P-ib(Zo(p.Math.round(P))),S.a.b-=x)),L=S.n.b+S.a.b,L!=p.Math.floor(L)&&(x=L-ib(Zo(p.Math.round(L))),S.n.b-=x)}e.g=v,e.b=r,e.i=ye(Ytn,Lt,410,v,0,1),e.c=ye(Ktn,Lt,651,r,0,1),e.d.a.$b()}function En(e){var t,n,i,r,o,a,d,b,v;if(e.Nj())if(b=e.Oj(),e.i>0){if(t=new K1e(e.i,e.g),n=e.i,o=n<100?null:new m0(n),e.Rj())for(i=0;i<e.i;++i)a=e.g[i],o=e.Tj(a,o);if(eT(e),r=n==1?e.Gj(4,re(t,0),null,0,b):e.Gj(6,t,null,-1,b),e.Kj()){for(i=new a5(t);i.e!=i.i.gc();)o=e.Mj(lne(i),o);o?(o.lj(r),o.mj()):e.Hj(r)}else o?(o.lj(r),o.mj()):e.Hj(r)}else eT(e),e.Hj(e.Gj(6,(Ct(),Rs),null,-1,b));else if(e.Kj())if(e.i>0){for(d=e.g,v=e.i,eT(e),o=v<100?null:new m0(v),i=0;i<v;++i)a=d[i],o=e.Mj(a,o);o&&o.mj()}else eT(e);else eT(e)}function Lye(e,t,n){var i,r,o,a,d,b,v,x,S,M;for(jVe(this),n==(Hm(),op)?Sr(this.r,e):Sr(this.w,e),x=nr,v=Qr,a=t.a.ec().Jc();a.Ob();)r=c(a.Pb(),49),d=c(r.a,457),i=c(r.b,17),b=i.c,b==e&&(b=i.d),d==op?Sr(this.r,b):Sr(this.w,b),M=(Je(),vl).Gc(b.j)?ue(he(R(b,(De(),I9)))):Lo(W(V(Vr,1),Be,8,0,[b.i.n,b.n,b.a])).b,x=p.Math.min(x,M),v=p.Math.max(v,M);for(S=(Je(),vl).Gc(e.j)?ue(he(R(e,(De(),I9)))):Lo(W(V(Vr,1),Be,8,0,[e.i.n,e.n,e.a])).b,QZe(this,S,x,v),o=t.a.ec().Jc();o.Ob();)r=c(o.Pb(),49),oet(this,c(r.b,17));this.o=!1}function gYt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt,Rt,fn;return n=e.l&8191,i=e.l>>13|(e.m&15)<<9,r=e.m>>4&8191,o=e.m>>17|(e.h&255)<<5,a=(e.h&1048320)>>8,d=t.l&8191,b=t.l>>13|(t.m&15)<<9,v=t.m>>4&8191,x=t.m>>17|(t.h&255)<<5,S=(t.h&1048320)>>8,pt=n*d,bt=i*d,Dt=r*d,Rt=o*d,fn=a*d,b!=0&&(bt+=n*b,Dt+=i*b,Rt+=r*b,fn+=o*b),v!=0&&(Dt+=n*v,Rt+=i*v,fn+=r*v),x!=0&&(Rt+=n*x,fn+=i*x),S!=0&&(fn+=n*S),L=pt&au,P=(bt&511)<<13,M=L+P,H=pt>>22,X=bt>>9,ie=(Dt&262143)<<4,se=(Rt&31)<<17,z=H+X+ie+se,Se=Dt>>18,xe=Rt>>5,We=(fn&4095)<<8,de=Se+xe+We,z+=M>>22,M&=au,de+=z>>22,z&=au,de&=Q1,el(M,z,de)}function yrt(e){var t,n,i,r,o,a,d;if(d=c(Xe(e.j,0),12),d.g.c.length!=0&&d.e.c.length!=0)throw J(new oo("Interactive layout does not support NORTH/SOUTH ports with incoming _and_ outgoing edges."));if(d.g.c.length!=0){for(o=nr,n=new G(d.g);n.a<n.c.c.length;)t=c(Q(n),17),a=t.d.i,i=c(R(a,(Ge(),rJ)),125),o=p.Math.min(o,a.n.a-i.b);return new Rj(Rn(o))}if(d.e.c.length!=0){for(r=Qr,n=new G(d.e);n.a<n.c.c.length;)t=c(Q(n),17),a=t.c.i,i=c(R(a,(Ge(),rJ)),125),r=p.Math.max(r,a.n.a+a.o.a+i.c);return new Rj(Rn(r))}return Kj(),Kj(),koe}function xrt(e){Am(e,new mb(rY(JN(Em(Sm(Tm(jm(new b1,ww),"ELK VertiFlex"),"Tree layout algorithm that allows defining set vertical positions for nodes rather than automatically placing nodes on levels according to their topology."),new E$),h4e),_i((V5(),XP),W(V(VP,1),_e,235,0,[JP]))))),Ie(e,ww,dw,20),Ie(e,ww,gw,Rje),Ie(e,ww,e9,Ve(Vmt)),Ie(e,ww,KQ,Ve(Kmt)),Ie(e,ww,vL,(Bt(),!1)),Ie(e,ww,t9,Ve(Ije)),Ie(e,ww,pse,Ve(Wmt)),Ie(e,ww,J4e,Ve(W9)),Ie(e,ww,X4e,Ve(Fue)),Ie(e,ww,V4e,Ve(Pje)),Ie(e,ww,W4e,Ve(zue))}function pYt(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H;for(n.Tg("Interactive cycle breaking",1),S=new Fe,L=new G(t.a);L.a<L.c.c.length;)for(M=c(Q(L),9),M.p=1,P=v2e(M).a,x=tw(M,(Qs(),Wc)).Jc();x.Ob();)for(v=c(x.Pb(),12),o=new G(v.g);o.a<o.c.c.length;)i=c(Q(o),17),z=i.d.i,z!=M&&(H=v2e(z).a,H<P&&It(S.c,i));for(a=new G(S);a.a<a.c.c.length;)i=c(Q(a),17),zg(i,!0);for(S.c.length=0,b=new G(t.a);b.a<b.c.c.length;)d=c(Q(b),9),d.p>0&&het(e,d,S);for(r=new G(S);r.a<r.c.c.length;)i=c(Q(r),17),zg(i,!0);S.c.length=0,n.Ug()}function krt(e,t){var n,i,r,o,a,d,b;if(e.ml()){if(e.i>4)if(e.dk(t)){if(e.$k()){if(r=c(t,52),i=r.Bh(),b=i==e.e&&(e.kl()?r.vh(r.Ch(),e.gl())==e.hl():-1-r.Ch()==e.Jj()),e.ll()&&!b&&!i&&r.Gh()){for(o=0;o<e.i;++o)if(n=e.nl(c(e.g[o],57)),ve(n)===ve(t))return!0}return b}else if(e.kl()&&!e.jl()){if(a=c(t,57).Jh(Hs(c(e.Jk(),20))),ve(a)===ve(e.e))return!0;if(a==null||!c(a,57).Sh())return!1}}else return!1;if(d=ES(e,t),e.ll()&&!d){for(o=0;o<e.i;++o)if(r=e.nl(c(e.g[o],57)),ve(r)===ve(t))return!0}return d}else return ES(e,t)}function bYt(e,t){var n,i,r,o,a,d,b,v,x;for(n=0,x=new Fe,d=new G(t);d.a<d.c.c.length;){switch(a=c(Q(d),12),Ume(e.b,e.d[a.p]),x.c.length=0,a.i.k.g){case 0:i=c(R(a,(De(),Ul)),9),Qc(i.j,new m_e(x));break;case 1:gjt(I1(pi(new jt(null,new Tt(a.i.j,16)),new w_e(a))),new v_e(x));break;case 3:r=c(R(a,(De(),Oi)),12),qe(x,new Ps(r,Pe(a.e.c.length+a.g.c.length)))}for(v=new G(x);v.a<v.c.c.length;)b=c(Q(v),49),o=c1e(e,c(b.a,12)),o>e.d[a.p]&&(n+=cbe(e.b,o)*c(b.b,15).a,C0(e.a,Pe(o)));for(;!e7(e.a);)Fbe(e.b,c(w5(e.a),15).a)}return n}function mYt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H;for(t.Tg(wct,1),L=new Fe,x=p.Math.max(e.a.c.length,c(R(e,(De(),np)),15).a),n=x*c(R(e,tP),15).a,d=ve(R(e,(Ge(),jk)))===ve((D0(),$v)),z=new G(e.a);z.a<z.c.c.length;)for(P=c(Q(z),9),i=new DO,b=d?J5(i,P,n,x):Q5(i,P,x),M=tw(P,(Qs(),Wc)).Jc();M.Ob();)for(S=c(M.Pb(),12),a=new G(S.g);a.a<a.c.c.length;)r=c(Q(a),17),H=r.d.i,v=d?J5(i,H,n,x):Q5(i,H,x),v<b&&It(L.c,r);for(o=new G(L);o.a<o.c.c.length;)r=c(Q(o),17),zg(r,!0),Ee(e,wk,(Bt(),!0));L.c.length=0,t.Ug()}function wYt(e,t){var n,i,r,o,a,d,b,v,x,S;if(x=c(R(e,(De(),Ko)),64),i=c(Xe(e.j,0),12),x==(Je(),Kt)?$r(i,bn):x==bn&&$r(i,Kt),c(R(t,(Ge(),Pb)),185).Gc((Cu(),Qb))){if(b=ue(he(R(e,F9))),v=ue(he(R(e,q9))),a=ue(he(R(e,Xv))),d=c(R(t,Gv),24),d.Gc((Ql(),eg)))for(n=v,S=e.o.a/2-i.n.a,o=new G(i.f);o.a<o.c.c.length;)r=c(Q(o),70),r.n.b=n,r.n.a=S-r.o.a/2,n+=r.o.b+a;else if(d.Gc(hp))for(o=new G(i.f);o.a<o.c.c.length;)r=c(Q(o),70),r.n.a=b+e.o.a-i.n.a;v_t(new fz((s7(),new iee(t,!1,!1,new I8))),new LF(null,e,!1))}}function vYt(e,t){var n,i,r,o,a,d,b,v,x;if(t.c.length!=0){for(Ct(),NZ(t.c,t.c.length,null),r=new G(t),i=c(Q(r),157);r.a<r.c.c.length;)n=c(Q(r),157),Gbe(i.e.c,n.e.c)&&!(Pwe(WBe(i.e).b,n.e.d)||Pwe(WBe(n.e).b,i.e.d))?i=(yr(i.k,n.k),yr(i.b,n.b),yr(i.c,n.c),Os(i.i,n.i),yr(i.d,n.d),yr(i.j,n.j),o=p.Math.min(i.e.c,n.e.c),a=p.Math.min(i.e.d,n.e.d),d=p.Math.max(i.e.c+i.e.b,n.e.c+n.e.b),b=d-o,v=p.Math.max(i.e.d+i.e.a,n.e.d+n.e.a),x=v-a,tFe(i.e,o,a,b,x),S_t(i.f,n.f),!i.a&&(i.a=n.a),yr(i.g,n.g),qe(i.g,n),i):(Lit(e,i),i=n);Lit(e,i)}}function yYt(e,t,n,i){var r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se;for(b=new Fe,o=new G(t.a);o.a<o.c.c.length;)for(r=c(Q(o),9),d=new G(r.j);d.a<d.c.c.length;){for(a=c(Q(d),12),x=null,se=rd(a.g),de=0,Se=se.length;de<Se;++de)ie=se[de],sS(ie.d.i,n)||(X=Sie(e,t,n,ie,ie.c,(Qs(),Wc),x),X!=x&&It(b.c,X),X.c&&(x=X));for(v=null,P=rd(a.e),z=0,H=P.length;z<H;++z)L=P[z],sS(L.c.i,n)||(X=Sie(e,t,n,L,L.d,(Qs(),Jl),v),X!=v&&It(b.c,X),X.c&&(v=X))}for(M=new G(b);M.a<M.c.c.length;)S=c(Q(M),447),Do(t.a,S.a,0)!=-1||qe(t.a,S.a),S.c&&It(i.c,S)}function xYt(e,t,n){var i,r,o,a,d,b,v,x,S,M,L;for(d=new G(t);d.a<d.c.c.length;)o=c(Q(d),242),o.e=null,o.c=0;for(b=null,a=new G(t);a.a<a.c.c.length;)if(o=c(Q(a),242),S=o.d[0],!(n&&S.k!=(Jt(),or))){for(L=c(R(S,(De(),yk)),16).Jc();L.Ob();)M=c(L.Pb(),9),(!n||M.k==(Jt(),or))&&((!o.e&&(o.e=new Fe),o.e).Ec(e.b[M.c.p][M.p]),++e.b[M.c.p][M.p].c);if(!n&&S.k==(Jt(),or)){if(b)for(x=c(Si(e.d,b),24).Jc();x.Ob();)for(v=c(x.Pb(),9),r=c(Si(e.d,S),24).Jc();r.Ob();)i=c(r.Pb(),9),CEt(e.b[v.c.p][v.p]).Ec(e.b[i.c.p][i.p]),++e.b[i.c.p][i.p].c;b=S}}}function kYt(e,t,n,i){var r,o,a,d,b,v,x,S,M,L,P,z,H;for(S=new Cs(c(ke(e,(fQ(),Uje)),8)),S.a=p.Math.max(S.a-n.b-n.c,0),S.b=p.Math.max(S.b-n.d-n.a,0),r=he(ke(e,Hje)),(r==null||(zt(r),r<=0))&&(r=1.3),d=new Fe,P=new cn((!e.a&&(e.a=new Me(Mn,e,10,11)),e.a));P.e!=P.i.gc();)L=c(un(P),19),a=new PBe(L),It(d.c,a);switch(M=c(ke(e,Wue),327),M.g){case 3:H=iWt(d,t,S.a,S.b,(v=i,zt(r),v));break;case 1:H=GWt(d,t,S.a,S.b,(x=i,zt(r),x));break;default:H=SYt(d,t,S.a,S.b,(b=i,zt(r),b))}o=new eH(H),z=_ie(o,t,n,S.a,S.b,i,(zt(r),r)),uw(e,z.a,z.b,!1,!0)}function OYt(e,t,n,i){var r,o,a,d,b,v;if(d=e.j,d==(Je(),$o)&&t!=(Zr(),Hh)&&t!=(Zr(),fp)&&(d=Mit(e,n),$r(e,d),!(e.q?e.q:(Ct(),Ct(),Yd))._b((Ge(),Qv))&&d!=$o&&(e.n.a!=0||e.n.b!=0)&&Ee(e,Qv,DFt(e,d))),t==(Zr(),r1)){switch(v=0,d.g){case 1:case 3:o=e.i.o.a,o>0&&(v=e.n.a/o);break;case 2:case 4:r=e.i.o.b,r>0&&(v=e.n.b/r)}Ee(e,(De(),Aw),v)}if(b=e.o,a=e.a,i)a.a=i.a,a.b=i.b,e.d=!0;else if(t!=Hh&&t!=fp&&d!=$o)switch(d.g){case 1:a.a=b.a/2;break;case 2:a.a=b.a,a.b=b.b/2;break;case 3:a.a=b.a/2,a.b=b.b;break;case 4:a.b=b.b/2}else a.a=b.a/2,a.b=b.b/2}function XT(e){var t,n,i,r,o,a,d,b,v,x;if(e.Nj())if(x=e.Cj(),b=e.Oj(),x>0)if(t=new vme(e.nj()),n=x,o=n<100?null:new m0(n),O_(e,n,t.g),r=n==1?e.Gj(4,re(t,0),null,0,b):e.Gj(6,t,null,-1,b),e.Kj()){for(i=new cn(t);i.e!=i.i.gc();)o=e.Mj(un(i),o);o?(o.lj(r),o.mj()):e.Hj(r)}else o?(o.lj(r),o.mj()):e.Hj(r);else O_(e,e.Cj(),e.Dj()),e.Hj(e.Gj(6,(Ct(),Rs),null,-1,b));else if(e.Kj())if(x=e.Cj(),x>0){for(d=e.Dj(),v=x,O_(e,x,d),o=v<100?null:new m0(v),i=0;i<v;++i)a=d[i],o=e.Mj(a,o);o&&o.mj()}else O_(e,e.Cj(),e.Dj());else O_(e,e.Cj(),e.Dj())}function SYt(e,t,n,i,r){var o,a,d,b,v,x,S,M,L,P,z,H;for(d=ye(ns,no,30,e.c.length,15,1),M=new nq(new JA),r2e(M,e),v=0,z=new Fe;M.b.c.length!=0;)if(a=c(M.b.c.length==0?null:Xe(M.b,0),168),v>1&&Ml(a)*ku(a)/2>d[0]){for(o=0;o<z.c.length-1&&Ml(a)*ku(a)/2>d[o];)++o;P=new nd(z,0,o+1),S=new eH(P),x=Ml(a)/ku(a),b=_ie(S,t,new X4,n,i,r,x),ki(Xf(S.e),b),p5(CS(M,S),XS),L=new nd(z,o+1,z.c.length),r2e(M,L),z.c.length=0,v=0,IFe(d,d.length,0)}else H=M.b.c.length==0?null:Xe(M.b,0),H!=null&&lte(M,0),v>0&&(d[v]=d[v-1]),d[v]+=Ml(a)*ku(a),++v,It(z.c,a);return z}function jYt(e,t){var n,i,r,o;n=t.b,o=new Fl(n.j),r=0,i=n.j,i.c.length=0,Rm(c(lb(e.b,(Je(),Kt),(Km(),Ew)),16),n),r=ND(o,r,new AO,i),Rm(c(lb(e.b,Kt,ep),16),n),r=ND(o,r,new fg,i),Rm(c(lb(e.b,Kt,Tw),16),n),Rm(c(lb(e.b,nn,Ew),16),n),Rm(c(lb(e.b,nn,ep),16),n),r=ND(o,r,new hg,i),Rm(c(lb(e.b,nn,Tw),16),n),Rm(c(lb(e.b,bn,Ew),16),n),r=ND(o,r,new l2,i),Rm(c(lb(e.b,bn,ep),16),n),r=ND(o,r,new Np,i),Rm(c(lb(e.b,bn,Tw),16),n),Rm(c(lb(e.b,Yt,Ew),16),n),r=ND(o,r,new ag,i),Rm(c(lb(e.b,Yt,ep),16),n),Rm(c(lb(e.b,Yt,Tw),16),n)}function TYt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z;for(t.Tg("Layer size calculation",1),x=nr,v=Qr,r=!1,d=new G(e.b);d.a<d.c.c.length;)if(a=c(Q(d),26),b=a.c,b.a=0,b.b=0,a.a.c.length!=0){for(r=!0,M=new G(a.a);M.a<M.c.c.length;)S=c(Q(M),9),P=S.o,L=S.d,b.a=p.Math.max(b.a,P.a+L.b+L.c);i=c(Xe(a.a,0),9),z=i.n.b-i.d.d,i.k==(Jt(),Cr)&&(z-=c(R(e,(Ge(),aP)),125).d),o=c(Xe(a.a,a.a.c.length-1),9),n=o.n.b+o.o.b+o.d.a,o.k==Cr&&(n+=c(R(e,(Ge(),aP)),125).a),b.b=n-z,x=p.Math.min(x,z),v=p.Math.max(v,n)}r||(x=0,v=0),e.f.b=v-x,e.c.b-=x,t.Ug()}function Ort(e,t,n){var i,r,o,a,d,b,v,x,S,M;for(a=t.d,d=n.d;a.a-d.a==0&&a.b-d.b==0;)b=!1,oe(t,254)&&oe(n,254)&&!b?(v=c(t,254).a,x=Hr(new Cs(Zbe(v)),Ybe(v)),i=2,r=new $e(x.a/p.Math.sqrt(x.a*x.a+x.b*x.b)*i,-x.b/p.Math.sqrt(x.a*x.a+x.b*x.b)*i),ki(a,r),S=c(n,254).a,M=Hr(new Cs(Zbe(S)),Ybe(S)),i=x==M?-2:2,o=new $e(M.a/p.Math.sqrt(M.a*M.a+M.b*M.b)*i,-(M.b/p.Math.sqrt(M.a*M.a+M.b*M.b))*i),ki(a,o),b=!0):(a.a+=lu(e,26)*YT+lu(e,27)*ZT-.5,a.b+=lu(e,26)*YT+lu(e,27)*ZT-.5,d.a+=lu(e,26)*YT+lu(e,27)*ZT-.5,d.b+=lu(e,26)*YT+lu(e,27)*ZT-.5)}function EYt(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H;for(v=rQt(t),z=c(R(t,(Ge(),KE)),302),ws(v,new rNe(z)),H=c(R(t,oP),303),ws(v,new sNe(H)),P=0,x=new Fe,o=new G7(v);o.a!=o.b;)r=c(EH(o),37),Irt(e.c,r),M=c(R(r,(De(),Xce)),16),P+=M.gc(),i=M.Jc(),qe(x,new Ps(r,i));for(n.Tg("Recursive hierarchical layout",P),L=c(c(Xe(x,x.c.length-1),49).b,51);L.Ob();)for(b=new G(x);b.a<b.c.c.length;)for(d=c(Q(b),49),M=c(d.b,51),a=c(d.a,37);M.Ob();)if(S=c(M.Pb(),43),oe(S,456)){if(a.e)break;S.If(a,n.dh(1));break}else S.If(a,n.dh(1));n.Ug()}function Pye(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X;for(o=0,a=0,v=new G(e.a);v.a<v.c.c.length;)d=c(Q(v),9),o=p.Math.max(o,d.d.b),a=p.Math.max(a,d.d.c);for(b=new G(e.a);b.a<b.c.c.length;){switch(d=c(Q(b),9),n=c(R(d,(Ge(),vd)),259),n.g){case 1:P=0;break;case 2:P=1;break;case 5:P=.5;break;default:for(i=0,S=0,L=new G(d.j);L.a<L.c.c.length;)M=c(Q(L),12),M.e.c.length==0||++i,M.g.c.length==0||++S;i+S==0?P=.5:P=S/(i+S)}H=e.c,x=d.o.a,X=(H.a-x)*P,P>.5?X-=a*2*(P-.5):P<.5&&(X+=o*2*(.5-P)),r=d.d.b,X<r&&(X=r),z=d.d.c,X>H.a-z-x&&(X=H.a-z-x),d.n.a=t+X}}function CYt(e){var t,n,i,r,o;if(i=c(R(e,(Ge(),Ro)),166),i==(Tu(),V1)){for(n=new Ht(Vt(pr(e).a.Jc(),new U));hn(n);)if(t=c(sn(n),17),!iUe(t))throw J(new Wh(Cre+_D(e)+"' has its layer constraint set to FIRST_SEPARATE, but has at least one incoming edge. FIRST_SEPARATE nodes must not have incoming edges."))}else if(i==Db){for(o=new Ht(Vt($i(e).a.Jc(),new U));hn(o);)if(r=c(sn(o),17),!iUe(r))throw J(new Wh(Cre+_D(e)+"' has its layer constraint set to LAST_SEPARATE, but has at least one outgoing edge. LAST_SEPARATE nodes must not have outgoing edges."))}}function VT(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P;if(e.e&&e.c.c<e.f)throw J(new oo("Expected "+e.f+" phases to be configured; only found "+e.c.c));for(x=c(Jf(e.g),10),L=Pd(e.f),o=x,d=0,v=o.length;d<v;++d)i=o[d],S=c(tD(e,i.g),173),S?qe(L,c(fKe(e,S),86)):L.c.push(null);for(P=new wr,lr(pi(qc(pi(new jt(null,new Tt(L,16)),new A$),new Z_e(t)),new bj),new eDe(P)),Fu(P,e.a),n=new Fe,r=x,a=0,b=r.length;a<b;++a)i=r[a],yr(n,IVe(e,aee(c(tD(P,i.g),22)))),M=c(Xe(L,i.g),86),M&&It(n.c,M);return yr(n,IVe(e,aee(c(tD(P,x[x.length-1].g+1),22)))),n}function MYt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de;for(M=new Fe,r=new Fe,z=null,d=t.Jc();d.Ob();)a=c(d.Pb(),15),o=new c_e(a.a),It(r.c,o),z&&(o.d=z,z.e=o),z=o;for(se=KWt(e),x=0;x<r.c.length;++x){for(L=null,H=xbe((ht(0,r.c.length),c(r.c[0],657))),n=null,i=nr,S=1;S<e.b.c.length;++S)X=H?p.Math.abs(H.b-S):p.Math.abs(S-L.b)+1,P=L?p.Math.abs(S-L.b):X+1,P<X?(v=L,b=P):(v=H,b=X),ie=(de=ue(he(R(e,(Ge(),JSe)))),se[S]+p.Math.pow(b,de)),ie<i&&(i=ie,n=v,n.c=S),H&&S==H.b&&(L=H,H=gMt(H));n&&(qe(M,Pe(n.c)),n.a=!0,m$t(n))}return Ct(),NZ(M.c,M.c.length,null),M}function Iye(e,t,n){var i,r,o,a,d,b;if(t.l==0&&t.m==0&&t.h==0)throw J(new Sz("divide by zero"));if(e.l==0&&e.m==0&&e.h==0)return n&&(W0=el(0,0,0)),el(0,0,0);if(t.h==aL&&t.m==0&&t.l==0)return B$t(e,n);if(b=!1,t.h>>19!=0&&(t=uS(t),b=!b),a=hJt(t),o=!1,r=!1,i=!1,e.h==aL&&e.m==0&&e.l==0)if(r=!0,o=!0,a==-1)e=y$e((Z6(),J5e)),i=!0,b=!b;else return d=Eve(e,a),b&&jte(d),n&&(W0=el(0,0,0)),d;else e.h>>19!=0&&(o=!0,e=uS(e),i=!0,b=!b);return a!=-1?hRt(e,a,b,o,n):h2e(e,t)<0?(n&&(o?W0=uS(e):W0=el(e.l,e.m,e.h)),el(0,0,0)):oWt(i?e:el(e.l,e.m,e.h),t,b,o,r,n)}function Eie(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P;if(a=e.e,b=t.e,a==0)return t;if(b==0)return e;if(o=e.d,d=t.d,o+d==2)return n=Yr(e.a[0],Us),i=Yr(t.a[0],Us),a==b?(x=As(n,i),P=Hn(x),L=Hn(Vp(x,32)),L==0?new A1(a,P):new Wp(a,2,W(V(Fn,1),ci,30,15,[P,L]))):(ld(),gF(a<0?Ha(i,n):Ha(n,i),0)?$0(a<0?Ha(i,n):Ha(n,i)):F7($0(Ng(a<0?Ha(i,n):Ha(n,i)))));if(a==b)M=a,S=o>=d?Bee(e.a,o,t.a,d):Bee(t.a,d,e.a,o);else{if(r=o!=d?o>d?1:-1:Gme(e.a,t.a,o),r==0)return ld(),ME;r==1?(M=a,S=Ree(e.a,o,t.a,d)):(M=b,S=Ree(t.a,d,e.a,o))}return v=new Wp(M,S.length,S),V7(v),v}function AYt(e,t){var n,i,r,o,a,d,b;if(!(e.g>t.f||t.g>e.f)){for(n=0,i=0,a=e.w.a.ec().Jc();a.Ob();)r=c(a.Pb(),12),Ite(Lo(W(V(Vr,1),Be,8,0,[r.i.n,r.n,r.a])).b,t.g,t.f)&&++n;for(d=e.r.a.ec().Jc();d.Ob();)r=c(d.Pb(),12),Ite(Lo(W(V(Vr,1),Be,8,0,[r.i.n,r.n,r.a])).b,t.g,t.f)&&--n;for(b=t.w.a.ec().Jc();b.Ob();)r=c(b.Pb(),12),Ite(Lo(W(V(Vr,1),Be,8,0,[r.i.n,r.n,r.a])).b,e.g,e.f)&&++i;for(o=t.r.a.ec().Jc();o.Ob();)r=c(o.Pb(),12),Ite(Lo(W(V(Vr,1),Be,8,0,[r.i.n,r.n,r.a])).b,e.g,e.f)&&--i;n<i?new $q(e,t,i-n):i<n?new $q(t,e,n-i):(new $q(t,e,0),new $q(e,t,0))}}function NYt(e){var t,n,i,r,o,a,d,b,v,x;for(t=new bh,n=new bh,v=Ot(PL,(r=qT(e.b,Kn),r?zn(Zf((!r.b&&(r.b=new yu((Mt(),Bs),Yo,r)),r.b),Ua)):null)),b=0;b<e.i;++b)d=c(e.g[b],182),oe(d,104)?(a=c(d,20),(a.Bb&nc)!=0?((a.Bb&ad)==0||!v&&(o=qT(a,Kn),(o?zn(Zf((!o.b&&(o.b=new yu((Mt(),Bs),Yo,o)),o.b),AG)):null)==null))&&Nn(t,a):(x=Hs(a),x&&(x.Bb&nc)!=0||((a.Bb&ad)==0||!v&&(i=qT(a,Kn),(i?zn(Zf((!i.b&&(i.b=new yu((Mt(),Bs),Yo,i)),i.b),AG)):null)==null))&&Nn(n,a))):(qs(),c(d,69).vk()&&(d.qk()||(Nn(t,d),Nn(n,d))));cv(t),cv(n),e.a=c(t.g,258),c(n.g,258)}function qx(e,t,n){var i,r,o,a,d,b,v,x,S;if(Vi(t,n)>=0)return n;switch(zm(uo(e,n))){case 2:{if(Ot("",Pg(e,n.ok()).ve())){if(b=I_(uo(e,n)),d=Q6(uo(e,n)),x=Dve(e,t,b,d),x)return x;for(r=uye(e,t),a=0,S=r.gc();a<S;++a)if(x=c(r.Xb(a),182),zve(GZ(uo(e,x)),b))return x}return null}case 4:{if(Ot("",Pg(e,n.ok()).ve())){for(i=n;i;i=b_t(uo(e,i)))if(v=I_(uo(e,i)),d=Q6(uo(e,i)),x=Lve(e,t,v,d),x)return x;if(b=I_(uo(e,n)),Ot(Cb,b))return b2e(e,t);for(o=aie(e,t),a=0,S=o.gc();a<S;++a)if(x=c(o.Xb(a),182),zve(GZ(uo(e,x)),b))return x}return null}default:return null}}function _Yt(e,t,n){var i,r,o,a,d,b,v,x;if(n.gc()==0)return!1;if(d=(qs(),c(t,69).vk()),o=d?n:new Um(n.gc()),F1(e.e,t)){if(t.Qi())for(v=n.Jc();v.Ob();)b=v.Pb(),NQ(e,t,b,oe(t,104)&&(c(t,20).Bb&Is)!=0)||(r=Fd(t,b),o.Gc(r)||o.Ec(r));else if(!d)for(v=n.Jc();v.Ob();)b=v.Pb(),r=Fd(t,b),o.Ec(r)}else{if(n.gc()>1)throw J(new qt($L));for(x=nl(e.e.Ah(),t),i=c(e.g,123),a=0;a<e.i;++a)if(r=i[a],x.$l(r.Jk())){if(n.Gc(d?r:r.kd()))return!1;for(v=n.Jc();v.Ob();)b=v.Pb(),c(Dx(e,a,d?c(b,76):Fd(t,b)),76);return!0}d||(r=Fd(t,n.Jc().Pb()),o.Ec(r))}return ur(e,o)}function DYt(e,t){var n,i,r,o,a,d,b,v,x;for(x=new Ai,d=(v=new x1(e.c).a.vc().Jc(),new C2(v));d.a.Ob();)o=(r=c(d.a.Pb(),45),c(r.kd(),459)),o.b==0&&tr(x,o,x.c.b,x.c);for(;x.b!=0;)for(o=c(x.b==0?null:(dn(x.b!=0),ba(x,x.a.a)),459),o.a==null&&(o.a=0),i=new G(o.d);i.a<i.c.c.length;)n=c(Q(i),659),n.b.a==null?n.b.a=ue(o.a)+n.a:t.o==(vh(),Bb)?n.b.a=p.Math.min(ue(n.b.a),ue(o.a)+n.a):n.b.a=p.Math.max(ue(n.b.a),ue(o.a)+n.a),--n.b.b,n.b.b==0&&ei(x,n.b);for(a=(b=new x1(e.c).a.vc().Jc(),new C2(b));a.a.Ob();)o=(r=c(a.a.Pb(),45),c(r.kd(),459)),t.i[o.c.p]=o.a}function LYt(e,t,n,i){var r,o,a,d,b,v,x,S,M,L,P;for(x=n+t.c.c.a,L=new G(t.j);L.a<L.c.c.length;){if(M=c(Q(L),12),r=Lo(W(V(Vr,1),Be,8,0,[M.i.n,M.n,M.a])),t.k==(Jt(),Dc)&&(d=c(R(M,(De(),Oi)),12),r.a=Lo(W(V(Vr,1),Be,8,0,[d.i.n,d.n,d.a])).a,t.n.a=r.a),a=new $e(0,r.b),M.j==(Je(),nn))a.a=x;else if(M.j==Yt)a.a=n;else continue;if(P=p.Math.abs(r.a-a.a),!(P<=i&&!zFt(t)))for(o=M.g.c.length+M.e.c.length>1,v=new kh(M.b);No(v.a)||No(v.b);)b=c(No(v.a)?Q(v.a):Q(v.b),17),S=b.c==M?b.d:b.c,p.Math.abs(Lo(W(V(Vr,1),Be,8,0,[S.i.n,S.n,S.a])).b-a.b)>1&&gXt(e,b,a,o,M)}}function PYt(e){var t,n,i,r,o,a;if(r=new os(e.e,0),i=new os(e.a,0),e.d)for(n=0;n<e.b;n++)dn(r.b<r.d.gc()),r.d.Xb(r.c=r.b++);else for(n=0;n<e.b-1;n++)dn(r.b<r.d.gc()),r.d.Xb(r.c=r.b++),iu(r);for(t=ue((dn(r.b<r.d.gc()),he(r.d.Xb(r.c=r.b++))));e.f-t>yse;){for(o=t,a=0;p.Math.abs(t-o)<yse;)++a,t=ue((dn(r.b<r.d.gc()),he(r.d.Xb(r.c=r.b++)))),dn(i.b<i.d.gc()),i.d.Xb(i.c=i.b++);a<e.b&&(dn(r.b>0),r.a.Xb(r.c=--r.b),UWt(e,e.b-a,o,i,r),dn(r.b<r.d.gc()),r.d.Xb(r.c=r.b++)),dn(i.b>0),i.a.Xb(i.c=--i.b)}if(!e.d)for(n=0;n<e.b-1;n++)dn(r.b<r.d.gc()),r.d.Xb(r.c=r.b++),iu(r);e.d=!0,e.c=!0}function Ci(){Ci=te,GTe=(s1e(),ic).b,cvt=c(re(Ne(ic.b),0),38),Gb=c(re(Ne(ic.b),1),38),ovt=c(re(Ne(ic.b),2),38),N3=ic.bb,c(re(Ne(ic.bb),0),38),c(re(Ne(ic.bb),1),38),_3=ic.fb,UC=c(re(Ne(ic.fb),0),38),c(re(Ne(ic.fb),1),38),c(re(Ne(ic.fb),2),20),Fw=ic.qb,vvt=c(re(Ne(ic.qb),0),38),c(re(Ne(ic.qb),1),20),c(re(Ne(ic.qb),2),20),nI=c(re(Ne(ic.qb),3),38),iI=c(re(Ne(ic.qb),4),38),XC=c(re(Ne(ic.qb),6),38),JC=c(re(Ne(ic.qb),5),20),lvt=ic.j,uvt=ic.k,avt=ic.q,fvt=ic.w,hvt=ic.B,dvt=ic.A,gvt=ic.C,pvt=ic.D,bvt=ic._,mvt=ic.cb,wvt=ic.hb}function IYt(e,t,n){var i,r,o,a,d,b,v,x,S,M,L;e.c=0,e.b=0,i=2*t.c.a.c.length+1;e:for(S=n.Jc();S.Ob();){if(x=c(S.Pb(),12),d=x.j==(Je(),Kt)||x.j==bn,L=0,d){if(M=c(R(x,(De(),Ul)),9),!M)continue;L+=rVt(e,i,x,M)}else{for(v=new G(x.g);v.a<v.c.c.length;)if(b=c(Q(v),17),r=b.d,r.i.c==t.c){qe(e.a,x);continue e}else L+=e.g[r.p];for(a=new G(x.e);a.a<a.c.c.length;)if(o=c(Q(a),17),r=o.c,r.i.c==t.c){qe(e.a,x);continue e}else L-=e.g[r.p]}x.e.c.length+x.g.c.length>0?(e.f[x.p]=L/(x.e.c.length+x.g.c.length),e.c=p.Math.min(e.c,e.f[x.p]),e.b=p.Math.max(e.b,e.f[x.p])):d&&(e.f[x.p]=L)}}function RYt(e){e.b=null,e.bb=null,e.fb=null,e.qb=null,e.a=null,e.c=null,e.d=null,e.e=null,e.f=null,e.n=null,e.M=null,e.L=null,e.Q=null,e.R=null,e.K=null,e.db=null,e.eb=null,e.g=null,e.i=null,e.j=null,e.k=null,e.gb=null,e.o=null,e.p=null,e.q=null,e.r=null,e.$=null,e.ib=null,e.S=null,e.T=null,e.t=null,e.s=null,e.u=null,e.v=null,e.w=null,e.B=null,e.A=null,e.C=null,e.D=null,e.F=null,e.G=null,e.H=null,e.I=null,e.J=null,e.P=null,e.Z=null,e.U=null,e.V=null,e.W=null,e.X=null,e.Y=null,e._=null,e.ab=null,e.cb=null,e.hb=null,e.nb=null,e.lb=null,e.mb=null,e.ob=null,e.pb=null,e.jb=null,e.kb=null,e.N=!1,e.O=!1}function $Yt(e,t,n){var i,r,o,a;for(n.Tg("Graph transformation ("+e.a+")",1),a=tb(t.a),o=new G(t.b);o.a<o.c.c.length;)r=c(Q(o),26),yr(a,r.a);if(i=c(R(t,(Ge(),dSe)),424),i==(oD(),PU))switch(c(R(t,Xu),87).g){case 2:W7(t,a);break;case 3:kT(t,a);break;case 4:e.a==(iS(),JL)?(kT(t,a),Tee(t,a)):(Tee(t,a),kT(t,a))}else if(e.a==(iS(),JL))switch(c(R(t,Xu),87).g){case 2:W7(t,a),Tee(t,a);break;case 3:kT(t,a),W7(t,a);break;case 4:W7(t,a),kT(t,a)}else switch(c(R(t,Xu),87).g){case 2:W7(t,a),Tee(t,a);break;case 3:W7(t,a),kT(t,a);break;case 4:kT(t,a),W7(t,a)}n.Ug()}function BYt(e){var t,n,i,r,o,a,d,b;for(o=new G(e.a.b);o.a<o.c.c.length;)r=c(Q(o),84),r.b.c=r.g.c,r.b.d=r.g.d;for(b=new $e(nr,nr),t=new $e(Qr,Qr),i=new G(e.a.b);i.a<i.c.c.length;)n=c(Q(i),84),b.a=p.Math.min(b.a,n.g.c),b.b=p.Math.min(b.b,n.g.d),t.a=p.Math.max(t.a,n.g.c+n.g.b),t.b=p.Math.max(t.b,n.g.d+n.g.a);for(d=lq(e.c).a.nc();d.Ob();)a=c(d.Pb(),49),n=c(a.b,84),b.a=p.Math.min(b.a,n.g.c),b.b=p.Math.min(b.b,n.g.d),t.a=p.Math.max(t.a,n.g.c+n.g.b),t.b=p.Math.max(t.b,n.g.d+n.g.a);e.d=MF(new $e(b.a,b.b)),e.e=Hr(new $e(t.a,t.b),b),e.a.a.c.length=0,e.a.b.c.length=0}function Srt(e,t,n){var i,r,o,a,d,b;for(ga(t,(q5(),W9))?b=ue(he(ke(t,W9))):b=n,r=b+t.f+p.Math.max(c(ke(t,(Dn(),Y1)),125).a,e.b),d=new cn((!t.e&&(t.e=new Et(Ii,t,7,4)),t.e));d.e!=d.i.gc();)if(o=c(un(d),74),i=c(re((!o.c&&(o.c=new Et(vn,o,5,8)),o.c),0),19),ga(i,W9)&&r>ue(he(ke(i,W9)))+c(ke(i,Y1),125).d)throw J(new Wh("Invalid vertical constraints. Node "+i.k+" has a vertical constraint that is too low for its ancestors."));for(a=new cn((!t.e&&(t.e=new Et(Ii,t,7,4)),t.e));a.e!=a.i.gc();)o=c(un(a),74),i=c(re((!o.c&&(o.c=new Et(vn,o,5,8)),o.c),0),19),Srt(e,i,r)}function zYt(e){nT();var t,n,i,r,o,a,d;for(d=new lLe,n=new G(e);n.a<n.c.c.length;)t=c(Q(n),148),(!d.b||t.c>=d.b.c)&&(d.b=t),(!d.c||t.c<=d.c.c)&&(d.d=d.c,d.c=t),(!d.e||t.d>=d.e.d)&&(d.e=t),(!d.f||t.d<=d.f.d)&&(d.f=t);return i=new UH((lS(),jw)),H_(e,Pht,new Ho(W(V(GL,1),Lt,378,0,[i]))),a=new UH(Dv),H_(e,Lht,new Ho(W(V(GL,1),Lt,378,0,[a]))),r=new UH(_v),H_(e,Dht,new Ho(W(V(GL,1),Lt,378,0,[r]))),o=new UH(i3),H_(e,_ht,new Ho(W(V(GL,1),Lt,378,0,[o]))),Zne(i.c,jw),Zne(r.c,_v),Zne(o.c,i3),Zne(a.c,Dv),d.a.c.length=0,yr(d.a,i.c),yr(d.a,Eu(r.c)),yr(d.a,o.c),yr(d.a,Eu(a.c)),d}function FYt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P;for(t.Tg(qct,1),L=ue(he(ke(e,(Gd(),Yv)))),a=ue(he(ke(e,(Ah(),xC)))),d=c(ke(e,yC),100),gme((!e.a&&(e.a=new Me(Mn,e,10,11)),e.a)),x=brt((!e.a&&(e.a=new Me(Mn,e,10,11)),e.a),L,a),!e.a&&(e.a=new Me(Mn,e,10,11)),v=new G(x);v.a<v.c.c.length;)for(b=c(Q(v),189),r=new G(b.a);r.a<r.c.c.length;)i=c(Q(r),175),M=new Dpe(i.s,i.t,ue(he(ke(e,xC)))),yme(M,i),qe(b.d,M);S=JYe(x,a),P=p.Math.max(S.a,ue(he(ke(e,vC)))-(d.b+d.c)),o=p.Math.max(S.b,ue(he(ke(e,_J)))-(d.d+d.a)),n=o-S.b,ii(e,wC,n),ii(e,Ck,P),ii(e,J9,o+n),ii(e,DJ,x),t.Ug()}function qYt(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z;for(v=new Ld,x=new Ld,P=new Ld,z=new Ld,b=ue(he(R(t,(Ge(),$b)))),o=ue(he(R(t,Mf))),d=new G(n);d.a<d.c.c.length;)if(a=c(Q(d),9),S=c(R(a,(De(),Ko)),64),S==(Je(),Kt))for(x.a.yc(a,x),r=new Ht(Vt(pr(a).a.Jc(),new U));hn(r);)i=c(sn(r),17),Sr(v,i.c.i);else if(S==bn)for(z.a.yc(a,z),r=new Ht(Vt(pr(a).a.Jc(),new U));hn(r);)i=c(sn(r),17),Sr(P,i.c.i);v.a.gc()!=0&&(M=new XZ(2,o),L=zye(M,t,v,x,-b-t.c.b),L>0&&(e.a=b+(L-1)*o,t.c.b+=e.a,t.f.b+=e.a)),P.a.gc()!=0&&(M=new XZ(1,o),L=zye(M,t,P,z,t.f.b+b-t.c.b),L>0&&(t.f.b+=b+(L-1)*o))}function jrt(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de;for(x=ue(he(R(e,(Ge(),Rb)))),i=ue(he(R(e,HSe))),M=new O4,Ee(M,Rb,x+i),v=t,X=v.d,z=v.c.i,ie=v.d.i,H=ige(z.c),se=ige(ie.c),r=new Fe,S=H;S<=se;S++)d=new Eh(e),mu(d,(Jt(),jr)),Ee(d,(De(),Oi),v),Ee(d,cr,(Zr(),xc)),Ee(d,lJ,M),L=c(Xe(e.b,S),26),S==H?B0(d,L.a.c.length-n,L):zr(d,L),de=ue(he(R(v,Xg))),de<0&&(de=0,Ee(v,Xg,de)),d.o.b=de,P=p.Math.floor(de/2),a=new bc,$r(a,(Je(),Yt)),_o(a,d),a.n.b=P,b=new bc,$r(b,nn),_o(b,d),b.n.b=P,ss(v,a),o=new qm,ec(o,v),Ee(o,ho,null),ks(o,b),ss(o,X),HFt(d,v,o),It(r.c,o),v=o;return r}function HYt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se;if(z=t.b.c.length,!(z<3)){for(L=ye(Fn,ci,30,z,15,1),S=0,x=new G(t.b);x.a<x.c.c.length;)v=c(Q(x),26),L[S++]=v.a.c.length;for(M=new os(t.b,2),i=1;i<z-1;i++)for(n=(dn(M.b<M.d.gc()),c(M.d.Xb(M.c=M.b++),26)),P=new G(n.a),o=0,d=0,b=0;b<L[i+1];b++)if(se=c(Q(P),9),b==L[i+1]-1||V2e(e,se,i+1,i)){for(a=L[i]-1,V2e(e,se,i+1,i)&&(a=e.c.e[c(c(c(Xe(e.c.b,se.p),16).Xb(0),49).a,9).p]);d<=b;){if(ie=c(Xe(n.a,d),9),!V2e(e,ie,i+1,i))for(X=c(Xe(e.c.b,ie.p),16).Jc();X.Ob();)H=c(X.Pb(),49),r=e.c.e[c(H.a,9).p],(r<o||r>a)&&Sr(e.b,c(H.b,17));++d}o=a}}}function Cie(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se;for(b=c(Bg(e,(Je(),Yt)).Jc().Pb(),12).e,L=c(Bg(e,nn).Jc().Pb(),12).g,d=b.c.length,se=xh(c(Xe(e.j,0),12));d-- >0;){for(z=(ht(0,b.c.length),c(b.c[0],17)),r=(ht(0,L.c.length),c(L.c[0],17)),ie=r.d.e,o=Do(ie,r,0),F_t(z,r.d,o),ks(r,null),ss(r,null),P=z.a,t&&ei(P,new Cs(se)),i=_n(r.a,0);i.b!=i.d.c;)n=c(An(i),8),ei(P,new Cs(n));for(X=z.b,M=new G(r.b);M.a<M.c.c.length;)S=c(Q(M),70),It(X.c,S);if(H=c(R(z,(Ge(),ho)),79),a=c(R(r,ho),79),a)for(H||(H=new nu,Ee(z,ho,H)),x=_n(a,0);x.b!=x.d.c;)v=c(An(x),8),ei(H,new Cs(v))}}function QYt(e,t){var n,i,r,o,a,d,b,v;for(t.Tg("Sort By Input Model "+R(e,(Ge(),t1)),1),o=0,r=new G(e.b);r.a<r.c.c.length;){for(i=c(Q(r),26),i.p=o,v=o==0?0:o-1,b=c(Xe(e.b,v),26),n=new Ome(e,b,c(R(e,t1),270),c(R(e,tle),353),(c(R(e,VE),330),!0)),ztt(i.a,n),d=new G(i.a);d.a<d.c.c.length;)a=c(Q(d),9),ve(R(a,cr))!==ve((Zr(),Hb))&&ve(R(a,cr))!==ve(xc)&&(Ct(),Rr(a.j,new rKe(e,b,c(R(e,t1),270),XYe(a),et(Ze(R(e,nle))))),t.ah("Node "+a+" ports: "+a.j));n=new Ome(e,b,c(R(e,t1),270),c(R(e,tle),353),(c(R(e,VE),330),!1)),ztt(i.a,n),t.ah("Layer "+o+": "+i),++o}t.Ug()}function Rye(e,t){var n;if(t==null||Ot(t,pl)||t.length==0&&e.k!=(q0(),Ak))return null;switch(e.k.g){case 1:return FH(t,h9)?(Bt(),k9):FH(t,Bse)?(Bt(),K0):null;case 2:try{return Pe(Hu(t,ls,di))}catch(i){if(i=vr(i),oe(i,133))return null;throw J(i)}case 4:try{return gv(t)}catch(i){if(i=vr(i),oe(i,133))return null;throw J(i)}case 3:return t;case 5:return wWe(e),Wet(e,t);case 6:return wWe(e),UUt(e,e.a,t);case 7:try{return n=KGt(e),n.ag(t),n}catch(i){if(i=vr(i),oe(i,33))return null;throw J(i)}default:throw J(new oo("Invalid type set for this layout option."))}}function $ye(e){var t;switch(e.d){case 1:{if(e.Qj())return e.o!=-2;break}case 2:{if(e.Qj())return e.o==-2;break}case 3:case 5:case 4:case 6:case 7:return e.o>-2;default:return!1}switch(t=e.Pj(),e.p){case 0:return t!=null&&et(Ze(t))!=O7(e.k,0);case 1:return t!=null&&c(t,224).a!=Hn(e.k)<<24>>24;case 2:return t!=null&&c(t,183).a!=(Hn(e.k)&_r);case 6:return t!=null&&O7(c(t,192).a,e.k);case 5:return t!=null&&c(t,15).a!=Hn(e.k);case 7:return t!=null&&c(t,193).a!=Hn(e.k)<<16>>16;case 3:return t!=null&&ue(he(t))!=e.j;case 4:return t!=null&&c(t,165).a!=e.j;default:return t==null?e.n!=null:!yi(t,e.n)}}function eL(e,t,n){var i,r,o,a;return e.ml()&&e.ll()&&(a=FZ(e,c(n,57)),ve(a)!==ve(n))?(e.vj(t),e.Bj(t,WUe(e,t,a)),e.$k()&&(o=(r=c(n,52),e.kl()?e.il()?r.Qh(e.b,Hs(c(_t(al(e.b),e.Jj()),20)).n,c(_t(al(e.b),e.Jj()).Fk(),29).ik(),null):r.Qh(e.b,Vi(r.Ah(),Hs(c(_t(al(e.b),e.Jj()),20))),null,null):r.Qh(e.b,-1-e.Jj(),null,null)),!c(a,52).Mh()&&(o=(i=c(a,52),e.kl()?e.il()?i.Oh(e.b,Hs(c(_t(al(e.b),e.Jj()),20)).n,c(_t(al(e.b),e.Jj()).Fk(),29).ik(),o):i.Oh(e.b,Vi(i.Ah(),Hs(c(_t(al(e.b),e.Jj()),20))),null,o):i.Oh(e.b,-1-e.Jj(),null,o))),o&&o.mj()),wu(e.b)&&e.Hj(e.Gj(9,n,a,t,!1)),a):n}function Trt(e){var t,n,i,r,o,a,d,b,v,x;for(i=new Fe,a=new G(e.e.a);a.a<a.c.c.length;){for(r=c(Q(a),126),x=0,r.k.c.length=0,n=new G(Ax(r));n.a<n.c.c.length;)t=c(Q(n),220),t.f&&(qe(r.k,t),++x);x==1&&It(i.c,r)}for(o=new G(i);o.a<o.c.c.length;)for(r=c(Q(o),126);r.k.c.length==1;){for(v=c(Q(new G(r.k)),220),e.b[v.c]=v.g,d=v.d,b=v.e,n=new G(Ax(r));n.a<n.c.c.length;)t=c(Q(n),220),yi(t,v)||(t.f?d==t.d||b==t.e?e.b[v.c]-=e.b[t.c]-t.g:e.b[v.c]+=e.b[t.c]-t.g:r==d?t.d==r?e.b[v.c]+=t.g:e.b[v.c]-=t.g:t.d==r?e.b[v.c]-=t.g:e.b[v.c]+=t.g);fl(d.k,v),fl(b.k,v),d==r?r=v.e:r=v.d}}function Ert(e,t){var n,i,r,o,a,d,b,v,x,S,M,L;if(n=c(Zs(e.b,t),129),b=c(c(Si(e.r,t),24),85),b.dc()){n.n.b=0,n.n.c=0;return}for(v=e.u.Gc((Ql(),eg)),a=0,d=b.Jc(),x=null,S=0,M=0;d.Ob();)i=c(d.Pb(),116),r=ue(he(i.b.mf((AF(),rU)))),o=i.b.Kf().a,e.A.Gc((Cu(),Qb))&&Ynt(e,t),x?(L=M+x.d.c+e.w+i.d.b,a=p.Math.max(a,(mh(),vf(_h),p.Math.abs(S-r)<=_h||S==r||isNaN(S)&&isNaN(r)?0:L/(r-S)))):e.C&&e.C.b>0&&(a=p.Math.max(a,rVe(e.C.b+i.d.b,r))),x=i,S=r,M=o;e.C&&e.C.c>0&&(L=M+e.C.c,v&&(L+=x.d.c),a=p.Math.max(a,(mh(),vf(_h),p.Math.abs(S-1)<=_h||S==1||isNaN(S)&&isNaN(1)?0:L/(1-S)))),n.n.b=0,n.a.a=a}function Crt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L;if(n=c(Zs(e.b,t),129),b=c(c(Si(e.r,t),24),85),b.dc()){n.n.d=0,n.n.a=0;return}for(v=e.u.Gc((Ql(),eg)),a=0,e.A.Gc((Cu(),Qb))&&Znt(e,t),d=b.Jc(),x=null,M=0,S=0;d.Ob();)i=c(d.Pb(),116),o=ue(he(i.b.mf((AF(),rU)))),r=i.b.Kf().b,x?(L=S+x.d.a+e.w+i.d.d,a=p.Math.max(a,(mh(),vf(_h),p.Math.abs(M-o)<=_h||M==o||isNaN(M)&&isNaN(o)?0:L/(o-M)))):e.C&&e.C.d>0&&(a=p.Math.max(a,rVe(e.C.d+i.d.d,o))),x=i,M=o,S=r;e.C&&e.C.a>0&&(L=S+e.C.a,v&&(L+=x.d.a),a=p.Math.max(a,(mh(),vf(_h),p.Math.abs(M-1)<=_h||M==1||isNaN(M)&&isNaN(1)?0:L/(1-M)))),n.n.d=0,n.a.b=a}function Mrt(e,t,n){var i,r,o,a,d,b;for(this.g=e,d=t.d.length,b=n.d.length,this.d=ye(e1,Hg,9,d+b,0,1),a=0;a<d;a++)this.d[a]=t.d[a];for(o=0;o<b;o++)this.d[d+o]=n.d[o];if(t.e){if(this.e=A_(t.e),this.e.Kc(n),n.e)for(r=n.e.Jc();r.Ob();)i=c(r.Pb(),242),i!=t&&(this.e.Gc(i)?--i.c:this.e.Ec(i))}else n.e&&(this.e=A_(n.e),this.e.Kc(t));this.f=t.f+n.f,this.a=t.a+n.a,this.a>0?nte(this,this.f/this.a):wh(t.g,t.d[0]).a!=null&&wh(n.g,n.d[0]).a!=null?nte(this,(ue(wh(t.g,t.d[0]).a)+ue(wh(n.g,n.d[0]).a))/2):wh(t.g,t.d[0]).a!=null?nte(this,wh(t.g,t.d[0]).a):wh(n.g,n.d[0]).a!=null&&nte(this,wh(n.g,n.d[0]).a)}function GYt(e,t,n,i,r,o,a,d){var b,v,x,S,M,L,P,z,H,X;if(P=!1,v=Fve(n.q,t.f+t.b-n.q.f),L=i.f>t.b&&d,X=r-(n.q.e+v-a),S=(b=UT(i,X,!1),b.a),L&&S>i.f)return!1;if(L){for(M=0,H=new G(t.d);H.a<H.c.c.length;)z=c(Q(H),320),M+=Fve(z,i.f)+a;X=r-M}return X<i.g||(x=o==e.c.length-1&&X>=(ht(o,e.c.length),c(e.c[o],189)).e,!L&&S>t.b&&!x)?!1:((x||L||S<=t.b)&&(x&&S>t.b?(n.d=S,K_(n,tet(n,S))):(dZe(n.q,v),n.c=!0),K_(i,r-(n.s+n.r)),AD(i,n.q.e+n.q.d,t.f),oH(t,i),e.c.length>o&&(LD((ht(o,e.c.length),c(e.c[o],189)),i),(ht(o,e.c.length),c(e.c[o],189)).a.c.length==0&&Mg(e,o)),P=!0),P)}function UYt(e){var t,n,i;for(Cx(gp,W(V(n3,1),Lt,139,0,[new NN])),n=new RN(e),i=0;i<n.a.length;++i)t=tv(n,i).re().a,Ot(t,"layered")?Cx(gp,W(V(n3,1),Lt,139,0,[new RB])):Ot(t,"force")?Cx(gp,W(V(n3,1),Lt,139,0,[new iK])):Ot(t,"stress")?Cx(gp,W(V(n3,1),Lt,139,0,[new LB])):Ot(t,"mrtree")?Cx(gp,W(V(n3,1),Lt,139,0,[new dK])):Ot(t,"radial")?Cx(gp,W(V(n3,1),Lt,139,0,[new aK])):Ot(t,"sporeOverlap")||Ot(t,"sporeCompaction")?Cx(gp,W(V(n3,1),Lt,139,0,[new UB])):Ot(t,"rectpacking")?Cx(gp,W(V(n3,1),Lt,139,0,[new GB])):Ot(t,"vertiflex")&&Cx(gp,W(V(n3,1),Lt,139,0,[new MN]))}function JYt(e,t){var n,i,r,o,a,d,b,v,x,S;for(e.a=new xqe(cRt(_C)),i=new G(t.a);i.a<i.c.c.length;){for(n=c(Q(i),847),d=new nne(W(V(Zoe,1),Lt,84,0,[])),qe(e.a.a,d),v=new G(n.d);v.a<v.c.c.length;)b=c(Q(v),120),x=new Age(e,b),Fye(x,c(R(n.c,(De(),X1)),24)),jc(e.g,n)||(oi(e.g,n,new $e(b.c,b.d)),oi(e.f,n,x)),qe(e.a.b,x),jee(d,x);for(a=new G(n.b);a.a<a.c.c.length;)o=c(Q(a),598),x=new Age(e,o.Bf()),oi(e.b,o,new Ps(d,x)),Fye(x,c(R(n.c,(De(),X1)),24)),o.zf()&&(S=new qwe(e,o.zf(),1),Fye(S,c(R(n.c,X1),24)),r=new nne(W(V(Zoe,1),Lt,84,0,[])),jee(r,S),St(e.c,o.yf(),new Ps(d,S)))}return e.a}function XYt(e,t,n){var i,r,o,a,d,b,v,x,S,M,L;for(n.Tg("Breadth-first cycle removal",1),e.c=t,S=t.a,e.a=new Ai,e.e=new Or,e.d=new Or,e.f=ye(kl,eh,30,S.c.length,16,1),e.b=new Fe,d=0,x=new G(S);x.a<x.c.c.length;)v=c(Q(x),9),v.p=d,Y2(pr(v))&&Sr(e.e,v),Y2($i(v))&&Sr(e.d,v),++d;for(L=e.e.a.ec().Jc();L.Ob();)M=c(L.Pb(),9),ei(e.a,M),bpe(e);for(bpe(e),i=!0;i;){for(i=!1,a=0;a<S.c.length;a++)if(!e.f[a]){b=(ht(a,S.c.length),c(S.c[a],9)),ei(e.a,b),i=!0;break}bpe(e)}for(o=new G(e.b);o.a<o.c.c.length;)r=c(Q(o),17),zg(r,!0),Ee(t,(De(),wk),(Bt(),!0));e.e=null,e.f=null,e.a=null,e.b=null,n.Ug()}function VYt(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H;if(a=n.Jk(),oe(a,104)&&(c(a,20).Bb&Is)!=0&&(M=c(n.kd(),52),z=I0(e.e,M),z!=M)){if(x=Fd(a,z),M7(e,t,Dne(e,t,x)),S=null,wu(e.e)&&(i=qx((Dl(),ps),e.e.Ah(),a),i!=_t(e.e.Ah(),e.c))){for(H=nl(e.e.Ah(),a),d=0,o=c(e.g,123),b=0;b<t;++b)r=o[b],H.$l(r.Jk())&&++d;S=new Aee(e.e,9,i,M,z,d,!1),S.lj(new _1(e.e,9,e.c,n,x,t,!1))}return P=c(a,20),L=Hs(P),L?(S=M.Qh(e.e,Vi(M.Ah(),L),null,S),S=c(z,52).Oh(e.e,Vi(z.Ah(),L),null,S)):(P.Bb&nc)!=0&&(v=-1-Vi(e.e.Ah(),P),S=M.Qh(e.e,v,null,null),!c(z,52).Mh()&&(S=c(z,52).Oh(e.e,v,null,S))),S&&S.mj(),x}return n}function Art(e){var t;this.a=e,t=(Jt(),W(V(sce,1),_e,252,0,[or,jr,Cr,Dc,lc,Ih,UL,PE])).length,this.b=H2(Xue,[Be,e4e],[597,149],0,[t,t],2),this.c=H2(Xue,[Be,e4e],[597,149],0,[t,t],2),hee(this,or,(Ge(),$b),Vv),uT(this,or,jr,Rb,ip),R_(this,or,Dc,Rb),R_(this,or,Cr,Rb),uT(this,or,lc,$b,Vv),hee(this,jr,Mf,Jv),R_(this,jr,Dc,Mf),R_(this,jr,Cr,Mf),uT(this,jr,lc,Rb,ip),D$e(this,Dc,Mf),R_(this,Dc,Cr,Mf),R_(this,Dc,lc,gle),D$e(this,Cr,tC),uT(this,Cr,lc,q9,F9),hee(this,lc,Mf,Mf),hee(this,Ih,Mf,Jv),uT(this,Ih,or,Rb,ip),uT(this,Ih,lc,Rb,ip),uT(this,Ih,jr,Rb,ip)}function WYt(e,t,n,i,r,o){var a;if(!(t==null||!Xte(t,STe,jTe)))throw J(new qt("invalid scheme: "+t));if(!e&&!(n!=null&&Zh(n,dl(35))==-1&&n.length>0&&(en(0,n.length),n.charCodeAt(0)!=47)))throw J(new qt("invalid opaquePart: "+n));if(e&&!(t!=null&&i7(lX,t.toLowerCase()))&&!(n==null||!Xte(n,HC,QC)))throw J(new qt(Sut+n));if(e&&t!=null&&i7(lX,t.toLowerCase())&&!Bqt(n))throw J(new qt(Sut+n));if(!U$t(i))throw J(new qt("invalid device: "+i));if(!FRt(r))throw a=r==null?"invalid segments: null":"invalid segment: "+LRt(r),J(new qt(a));if(!(o==null||Zh(o,dl(35))==-1))throw J(new qt("invalid query: "+o))}function Nrt(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X;if(M=new Cs(e.o),X=t.a/M.a,d=t.b/M.b,z=t.a-M.a,o=t.b-M.b,n)for(r=ve(R(e,(Ge(),cr)))===ve((Zr(),xc)),P=new G(e.j);P.a<P.c.c.length;)switch(L=c(Q(P),12),L.j.g){case 1:r||(L.n.a*=X);break;case 2:L.n.a+=z,r||(L.n.b*=d);break;case 3:r||(L.n.a*=X),L.n.b+=o;break;case 4:r||(L.n.b*=d)}for(v=new G(e.b);v.a<v.c.c.length;)b=c(Q(v),70),x=b.n.a+b.o.a/2,S=b.n.b+b.o.b/2,H=x/M.a,a=S/M.b,H+a>=1&&(H-a>0&&S>=0?(b.n.a+=z,b.n.b+=o*a):H-a<0&&x>=0&&(b.n.a+=z*H,b.n.b+=o));e.o.a=t.a,e.o.b=t.b,Ee(e,(Ge(),Pb),(Cu(),i=c(Jf(BC),10),new ha(i,c(gf(i,i.length),10),0)))}function KYt(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X;if(n.Tg("Network simplex layering",1),e.b=t,X=c(R(t,(Ge(),nC)),15).a*4,H=e.b.a,H.c.length<1){n.Ug();return}for(o=qVt(e,H),z=null,r=_n(o,0);r.b!=r.d.c;){for(i=c(An(r),16),d=X*xs(p.Math.sqrt(i.gc())),a=nWt(i),fie(Yde(L9t(Zde(xZ(a),d),z),!0),n.dh(1)),M=e.b.b,P=new G(a.a);P.a<P.c.c.length;){for(L=c(Q(P),126);M.c.length<=L.e;)Up(M,M.c.length,new hc(e.b));x=c(L.f,9),zr(x,c(Xe(M,L.e),26))}if(o.b>1)for(z=ye(Fn,ci,30,e.b.b.c.length,15,1),S=0,v=new G(e.b.b);v.a<v.c.c.length;)b=c(Q(v),26),z[S++]=b.a.c.length}H.c.length=0,e.a=null,e.b=null,e.c=null,n.Ug()}function YYt(e,t){var n,i,r,o,a,d,b,v,x,S;for(x=new Fe,S=new bx,o=null,r=0,i=0;i<t.length;++i)switch(n=t[i],ORt(o,n)&&(r=vwe(e,S,x,wJ,r)),xi(n,(De(),Mw))&&(o=c(R(n,Mw),9)),n.k.g){case 0:for(b=oge(g5(Po(n,(Je(),Kt)),new gA));cte(b);)a=c(Rbe(b),12),e.d[a.p]=r++,It(x.c,a);for(r=vwe(e,S,x,wJ,r),v=oge(g5(Po(n,bn),new gA));cte(v);)a=c(Rbe(v),12),e.d[a.p]=r++,It(x.c,a);break;case 3:Po(n,T9e).dc()||(a=c(Po(n,T9e).Xb(0),12),e.d[a.p]=r++,It(x.c,a)),Po(n,wJ).dc()||C0(S,n);break;case 1:for(d=Po(n,(Je(),Yt)).Jc();d.Ob();)a=c(d.Pb(),12),e.d[a.p]=r++,It(x.c,a);Po(n,nn).Ic(new dRe(S,n))}return vwe(e,S,x,wJ,r),x}function Bye(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P;if(t==null||t.length==0)return null;if(o=c(Tc(e.f,t),21),!o){for(r=(L=new x1(e.d).a.vc().Jc(),new C2(L));r.a.Ob();)if(n=(a=c(r.a.Pb(),45),c(a.kd(),21)),d=n.f,P=t.length,Ot(d.substr(d.length-P,P),t)&&(t.length==d.length||ms(d,d.length-t.length-1)==46)){if(o)return null;o=n}if(!o){for(i=(M=new x1(e.d).a.vc().Jc(),new C2(M));i.a.Ob();)if(n=(a=c(i.a.Pb(),45),c(a.kd(),21)),S=n.g,S!=null){for(b=S,v=0,x=b.length;v<x;++v)if(d=b[v],P=t.length,Ot(d.substr(d.length-P,P),t)&&(t.length==d.length||ms(d,d.length-t.length-1)==46)){if(o)return null;o=n}}}o&&lo(e.f,t,o)}return o}function ZYt(e,t){var n,i,r,o,a;for(n=new Z4,a=!1,o=0;o<t.length;o++){if(i=(en(o,t.length),t.charCodeAt(o)),i==32){for(HH(e,n,0),n.a+=" ",HH(e,n,0);o+1<t.length&&(en(o+1,t.length),t.charCodeAt(o+1)==32);)++o;continue}if(a){i==39?o+1<t.length&&(en(o+1,t.length),t.charCodeAt(o+1)==39)?(n.a+=String.fromCharCode(i),++o):a=!1:n.a+=String.fromCharCode(i);continue}if(Zh("GyMLdkHmsSEcDahKzZv",dl(i))>0){HH(e,n,0),n.a+=String.fromCharCode(i),r=TBt(t,o),HH(e,n,r),o+=r-1;continue}i==39?o+1<t.length&&(en(o+1,t.length),t.charCodeAt(o+1)==39)?(n.a+="'",++o):a=!0:n.a+=String.fromCharCode(i)}HH(e,n,0),oHt(e)}function eZt(e,t,n,i,r){var o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se;for(se=eFe(e),b=new Fe,o=e.c.length,v=o-1,x=o+1;se.a.gc()!=0;){for(;n.b!=0;)X=(dn(n.b!=0),c(ba(n,n.a.a),117)),se.a.Ac(X)!=null,X.g=v--,jye(X,t,n,i);for(;t.b!=0;)ie=(dn(t.b!=0),c(ba(t,t.a.a),117)),se.a.Ac(ie)!=null,ie.g=x++,jye(ie,t,n,i);for(d=ls,z=se.a.ec().Jc();z.Ob();){if(P=c(z.Pb(),117),!i&&P.b>0&&P.a<=0){b.c.length=0,It(b.c,P);break}L=P.i-P.d,L>=d&&(L>d&&(b.c.length=0,d=L),It(b.c,P))}b.c.length!=0&&(a=c(Xe(b,VH(r,b.c.length)),117),se.a.Ac(a)!=null,a.g=x++,jye(a,t,n,i),b.c.length=0)}for(H=e.c.length+1,M=new G(e);M.a<M.c.c.length;)S=c(Q(M),117),S.g<o&&(S.g=S.g+H)}function tZt(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X;for(v=mse,b=Vx,X=new Fe,P=new G(t);P.a<P.c.c.length;){for(L=c(Q(P),9),r=new Fe,d=new Ht(Vt(pr(L).a.Jc(),new U));hn(d);)o=c(sn(d),17),H=o.d.i,z=o.c.i,H.c.p==n&&It(r.c,H),z.c.p==n&&It(r.c,z);for(a=new Ht(Vt($i(L).a.Jc(),new U));hn(a);)o=c(sn(a),17),H=o.d.i,z=o.c.i,H.c.p==n&&It(r.c,H),z.c.p==n&&It(r.c,z);r.c.length==0?It(X.c,L):(Ct(),Rr(r,e.b),M=ue(he(R(c(Xe(r,r.c.length/2|0),9),(De(),p3)))),Ee(L,p3,M),v=p.Math.min(v,M),b=p.Math.max(b,M))}for(i=(b+v)/2,S=new G(X);S.a<S.c.c.length;)x=c(Q(S),9),Ee(x,(De(),p3),i)}function nZt(e,t){var n,i,r,o,a,d,b,v,x,S,M;for(r=new G(e.a.b);r.a<r.c.c.length;)for(n=c(Q(r),26),b=new G(n.a);b.a<b.c.c.length;)d=c(Q(b),9),t.j[d.p]=d,t.i[d.p]=t.o==(vh(),Rh)?Qr:nr;for(sc(e.c),a=e.a.b,t.c==(td(),Wg)&&(a=Eu(a)),D_t(e.e,t,e.b),n_(t.p,null),o=a.Jc();o.Ob();)for(n=c(o.Pb(),26),v=n.a,t.o==(vh(),Rh)&&(v=Eu(v)),M=v.Jc();M.Ob();)S=c(M.Pb(),9),t.g[S.p]==S&&mst(e,S,t);for(DYt(e,t),i=a.Jc();i.Ob();)for(n=c(i.Pb(),26),M=new G(n.a);M.a<M.c.c.length;)S=c(Q(M),9),t.p[S.p]=t.p[t.g[S.p].p],S==t.g[S.p]&&(x=ue(t.i[t.j[S.p].p]),(t.o==(vh(),Rh)&&x>Qr||t.o==Bb&&x<nr)&&(t.p[S.p]=ue(t.p[S.p])+x));e.e.wg()}function iZt(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H;if(et(Ze(R(n,(Ge(),qv)))))for(d=new G(n.j);d.a<d.c.c.length;)for(a=c(Q(d),12),M=rd(a.g),v=M,x=0,S=v.length;x<S;++x)b=v[x],o=b.d.i==n,r=o&&et(Ze(R(b,Lb))),r&&(P=b.c,L=c(Ut(e.b,P),9),L||(L=tL(P,(Zr(),Hh),P.j,-1,null,null,P.o,c(R(t,Xu),87),t),Ee(L,(De(),Oi),P),oi(e.b,P,L),qe(t.a,L)),H=b.d,z=c(Ut(e.b,H),9),z||(z=tL(H,(Zr(),Hh),H.j,1,null,null,H.o,c(R(t,Xu),87),t),Ee(z,(De(),Oi),H),oi(e.b,H,z),qe(t.a,z)),i=Iee(b),ks(i,c(Xe(L.j,0),12)),ss(i,c(Xe(z.j,0),12)),St(e.a,b,new PF(i,t,(Qs(),Wc))),c(R(t,(De(),Lc)),24).Ec((Gs(),Ea)))}function rZt(e,t,n,i,r){var o,a,d,b,v,x,S,M,L,P,z,H;for(o=new Fe,v=new G(i);v.a<v.c.c.length;)if(d=c(Q(v),447),a=null,d.f==(Qs(),Wc))for(P=new G(d.e);P.a<P.c.c.length;)L=c(Q(P),17),H=L.d.i,Jr(H)==t?cXe(e,t,d,L,d.b,L.d):!n||sS(H,n)?FHt(e,t,d,i,L):(M=Sie(e,t,n,L,d.b,Wc,a),M!=a&&It(o.c,M),M.c&&(a=M));else for(S=new G(d.e);S.a<S.c.c.length;)if(x=c(Q(S),17),z=x.c.i,Jr(z)==t)cXe(e,t,d,x,x.c,d.b);else{if(!n||sS(z,n))continue;M=Sie(e,t,n,x,d.b,Jl,a),M!=a&&It(o.c,M),M.c&&(a=M)}for(b=new G(o);b.a<b.c.c.length;)d=c(Q(b),447),Do(t.a,d.a,0)!=-1||qe(t.a,d.a),d.c&&It(r.c,d)}function sZt(e){var t,n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de;for(r=c(R(e,(Li(),pC)),19),v=di,x=di,d=ls,b=ls,se=_n(e.b,0);se.b!=se.d.c;)X=c(An(se),41),L=X.e,P=X.f,v=p.Math.min(v,L.a-P.a/2),x=p.Math.min(x,L.b-P.b/2),d=p.Math.max(d,L.a+P.a/2),b=p.Math.max(b,L.b+P.b/2);for(M=c(ke(r,(Uo(),e8e)),100),ie=_n(e.b,0);ie.b!=ie.d.c;)X=c(An(ie),41),S=R(X,pC),oe(S,209)&&(o=c(S,19),aa(o,X.e.a,X.e.b),GD(o,X));for(H=_n(e.a,0);H.b!=H.d.c;)z=c(An(H),65),i=c(R(z,pC),74),i&&(t=z.a,n=$T(i),Tye(t,n));de=d-v+(M.b+M.c),a=b-x+(M.d+M.a),et(Ze(ke(r,(Dn(),ny))))||uw(r,de,a,!1,!1),ii(r,ty,de-(M.b+M.c)),ii(r,ey,a-(M.d+M.a))}function _rt(e){var t,n,i,r,o,a,d;for(t=0,o=new G(e.b.a);o.a<o.c.c.length;)i=c(Q(o),197),i.b=0,i.c=0;for(KZe(e,0),Vte(e,e.g),OQ(e.c),Jde(e.c),n=(Nr(),go),KD(DY(Hx(KD(DY(Hx(KD(Hx(e.c,n)),ZWe(n)))),n))),Hx(e.c,go),qte(e,e.g),PZe(e,0),frt(e,0),Btt(e,1),KZe(e,1),Vte(e,e.d),OQ(e.c),a=new G(e.b.a);a.a<a.c.c.length;)i=c(Q(a),197),t+=p.Math.abs(i.c);for(d=new G(e.b.a);d.a<d.c.c.length;)i=c(Q(d),197),i.b=0,i.c=0;for(n=Ca,KD(DY(Hx(KD(DY(Hx(KD(Jde(Hx(e.c,n))),ZWe(n)))),n))),Hx(e.c,go),qte(e,e.d),PZe(e,1),frt(e,1),Btt(e,0),Jde(e.c),r=new G(e.b.a);r.a<r.c.c.length;)i=c(Q(r),197),t+=p.Math.abs(i.c);return t}function oZt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z;for(n=c(R(e,(Ge(),cr)),103),a=e.f,o=e.d,d=a.a+o.b+o.c,b=0-o.d-e.c.b,x=a.b+o.d+o.a-e.c.b,v=new Fe,S=new Fe,r=new G(t);r.a<r.c.c.length;){switch(i=c(Q(r),9),n.g){case 1:case 2:case 3:GJt(i);break;case 4:M=c(R(i,Lw),8),L=M?M.a:0,i.n.a=d*ue(he(R(i,(De(),Aw))))-L,xH(i,!0,!1);break;case 5:P=c(R(i,Lw),8),z=P?P.a:0,i.n.a=ue(he(R(i,(De(),Aw))))-z,xH(i,!0,!1),a.a=p.Math.max(a.a,i.n.a+i.o.a/2)}switch(c(R(i,(De(),Ko)),64).g){case 1:i.n.b=b,It(v.c,i);break;case 3:i.n.b=x,It(S.c,i)}}switch(n.g){case 1:case 2:zWe(v,e),zWe(S,e);break;case 3:FWe(v,e),FWe(S,e)}}function cZt(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P;for(n.Tg("Label dummy switching",1),i=c(R(t,(Ge(),ZU)),233),mIt(t),r=DUt(t,i),e.a=ye(ns,no,30,t.b.c.length,15,1),d=(H5(),W(V(N9,1),_e,233,0,[A9,RE,M9,Rv,c3,o3])),x=0,L=d.length;x<L;++x)if(o=d[x],(o==c3||o==o3||o==Rv)&&!c(Cl(r.a,o)?r.b[o.g]:null,16).dc()){TIt(e,t);break}for(b=W(V(N9,1),_e,233,0,[A9,RE,M9,Rv,c3,o3]),S=0,P=b.length;S<P;++S)o=b[S],o==c3||o==o3||o==Rv||bit(e,c(Cl(r.a,o)?r.b[o.g]:null,16));for(a=W(V(N9,1),_e,233,0,[A9,RE,M9,Rv,c3,o3]),v=0,M=a.length;v<M;++v)o=a[v],(o==c3||o==o3||o==Rv)&&bit(e,c(Cl(r.a,o)?r.b[o.g]:null,16));e.a=null,n.Ug()}function Drt(e,t){var n,i,r,o,a,d,b,v,x;if(v=t,!(v.b==null||e.b==null)){for($x(e),JT(e),$x(v),JT(v),n=ye(Fn,ci,30,e.b.length+v.b.length,15,1),x=0,i=0,a=0;i<e.b.length&&a<v.b.length;)if(r=e.b[i],o=e.b[i+1],d=v.b[a],b=v.b[a+1],o<d)i+=2;else if(o>=d&&r<=b)d<=r&&o<=b?(n[x++]=r,n[x++]=o,i+=2):d<=r?(n[x++]=r,n[x++]=b,e.b[i]=b+1,a+=2):o<=b?(n[x++]=d,n[x++]=o,i+=2):(n[x++]=d,n[x++]=b,e.b[i]=b+1);else if(b<r)a+=2;else throw J(new Mo("Token#intersectRanges(): Internal Error: ["+e.b[i]+","+e.b[i+1]+"] & ["+v.b[a]+","+v.b[a+1]+"]"));for(;i<e.b.length;)n[x++]=e.b[i++],n[x++]=e.b[i++];e.b=ye(Fn,ci,30,x,15,1),mc(n,0,e.b,0,x)}}function lZt(e){var t,n,i,r,o,a,d;for(t=new Fe,e.g=new Fe,e.d=new Fe,a=new sv(new Bp(e.f.b).a);a.b;)o=Ex(a),qe(t,c(c(o.kd(),49).b,84)),O1(c(o.jd(),598).yf())?qe(e.d,c(o.kd(),49)):qe(e.g,c(o.kd(),49));for(Vte(e,e.d),Vte(e,e.g),e.c=new Zet(e.b),I9t(e.c,(p1e(),Eht)),qte(e,e.d),qte(e,e.g),yr(t,e.c.a.b),e.e=new $e(nr,nr),e.a=new $e(Qr,Qr),i=new G(t);i.a<i.c.c.length;)n=c(Q(i),84),e.e.a=p.Math.min(e.e.a,n.g.c),e.e.b=p.Math.min(e.e.b,n.g.d),e.a.a=p.Math.max(e.a.a,n.g.c+n.g.b),e.a.b=p.Math.max(e.a.b,n.g.d+n.g.a);e1e(e.c,new rm),d=0;do r=_rt(e),++d;while((d<2||r>Fg)&&d<10);e1e(e.c,new e4),_rt(e),jMt(e.c),BYt(e.f)}function uZt(e,t){var n,i,r,o,a,d,b,v,x,S,M;switch(e.k.g){case 1:if(i=c(R(e,(De(),Oi)),17),n=c(R(i,v6e),79),n?et(Ze(R(i,Jg)))&&(n=Fme(n)):n=new nu,v=c(R(e,sh),12),v){if(x=Lo(W(V(Vr,1),Be,8,0,[v.i.n,v.n,v.a])),t<=x.a)return x.b;tr(n,x,n.a,n.a.a)}if(S=c(R(e,Wa),12),S){if(M=Lo(W(V(Vr,1),Be,8,0,[S.i.n,S.n,S.a])),M.a<=t)return M.b;tr(n,M,n.c.b,n.c)}if(n.b>=2){for(b=_n(n,0),a=c(An(b),8),d=c(An(b),8);d.a<t&&b.b!=b.d.c;)a=d,d=c(An(b),8);return a.b+(t-a.a)/(d.a-a.a)*(d.b-a.b)}break;case 3:switch(o=c(R(c(Xe(e.j,0),12),(De(),Oi)),12),r=o.i,o.j.g){case 1:return r.n.b;case 3:return r.n.b+r.o.b}}return v2e(e).b}function aZt(e){var t,n,i,r,o,a,d,b,v,x,S;for(a=new G(e.d.b);a.a<a.c.c.length;)for(o=c(Q(a),26),b=new G(o.a);b.a<b.c.c.length;){if(d=c(Q(b),9),et(Ze(R(d,(Ge(),JE))))&&!Y2(sd(d))){i=c($At(sd(d)),17),x=i.c.i,x==d&&(x=i.d.i),S=new Ps(x,Hr(Ms(d.n),x.n)),oi(e.b,d,S);continue}r=new pf(d.n.a-d.d.b,d.n.b-d.d.d,d.o.a+d.d.b+d.d.c,d.o.b+d.d.d+d.d.a),t=xBe(CIe(TIe(EIe(new _de,d),r),idt),e.a),yBe(u8t(TXe(new Nde,W(V(nU,1),Lt,60,0,[t])),t),e.a),v=new $K,oi(e.e,t,v),n=Vf(new Ht(Vt(pr(d).a.Jc(),new U)))-Vf(new Ht(Vt($i(d).a.Jc(),new U))),n<0?vD(v,!0,(Nr(),go)):n>0&&vD(v,!0,(Nr(),yo)),d.k==(Jt(),Cr)&&Dqe(v),oi(e.f,d,t)}}function Lrt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie;for(v=nr,x=nr,d=Qr,b=Qr,M=new G(t.i);M.a<M.c.c.length;)S=c(Q(M),68),r=c(c(Ut(e.g,S.a),49).b,19),aa(r,S.b.c,S.b.d),v=p.Math.min(v,r.i),x=p.Math.min(x,r.j),d=p.Math.max(d,r.i+r.g),b=p.Math.max(b,r.j+r.f);for(L=c(ke(e.c,($D(),Tmt)),100),uw(e.c,d-v+(L.b+L.c),b-x+(L.d+L.a),!0,!0),B2e(e.c,-v+L.b,-x+L.d),i=new cn(eHe(e.c));i.e!=i.i.gc();)n=c(un(i),74),a=$T(n),P=Bne(n),H=$Ze(n),z=new $e(P.i+P.g/2,P.j+P.f/2),o=new $e(H.i+H.g/2,H.j+H.f/2),X=Hr(new $e(o.a,o.b),z),TS(X,P.g,P.f),ki(z,X),ie=Hr(new $e(z.a,z.b),o),TS(ie,H.g,H.f),ki(o,ie),m_(a,z.a,z.b),b_(a,o.a,o.b)}function Prt(e,t){var n,i,r,o,a,d,b,v,x,S;for(b=!0,r=0,v=e.g[t.p],x=t.o.b+e.o,n=e.d[t.p][2],Su(e.b,v,Pe(c(Xe(e.b,v),15).a-1+n)),Su(e.c,v,ue(he(Xe(e.c,v)))-x+n*e.f),++v,v>=e.j?(++e.j,qe(e.b,Pe(1)),qe(e.c,x)):(i=e.d[t.p][1],Su(e.b,v,Pe(c(Xe(e.b,v),15).a+1-i)),Su(e.c,v,ue(he(Xe(e.c,v)))+x-i*e.f)),(e.r==(H0(),fP)&&(c(Xe(e.b,v),15).a>e.k||c(Xe(e.b,v-1),15).a>e.k)||e.r==hP&&(ue(he(Xe(e.c,v)))>e.n||ue(he(Xe(e.c,v-1)))>e.n))&&(b=!1),a=new Ht(Vt(pr(t).a.Jc(),new U));hn(a);)o=c(sn(a),17),d=o.c.i,e.g[d.p]==v&&(S=Prt(e,d),r=r+c(S.a,15).a,b=b&&et(Ze(S.b)));return e.g[t.p]=v,r=r+e.d[t.p][0],new Ps(Pe(r),(Bt(),!!b))}function fZt(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe;return M=e.c[t],L=e.c[n],P=c(R(M,(De(),yk)),16),!!P&&P.gc()!=0&&P.Gc(L)||(z=M.k!=(Jt(),jr)&&L.k!=jr,H=c(R(M,Mw),9),X=c(R(L,Mw),9),ie=H!=X,se=!!H&&H!=M||!!X&&X!=L,de=wne(M,(Je(),Kt)),Se=wne(L,bn),se=se|(wne(M,bn)||wne(L,Kt)),xe=se&&ie||de||Se,z&&xe)||M.k==(Jt(),Dc)&&L.k==or||L.k==(Jt(),Dc)&&M.k==or?!1:(x=e.c[t],o=e.c[n],r=sZe(e.e,x,o,(Je(),Yt)),b=sZe(e.i,x,o,nn),IJt(e.f,x,o),v=bWe(e.b,x,o)+c(r.a,15).a+c(b.a,15).a+e.f.d,d=bWe(e.b,o,x)+c(r.b,15).a+c(b.b,15).a+e.f.b,e.a&&(S=c(R(x,Oi),12),a=c(R(o,Oi),12),i=HYe(e.g,S,a),v+=c(i.a,15).a,d+=c(i.b,15).a),v>d)}function Irt(e,t){var n,i,r,o,a;n=ue(he(R(t,(Ge(),Mf)))),n<2&&Ee(t,Mf,2),i=c(R(t,Xu),87),i==(Nr(),qh)&&Ee(t,Xu,NH(t)),r=c(R(t,p0t),15),r.a==0?Ee(t,(De(),kk),new Ute):Ee(t,(De(),kk),new Lq(r.a)),o=Ze(R(t,ZE)),o==null&&Ee(t,ZE,(Bt(),ve(R(t,W1))===ve(($1(),i8)))),lr(new jt(null,new Tt(t.a,16)),new bde(e)),lr(So(new jt(null,new Tt(t.b,16)),new mO),new mde(e)),a=new Art(t),Ee(t,(De(),d3),a),U7(e.a),Iu(e.a,(es(),Cf),c(R(t,Tk),173)),Iu(e.a,Zd,c(R(t,nJ),173)),Iu(e.a,vc,c(R(t,KE),173)),Iu(e.a,yc,c(R(t,oJ),173)),Iu(e.a,Vs,LIt(c(R(t,W1),225))),sge(e.a,ctn(t)),Ee(t,Xce,VT(e.a,t))}function zye(e,t,n,i,r){var o,a,d,b,v,x,S,M,L,P,z,H,X;for(S=new wn,a=new Fe,ket(e,n,e.d.zg(),a,S),ket(e,i,e.d.Ag(),a,S),e.b=.2*(z=Att(So(new jt(null,new Tt(a,16)),new vA)),H=Att(So(new jt(null,new Tt(a,16)),new yA)),p.Math.min(z,H)),o=0,d=0;d<a.c.length-1;d++)for(b=(ht(d,a.c.length),c(a.c[d],117)),P=d+1;P<a.c.length;P++)o+=Dye(e,b,(ht(P,a.c.length),c(a.c[P],117)));for(M=c(R(t,(De(),kk)),237),o>=2&&(X=Ztt(a,!0,M),!e.e&&(e.e=new A_e(e)),SBt(e.e,X,a,e.b)),SZe(a,M),wZt(a),L=-1,x=new G(a);x.a<x.c.c.length;)v=c(Q(x),117),!(p.Math.abs(v.s-v.c)<dd)&&(L=p.Math.max(L,v.o),e.d.xg(v,r,e.c));return e.d.a.a.$b(),L+1}function hZt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de;for(S=c(kF((a=_n(new k1(t).a.d,0),new ix(a))),41),P=S?c(R(S,(Li(),Ule)),41):null,r=1;S&&P;){for(b=0,de=0,n=S,i=P,d=0;d<r;d++)n=$ee(n),i=$ee(i),de+=ue(he(R(n,(Li(),U9)))),b+=ue(he(R(i,U9)));if(se=ue(he(R(P,(Li(),Kg)))),ie=ue(he(R(S,Kg))),M=bwe(e,S,P),L=se+b+e.b+M-ie-de,0<L){for(v=t,x=0;v&&v!=i;)++x,v=c(R(v,OJ),41);if(v)for(X=L/x,v=t;v!=i;)H=ue(he(R(v,Kg)))+L,Ee(v,Kg,H),z=ue(he(R(v,U9)))+L,Ee(v,U9,z),L-=X,v=c(R(v,OJ),41);else return}++r,S.d.b==0?S=pye(new k1(t),r):S=c(kF((o=_n(new k1(S).a.d,0),new ix(o))),41),P=S?c(R(S,Ule),41):null}}function dZt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P;for(t.Tg("Label dummy removal",1),i=ue(he(R(e,(Ge(),m3)))),r=ue(he(R(e,Xv))),v=c(R(e,Xu),87),b=new G(e.b);b.a<b.c.c.length;)for(d=c(Q(b),26),S=new os(d.a,0);S.b<S.d.gc();)x=(dn(S.b<S.d.gc()),c(S.d.Xb(S.c=S.b++),9)),x.k==(Jt(),lc)&&(M=c(R(x,(De(),Oi)),17),P=ue(he(R(M,Xg))),a=ve(R(x,xk))===ve((qu(),up)),n=new Cs(x.n),a&&(n.b+=P+i),o=new $e(x.o.a,x.o.b+(x.k==lc&&!k6(pi(c(R(x,HE),16).Mc(),new d6(new Py))).zd((Hp(),hk))?0:-P-i)),L=c(R(x,HE),16),v==(Nr(),Ca)||v==Fh?bUt(L,n,r,o,a,v):XRt(L,n,r,o),yr(M.b,L),Cie(x,ve(R(e,W1))===ve(($1(),DP))),iu(S));t.Ug()}function gZt(e){e.q||(e.q=!0,e.p=Go(e,0),e.a=Go(e,1),zi(e.a,0),e.f=Go(e,2),zi(e.f,1),sr(e.f,2),e.n=Go(e,3),sr(e.n,3),sr(e.n,4),sr(e.n,5),sr(e.n,6),e.g=Go(e,4),zi(e.g,7),sr(e.g,8),e.c=Go(e,5),zi(e.c,7),zi(e.c,8),e.i=Go(e,6),zi(e.i,9),zi(e.i,10),zi(e.i,11),zi(e.i,12),sr(e.i,13),e.j=Go(e,7),zi(e.j,9),e.d=Go(e,8),zi(e.d,3),zi(e.d,4),zi(e.d,5),zi(e.d,6),sr(e.d,7),sr(e.d,8),sr(e.d,9),sr(e.d,10),e.b=Go(e,9),sr(e.b,0),sr(e.b,1),e.e=Go(e,10),sr(e.e,1),sr(e.e,2),sr(e.e,3),sr(e.e,4),zi(e.e,5),zi(e.e,6),zi(e.e,7),zi(e.e,8),zi(e.e,9),zi(e.e,10),sr(e.e,11),e.k=Go(e,11),sr(e.k,0),sr(e.k,1),e.o=fi(e,12),e.s=fi(e,13))}function pZt(e,t,n){var i,r,o,a,d,b,v,x;if(e.c.length!=0)for(e.c.length==1&&qe(t,(ht(0,e.c.length),c(e.c[0],19))),e.c.length==2&&(a=(ht(0,e.c.length),c(e.c[0],19)),v=(ht(1,e.c.length),c(e.c[1],19)),c(ke(a,(Qd(),jP)),15).a>c(ke(v,jP),15).a?(It(t.c,v),It(n.c,a)):(It(t.c,a),It(n.c,v))),r=new Fe,x=new HW,x.a=0,x.b=0,i=(ht(0,e.c.length),c(e.c[0],19)),It(r.c,i),d=1;d<e.c.length;d++)b=(ht(d,e.c.length),c(e.c[d],19)),ji(i.j,b.j)==0||(o=Git(r,x),yr(t,new nd(r,0,o+1)),yr(n,new nd(r,o+1,r.c.length)),r=new Fe),It(r.c,b),i=b,d==e.c.length-1&&(o=Git(r,x),yr(t,new nd(r,0,o+1)),yr(n,new nd(r,o+1,r.c.length)))}function Fye(e,t){t.dc()&&Id(e.j,!0,!0,!0,!0),yi(t,(Je(),Pf))&&Id(e.j,!0,!0,!0,!1),yi(t,Ma)&&Id(e.j,!1,!0,!0,!0),yi(t,Wu)&&Id(e.j,!0,!0,!1,!0),yi(t,Za)&&Id(e.j,!0,!1,!0,!0),yi(t,Xl)&&Id(e.j,!1,!0,!0,!1),yi(t,Aa)&&Id(e.j,!1,!0,!1,!0),yi(t,Ku)&&Id(e.j,!0,!1,!1,!0),yi(t,If)&&Id(e.j,!0,!1,!0,!1),yi(t,vl)&&Id(e.j,!0,!0,!0,!0),yi(t,ol)&&Id(e.j,!0,!0,!0,!0),yi(t,vl)&&Id(e.j,!0,!0,!0,!0),yi(t,wl)&&Id(e.j,!0,!0,!0,!0),yi(t,yl)&&Id(e.j,!0,!0,!0,!0),yi(t,Vl)&&Id(e.j,!0,!0,!0,!0),yi(t,Pc)&&Id(e.j,!0,!0,!0,!0)}function Rrt(e,t,n){var i,r,o,a,d,b,v,x,S;if(e.a!=t.hk())throw J(new qt(p9+t.ve()+xw));if(i=Pg((Dl(),ps),t).Hl(),i)return i.hk().ti().oi(i,n);if(a=Pg(ps,t).Jl(),a){if(n==null)return null;if(d=c(n,16),d.dc())return"";for(S=new yg,o=d.Jc();o.Ob();)r=o.Pb(),Ys(S,a.hk().ti().oi(a,r)),S.a+=" ";return VY(S,S.a.length-1)}if(x=Pg(ps,t).Kl(),!x.dc()){for(v=x.Jc();v.Ob();)if(b=c(v.Pb(),160),b.dk(n))try{if(S=b.hk().ti().oi(b,n),S!=null)return S}catch(M){if(M=vr(M),!oe(M,102))throw J(M)}throw J(new qt("Invalid value: '"+n+"' for datatype :"+t.ve()))}return c(t,839).mk(),n==null?null:oe(n,183)?""+c(n,183).a:ju(n)==KG?G$e(qC[0],c(n,208)):jo(n)}function $rt(e,t,n){var i,r,o,a;this.j=e,this.e=C2e(e),this.o=this.j.e,this.i=!!this.o,this.p=this.i?c(Xe(n,Jr(this.o).p),221):null,r=c(R(e,(De(),Lc)),24),this.g=r.Gc((Gs(),Ea)),this.b=new Fe,this.d=new OKe(this.e),a=c(R(this.j,kk),237),this.q=CIt(t,a,this.e),this.k=new QHe(this),o=mf(W(V(sdt,1),Lt,223,0,[this,this.d,this.k,this.q])),t==(hb(),gP)&&!et(Ze(R(e,(Ge(),R9))))?(i=new N2e(this.e),It(o.c,i),this.c=new Kpe(i,a,c(this.q,411))):t==gP&&et(Ze(R(e,(Ge(),R9))))?(i=new N2e(this.e),It(o.c,i),this.c=new XXe(i,a,c(this.q,411))):t==bJ?this.c=new pHe(a):this.c=new oRe(t,this),qe(o,this.c),drt(o,this.e),this.s=Fen(this.k)}function bZt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X;for(t.Tg("Interactive crossing minimization",1),a=0,o=new G(e.b);o.a<o.c.c.length;)i=c(Q(o),26),i.p=a++;for(M=C2e(e),H=new n1e(M.length),drt(new Ho(W(V(sdt,1),Lt,223,0,[H])),M),z=0,a=0,r=new G(e.b);r.a<r.c.c.length;){for(i=c(Q(r),26),n=0,S=0,x=new G(i.a);x.a<x.c.c.length;)for(b=c(Q(x),9),b.n.a>0&&(n+=b.n.a+b.o.a/2,++S),P=new G(b.j);P.a<P.c.c.length;)L=c(Q(P),12),L.p=z++;for(S>0&&(n/=S),X=ye(ns,no,30,i.a.c.length,15,1),d=0,v=new G(i.a);v.a<v.c.c.length;)b=c(Q(v),9),b.p=d++,X[b.p]=uZt(b,n),b.k==(Jt(),jr)&&Ee(b,(De(),y6e),X[b.p]);Ct(),Rr(i.a,new l_e(X)),yit(H,M,a,!0),++a}t.Ug()}function mZt(e){var t,n,i,r,o,a,d,b,v,x;for(v=new Ai,d=new Ai,o=new G(e);o.a<o.c.c.length;)i=c(Q(o),134),i.v=0,i.n=i.i.c.length,i.u=i.t.c.length,i.n==0&&tr(v,i,v.c.b,v.c),i.u==0&&i.r.a.gc()==0&&tr(d,i,d.c.b,d.c);for(a=-1;v.b!=0;)for(i=c(Ene(v,0),134),n=new G(i.t);n.a<n.c.c.length;)t=c(Q(n),275),x=t.b,x.v=p.Math.max(x.v,i.v+1),a=p.Math.max(a,x.v),--x.n,x.n==0&&tr(v,x,v.c.b,v.c);if(a>-1){for(r=_n(d,0);r.b!=r.d.c;)i=c(An(r),134),i.v=a;for(;d.b!=0;)for(i=c(Ene(d,0),134),n=new G(i.i);n.a<n.c.c.length;)t=c(Q(n),275),b=t.a,b.r.a.gc()==0&&(b.v=p.Math.min(b.v,i.v-1),--b.u,b.u==0&&tr(d,b,d.c.b,d.c))}}function wZt(e){var t,n,i,r,o,a,d,b,v,x;for(v=new Fe,d=new Fe,a=new G(e);a.a<a.c.c.length;)r=c(Q(a),117),BN(r,r.f.c.length),u6(r,r.k.c.length),r.d==0&&It(v.c,r),r.i==0&&r.e.b==0&&It(d.c,r);for(i=-1;v.c.length!=0;)for(r=c(Mg(v,0),117),n=new G(r.k);n.a<n.c.c.length;)t=c(Q(n),135),x=t.b,a6(x,p.Math.max(x.o,r.o+1)),i=p.Math.max(i,x.o),BN(x,x.d-1),x.d==0&&It(v.c,x);if(i>-1){for(o=new G(d);o.a<o.c.c.length;)r=c(Q(o),117),r.o=i;for(;d.c.length!=0;)for(r=c(Mg(d,0),117),n=new G(r.f);n.a<n.c.c.length;)t=c(Q(n),135),b=t.a,!(b.e.b>0)&&(a6(b,p.Math.min(b.o,r.o-1)),u6(b,b.i-1),b.i==0&&It(d.c,b))}}function Brt(e,t,n,i,r){var o,a,d,b;return b=nr,a=!1,d=Nye(e,Hr(new $e(t.a,t.b),e),ki(new $e(n.a,n.b),r),Hr(new $e(i.a,i.b),n)),o=!!d&&!(p.Math.abs(d.a-e.a)<=vw&&p.Math.abs(d.b-e.b)<=vw||p.Math.abs(d.a-t.a)<=vw&&p.Math.abs(d.b-t.b)<=vw),d=Nye(e,Hr(new $e(t.a,t.b),e),n,r),d&&((p.Math.abs(d.a-e.a)<=vw&&p.Math.abs(d.b-e.b)<=vw)==(p.Math.abs(d.a-t.a)<=vw&&p.Math.abs(d.b-t.b)<=vw)||o?b=p.Math.min(b,H7(Hr(d,n))):a=!0),d=Nye(e,Hr(new $e(t.a,t.b),e),i,r),d&&(a||(p.Math.abs(d.a-e.a)<=vw&&p.Math.abs(d.b-e.b)<=vw)==(p.Math.abs(d.a-t.a)<=vw&&p.Math.abs(d.b-t.b)<=vw)||o)&&(b=p.Math.min(b,H7(Hr(d,i)))),b}function zrt(e){Am(e,new mb(JN(Em(Sm(Tm(jm(new b1,U0),Iot),"Minimizes the stress within a layout using stress majorization. Stress exists if the euclidean distance between a pair of nodes doesn't match their graph theoretic distance, that is, the shortest path between the two nodes. The method allows to specify individual edge lengths."),new A8),il))),Ie(e,U0,e9,Ve($ke)),Ie(e,U0,vL,(Bt(),!0)),Ie(e,U0,Jx,Ve(wht)),Ie(e,U0,ok,Ve(vht)),Ie(e,U0,sk,Ve(yht)),Ie(e,U0,i9,Ve(mht)),Ie(e,U0,t9,Ve(zke)),Ie(e,U0,r9,Ve(xht)),Ie(e,U0,Txe,Ve(Rke)),Ie(e,U0,Cxe,Ve(Pke)),Ie(e,U0,Mxe,Ve(Ike)),Ie(e,U0,Axe,Ve(Bke)),Ie(e,U0,Exe,Ve(uU))}function vZt(e){var t,n,i,r,o,a,d,b;for(t=null,i=new G(e);i.a<i.c.c.length;)n=c(Q(i),242),ue(wh(n.g,n.d[0]).a),n.b=null,n.e&&n.e.gc()>0&&n.c==0&&(!t&&(t=new Fe),It(t.c,n));if(t)for(;t.c.length!=0;){if(n=c(Mg(t,0),242),n.b&&n.b.c.length>0){for(o=(!n.b&&(n.b=new Fe),new G(n.b));o.a<o.c.c.length;)if(r=c(Q(o),242),UN(wh(r.g,r.d[0]).a)==UN(wh(n.g,n.d[0]).a)){if(Do(e,r,0)>Do(e,n,0))return new Ps(r,n)}else if(ue(wh(r.g,r.d[0]).a)>ue(wh(n.g,n.d[0]).a))return new Ps(r,n)}for(d=(!n.e&&(n.e=new Fe),n.e).Jc();d.Ob();)a=c(d.Pb(),242),b=(!a.b&&(a.b=new Fe),a.b),K2(0,b.c.length),h7(b.c,0,n),a.c==b.c.length&&It(t.c,a)}return null}function WT(e,t){var n,i,r,o,a,d,b,v,x;if(t.e==5){Drt(e,t);return}if(v=t,!(v.b==null||e.b==null)){for($x(e),JT(e),$x(v),JT(v),n=ye(Fn,ci,30,e.b.length+v.b.length,15,1),x=0,i=0,a=0;i<e.b.length&&a<v.b.length;)if(r=e.b[i],o=e.b[i+1],d=v.b[a],b=v.b[a+1],o<d)n[x++]=e.b[i++],n[x++]=e.b[i++];else if(o>=d&&r<=b)d<=r&&o<=b?i+=2:d<=r?(e.b[i]=b+1,a+=2):o<=b?(n[x++]=r,n[x++]=d-1,i+=2):(n[x++]=r,n[x++]=d-1,e.b[i]=b+1,a+=2);else if(b<r)a+=2;else throw J(new Mo("Token#subtractRanges(): Internal Error: ["+e.b[i]+","+e.b[i+1]+"] - ["+v.b[a]+","+v.b[a+1]+"]"));for(;i<e.b.length;)n[x++]=e.b[i++],n[x++]=e.b[i++];e.b=ye(Fn,ci,30,x,15,1),mc(n,0,e.b,0,x)}}function yZt(e){var t,n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X;for(i=new G(e.e.b);i.a<i.c.c.length;)for(n=c(Q(i),26),o=new G(n.a);o.a<o.c.c.length;)if(r=c(Q(o),9),L=e.i[r.p],v=L.a.e,b=L.d.e,r.n.b=v,X=b-v-r.o.b,t=Oie(r),M=(hv(),(r.q?r.q:(Ct(),Ct(),Yd))._b((Ge(),Dw))?S=c(R(r,Dw),205):S=c(R(Jr(r),eC),205),S),t&&(M==v3||M==w3)&&(r.o.b+=X),t&&(M==Sle||M==v3||M==w3)){for(z=new G(r.j);z.a<z.c.c.length;)P=c(Q(z),12),(Je(),ol).Gc(P.j)&&(x=c(Ut(e.k,P),126),P.n.b=x.e-v);for(d=new G(r.b);d.a<d.c.c.length;)a=c(Q(d),70),H=c(R(r,_w),24),H.Gc((mv(),Ya))?a.n.b+=X:H.Gc(i1)&&(a.n.b+=X/2);(M==v3||M==w3)&&Po(r,(Je(),bn)).Ic(new S_e(X))}}function xZt(e){var t,n,i,r,o,a,d;if(!e.A.dc()){if(e.A.Gc((Cu(),zP))&&(c(Zs(e.b,(Je(),Kt)),129).k=!0,c(Zs(e.b,bn),129).k=!0,t=e.q!=(Zr(),r1)&&e.q!=xc,ym(c(Zs(e.b,nn),129),t),ym(c(Zs(e.b,Yt),129),t),ym(e.g,t),e.A.Gc(Qb)&&(c(Zs(e.b,Kt),129).j=!0,c(Zs(e.b,bn),129).j=!0,c(Zs(e.b,nn),129).k=!0,c(Zs(e.b,Yt),129).k=!0,e.g.k=!0)),e.A.Gc(BP))for(e.a.j=!0,e.a.k=!0,e.g.j=!0,e.g.k=!0,d=e.B.Gc((uu(),zC)),r=sne(),o=0,a=r.length;o<a;++o)i=r[o],n=c(Zs(e.i,i),319),n&&(Iwe(i)?(n.j=!0,n.k=!0):(n.j=!d,n.k=!d));e.A.Gc(cy)&&e.B.Gc((uu(),qP))&&(e.g.j=!0,e.g.j=!0,e.a.j||(e.a.j=!0,e.a.k=!0,e.a.e=!0))}}function kZt(e,t,n){var i,r,o,a,d,b,v,x,S,M;for(v=new Fe,b=new G(t.a);b.a<b.c.c.length;)for(a=c(Q(b),9),M=Po(a,(Je(),nn)).Jc();M.Ob();)for(S=c(M.Pb(),12),r=new G(S.g);r.a<r.c.c.length;)i=c(Q(r),17),!(!vs(i)&&i.c.i.c==i.d.i.c||vs(i)||i.d.i.c!=n)&&It(v.c,i);for(d=Eu(n.a).Jc();d.Ob();)for(a=c(d.Pb(),9),M=Po(a,(Je(),Yt)).Jc();M.Ob();)for(S=c(M.Pb(),12),r=new G(S.e);r.a<r.c.c.length;)if(i=c(Q(r),17),!(!vs(i)&&i.c.i.c==i.d.i.c||vs(i)||i.c.i.c!=t)&&v.c.length!=0){for(x=new os(v,v.c.length),o=(dn(x.b>0),c(x.a.Xb(x.c=--x.b),17));o!=i&&x.b>0;)e.a[o.p]=!0,e.a[i.p]=!0,o=(dn(x.b>0),c(x.a.Xb(x.c=--x.b),17));x.b>0&&iu(x)}}function Frt(e,t,n){var i,r,o,a,d,b,v,x,S,M;if(n)for(i=-1,x=new os(t,0);x.b<x.d.gc();){if(d=(dn(x.b<x.d.gc()),c(x.d.Xb(x.c=x.b++),9)),S=e.c[d.c.p][d.p].a,S==null){for(a=i+1,o=new os(t,x.b);o.b<o.d.gc();)if(M=Cjt(e,(dn(o.b<o.d.gc()),c(o.d.Xb(o.c=o.b++),9))).a,M!=null){a=(zt(M),M);break}S=(i+a)/2,e.c[d.c.p][d.p].a=S,e.c[d.c.p][d.p].d=(zt(S),S),e.c[d.c.p][d.p].b=1}i=(zt(S),S)}else{for(r=0,v=new G(t);v.a<v.c.c.length;)d=c(Q(v),9),e.c[d.c.p][d.p].a!=null&&(r=p.Math.max(r,ue(e.c[d.c.p][d.p].a)));for(r+=2,b=new G(t);b.a<b.c.c.length;)d=c(Q(b),9),e.c[d.c.p][d.p].a==null&&(S=lu(e.i,24)*gL*r-1,e.c[d.c.p][d.p].a=S,e.c[d.c.p][d.p].d=S,e.c[d.c.p][d.p].b=1)}}function OZt(e){var t,n,i,r,o,a,d,b,v,x,S,M;for(r=new G(e.a.a.b);r.a<r.c.c.length;)for(i=c(Q(r),60),b=i.c.Jc();b.Ob();)d=c(b.Pb(),60),i.a!=d.a&&(O1(e.a.d)?S=e.a.g.df(i,d):S=e.a.g.ef(i,d),o=i.b.a+i.d.b+S-d.b.a,o=p.Math.ceil(o),o=p.Math.max(0,o),$be(i,d)?(a=Dm(new Fp,e.d),v=xs(p.Math.ceil(d.b.a-i.b.a)),t=v-(d.b.a-i.b.a),x=j5(i).a,n=i,x||(x=j5(d).a,t=-t,n=d),x&&(n.b.a-=t,x.n.a-=t),Of(uf(ff(hf(af(new Ra,p.Math.max(0,v)),1),a),e.c[i.a.d])),Of(uf(ff(hf(af(new Ra,p.Math.max(0,-v)),1),a),e.c[d.a.d]))):(M=1,(oe(i.g,157)&&oe(d.g,9)||oe(d.g,157)&&oe(i.g,9))&&(M=2),Of(uf(ff(hf(af(new Ra,xs(o)),M),e.c[i.a.d]),e.c[d.a.d]))))}function qrt(e,t,n){var i,r,o,a,d,b,v,x,S,M,L;if(!e.b)return!1;for(a=null,M=null,b=new qee(null,null),r=1,b.a[1]=e.b,S=b;S.a[r];)v=r,d=M,M=S,S=S.a[r],i=e.a.Le(t,S.d),r=i<0?0:1,i==0&&(!n.c||dc(S.e,n.d))&&(a=S),!(S&&S.b)&&!A2(S.a[r])&&(A2(S.a[1-r])?M=M.a[v]=fH(S,r):A2(S.a[1-r])||(L=M.a[1-v],L&&(!A2(L.a[1-v])&&!A2(L.a[v])?(M.b=!1,L.b=!0,S.b=!0):(o=d.a[1]==M?1:0,A2(L.a[v])?d.a[o]=BQe(M,v):A2(L.a[1-v])&&(d.a[o]=fH(M,v)),S.b=d.a[o].b=!0,d.a[o].a[0].b=!1,d.a[o].a[1].b=!1))));return a&&(n.b=!0,n.d=a.e,S!=a&&(x=new qee(S.d,S.e),MHt(e,b,a,x),M==a&&(M=x)),M.a[M.a[1]==S?1:0]=S.a[S.a[0]?0:1],--e.c),e.b=b.a[1],e.b&&(e.b.b=!1),n.b}function SZt(e,t,n){var i,r,o,a,d,b,v,x,S;for(!n&&(n=eRt(t.q.getTimezoneOffset())),r=(t.q.getTimezoneOffset()-n.a)*6e4,d=new Vge(As(Zo(t.q.getTime()),r)),b=d,d.q.getTimezoneOffset()!=t.q.getTimezoneOffset()&&(r>0?r-=864e5:r+=864e5,b=new Vge(As(Zo(t.q.getTime()),r))),x=new Z4,v=e.a.length,o=0;o<v;)if(i=ms(e.a,o),i>=97&&i<=122||i>=65&&i<=90){for(a=o+1;a<v&&ms(e.a,a)==i;++a);ktn(x,i,a-o,d,b,n),o=a}else if(i==39){if(++o,o<v&&ms(e.a,o)==39){x.a+="'",++o;continue}for(S=!1;!S;){for(a=o;a<v&&ms(e.a,a)!=39;)++a;if(a>=v)throw J(new qt("Missing trailing '"));a+1<v&&ms(e.a,a+1)==39?++a:S=!0,Zn(x,Fa(e.a,o,a)),o=a+1}}else x.a+=String.fromCharCode(i),++o;return x.a}function jZt(){li(ay,new rc),li(si,new k2),li(ef,new Tj),li(ah,new cN),li(jae,new lN),li(uX,new lB),li(tg,new e6),li(FC,new uN),li(UP,new KO),li(vae,new T4),li(dp,new iB),li(tf,new rB),li(uh,new YO),li($w,new sB),li(fy,new Oj),li(xl,new oB),li(uy,new GW),li(Yo,new UW),li(Ks,new Yc),li(cl,new ro),li(ir,new wo),li(V(Rl,1),new kc),li(ak,new m1),li(CE,new x2),li(KG,new E4),li(nEe,new rN),li(kr,new wm),li(mTe,new bu),li(yTe,new Yy),li(HTe,new sN),li(aX,new w1),li(O9,new C4),li(Lr,new ZO),li(F5e,new _d),li(Ow,new oN),li(q5e,new Sj),li(BTe,new cB),li(iEe,new jj),li(Sw,new O2),li(nt,new Ia),li(vTe,new S2),li(rEe,new M4)}function Hrt(e,t){var n,i,r,o,a,d,b,v,x;if(e==null)return pl;if(b=t.a.yc(e,t),b!=null)return"[...]";for(n=new ub(Jc,"[","]"),r=e,o=0,a=r.length;o<a;++o)i=r[o],i!=null&&(ju(i).i&4)!=0?Array.isArray(i)&&(x=sD(i),!(x>=14&&x<=16))?t.a._b(i)?(n.a?Zn(n.a,n.b):n.a=new Lu(n.d),j7(n.a,"[...]")):(d=N5(i),v=new q2(t),N1(n,Hrt(d,v))):oe(i,172)?N1(n,cGt(c(i,172))):oe(i,198)?N1(n,Jqt(c(i,198))):oe(i,203)?N1(n,eQt(c(i,203))):oe(i,2090)?N1(n,Xqt(c(i,2090))):oe(i,54)?N1(n,oGt(c(i,54))):oe(i,591)?N1(n,vGt(c(i,591))):oe(i,838)?N1(n,sGt(c(i,838))):oe(i,109)&&N1(n,rGt(c(i,109))):N1(n,i==null?pl:jo(i));return n.a?n.e.length==0?n.a.a:n.a.a+(""+n.e):n.c}function zS(e,t){var n,i,r,o;o=e.F,t==null?(e.F=null,hS(e,null)):(e.F=(zt(t),t),i=Zh(t,dl(60)),i!=-1?(r=(fs(0,i,t.length),t.substr(0,i)),Zh(t,dl(46))==-1&&!Ot(r,K5)&&!Ot(r,vE)&&!Ot(r,PG)&&!Ot(r,yE)&&!Ot(r,xE)&&!Ot(r,kE)&&!Ot(r,OE)&&!Ot(r,SE)&&(r=Rut),n=SF(t,dl(62)),n!=-1&&(r+=""+(en(n+1,t.length+1),t.substr(n+1))),hS(e,r)):(r=t,Zh(t,dl(46))==-1&&(i=Zh(t,dl(91)),i!=-1&&(r=(fs(0,i,t.length),t.substr(0,i))),!Ot(r,K5)&&!Ot(r,vE)&&!Ot(r,PG)&&!Ot(r,yE)&&!Ot(r,xE)&&!Ot(r,kE)&&!Ot(r,OE)&&!Ot(r,SE)?(r=Rut,i!=-1&&(r+=""+(en(i,t.length+1),t.substr(i)))):r=t),hS(e,r),r==t&&(e.F=e.D))),(e.Db&4)!=0&&(e.Db&1)==0&&vi(e,new Ur(e,1,5,o,t))}function TZt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P;if(e.c=e.e,P=Ze(R(t,(Ge(),b0t))),L=P==null||(zt(P),P),o=c(R(t,(De(),Lc)),24).Gc((Gs(),Ea)),r=c(R(t,cr),103),n=!(r==(Zr(),Hb)||r==r1||r==xc),L&&(n||!o)){for(S=new G(t.a);S.a<S.c.c.length;)v=c(Q(S),9),v.p=0;for(M=new Fe,x=new G(t.a);x.a<x.c.c.length;)if(v=c(Q(x),9),i=Tit(e,v,null),i){for(b=new tme,ec(b,t),Ee(b,X1,c(i.b,24)),jpe(b.d,t.d),Ee(b,$9,null),d=c(i.a,16).Jc();d.Ob();)a=c(d.Pb(),9),qe(b.a,a),a.a=b;M.Ec(b)}o&&(ve(R(t,XE))===ve(($5(),ice))?e.c=e.b:ve(R(t,XE))===ve(rce)?e.c=e.d:e.c=e.a)}else M=new Ho(W(V(Bht,1),$ot,37,0,[t]));return ve(R(t,XE))!==ve(($5(),LE))&&(Ct(),M.gd(new L8)),M}function Qrt(e,t){var n,i,r,o,a,d,b,v,x,S;if(b=t.length-1,d=(en(b,t.length),t.charCodeAt(b)),d==93){if(a=Zh(t,dl(91)),a>=0)return r=$$t(e,(fs(1,a,t.length),t.substr(1,a-1))),x=(fs(a+1,b,t.length),t.substr(a+1,b-(a+1))),Yen(e,x,r)}else{if(n=-1,Y5e==null&&(Y5e=new RegExp("\\d")),Y5e.test(String.fromCharCode(d))&&(n=u0e(t,dl(46),b-1),n>=0)){i=c(Pee(e,aXe(e,(fs(1,n,t.length),t.substr(1,n-1))),!1),61),v=0;try{v=Hu((en(n+1,t.length+1),t.substr(n+1)),ls,di)}catch(M){throw M=vr(M),oe(M,133)?(o=M,J(new Uq(o))):J(M)}if(v<i.gc())return S=i.Xb(v),oe(S,76)&&(S=c(S,76).kd()),c(S,57)}if(n<0)return c(Pee(e,aXe(e,(en(1,t.length+1),t.substr(1))),!1),57)}return null}function EZt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z;for(t.Tg("Label dummy insertions",1),S=new Fe,a=ue(he(R(e,(Ge(),m3)))),v=ue(he(R(e,Xv))),x=c(R(e,Xu),87),L=new G(e.a);L.a<L.c.c.length;)for(M=c(Q(L),9),o=new Ht(Vt($i(M).a.Jc(),new U));hn(o);)if(r=c(sn(o),17),r.c.i!=r.d.i&&iZ(r.b,Xht)){for(z=yPt(r),P=Pd(r.b.c.length),n=ZUt(e,r,z,P),It(S.c,n),i=n.o,d=new os(r.b,0);d.b<d.d.gc();)b=(dn(d.b<d.d.gc()),c(d.d.Xb(d.c=d.b++),70)),ve(R(b,yd))===ve((Sh(),t8))&&(x==(Nr(),Ca)||x==Fh?(i.a+=b.o.a+v,i.b=p.Math.max(i.b,b.o.b)):(i.a=p.Math.max(i.a,b.o.a),i.b+=b.o.b+v),It(P.c,b),iu(d));x==(Nr(),Ca)||x==Fh?(i.a-=v,i.b+=a+z):i.b+=a-v+z}yr(e.a,S),t.Ug()}function FS(e,t,n){var i,r,o,a,d,b,v;if(v=e.c,!t&&(t=MTe),e.c=t,(e.Db&4)!=0&&(e.Db&1)==0&&(b=new Ur(e,1,2,v,e.c),n?n.lj(b):n=b),v!=t){if(oe(e.Cb,294))e.Db>>16==-10?n=c(e.Cb,294).Wk(t,n):e.Db>>16==-15&&(!t&&(t=(Mt(),Gh)),!v&&(v=(Mt(),Gh)),e.Cb.Vh()&&(b=new _1(e.Cb,1,13,v,t,$g(ou(c(e.Cb,62)),e),!1),n?n.lj(b):n=b));else if(oe(e.Cb,89))e.Db>>16==-23&&(oe(t,89)||(t=(Mt(),rf)),oe(v,89)||(v=(Mt(),rf)),e.Cb.Vh()&&(b=new _1(e.Cb,1,10,v,t,$g(gc(c(e.Cb,29)),e),!1),n?n.lj(b):n=b));else if(oe(e.Cb,449))for(d=c(e.Cb,842),a=(!d.b&&(d.b=new pz(new UK)),d.b),o=(i=new sv(new Bp(a.a).a),new bz(i));o.a.b;)r=c(Ex(o.a).jd(),88),n=FS(r,vQ(r,d),n)}return n}function CZt(e,t){var n,i,r,o,a,d,b,v,x,S,M;for(a=et(Ze(ke(e,(Ge(),qv)))),M=c(ke(e,Gv),24),b=!1,v=!1,S=new cn((!e.c&&(e.c=new Me(hu,e,9,9)),e.c));S.e!=S.i.gc()&&(!b||!v);){for(o=c(un(S),127),d=0,r=Bd(ma(W(V(Ta,1),Lt,22,0,[(!o.d&&(o.d=new Et(Ii,o,8,5)),o.d),(!o.e&&(o.e=new Et(Ii,o,7,4)),o.e)])));hn(r)&&(i=c(sn(r),74),x=a&&sw(i)&&et(Ze(ke(i,Lb))),n=krt((!i.b&&(i.b=new Et(vn,i,4,7)),i.b),o)?e==Xi(to(c(re((!i.c&&(i.c=new Et(vn,i,5,8)),i.c),0),83))):e==Xi(to(c(re((!i.b&&(i.b=new Et(vn,i,4,7)),i.b),0),83))),!((x||n)&&(++d,d>1))););(d>0||M.Gc((Ql(),eg))&&(!o.n&&(o.n=new Me(Bo,o,1,7)),o.n).i>0)&&(b=!0),d>1&&(v=!0)}b&&t.Ec((Gs(),Ea)),v&&t.Ec((Gs(),zE))}function Grt(e){var t,n,i,r,o,a,d,b,v,x,S,M;if(M=c(ke(e,(Dn(),qb)),24),M.dc())return null;if(d=0,a=0,M.Gc((Cu(),zP))){for(x=c(ke(e,Y9),103),i=2,n=2,r=2,o=2,t=Xi(e)?c(ke(Xi(e),Fb),87):c(ke(e,Fb),87),v=new cn((!e.c&&(e.c=new Me(hu,e,9,9)),e.c));v.e!=v.i.gc();)if(b=c(un(v),127),S=c(ke(b,M3),64),S==(Je(),$o)&&(S=Sye(b,t),ii(b,M3,S)),x==(Zr(),xc))switch(S.g){case 1:i=p.Math.max(i,b.i+b.g);break;case 2:n=p.Math.max(n,b.j+b.f);break;case 3:r=p.Math.max(r,b.i+b.g);break;case 4:o=p.Math.max(o,b.j+b.f)}else switch(S.g){case 1:i+=b.g+2;break;case 2:n+=b.f+2;break;case 3:r+=b.g+2;break;case 4:o+=b.f+2}d=p.Math.max(i,r),a=p.Math.max(n,o)}return uw(e,d,a,!0,!0)}function MZt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z;for(r=null,i=new G(t.a);i.a<i.c.c.length;)n=c(Q(i),9),Oie(n)?o=(d=Dm(ZN(new Fp,n),e.f),b=Dm(ZN(new Fp,n),e.f),v=new Spe(n,!0,d,b),x=n.o.b,S=(hv(),(n.q?n.q:(Ct(),Ct(),Yd))._b((Ge(),Dw))?M=c(R(n,Dw),205):M=c(R(Jr(n),eC),205),M),L=1e4,S==w3&&(L=1),P=Of(uf(ff(af(hf(new Ra,L),xs(p.Math.ceil(x))),d),b)),S==v3&&Sr(e.d,P),Sit(e,Eu(Po(n,(Je(),Yt))),v),Sit(e,Po(n,nn),v),v):o=(z=Dm(ZN(new Fp,n),e.f),lr(pi(new jt(null,new Tt(n.j,16)),new DR),new fRe(e,z)),new Spe(n,!1,z,z)),e.i[n.p]=o,r&&(a=r.c.d.a+px(e.n,r.c,n)+n.d.d,r.b||(a+=r.c.o.b),Of(uf(ff(hf(af(new Ra,xs(p.Math.ceil(a))),0),r.d),o.a))),r=o}function Mie(e,t,n,i,r){var o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de;for(ie=c(ql(Yq(pi(new jt(null,new Tt(t.d,16)),new WNe(n)),new KNe(n)),su(new Ls,new rs,new mo,W(V(ml,1),_e,132,0,[(va(),bl)]))),16),S=di,x=ls,b=new G(t.b.j);b.a<b.c.c.length;)d=c(Q(b),12),d.j==n&&(S=p.Math.min(S,d.p),x=p.Math.max(x,d.p));if(S==di)for(a=0;a<ie.gc();a++)Nbe(c(ie.Xb(a),108),n,a);else for(se=ye(Fn,ci,30,r.length,15,1),YCt(se,se.length),X=ie.Jc();X.Ob();){for(H=c(X.Pb(),108),o=c(Ut(e.b,H),172),v=0,z=S;z<=x;z++)o[z]&&(v=p.Math.max(v,i[z]));if(H.i){for(L=H.i.c,de=new Or,M=0;M<r.length;M++)r[L][M]&&Sr(de,Pe(se[M]));for(;$a(de,Pe(v));)++v}for(Nbe(H,n,v),P=S;P<=x;P++)o[P]&&(i[P]=v+1);H.i&&(se[H.i.c]=v)}}function Urt(e,t){var n,i,r,o,a,d,b,v;for(Ee(t,(De(),QE),Pe(e.b)),Ee(t,Ok,Pe(e.b)),++e.b,j$e(e.d,t),Ee(t,JU,(Bt(),!0)),i=new Ht(Vt(sd(t).a.Jc(),new U));hn(i);)n=c(sn(i),17),!(n.c.i!=t&&Do(e.a,n,0)==-1)&&(n.c.i==t&&Do(e.a,n,0)!=-1||(v=null,n.d.i==t?v=n.c.i:v=n.d.i,c(R(v,QE),15).a==-1?(Urt(e,v),Ee(t,Ok,Pe(p.Math.min(c(R(t,Ok),15).a,c(R(v,Ok),15).a)))):et(Ze(R(v,JU)))&&Ee(t,Ok,Pe(p.Math.min(c(R(t,Ok),15).a,c(R(v,QE),15).a)))));if(ve(R(t,Ok))===ve(R(t,QE))){b=new Or,o=null;do o=c(Jme(e.d),9),Ee(o,JU,!1),b.a.yc(o,b);while(t!=o);if(b.a.gc()>1)for(r=e.e.b,ei(e.e,b),d=b.a.ec().Jc();d.Ob();)a=c(d.Pb(),9),oi(e.c,a,Pe(r))}}function AZt(e,t,n,i){var r,o,a,d,b,v,x,S,M,L;for(o=new itt(t),S=eVt(e,t,o),L=p.Math.max(ue(he(R(t,(Ge(),Xg)))),1),x=new G(S.a);x.a<x.c.c.length;)v=c(Q(x),49),b=QKe(c(v.a,8),c(v.b,8),L),k=!0,k=k&Pm(n,new $e(b.c,b.d)),k=k&Pm(n,$2(new $e(b.c,b.d),b.b,0)),k=k&Pm(n,$2(new $e(b.c,b.d),0,b.a)),k&Pm(n,$2(new $e(b.c,b.d),b.b,b.a));switch(M=o.d,d=QKe(c(S.b.a,8),c(S.b.b,8),L),M==(Je(),Yt)||M==nn?(i.c[M.g]=p.Math.min(i.c[M.g],d.d),i.b[M.g]=p.Math.max(i.b[M.g],d.d+d.a)):(i.c[M.g]=p.Math.min(i.c[M.g],d.c),i.b[M.g]=p.Math.max(i.b[M.g],d.c+d.b)),r=Qr,a=o.c.i.d,M.g){case 4:r=a.c;break;case 2:r=a.b;break;case 1:r=a.a;break;case 3:r=a.d}return i.a[M.g]=p.Math.max(i.a[M.g],r),o}function NZt(e,t,n){var i,r,o,a,d,b,v,x,S,M,L;if(o=c(R(e,(De(),Oi)),74),!!o){for(i=e.a,r=new Cs(n),ki(r,gqt(e)),sS(e.d.i,e.c.i)?(M=e.c,S=Lo(W(V(Vr,1),Be,8,0,[M.n,M.a])),Hr(S,n)):S=xh(e.c),tr(i,S,i.a,i.a.a),L=xh(e.d),R(e,Wce)!=null&&ki(L,c(R(e,Wce),8)),tr(i,L,i.c.b,i.c),rv(i,r),a=$T(o),lH(a,c(re((!o.b&&(o.b=new Et(vn,o,4,7)),o.b),0),83)),uH(a,c(re((!o.c&&(o.c=new Et(vn,o,5,8)),o.c),0),83)),Tye(i,a),x=new G(e.b);x.a<x.c.c.length;)v=c(Q(x),70),d=c(R(v,Oi),158),ob(d,v.o.a),sb(d,v.o.b),aa(d,v.n.a+r.a,v.n.b+r.b),ii(d,(_5(),uce),Ze(R(v,uce)));b=c(R(e,(Ge(),ho)),79),b?(rv(b,r),ii(o,ho,b)):ii(o,ho,null),t==($1(),Ik)?ii(o,W1,Ik):ii(o,W1,null)}}function _Zt(e,t,n,i){var r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie;for(L=t.c.length,M=0,S=new G(e.b);S.a<S.c.c.length;)if(x=c(Q(S),26),X=x.a,X.c.length!=0){for(H=new G(X),v=0,ie=null,r=c(Q(H),9),o=null;r;){if(o=c(Xe(t,r.p),264),o.c>=0){for(b=null,d=new os(x.a,v+1);d.b<d.d.gc()&&(a=(dn(d.b<d.d.gc()),c(d.d.Xb(d.c=d.b++),9)),b=c(Xe(t,a.p),264),!(b.d==o.d&&b.c<o.c));)b=null;b&&(ie&&(Su(i,r.p,Pe(c(Xe(i,r.p),15).a-1)),c(Xe(n,ie.p),16).Kc(o)),o=Yqt(o,r,L++),It(t.c,o),qe(n,new Fe),ie?(c(Xe(n,ie.p),16).Ec(o),qe(i,Pe(1))):qe(i,Pe(0)))}P=null,H.a<H.c.c.length&&(P=c(Q(H),9),z=c(Xe(t,P.p),264),c(Xe(n,r.p),16).Ec(z),Su(i,P.p,Pe(c(Xe(i,P.p),15).a+1))),o.d=M,o.c=v++,ie=r,r=P}++M}}function DZt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt;d=c(Ut(t.c,e),460),ie=t.a.c,b=t.a.c+t.a.b,bt=d.f,Dt=d.a,a=bt<Dt,z=new $e(ie,bt),se=new $e(b,Dt),r=(ie+b)/2,H=new $e(r,bt),de=new $e(r,Dt),o=TJt(e,bt,Dt),xe=xh(t.B),We=new $e(r,o),pt=xh(t.D),n=sRt(W(V(Vr,1),Be,8,0,[xe,We,pt])),L=!1,X=t.B.i,X&&X.c&&d.d&&(v=a&&X.p<X.c.a.c.length-1||!a&&X.p>0,v?v&&(M=X.p,a?++M:--M,S=c(Xe(X.c.a,M),9),i=HVe(S),L=!(ont(i,xe,n[0])||YFe(i,xe,n[0]))):L=!0),P=!1,Se=t.D.i,Se&&Se.c&&d.e&&(x=a&&Se.p>0||!a&&Se.p<Se.c.a.c.length-1,x?(M=Se.p,a?--M:++M,S=c(Xe(Se.c.a,M),9),i=HVe(S),P=!(ont(i,n[0],pt)||YFe(i,n[0],pt))):P=!0),L&&P&&ei(e.a,We),L||sT(e.a,W(V(Vr,1),Be,8,0,[z,H])),P||sT(e.a,W(V(Vr,1),Be,8,0,[de,se]))}function Jrt(e,t,n,i){var r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt;if(n.c.length!=0){for(P=new Fe,L=new G(n);L.a<L.c.c.length;)M=c(Q(L),19),qe(P,new $e(M.i,M.j));for(i.bh(t,"Before removing overlaps");q2e(e,n);)bQ(e,n,!1);if(i.bh(t,"After removing overlaps"),d=0,b=0,r=null,n.c.length!=0&&(r=(ht(0,n.c.length),c(n.c[0],19)),d=r.i-(ht(0,P.c.length),c(P.c[0],8)).a,b=r.j-(ht(0,P.c.length),c(P.c[0],8)).b),a=p.Math.sqrt(d*d+b*b),S=URt(n),o=1,S.a.gc()!=0){for(x=S.a.ec().Jc();x.Ob();)v=c(x.Pb(),19),z=e.f,H=z.i+z.g/2,X=z.j+z.f/2,ie=v.i+v.g/2,se=v.j+v.f/2,de=ie-H,Se=se-X,xe=p.Math.sqrt(de*de+Se*Se),We=de/xe,pt=Se/xe,Cc(v,v.i+We*a),Nl(v,v.j+pt*a);i.bh(t,"Child movement "+o),++o}e.a&&e.a.Fg(new Fl(S)),Jrt(e,t,new Fl(S),i)}}function LZt(e,t){var n,i,r,o,a,d,b,v,x,S,M;if(!e.f[t.p]){for(e.f[t.p]=!0,b=new wn,r=ve(R(e.c,(Ge(),jk)))===ve((D0(),$v)),i=new Ht(Vt($i(t).a.Jc(),new U));hn(i);)n=c(sn(i),17),xi(n.d.i,(De(),Pi))?(M=0,S=n.d.i,r?(d=c(R(e.c,np),15).a,M=d*c(R(S,zv),15).a+c(R(S,Pi),15).a):M=c(R(n.d.i,Pi),15).a,jc(b,Pe(M))?Sr(c(Ut(b,Pe(M)),47),n):oi(b,Pe(M),new q2(new Ho(W(V(j9,1),s9,17,0,[n]))))):oi(b,Pe(di-(b.f.c+b.i.c)),new q2(new Ho(W(V(j9,1),s9,17,0,[n]))));for(v=new Mge(new an(b)),a=v.a.ec().Jc();a.Ob();)o=c(a.Pb(),15).a,x=c(c(Ut(b,Pe(o)),47).a.ec().Jc().Pb(),17),!vs(x)&&(S=x.d.i,e.f[S.p]&&!$a(e.e,t)&&!$a(e.d,S)?yr(e.b,c(Ut(b,Pe(o)),18)):ei(e.a,S))}}function PZt(e){var t,n,i,r;if(n=e.D!=null?e.D:e.B,t=Zh(n,dl(91)),t!=-1){i=(fs(0,t,n.length),n.substr(0,t)),r=new yg;do r.a+="[";while((t=A6(n,91,++t))!=-1);Ot(i,K5)?r.a+="Z":Ot(i,vE)?r.a+="B":Ot(i,PG)?r.a+="C":Ot(i,yE)?r.a+="D":Ot(i,xE)?r.a+="F":Ot(i,kE)?r.a+="I":Ot(i,OE)?r.a+="J":Ot(i,SE)?r.a+="S":(r.a+="L",r.a+=""+i,r.a+=";");try{return null}catch(o){if(o=vr(o),!oe(o,63))throw J(o)}}else if(Zh(n,dl(46))==-1){if(Ot(n,K5))return kl;if(Ot(n,vE))return Rl;if(Ot(n,PG))return Na;if(Ot(n,yE))return ns;if(Ot(n,xE))return py;if(Ot(n,kE))return Fn;if(Ot(n,OE))return qw;if(Ot(n,SE))return L3}return null}function IZt(e){var t,n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe;for(S=new fpe(new ade(e));S.c!=S.d.a.d;)for(x=CJe(S),d=c(x.d,57),t=c(x.e,57),a=d.Ah(),z=0,de=(a.i==null&&ud(a),a.i).length;z<de;++z)if(v=(o=(a.i==null&&ud(a),a.i),z>=0&&z<o.length?o[z]:null),v.pk()&&!v.qk()){if(oe(v,104))b=c(v,20),(b.Bb&nc)==0&&(xe=Hs(b),!(xe&&(xe.Bb&nc)!=0))&&pKt(e,b,d,t);else if(qs(),c(v,69).vk()&&(n=(Se=v,c(Se?c(t,52).di(Se):null,164)),n))for(L=c(d.Jh(v),164),i=n.gc(),H=0,P=L.gc();H<P;++H)if(M=L.Rl(H),oe(M,104)){if(se=L.Sl(H),r=Oh(e,se),r==null&&se!=null){if(ie=c(M,20),!e.b||(ie.Bb&nc)!=0||Hs(ie))continue;r=se}if(!n.Ml(M,r)){for(X=0;X<i;++X)if(n.Rl(X)==M&&ve(n.Sl(X))===ve(r)){n.Ri(n.gc()-1,X),--i;break}}}else n.Ml(L.Rl(H),L.Sl(H))}}function RZt(e,t,n){var i;if(n.Tg("StretchWidth layering",1),t.a.c.length==0){n.Ug();return}for(e.c=t,e.t=0,e.u=0,e.i=nr,e.g=Qr,e.d=ue(he(R(t,(Ge(),Mf)))),uzt(e),rUt(e),iUt(e),uqt(e),gBt(e),e.i=p.Math.max(1,e.i),e.g=p.Math.max(1,e.g),e.d=e.d/e.i,e.f=e.g/e.i,e.s=Tzt(e),i=new hc(e.c),qe(e.c.b,i),e.r=tb(e.p),e.n=yq(e.k,e.k.length);e.r.c.length!=0;)e.o=IRt(e),!e.o||VVe(e)&&e.b.a.gc()!=0?(Rqt(e,i),i=new hc(e.c),qe(e.c.b,i),Os(e.a,e.b),e.b.a.$b(),e.t=e.u,e.u=0):VVe(e)?(e.c.b.c.length=0,i=new hc(e.c),qe(e.c.b,i),e.t=0,e.u=0,e.b.a.$b(),e.a.a.$b(),++e.f,e.r=tb(e.p),e.n=yq(e.k,e.k.length)):(zr(e.o,i),fl(e.r,e.o),Sr(e.b,e.o),e.t=e.t-e.k[e.o.p]*e.d+e.j[e.o.p],e.u+=e.e[e.o.p]*e.d);t.a.c.length=0,NT(t.b),n.Ug()}function Aie(e,t,n,i){var r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se;return b=e,x=Hr(new $e(t.a,t.b),e),v=n,S=Hr(new $e(i.a,i.b),n),M=b.a,H=b.b,P=v.a,ie=v.b,L=x.a,X=x.b,z=S.a,se=S.b,r=z*X-L*se,mh(),vf(pd),p.Math.abs(0-r)<=pd||r==0||isNaN(0)&&isNaN(r)?!1:(a=1/r*((M-P)*X-(H-ie)*L),d=1/r*-(-(M-P)*se+(H-ie)*z),o=(vf(pd),(p.Math.abs(0-a)<=pd||a==0||isNaN(0)&&isNaN(a)?0:0<a?-1:0>a?1:Gp(isNaN(0),isNaN(a)))<0&&(vf(pd),(p.Math.abs(a-1)<=pd||a==1||isNaN(a)&&isNaN(1)?0:a<1?-1:a>1?1:Gp(isNaN(a),isNaN(1)))<0)&&(vf(pd),(p.Math.abs(0-d)<=pd||d==0||isNaN(0)&&isNaN(d)?0:0<d?-1:0>d?1:Gp(isNaN(0),isNaN(d)))<0)&&(vf(pd),(p.Math.abs(d-1)<=pd||d==1||isNaN(d)&&isNaN(1)?0:d<1?-1:d>1?1:Gp(isNaN(d),isNaN(1)))<0)),o)}function $Zt(e){var t,n,i,r,o,a,d,b,v,x,S;for(e.j=ye(Fn,ci,30,e.g,15,1),e.o=new Fe,lr(So(new jt(null,new Tt(e.e.b,16)),new PR),new j_e(e)),e.a=ye(kl,eh,30,e.b,16,1),OD(new jt(null,new Tt(e.e.b,16)),new E_e(e)),i=(S=new Fe,lr(pi(So(new jt(null,new Tt(e.e.b,16)),new w4),new T_e(e)),new hRe(e,S)),S),b=new G(i);b.a<b.c.c.length;)if(d=c(Q(b),504),!(d.c.length<=1)){if(d.c.length==2){OGt(d),Oie((ht(0,d.c.length),c(d.c[0],17)).d.i)||qe(e.o,d);continue}if(!(Gqt(d)||_Qt(d,new IR)))for(v=new G(d),r=null;v.a<v.c.c.length;)t=c(Q(v),17),n=e.c[t.p],!r||v.a>=v.c.c.length?x=nbe((Jt(),or),jr):x=nbe((Jt(),jr),jr),x*=2,o=n.a.g,n.a.g=p.Math.max(o,o+(x-o)),a=n.b.g,n.b.g=p.Math.max(a,a+(x-a)),r=t}}function RQ(e,t){var n;if(e.e)throw J(new oo((j1(qoe),mre+qoe.k+wre)));if(!T8t(e.a,t))throw J(new Mo(got+t+pot));if(t==e.d)return e;switch(n=e.d,e.d=t,n.g){case 0:switch(t.g){case 2:iw(e);break;case 1:P0(e),iw(e);break;case 4:Px(e),iw(e);break;case 3:Px(e),P0(e),iw(e)}break;case 2:switch(t.g){case 1:P0(e),oie(e);break;case 4:Px(e),iw(e);break;case 3:Px(e),P0(e),iw(e)}break;case 1:switch(t.g){case 2:P0(e),oie(e);break;case 4:P0(e),Px(e),iw(e);break;case 3:P0(e),Px(e),P0(e),iw(e)}break;case 4:switch(t.g){case 2:Px(e),iw(e);break;case 1:Px(e),P0(e),iw(e);break;case 3:P0(e),oie(e)}break;case 3:switch(t.g){case 2:P0(e),Px(e),iw(e);break;case 1:P0(e),Px(e),P0(e),iw(e);break;case 4:P0(e),oie(e)}}return e}function Hx(e,t){var n;if(e.d)throw J(new oo((j1(nce),mre+nce.k+wre)));if(!E8t(e.a,t))throw J(new Mo(got+t+pot));if(t==e.c)return e;switch(n=e.c,e.c=t,n.g){case 0:switch(t.g){case 2:fb(e);break;case 1:L0(e),fb(e);break;case 4:Ix(e),fb(e);break;case 3:Ix(e),L0(e),fb(e)}break;case 2:switch(t.g){case 1:L0(e),cie(e);break;case 4:Ix(e),fb(e);break;case 3:Ix(e),L0(e),fb(e)}break;case 1:switch(t.g){case 2:L0(e),cie(e);break;case 4:L0(e),Ix(e),fb(e);break;case 3:L0(e),Ix(e),L0(e),fb(e)}break;case 4:switch(t.g){case 2:Ix(e),fb(e);break;case 1:Ix(e),L0(e),fb(e);break;case 3:L0(e),cie(e)}break;case 3:switch(t.g){case 2:L0(e),Ix(e),fb(e);break;case 1:L0(e),Ix(e),L0(e),fb(e);break;case 4:L0(e),cie(e)}}return e}function BZt(e){var t,n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se;for(S=e.b,x=new os(S,0),z2(x,new hc(e)),ie=!1,a=1;x.b<x.d.gc();){for(v=(dn(x.b<x.d.gc()),c(x.d.Xb(x.c=x.b++),26)),z=(ht(a,S.c.length),c(S.c[a],26)),H=tb(v.a),X=H.c.length,P=new G(H);P.a<P.c.c.length;)M=c(Q(P),9),zr(M,z);if(ie){for(L=Eu(H).Jc();L.Ob();)for(M=c(L.Pb(),9),o=new G(tb(pr(M)));o.a<o.c.c.length;)r=c(Q(o),17),zg(r,!0),Ee(e,(De(),wk),(Bt(),!0)),i=jrt(e,r,X),n=c(R(M,Cw),318),se=c(Xe(i,i.c.length-1),17),n.k=se.c.i,n.n=se,n.b=r.d.i,n.c=r;ie=!1}else H.c.length!=0&&(t=(ht(0,H.c.length),c(H.c[0],9)),t.k==(Jt(),Ih)&&(ie=!0,a=-1));++a}for(d=new os(e.b,0);d.b<d.d.gc();)b=(dn(d.b<d.d.gc()),c(d.d.Xb(d.c=d.b++),26)),b.a.c.length==0&&iu(d)}function $Q(e,t){var n,i,r,o,a,d,b,v;if(oe(e.Bh(),176)?($Q(c(e.Bh(),176),t),t.a+=" > "):t.a+="Root ",n=e.Ah().zb,Ot(n.substr(0,3),"Elk")?Zn(t,(en(3,n.length+1),n.substr(3))):t.a+=""+n,r=e.ih(),r){Zn((t.a+=" ",t),r);return}if(oe(e,363)&&(v=c(e,158).a,v)){Zn((t.a+=" ",t),v);return}for(a=new cn(e.jh());a.e!=a.i.gc();)if(o=c(un(a),158),v=o.a,v){Zn((t.a+=" ",t),v);return}if(oe(e,273)&&(i=c(e,74),!i.b&&(i.b=new Et(vn,i,4,7)),i.b.i!=0&&(!i.c&&(i.c=new Et(vn,i,5,8)),i.c.i!=0))){for(t.a+=" (",d=new f5((!i.b&&(i.b=new Et(vn,i,4,7)),i.b));d.e!=d.i.gc();)d.e>0&&(t.a+=Jc),$Q(c(un(d),176),t);for(t.a+=jre,b=new f5((!i.c&&(i.c=new Et(vn,i,5,8)),i.c));b.e!=b.i.gc();)b.e>0&&(t.a+=Jc),$Q(c(un(b),176),t);t.a+=")"}}function zZt(e,t,n){var i,r,o,a,d,b,v,x;for(b=new cn((!e.a&&(e.a=new Me(Mn,e,10,11)),e.a));b.e!=b.i.gc();)for(d=c(un(b),19),r=new Ht(Vt(z1(d).a.Jc(),new U));hn(r);){if(i=c(sn(r),74),!i.b&&(i.b=new Et(vn,i,4,7)),!(i.b.i<=1&&(!i.c&&(i.c=new Et(vn,i,5,8)),i.c.i<=1)))throw J(new Y4("Graph must not contain hyperedges."));if(!PT(i)&&d!=to(c(re((!i.c&&(i.c=new Et(vn,i,5,8)),i.c),0),83)))for(v=new lze,ec(v,i),Ee(v,(N0(),gk),i),lz(v,c(Ao(co(n.f,d)),156)),CK(v,c(Ut(n,to(c(re((!i.c&&(i.c=new Et(vn,i,5,8)),i.c),0),83))),156)),qe(t.c,v),a=new cn((!i.n&&(i.n=new Me(Bo,i,1,7)),i.n));a.e!=a.i.gc();)o=c(un(a),158),x=new vGe(v,o.a),ec(x,o),Ee(x,gk,o),x.e.a=p.Math.max(o.g,1),x.e.b=p.Math.max(o.f,1),Aye(x),qe(t.d,x)}}function FZt(e,t,n){var i,r,o,a,d,b,v,x,S,M;switch(n.Tg("Node promotion heuristic",1),e.i=t,e.r=c(R(t,(Ge(),cP)),246),e.r!=(H0(),H9)&&e.r!=sC?den(e):IXt(e),x=c(R(e.i,CSe),15).a,o=new uW,e.r.g){case 2:case 1:BS(e,o);break;case 3:for(e.r=pJ,BS(e,o),b=0,d=new G(e.b);d.a<d.c.c.length;)a=c(Q(d),15),b=p.Math.max(b,a.a);b>e.k&&(e.r=fP,BS(e,o));break;case 4:for(e.r=pJ,BS(e,o),v=0,r=new G(e.c);r.a<r.c.c.length;)i=he(Q(r)),v=p.Math.max(v,(zt(i),i));v>e.n&&(e.r=hP,BS(e,o));break;case 6:M=xs(p.Math.ceil(e.g.length*x/100)),BS(e,new SNe(M));break;case 5:S=xs(p.Math.ceil(e.e*x/100)),BS(e,new jNe(S));break;case 8:Cst(e,!0);break;case 9:Cst(e,!1);break;default:BS(e,o)}e.r!=H9&&e.r!=sC?nXt(e,t):xVt(e,t),n.Ug()}function qZt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se;for(S=new Gye(e),mNt(S,!(t==(Nr(),Ca)||t==Fh)),x=S.a,M=new X4,r=(Yf(),W(V(Nv,1),_e,240,0,[Vo,Vc,Wo])),a=0,b=r.length;a<b;++a)n=r[a],v=sZ(x,Vo,n),v&&(M.d=p.Math.max(M.d,v.ff()));for(i=W(V(Nv,1),_e,240,0,[Vo,Vc,Wo]),o=0,d=i.length;o<d;++o)n=i[o],v=sZ(x,Wo,n),v&&(M.a=p.Math.max(M.a,v.ff()));for(z=W(V(Nv,1),_e,240,0,[Vo,Vc,Wo]),X=0,se=z.length;X<se;++X)L=z[X],v=sZ(x,L,Vo),v&&(M.b=p.Math.max(M.b,v.gf()));for(P=W(V(Nv,1),_e,240,0,[Vo,Vc,Wo]),H=0,ie=P.length;H<ie;++H)L=P[H],v=sZ(x,L,Wo),v&&(M.c=p.Math.max(M.c,v.gf()));return M.d>0&&(M.d+=x.n.d,M.d+=x.d),M.a>0&&(M.a+=x.n.a,M.a+=x.d),M.b>0&&(M.b+=x.n.b,M.b+=x.d),M.c>0&&(M.c+=x.n.c,M.c+=x.d),M}function Xrt(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P;for(M=n.d,S=n.c,o=new $e(n.f.a+n.d.b+n.d.c,n.f.b+n.d.d+n.d.a),a=o.b,v=new G(e.a);v.a<v.c.c.length;)if(d=c(Q(v),9),d.k==(Jt(),Cr)){switch(i=c(R(d,(De(),Ko)),64),r=c(R(d,m6e),8),x=d.n,i.g){case 2:x.a=n.f.a+M.c-S.a;break;case 4:x.a=-S.a-M.b}switch(P=0,i.g){case 2:case 4:t==(Zr(),r1)?(L=ue(he(R(d,Aw))),x.b=o.b*L-c(R(d,(Ge(),Lw)),8).b,P=x.b+r.b,xH(d,!1,!0)):t==xc&&(x.b=ue(he(R(d,Aw)))-c(R(d,(Ge(),Lw)),8).b,P=x.b+r.b,xH(d,!1,!0))}a=p.Math.max(a,P)}for(n.f.b+=a-o.b,b=new G(e.a);b.a<b.c.c.length;)if(d=c(Q(b),9),d.k==(Jt(),Cr))switch(i=c(R(d,(De(),Ko)),64),x=d.n,i.g){case 1:x.b=-S.b-M.d;break;case 3:x.b=n.f.b+M.a-S.b}}function Vrt(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z;if(v=cKt(c(ke(t,(Qd(),Zv)),107),c(ke(n,zb),107)),Cc(n,t.i+v),ue(he(ke(e,kd)))<ue(he(ke(n,kd)))){for(M=c(ke(e,zb),107),x=M.c+e.i;M.b;)M=M.b,x+=M.c;for(o=new xu(c(ke(n,zb),107).c,-100,c(ke(n,zb),107).b),z=o.c+n.i;o.b.a<=M.a;)o=o.b,z+=o.c;d=o.b.c,b=o.b.a-o.a,a=(M.a-o.a)*d/b,P=-x+z+a,L=new xu(o.b.c-a,o.b.a,o.b.b),q4(M,new xu(P,M.a,L)),ii(e,kd,he(ke(n,kd)))}if(ue(he(ke(n,kd)))<ue(he(ke(t,kd)))){for(S=c(ke(n,Zv),107),z=S.c+n.i;S.b;)S=S.b,z+=S.c;for(r=new xu(c(ke(t,Zv),107).c,-100,c(ke(t,Zv),107).b),i=r.c+t.i;r.b.a<=S.a;)r=r.b,i+=r.c;d=r.b.c,b=r.b.a-r.a,a=(S.a-r.a)*d/b,P=i-z+a,L=new xu(r.b.c-a,r.b.a,r.b.b),q4(S,new xu(P,S.a,L)),ii(n,kd,he(ke(t,kd)))}}function HZt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X;if(x=c(c(Si(e.r,t),24),85),x.gc()<=2||t==(Je(),nn)||t==(Je(),Yt)){pst(e,t);return}for(z=e.u.Gc((Ql(),Rk)),n=t==(Je(),Kt)?(Ym(),HL):(Ym(),qL),X=t==Kt?(hl(),Ef):(hl(),rh),i=t1e(p0e(n),e.s),H=t==Kt?nr:Qr,v=x.Jc();v.Ob();)d=c(v.Pb(),116),!(!d.c||d.c.d.c.length<=0)&&(P=d.b.Kf(),L=d.e,S=d.c,M=S.i,M.b=(o=S.n,S.e.a+o.b+o.c),M.a=(a=S.n,S.e.b+a.d+a.a),z?(M.c=L.a-(r=S.n,S.e.a+r.b+r.c)-e.s,z=!1):M.c=L.a+P.a+e.s,$_(X,wxe),S.f=X,Kf(S,(Hl(),Tf)),qe(i.d,new PZ(M,awe(i,M))),H=t==Kt?p.Math.min(H,L.b):p.Math.max(H,L.b+d.b.Kf().b));for(H+=t==Kt?-e.t:e.t,Ewe((i.e=H,i)),b=x.Jc();b.Ob();)d=c(b.Pb(),116),!(!d.c||d.c.d.c.length<=0)&&(M=d.c.i,M.c-=d.e.a,M.d-=d.e.b)}function Wrt(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se;for(r=new Fe,z=new G(t.a);z.a<z.c.c.length;)if(P=c(Q(z),9),L=P.e,L&&(i=Wrt(e,L,P),yr(r,i),iZt(e,L,P),c(R(L,(De(),Lc)),24).Gc((Gs(),Ea))))for(ie=c(R(P,(Ge(),cr)),103),M=c(R(P,Gv),185).Gc((Ql(),eg)),X=new G(P.j);X.a<X.c.c.length;)for(H=c(Q(X),12),o=c(Ut(e.b,H),9),o||(o=tL(H,ie,H.j,-(H.e.c.length-H.g.c.length),null,new as,H.o,c(R(L,Xu),87),L),Ee(o,Oi,H),oi(e.b,H,o),qe(L.a,o)),a=c(Xe(o.j,0),12),x=new G(H.f);x.a<x.c.c.length;)v=c(Q(x),70),d=new pPe,d.o.a=v.o.a,d.o.b=v.o.b,qe(a.f,d),M||(se=H.j,S=0,$7(c(R(P,Gv),24))&&(S=dve(v.n,v.o,H.o,0,se)),ie==(Zr(),Hh)||(Je(),ol).Gc(se)?d.o.a=S:d.o.b=S);return b=new Fe,rZt(e,t,n,r,b),n&&yYt(e,t,n,b),b}function qye(e,t,n){var i,r,o,a,d,b,v,x,S;if(!e.c[t.c.p][t.p].e){for(e.c[t.c.p][t.p].e=!0,e.c[t.c.p][t.p].b=0,e.c[t.c.p][t.p].d=0,e.c[t.c.p][t.p].a=null,x=new G(t.j);x.a<x.c.c.length;)for(v=c(Q(x),12),S=n?new p6(v):new Q4(v),b=S.Jc();b.Ob();)d=c(b.Pb(),12),a=d.i,a.c==t.c?a!=t&&(qye(e,a,n),e.c[t.c.p][t.p].b+=e.c[a.c.p][a.p].b,e.c[t.c.p][t.p].d+=e.c[a.c.p][a.p].d):(e.c[t.c.p][t.p].d+=e.g[d.p],++e.c[t.c.p][t.p].b);if(o=c(R(t,(De(),d6e)),16),o)for(r=o.Jc();r.Ob();)i=c(r.Pb(),9),t.c==i.c&&(qye(e,i,n),e.c[t.c.p][t.p].b+=e.c[i.c.p][i.p].b,e.c[t.c.p][t.p].d+=e.c[i.c.p][i.p].d);e.c[t.c.p][t.p].b>0&&(e.c[t.c.p][t.p].d+=lu(e.i,24)*gL*.07000000029802322-.03500000014901161,e.c[t.c.p][t.p].a=e.c[t.c.p][t.p].d/e.c[t.c.p][t.p].b)}}function QZt(e){var t,n,i,r,o,a,d,b,v,x,S,M,L,P,z,H;for(P=new G(e);P.a<P.c.c.length;){for(L=c(Q(P),9),jg(L.n),jg(L.o),kbe(L.f),sit(L),sVt(L),H=new G(L.j);H.a<H.c.c.length;){for(z=c(Q(H),12),jg(z.n),jg(z.a),jg(z.o),$r(z,xYe(z.j)),o=c(R(z,(Ge(),Vg)),15),o&&Ee(z,Vg,Pe(-o.a)),r=new G(z.g);r.a<r.c.c.length;){for(i=c(Q(r),17),n=_n(i.a,0);n.b!=n.d.c;)t=c(An(n),8),jg(t);if(b=c(R(i,ho),79),b)for(d=_n(b,0);d.b!=d.d.c;)a=c(An(d),8),jg(a);for(S=new G(i.b);S.a<S.c.c.length;)v=c(Q(S),70),jg(v.n),jg(v.o)}for(M=new G(z.f);M.a<M.c.c.length;)v=c(Q(M),70),jg(v.n),jg(v.o)}for(L.k==(Jt(),Cr)&&(Ee(L,(De(),Ko),xYe(c(R(L,Ko),64))),dXt(L)),x=new G(L.b);x.a<x.c.c.length;)v=c(Q(x),70),sit(v),jg(v.o),jg(v.n)}}function GZt(e){B2();var t,n,i,r,o,a,d;for(i=e.f.n,a=cpe(e.r).a.nc();a.Ob();){if(o=c(a.Pb(),116),r=0,o.b.nf((Dn(),fu))&&(r=ue(he(o.b.mf(fu))),r<0))switch(o.b.$f().g){case 1:i.d=p.Math.max(i.d,-r);break;case 3:i.a=p.Math.max(i.a,-r);break;case 2:i.c=p.Math.max(i.c,-r);break;case 4:i.b=p.Math.max(i.b,-r)}if($7(e.u))switch(t=bIt(o.b,r),d=!c(e.e.mf(lp),185).Gc((uu(),FP)),n=!1,o.b.$f().g){case 1:n=t>i.d,i.d=p.Math.max(i.d,t),d&&n&&(i.d=p.Math.max(i.d,i.a),i.a=i.d+r);break;case 3:n=t>i.a,i.a=p.Math.max(i.a,t),d&&n&&(i.a=p.Math.max(i.a,i.d),i.d=i.a+r);break;case 2:n=t>i.c,i.c=p.Math.max(i.c,t),d&&n&&(i.c=p.Math.max(i.b,i.c),i.b=i.c+r);break;case 4:n=t>i.b,i.b=p.Math.max(i.b,t),d&&n&&(i.b=p.Math.max(i.b,i.c),i.c=i.b+r)}}}function Krt(e,t){var n,i,r,o,a,d,b,v,x;return v="",t.length==0?e.le(oxe,qie,-1,-1):(x=pv(t),Ot(x.substr(0,3),"at ")&&(x=(en(3,x.length+1),x.substr(3))),x=x.replace(/\[.*?\]/g,""),a=x.indexOf("("),a==-1?(a=x.indexOf("@"),a==-1?(v=x,x=""):(v=pv((en(a+1,x.length+1),x.substr(a+1))),x=pv((fs(0,a,x.length),x.substr(0,a))))):(n=x.indexOf(")",a),v=(fs(a+1,n,x.length),x.substr(a+1,n-(a+1))),x=pv((fs(0,a,x.length),x.substr(0,a)))),a=Zh(x,dl(46)),a!=-1&&(x=(en(a+1,x.length+1),x.substr(a+1))),(x.length==0||Ot(x,"Anonymous function"))&&(x=qie),d=SF(v,dl(58)),r=u0e(v,dl(58),d-1),b=-1,i=-1,o=oxe,d!=-1&&r!=-1&&(o=(fs(0,r,v.length),v.substr(0,r)),b=CBe((fs(r+1,d,v.length),v.substr(r+1,d-(r+1)))),i=CBe((en(d+1,v.length+1),v.substr(d+1)))),e.le(o,x,b,i))}function UZt(e){var t,n,i,r,o,a,d,b,v,x,S;for(v=new G(e);v.a<v.c.c.length;){switch(b=c(Q(v),9),a=c(R(b,(Ge(),Ro)),166),o=null,a.g){case 1:case 2:o=(ab(),l3);break;case 3:case 4:o=(ab(),_9)}if(o)Ee(b,(De(),QU),(ab(),l3)),o==_9?SQ(b,a,(Qs(),Jl)):o==l3&&SQ(b,a,(Qs(),Wc));else if(dx(c(R(b,cr),103))&&b.j.c.length!=0){for(t=!0,S=new G(b.j);S.a<S.c.c.length;){if(x=c(Q(S),12),!(x.j==(Je(),nn)&&x.e.c.length-x.g.c.length>0||x.j==Yt&&x.e.c.length-x.g.c.length<0)){t=!1;break}for(r=new G(x.g);r.a<r.c.c.length;)if(n=c(Q(r),17),d=c(R(n.d.i,Ro),166),d==(Tu(),UE)||d==Db){t=!1;break}for(i=new G(x.e);i.a<i.c.c.length;)if(n=c(Q(i),17),d=c(R(n.c.i,Ro),166),d==(Tu(),GE)||d==V1){t=!1;break}}t&&SQ(b,a,(Qs(),oC))}}}function JZt(e,t,n,i,r){var o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe;for(xe=0,L=0,S=new G(t.e);S.a<S.c.c.length;){for(x=c(Q(S),9),M=0,d=0,b=n?c(R(x,vJ),15).a:ls,X=i?c(R(x,yJ),15).a:ls,v=p.Math.max(b,X),se=new G(x.j);se.a<se.c.c.length;){if(ie=c(Q(se),12),de=x.n.b+ie.n.b+ie.a.b,i)for(a=new G(ie.g);a.a<a.c.c.length;)o=c(Q(a),17),z=o.d,P=z.i,t!=e.a[P.p]&&(H=p.Math.max(c(R(P,vJ),15).a,c(R(P,yJ),15).a),Se=c(R(o,(Ge(),Ek)),15).a,Se>=v&&Se>=H&&(M+=P.n.b+z.n.b+z.a.b-de,++d));if(n)for(a=new G(ie.e);a.a<a.c.c.length;)o=c(Q(a),17),z=o.c,P=z.i,t!=e.a[P.p]&&(H=p.Math.max(c(R(P,vJ),15).a,c(R(P,yJ),15).a),Se=c(R(o,(Ge(),Ek)),15).a,Se>=v&&Se>=H&&(M+=P.n.b+z.n.b+z.a.b-de,++d))}d>0&&(xe+=M/d,++L)}L>0?(t.a=r*xe/L,t.g=L):(t.a=0,t.g=0)}function Hye(e,t,n,i){var r,o,a,d,b;return d=new Gye(t),BJt(d,i),r=!0,e&&e.nf((Dn(),Fb))&&(o=c(e.mf((Dn(),Fb)),87),r=o==(Nr(),qh)||o==go||o==yo),Gnt(d,!1),Qc(d.e.Pf(),new g0e(d,!1,r)),dee(d,d.f,(Yf(),Vo),(Je(),Kt)),dee(d,d.f,Wo,bn),dee(d,d.g,Vo,Yt),dee(d,d.g,Wo,nn),sYe(d,Kt),sYe(d,bn),Gqe(d,nn),Gqe(d,Yt),B2(),a=d.A.Gc((Cu(),cy))&&d.B.Gc((uu(),qP))?mKe(d):null,a&&R9t(d.a,a),GZt(d),iFt(d),rFt(d),xZt(d),NWt(d),AFt(d),ine(d,Kt),ine(d,bn),vVt(d),uYt(d),n&&(H$t(d),NFt(d),ine(d,nn),ine(d,Yt),b=d.B.Gc((uu(),zC)),Aet(d,b,Kt),Aet(d,b,bn),Net(d,b,nn),Net(d,b,Yt),lr(new jt(null,new Tt(new x1(d.i),0)),new Yw),lr(pi(new jt(null,cpe(d.r).a.oc()),new Zw),new e2),Hqt(d),d.e.Nf(d.o),lr(new jt(null,cpe(d.r).a.oc()),new f0)),d.o}function XZt(e){var t,n,i,r,o,a,d,b,v,x,S,M,L,P,z;for(v=nr,i=new G(e.a.b);i.a<i.c.c.length;)t=c(Q(i),84),v=p.Math.min(v,t.d.f.g.c+t.e.a);for(L=new Ai,a=new G(e.a.a);a.a<a.c.c.length;)o=c(Q(a),197),o.i=v,o.e==0&&tr(L,o,L.c.b,L.c);for(;L.b!=0;){for(o=c(L.b==0?null:(dn(L.b!=0),ba(L,L.a.a)),197),r=o.f.g.c,M=o.a.a.ec().Jc();M.Ob();)x=c(M.Pb(),84),z=o.i+x.e.a,x.d.g||x.g.c<z?x.o=z:x.o=x.g.c;for(r-=o.f.o,o.b+=r,e.c==(Nr(),yo)||e.c==Fh?o.c+=r:o.c-=r,S=o.a.a.ec().Jc();S.Ob();)for(x=c(S.Pb(),84),b=x.f.Jc();b.Ob();)d=c(b.Pb(),84),O1(e.c)?P=e.f.wf(x,d):P=e.f.xf(x,d),d.d.i=p.Math.max(d.d.i,x.o+x.g.b+P-d.e.a),d.k||(d.d.i=p.Math.max(d.d.i,d.g.c-d.e.a)),--d.d.e,d.d.e==0&&ei(L,d.d)}for(n=new G(e.a.b);n.a<n.c.c.length;)t=c(Q(n),84),t.g.c=t.o}function Yrt(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe;for(n.Tg(Mct,1),M=(Li(),Hle),e.a==(hT(),TJ)&&(M=q9e),x=0,Ct(),t.gd(new IK(M)),o=t.gc(),d=t.dd(t.gc()),v=!0;v&&d.Sb();)ie=c(d.Ub(),41),c(R(ie,M),15).a==0?--o:v=!1;if(xe=t.hd(0,o),a=new wZ(xe),xe=t.hd(o,t.gc()),b=new wZ(xe),a.b==0)for(z=_n(b,0);z.b!=z.d.c;)P=c(An(z),41),Ee(P,bC,Pe(x++));else for(S=a.b,Se=_n(a,0);Se.b!=Se.d.c;){for(de=c(An(Se),41),Ee(de,bC,Pe(x++)),i=xte(de),Yrt(e,i,n.dh(1/S|0)),cb(i,vpe(new IK(bC))),L=new Ai,se=_n(i,0);se.b!=se.d.c;)for(ie=c(An(se),41),X=_n(de.d,0);X.b!=X.d.c;)H=c(An(X),65),H.c==ie&&tr(L,H,L.c.b,L.c);for(Ou(de.d),Os(de.d,L),d=_n(b,b.b),r=de.d.b,v=!0;0<r&&v&&d.Sb();)ie=c(d.Ub(),41),c(R(ie,M),15).a==0?(Ee(ie,bC,Pe(x++)),--r,d.Qb()):v=!1}n.Ug()}function Zrt(e,t,n){var i,r,o,a,d,b,v,x,S,M;for(x=new Eh(n),ec(x,t),Ee(x,(De(),Oi),t),x.o.a=t.g,x.o.b=t.f,x.n.a=t.i,x.n.b=t.j,qe(n.a,x),oi(e.a,t,x),((!t.a&&(t.a=new Me(Mn,t,10,11)),t.a).i!=0||et(Ze(ke(t,(Ge(),qv)))))&&Ee(x,g6e,(Bt(),!0)),v=c(R(n,Lc),24),S=c(R(x,(Ge(),cr)),103),S==(Zr(),fp)?Ee(x,cr,Hh):S!=Hh&&v.Ec((Gs(),P9)),M=0,i=c(R(n,Xu),87),b=new cn((!t.c&&(t.c=new Me(hu,t,9,9)),t.c));b.e!=b.i.gc();)d=c(un(b),127),r=Xi(t),DQ(r)&&!et(Ze(ke(t,KU)))&&ii(d,Pi,Pe(M++)),et(Ze(ke(d,Ib)))||een(e,d,x,v,i,S);for(a=new cn((!t.n&&(t.n=new Me(Bo,t,1,7)),t.n));a.e!=a.i.gc();)o=c(un(a),158),!et(Ze(ke(o,Ib)))&&o.a&&qe(x.b,Rte(o));return et(Ze(R(x,JE)))&&v.Ec((Gs(),BU)),et(Ze(R(x,tJ)))&&(v.Ec((Gs(),zU)),v.Ec(zE),Ee(x,cr,Hh)),x}function VZt(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se;for(t.Tg("Inverted port preprocessing",1),x=e.b,v=new os(x,0),n=null,se=new Fe;v.b<v.d.gc();){for(ie=n,n=(dn(v.b<v.d.gc()),c(v.d.Xb(v.c=v.b++),26)),L=new G(se);L.a<L.c.c.length;)S=c(Q(L),9),zr(S,ie);for(se.c.length=0,P=new G(n.a);P.a<P.c.c.length;)if(S=c(Q(P),9),S.k==(Jt(),or)&&dx(c(R(S,(Ge(),cr)),103))){for(X=nye(S,(Qs(),Jl),(Je(),nn)).Jc();X.Ob();)for(z=c(X.Pb(),12),b=z.e,d=c(jh(b,ye(j9,s9,17,b.c.length,0,1)),324),r=d,o=0,a=r.length;o<a;++o)i=r[o],wKt(e,z,i,se);for(H=nye(S,Wc,Yt).Jc();H.Ob();)for(z=c(H.Pb(),12),b=z.g,d=c(jh(b,ye(j9,s9,17,b.c.length,0,1)),324),r=d,o=0,a=r.length;o<a;++o)i=r[o],mKt(e,z,i,se)}}for(M=new G(se);M.a<M.c.c.length;)S=c(Q(M),9),zr(S,n);t.Ug()}function WZt(e){var t,n,i,r,o,a,d,b,v,x,S,M,L;for(S=ue(he(ke(e,(F0(),lue)))),et(Ze(ke(e,O8e)))&&(x=c(ke(e,(vx(),k3)),19),o=c(re(H6(c(re((!x.e&&(x.e=new Et(Ii,x,7,4)),x.e),(!x.e&&(x.e=new Et(Ii,x,7,4)),x.e).i-1),74)),0),19),i=c(re(H6(c(re((!x.e&&(x.e=new Et(Ii,x,7,4)),x.e),0),74)),0),19),a=new $e(o.i+o.g/2,o.j+o.f/2),r=new $e(i.i+i.g/2,i.j+i.f/2),n=S,n<=0&&(n+=Sb),M=p.Math.acos((a.a*r.a+a.b*r.b)/(p.Math.sqrt(a.a*a.a+a.b*a.b)*p.Math.sqrt(r.a*r.a+r.b*r.b))),M<=0&&(M+=Sb),t=p.Math.atan2(a.b,a.a),t<=0&&(t+=Sb),S=i4e-(t-n+M/2)),b=new cn((!e.a&&(e.a=new Me(Mn,e,10,11)),e.a));b.e!=b.i.gc();)d=c(un(b),19),v=new $e(d.i+d.g/2,d.j+d.f/2),L=v.a*p.Math.cos(S)-v.b*p.Math.sin(S),v.b=v.a*p.Math.sin(S)+v.b*p.Math.cos(S),v.a=L,aa(d,v.a-d.g/2,v.b-d.f/2)}function KZt(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X;if(z=e.n,H=e.o,M=e.d,S=ue(he(av(e,(Ge(),dle)))),t){for(x=S*(t.gc()-1),L=0,b=t.Jc();b.Ob();)a=c(b.Pb(),9),x+=a.o.a,L=p.Math.max(L,a.o.b);for(X=z.a-(x-H.a)/2,o=z.b-M.d+L,i=H.a/(t.gc()+1),r=i,d=t.Jc();d.Ob();)a=c(d.Pb(),9),a.n.a=X,a.n.b=o-a.o.b,X+=a.o.a+S,v=tnt(a),v.n.a=a.o.a/2-v.a.a,v.n.b=a.o.b,P=c(R(a,(De(),qU)),12),P.e.c.length+P.g.c.length==1&&(P.n.a=r-P.a.a,P.n.b=0,_o(P,e)),r+=i}if(n){for(x=S*(n.gc()-1),L=0,b=n.Jc();b.Ob();)a=c(b.Pb(),9),x+=a.o.a,L=p.Math.max(L,a.o.b);for(X=z.a-(x-H.a)/2,o=z.b+H.b+M.a-L,i=H.a/(n.gc()+1),r=i,d=n.Jc();d.Ob();)a=c(d.Pb(),9),a.n.a=X,a.n.b=o,X+=a.o.a+S,v=tnt(a),v.n.a=a.o.a/2-v.a.a,v.n.b=0,P=c(R(a,(De(),qU)),12),P.e.c.length+P.g.c.length==1&&(P.n.a=r-P.a.a,P.n.b=H.b,_o(P,e)),r+=i}}function Nie(e,t,n,i,r,o,a){var d,b,v,x,S,M,L,P,z,H,X,ie,se;for(M=null,i==(Hm(),op)?M=t:i==y3&&(M=n),z=M.a.ec().Jc();z.Ob();){for(P=c(z.Pb(),12),H=Lo(W(V(Vr,1),Be,8,0,[P.i.n,P.n,P.a])).b,se=new Or,d=new Or,v=new kh(P.b);No(v.a)||No(v.b);)if(b=c(No(v.a)?Q(v.a):Q(v.b),17),et(Ze(R(b,(De(),Jg))))==r&&Do(o,b,0)!=-1){if(b.d==P?X=b.c:X=b.d,ie=Lo(W(V(Vr,1),Be,8,0,[X.i.n,X.n,X.a])).b,p.Math.abs(ie-H)<.2)continue;ie<H?t.a._b(X)?Sr(se,new Ps(op,b)):Sr(se,new Ps(y3,b)):t.a._b(X)?Sr(d,new Ps(op,b)):Sr(d,new Ps(y3,b))}if(se.a.gc()>1)for(L=new Lye(P,se,i),ws(se,new pRe(e,L)),It(a.c,L),S=se.a.ec().Jc();S.Ob();)x=c(S.Pb(),49),fl(o,x.b);if(d.a.gc()>1)for(L=new Lye(P,d,i),ws(d,new bRe(e,L)),It(a.c,L),S=d.a.ec().Jc();S.Ob();)x=c(S.Pb(),49),fl(o,x.b)}}function YZt(e,t){var n,i,r,o,a,d;if(c(R(t,(De(),Lc)),24).Gc((Gs(),Ea))){for(d=new G(t.a);d.a<d.c.c.length;)o=c(Q(d),9),o.k==(Jt(),or)&&(r=c(R(o,(Ge(),rJ)),125),e.c=p.Math.min(e.c,o.n.a-r.b),e.a=p.Math.max(e.a,o.n.a+o.o.a+r.c),e.d=p.Math.min(e.d,o.n.b-r.d),e.b=p.Math.max(e.b,o.n.b+o.o.b+r.a));for(a=new G(t.a);a.a<a.c.c.length;)if(o=c(Q(a),9),o.k!=(Jt(),or))switch(o.k.g){case 2:if(i=c(R(o,(Ge(),Ro)),166),i==(Tu(),V1)){o.n.a=e.c-10,BYe(o,new UV).Jb(new wNe(o));break}if(i==Db){o.n.a=e.a+10,BYe(o,new JV).Jb(new vNe(o));break}if(n=c(R(o,Nb),316),n==(D1(),a3)){yrt(o).Jb(new yNe(o)),o.n.b=e.d-10;break}if(n==bk){yrt(o).Jb(new xNe(o)),o.n.b=e.b+10;break}break;default:throw J(new qt("The node type "+o.k+" is not supported by the "+Xtn))}}}function ZZt(e,t,n,i){var r,o,a,d,b,v,x,S,M,L,P,z,H;for(b=new $e(i.i+i.g/2,i.j+i.f/2),L=mrt(i),P=c(ke(t,(Ge(),cr)),103),H=c(ke(i,B9),64),s$e(eYe(i),Qv)||(i.i==0&&i.j==0?z=0:z=OHt(i,H),ii(i,Qv,z)),v=new $e(t.g,t.f),r=tL(i,P,H,L,v,b,new $e(i.g,i.f),c(R(n,Xu),87),n),Ee(r,(De(),Oi),i),o=c(Xe(r.j,0),12),Zy(o,pWt(i)),Ee(r,Gv,(Ql(),gt(hp))),S=c(ke(t,Gv),185).Gc(eg),d=new cn((!i.n&&(i.n=new Me(Bo,i,1,7)),i.n));d.e!=d.i.gc();)if(a=c(un(d),158),!et(Ze(ke(a,Ib)))&&a.a&&(M=Rte(a),qe(o.f,M),!S))switch(x=0,$7(c(ke(t,Gv),24))&&(x=dve(new $e(a.i,a.j),new $e(a.g,a.f),new $e(i.g,i.f),0,H)),H.g){case 2:case 4:M.o.a=x;break;case 1:case 3:M.o.b=x}Ee(r,F9,he(ke(Xi(t),F9))),Ee(r,q9,he(ke(Xi(t),q9))),Ee(r,Xv,he(ke(Xi(t),Xv))),qe(n.a,r),oi(e.a,i,r)}function een(e,t,n,i,r,o){var a,d,b,v,x,S;for(v=new bc,ec(v,t),$r(v,c(ke(t,(Ge(),B9)),64)),Ee(v,(De(),Oi),t),_o(v,n),S=v.o,S.a=t.g,S.b=t.f,x=v.n,x.a=t.i,x.b=t.j,oi(e.a,t,v),a=Sx(qc(So(new jt(null,(!t.e&&(t.e=new Et(Ii,t,7,4)),new Tt(t.e,16))),new _M),new $8),new uNe(t)),a||(a=Sx(qc(So(new jt(null,(!t.d&&(t.d=new Et(Ii,t,8,5)),new Tt(t.d,16))),new Cd),new Iy),new aNe(t))),a||(a=Sx(new jt(null,(!t.e&&(t.e=new Et(Ii,t,7,4)),new Tt(t.e,16))),new Ry)),Ee(v,nP,(Bt(),!!a)),OYt(v,o,r,c(ke(t,Lw),8)),b=new cn((!t.n&&(t.n=new Me(Bo,t,1,7)),t.n));b.e!=b.i.gc();)d=c(un(b),158),!et(Ze(ke(d,Ib)))&&d.a&&qe(v.f,Rte(d));switch(r.g){case 2:case 1:(v.j==(Je(),Kt)||v.j==bn)&&i.Ec((Gs(),u3));break;case 4:case 3:(v.j==(Je(),nn)||v.j==Yt)&&i.Ec((Gs(),u3))}return v}function ten(e,t,n,i,r,o){var a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt,Rt,fn,ti;Rt=Ut(e.g,r),Rt==null&&(Rt=new W4,P=c(Rt,150),se=t+"_s",de=se+o,L=new J2(de),wf(P,bd,L)),Dt=c(Rt,150),y5(n,Dt),ti=new W4,Zp(ti,"x",sQ(e,i,r.j)),Zp(ti,"y",oQ(e,i,r.k)),wf(Dt,Blt,ti),pt=new W4,Zp(pt,"x",sQ(e,i,r.b)),Zp(pt,"y",oQ(e,i,r.c)),wf(Dt,"endPoint",pt),M=WN((!r.a&&(r.a=new Ar(Yu,r,5)),r.a)),z=!M,z&&(We=new mg,a=new Fze(e,i,We),ws((!r.a&&(r.a=new Ar(Yu,r,5)),r.a),a),wf(Dt,MG,We)),v=fne(r),Se=!!v,Se&&$2e(e.a,Dt,g5e,Gne(e,fne(r))),ie=hne(r),xe=!!ie,xe&&$2e(e.a,Dt,d5e,Gne(e,hne(r))),x=(!r.e&&(r.e=new Et(Hi,r,10,9)),r.e).i==0,H=!x,H&&(bt=new mg,d=new URe(e,bt),ws((!r.e&&(r.e=new Et(Hi,r,10,9)),r.e),d),wf(Dt,b5e,bt)),S=(!r.g&&(r.g=new Et(Hi,r,9,10)),r.g).i==0,X=!S,X&&(fn=new mg,b=new JRe(e,fn),ws((!r.g&&(r.g=new Et(Hi,r,9,10)),r.g),b),wf(Dt,p5e,fn))}function nen(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X;for(t.Tg("Comment pre-processing",1),n=0,b=new G(e.a);b.a<b.c.c.length;)if(d=c(Q(b),9),et(Ze(R(d,(Ge(),JE))))){for(++n,r=0,i=null,v=null,P=new G(d.j);P.a<P.c.c.length;)M=c(Q(P),12),r+=M.e.c.length+M.g.c.length,M.e.c.length==1&&(i=c(Xe(M.e,0),17),v=i.c),M.g.c.length==1&&(i=c(Xe(M.g,0),17),v=i.d);if(r==1&&v.e.c.length+v.g.c.length==1&&!et(Ze(R(v.i,JE))))Len(d,i,v,v.i),z7(b);else{for(X=new Fe,L=new G(d.j);L.a<L.c.c.length;){for(M=c(Q(L),12),S=new G(M.g);S.a<S.c.c.length;)x=c(Q(S),17),x.d.g.c.length==0||It(X.c,x);for(a=new G(M.e);a.a<a.c.c.length;)o=c(Q(a),17),o.c.e.c.length==0||It(X.c,o)}for(H=new G(X);H.a<H.c.c.length;)z=c(Q(H),17),zg(z,!0)}}t.$g()&&t.ah("Found "+n+" comment boxes"),t.Ug()}function ien(e,t,n,i,r){var o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt;for(se=0,P=0,L=0,M=1,ie=new cn((!e.a&&(e.a=new Me(Mn,e,10,11)),e.a));ie.e!=ie.i.gc();)H=c(un(ie),19),M+=Vf(new Ht(Vt(z1(H).a.Jc(),new U))),pt=H.g,P=p.Math.max(P,pt),S=H.f,L=p.Math.max(L,S),se+=pt*S;for(z=(!e.a&&(e.a=new Me(Mn,e,10,11)),e.a).i,a=se+2*i*i*M*z,o=p.Math.sqrt(a),b=p.Math.max(o*n,P),d=p.Math.max(o/n,L),X=new cn((!e.a&&(e.a=new Me(Mn,e,10,11)),e.a));X.e!=X.i.gc();)H=c(un(X),19),bt=r.b+(lu(t,26)*YT+lu(t,27)*ZT)*(b-H.g),Dt=r.b+(lu(t,26)*YT+lu(t,27)*ZT)*(d-H.f),Cc(H,bt),Nl(H,Dt);for(We=b+(r.b+r.c),xe=d+(r.d+r.a),Se=new cn((!e.a&&(e.a=new Me(Mn,e,10,11)),e.a));Se.e!=Se.i.gc();)for(de=c(un(Se),19),x=new Ht(Vt(z1(de).a.Jc(),new U));hn(x);)v=c(sn(x),74),PT(v)||utn(v,t,We,xe);We+=r.b+r.c,xe+=r.d+r.a,uw(e,We,xe,!1,!0)}function ren(e){var t,n,i,r;for(lr(pi(new jt(null,new Tt(e.a.b,16)),new l4),new YM),xqt(e),lr(pi(new jt(null,new Tt(e.a.b,16)),new X8),new V8),e.c==($1(),Ik)&&(lr(pi(So(new jt(null,new Tt(new an(e.f),1)),new ZM),new Fy),new FNe(e)),lr(pi(qc(So(So(new jt(null,new Tt(e.d.b,16)),new OR),new W8),new u4),new EW),new HNe(e))),lr(pi(So(new jt(null,new Tt(new an(e.f),1)),new d1),new eA),new QNe(e)),r=new $e(nr,nr),t=new $e(Qr,Qr),i=new G(e.a.b);i.a<i.c.c.length;)n=c(Q(i),60),r.a=p.Math.min(r.a,n.d.c),r.b=p.Math.min(r.b,n.d.d),t.a=p.Math.max(t.a,n.d.c+n.d.b),t.b=p.Math.max(t.b,n.d.d+n.d.a);ki(Xf(e.d.c),MF(new $e(r.a,r.b))),ki(Xf(e.d.f),Hr(new $e(t.a,t.b),r)),AJt(e,r,t),sc(e.f),sc(e.b),sc(e.g),sc(e.e),e.a.a.c.length=0,e.a.b.c.length=0,e.a=null,e.d=null}function Qye(e,t){aFe();var n,i,r,o,a,d,b;if(this.a=new gge(this),this.b=e,this.c=t,this.f=GZ(uo((Dl(),ps),t)),this.f.dc())if((d=b2e(ps,e))==t)for(this.e=!0,this.d=new Fe,this.f=new W$,this.f.Ec(Cb),c(IQ(nD(ps,Bu(e)),""),29)==e&&this.f.Ec(I7(ps,Bu(e))),r=aie(ps,e).Jc();r.Ob();)switch(i=c(r.Pb(),182),zm(uo(ps,i))){case 4:{this.d.Ec(i);break}case 5:{this.f.Fc(GZ(uo(ps,i)));break}}else if(qs(),c(t,69).vk())for(this.e=!0,this.f=null,this.d=new Fe,a=0,b=(e.i==null&&ud(e),e.i).length;a<b;++a)for(i=(n=(e.i==null&&ud(e),e.i),a>=0&&a<n.length?n[a]:null),o=S5(uo(ps,i));o;o=S5(uo(ps,o)))o==t&&this.d.Ec(i);else zm(uo(ps,t))==1&&d?(this.f=null,this.d=(U5(),rvt)):(this.f=null,this.e=!0,this.d=(Ct(),new DK(t)));else this.e=zm(uo(ps,t))==5,this.f.Fb(Mae)&&(this.f=Mae)}function est(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P;for(n=0,i=Uzt(e,t),M=e.s,L=e.t,v=c(c(Si(e.r,t),24),85).Jc();v.Ob();)if(b=c(v.Pb(),116),!(!b.c||b.c.d.c.length<=0)){switch(P=b.b.Kf(),d=b.b.nf((Dn(),fu))?ue(he(b.b.mf(fu))):0,x=b.c,S=x.i,S.b=(a=x.n,x.e.a+a.b+a.c),S.a=(o=x.n,x.e.b+o.d+o.a),t.g){case 1:S.c=b.a?(P.a-S.b)/2:P.a+M,S.d=P.b+d+i,Kf(x,(Hl(),Y0)),ed(x,(hl(),rh));break;case 3:S.c=b.a?(P.a-S.b)/2:P.a+M,S.d=-d-i-S.a,Kf(x,(Hl(),Y0)),ed(x,(hl(),Ef));break;case 2:S.c=-d-i-S.b,b.a?(r=e.v?S.a:c(Xe(x.d,0),190).Kf().b,S.d=(P.b-r)/2):S.d=P.b+L,Kf(x,(Hl(),Tf)),ed(x,(hl(),Z0));break;case 4:S.c=P.a+d+i,b.a?(r=e.v?S.a:c(Xe(x.d,0),190).Kf().b,S.d=(P.b-r)/2):S.d=P.b+L,Kf(x,(Hl(),wd)),ed(x,(hl(),Z0))}(t==(Je(),Kt)||t==bn)&&(n=p.Math.max(n,S.a))}n>0&&(c(Zs(e.b,t),129).a.b=n)}function sen(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X;for(L=0,i=new Or,o=new cn((!t.a&&(t.a=new Me(Mn,t,10,11)),t.a));o.e!=o.i.gc();)r=c(un(o),19),et(Ze(ke(r,(Ge(),Ib))))||(S=Xi(r),DQ(S)&&!et(Ze(ke(r,KU)))&&(ii(r,(De(),Pi),Pe(L)),++L,ga(r,zv)&&Sr(i,c(ke(r,zv),15))),Zrt(e,r,n));for(Ee(n,(De(),np),Pe(L)),Ee(n,tP,Pe(i.a.gc())),L=0,x=new cn((!t.b&&(t.b=new Me(Ii,t,12,3)),t.b));x.e!=x.i.gc();)b=c(un(x),74),DQ(t)&&(ii(b,Pi,Pe(L)),++L),H=Bne(b),X=$Ze(b),M=et(Ze(ke(H,(Ge(),qv)))),z=!et(Ze(ke(b,Ib))),P=M&&sw(b)&&et(Ze(ke(b,Lb))),a=Xi(H)==t&&Xi(H)==Xi(X),d=(Xi(H)==t&&X==t)^(Xi(X)==t&&H==t),z&&!P&&(d||a)&&Wye(e,b,t,n);if(Xi(t))for(v=new cn(eHe(Xi(t)));v.e!=v.i.gc();)b=c(un(v),74),H=Bne(b),H==t&&sw(b)&&(P=et(Ze(ke(H,(Ge(),qv))))&&et(Ze(ke(b,Lb))),P&&Wye(e,b,t,n))}function oen(e){var t,n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt,Rt;for(xe=new Fe,P=new G(e.b);P.a<P.c.c.length;)for(L=c(Q(P),26),X=new G(L.a);X.a<X.c.c.length;)if(z=c(Q(X),9),z.k==(Jt(),Cr)&&xi(z,(De(),GU))){for(ie=null,de=null,se=null,bt=new G(z.j);bt.a<bt.c.c.length;)switch(pt=c(Q(bt),12),pt.j.g){case 4:ie=pt;break;case 2:de=pt;break;default:se=pt}for(Se=c(Xe(se.g,0),17),x=new Ez(Se.a),v=new Cs(se.n),ki(v,z.n),S=_n(x,0),oq(S,v),We=Fme(Se.a),M=new Cs(se.n),ki(M,z.n),tr(We,M,We.c.b,We.c),Dt=c(R(z,GU),9),Rt=c(Xe(Dt.j,0),12),b=c(jh(ie.e,ye(j9,s9,17,0,0,1)),324),i=b,o=0,d=i.length;o<d;++o)t=i[o],ss(t,Rt),Lte(t.a,t.a.b,x);for(b=rd(de.g),n=b,r=0,a=n.length;r<a;++r)t=n[r],ks(t,Rt),Lte(t.a,0,We);ks(Se,null),ss(Se,null),It(xe.c,z)}for(H=new G(xe);H.a<H.c.c.length;)z=c(Q(H),9),zr(z,null)}function cen(e,t,n,i){var r,o,a,d,b,v,x,S,M,L,P,z;if(M=ue(he(R(e,(Ge(),F9)))),L=ue(he(R(e,q9))),S=ue(he(R(e,Xv))),d=e.o,o=c(Xe(e.j,0),12),a=o.n,z=CQt(o,S),!!z){if(t.Gc((Ql(),eg)))switch(c(R(e,(De(),Ko)),64).g){case 1:z.c=(d.a-z.b)/2-a.a,z.d=L;break;case 3:z.c=(d.a-z.b)/2-a.a,z.d=-L-z.a;break;case 2:n&&o.e.c.length==0&&o.g.c.length==0?(x=i?z.a:c(Xe(o.f,0),70).o.b,z.d=(d.b-x)/2-a.b):z.d=d.b+L-a.b,z.c=-M-z.b;break;case 4:n&&o.e.c.length==0&&o.g.c.length==0?(x=i?z.a:c(Xe(o.f,0),70).o.b,z.d=(d.b-x)/2-a.b):z.d=d.b+L-a.b,z.c=M}else if(t.Gc(hp))switch(c(R(e,(De(),Ko)),64).g){case 1:case 3:z.c=a.a+M;break;case 2:case 4:n&&!o.c?(x=i?z.a:c(Xe(o.f,0),70).o.b,z.d=(d.b-x)/2-a.b):z.d=a.b+L}for(r=z.d,v=new G(o.f);v.a<v.c.c.length;)b=c(Q(v),70),P=b.n,P.a=z.c,P.b=r,r+=b.o.b+S}}function Gye(e){var t;if(this.r=dAt(new fO,new hO),this.b=new yT(c(Rn($s),299)),this.p=new yT(c(Rn($s),299)),this.i=new yT(c(Rn($ft),299)),this.e=e,this.o=new Cs(e.Kf()),this.D=et(Ze(e.mf((Dn(),e8)))),this.F=e.Wf()||et(Ze(e.mf(AP))),this.A=c(e.mf(qb),24),this.B=c(e.mf(lp),24),this.q=c(e.mf(Y9),103),this.u=c(e.mf(iy),24),!_Ht(this.u))throw J(new Wh("Invalid port label placement: "+this.u));if(this.v=et(Ze(e.mf(x7e))),this.j=c(e.mf(E3),24),!WUt(this.j))throw J(new Wh("Invalid node label placement: "+this.j));this.n=c(TT(e,l7e),100),this.k=ue(he(TT(e,UJ))),this.d=ue(he(TT(e,j7e))),this.w=ue(he(TT(e,A7e))),this.s=ue(he(TT(e,T7e))),this.t=ue(he(TT(e,E7e))),this.C=c(TT(e,C7e),125),this.c=2*this.d,t=!this.B.Gc((uu(),FP)),this.f=new OT(0,t,0),this.g=new OT(1,t,0),WK(this.f,(Yf(),Vc),this.g)}function len(){li(eI,new fN),li(dX,new xB),li(tI,new ZW),li(QTe,new EB),li(nt,new nK),li(V(Rl,1),new pN),li(ir,new NB),li(ak,new _B),li(nt,new fB),li(nt,new JW),li(nt,new j2),li(kr,new Ej),li(nt,new aN),li(Ju,new A4),li(Ju,new hB),li(nt,new dB),li(O9,new gB),li(nt,new Cj),li(nt,new XW),li(nt,new VW),li(nt,new WW),li(nt,new bB),li(V(Rl,1),new mB),li(nt,new N4),li(nt,new Mj),li(Ju,new wB),li(Ju,new vB),li(nt,new yB),li(Lr,new kB),li(nt,new OB),li(Ow,new Aj),li(nt,new SB),li(nt,new jB),li(nt,new Oc),li(nt,new hN),li(Ju,new KW),li(Ju,new TB),li(nt,new YW),li(nt,new eK),li(nt,new Nj),li(nt,new _4),li(nt,new dN),li(nt,new _j),li(Sw,new gN),li(nt,new T2),li(nt,new Rp),li(nt,new t6),li(Sw,new tK),li(Ow,new CB),li(nt,new MB),li(Lr,new AB)}function tst(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P;switch(x=new nu,e.a.g){case 3:M=c(R(t.e,(De(),_b)),16),L=c(R(t.j,_b),16),P=c(R(t.f,_b),16),n=c(R(t.e,g3),16),i=c(R(t.j,g3),16),r=c(R(t.f,g3),16),a=new Fe,yr(a,M),L.Ic(new g4),yr(a,Eu(L)),yr(a,P),o=new Fe,yr(o,n),yr(o,Eu(i)),yr(o,r),Ee(t.f,_b,a),Ee(t.f,g3,o),Ee(t.f,S6e,t.f),Ee(t.e,_b,null),Ee(t.e,g3,null),Ee(t.j,_b,null),Ee(t.j,g3,null);break;case 1:Os(x,t.e.a),ei(x,t.i.n),Os(x,Eu(t.j.a)),ei(x,t.a.n),Os(x,t.f.a);break;default:Os(x,t.e.a),Os(x,Eu(t.j.a)),Os(x,t.f.a)}Ou(t.f.a),Os(t.f.a,x),ks(t.f,t.e.c),d=c(R(t.e,(Ge(),ho)),79),v=c(R(t.j,ho),79),b=c(R(t.f,ho),79),(d||v||b)&&(S=new nu,tpe(S,b),tpe(S,v),tpe(S,d),Ee(t.f,ho,S)),ks(t.j,null),ss(t.j,null),ks(t.e,null),ss(t.e,null),zr(t.a,null),zr(t.i,null),t.g&&tst(e,t.g)}function nst(){nst=te;var e,t,n;for(new TD(1,0),new TD(10,0),new TD(0,0),zat=ye(Doe,Be,249,11,0,1),Ab=ye(Na,fd,30,100,15,1),oke=W(V(ns,1),no,30,15,[1,5,25,125,625,3125,15625,78125,390625,1953125,9765625,48828125,244140625,1220703125,6103515625,30517578125,152587890625,762939453125,3814697265625,19073486328125,95367431640625,476837158203125,0x878678326eac9]),cke=ye(Fn,ci,30,oke.length,15,1),lke=W(V(ns,1),no,30,15,[1,10,100,qg,1e4,ure,1e6,1e7,1e8,QQ,1e10,1e11,1e12,1e13,1e14,1e15,1e16]),uke=ye(Fn,ci,30,lke.length,15,1),ake=ye(Doe,Be,249,11,0,1),e=0;e<ake.length;e++)zat[e]=new TD(e,0),ake[e]=new TD(0,e),Ab[e]=48;for(;e<Ab.length;e++)Ab[e]=48;for(n=0;n<cke.length;n++)cke[n]=ave(oke[n]);for(t=0;t<uke.length;t++)uke[t]=ave(lke[t]);PS()}function uen(){function e(){this.obj=this.createObject()}return e.prototype.createObject=function(t){return Object.create(null)},e.prototype.get=function(t){return this.obj[t]},e.prototype.set=function(t,n){this.obj[t]=n},e.prototype[hre]=function(t){delete this.obj[t]},e.prototype.keys=function(){return Object.getOwnPropertyNames(this.obj)},e.prototype.entries=function(){var t=this.keys(),n=this,i=0;return{next:function(){if(i>=t.length)return{done:!0};var r=t[i++];return{value:[r,n.get(r)],done:!1}}}},ZXt()||(e.prototype.createObject=function(){return{}},e.prototype.get=function(t){return this.obj[":"+t]},e.prototype.set=function(t,n){this.obj[":"+t]=n},e.prototype[hre]=function(t){delete this.obj[":"+t]},e.prototype.keys=function(){var t=[];for(var n in this.obj)n.charCodeAt(0)==58&&t.push(n.substring(1));return t}),e}function Li(){Li=te,pC=new gi(jxe),new qi("DEPTH",Pe(0)),Hle=new qi("FAN",Pe(0)),q9e=new qi(Ect,Pe(0)),cp=new qi("ROOT",(Bt(),!1)),Ule=new qi("LEFTNEIGHBOR",null),Fpt=new qi("RIGHTNEIGHBOR",null),OJ=new qi("LEFTSIBLING",null),Jle=new qi("RIGHTSIBLING",null),qle=new qi("DUMMY",!1),new qi("LEVEL",Pe(0)),G9e=new qi("REMOVABLE_EDGES",new Ai),wP=new qi("XCOOR",Pe(0)),vP=new qi("YCOOR",Pe(0)),SJ=new qi("LEVELHEIGHT",0),oh=new qi("LEVELMIN",0),Af=new qi("LEVELMAX",0),Qle=new qi("GRAPH_XMIN",0),Gle=new qi("GRAPH_YMIN",0),H9e=new qi("GRAPH_XMAX",0),Q9e=new qi("GRAPH_YMAX",0),F9e=new qi("COMPACT_LEVEL_ASCENSION",!1),Fle=new qi("COMPACT_CONSTRAINTS",new Fe),gC=new qi("ID",""),bC=new qi("POSITION",Pe(0)),Kg=new qi("PRELIM",0),U9=new qi("MODIFIER",0),G9=new gi(Lot),mP=new gi(Pot)}function aen(e){Oye();var t,n,i,r,o,a,d,b,v,x,S,M,L,P,z,H;if(e==null)return null;if(S=e.length*8,S==0)return"";for(d=S%24,L=S/24|0,M=d!=0?L+1:L,o=null,o=ye(Na,fd,30,M*4,15,1),v=0,x=0,t=0,n=0,i=0,a=0,r=0,b=0;b<L;b++)t=e[r++],n=e[r++],i=e[r++],x=(n&15)<<24>>24,v=(t&3)<<24>>24,P=(t&-128)==0?t>>2<<24>>24:(t>>2^192)<<24>>24,z=(n&-128)==0?n>>4<<24>>24:(n>>4^240)<<24>>24,H=(i&-128)==0?i>>6<<24>>24:(i>>6^252)<<24>>24,o[a++]=s0[P],o[a++]=s0[z|v<<4],o[a++]=s0[x<<2|H],o[a++]=s0[i&63];return d==8?(t=e[r],v=(t&3)<<24>>24,P=(t&-128)==0?t>>2<<24>>24:(t>>2^192)<<24>>24,o[a++]=s0[P],o[a++]=s0[v<<4],o[a++]=61,o[a++]=61):d==16&&(t=e[r],n=e[r+1],x=(n&15)<<24>>24,v=(t&3)<<24>>24,P=(t&-128)==0?t>>2<<24>>24:(t>>2^192)<<24>>24,z=(n&-128)==0?n>>4<<24>>24:(n>>4^240)<<24>>24,o[a++]=s0[P],o[a++]=s0[z|v<<4],o[a++]=s0[x<<2],o[a++]=61),od(o,0,o.length)}function fen(e,t){var n,i,r,o,a,d,b;if(e.e==0&&e.p>0&&(e.p=-(e.p-1)),e.p>ls&&rbe(t,e.p-G0),a=t.q.getDate(),z_(t,1),e.k>=0&&ENt(t,e.k),e.c>=0?z_(t,e.c):e.k>=0?(b=new _me(t.q.getFullYear()-G0,t.q.getMonth(),35),i=35-b.q.getDate(),z_(t,p.Math.min(i,a))):z_(t,a),e.f<0&&(e.f=t.q.getHours()),e.b>0&&e.f<12&&(e.f+=12),Ejt(t,e.f==24&&e.g?0:e.f),e.j>=0&&cLt(t,e.j),e.n>=0&&xLt(t,e.n),e.i>=0&&c$e(t,As(Ss(ID(Zo(t.q.getTime()),qg),qg),e.i)),e.a&&(r=new _z,rbe(r,r.q.getFullYear()-G0-80),dY(Zo(t.q.getTime()),Zo(r.q.getTime()))&&rbe(t,r.q.getFullYear()-G0+100)),e.d>=0){if(e.c==-1)n=(7+e.d-t.q.getDay())%7,n>3&&(n-=7),d=t.q.getMonth(),z_(t,t.q.getDate()+n),t.q.getMonth()!=d&&z_(t,t.q.getDate()+(n>0?-7:7));else if(t.q.getDay()!=e.d)return!1}return e.o>ls&&(o=t.q.getTimezoneOffset(),c$e(t,As(Zo(t.q.getTime()),(e.o-o)*60*qg))),!0}function ist(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de;if(r=R(t,(De(),Oi)),!!oe(r,209)){for(P=c(r,19),z=t.e,M=new Cs(t.c),o=t.d,M.a+=o.b,M.b+=o.d,de=c(ke(P,(Ge(),cJ)),185),Cl(de,(uu(),YJ))&&(L=c(ke(P,LSe),100),oz(L,o.a),uz(L,o.d),cz(L,o.b),$N(L,o.c)),n=new Fe,x=new G(t.a);x.a<x.c.c.length;)for(b=c(Q(x),9),oe(R(b,Oi),209)?pen(b,M):oe(R(b,Oi),196)&&!z&&(i=c(R(b,Oi),127),ie=Fit(t,b,i.g,i.f),aa(i,ie.a,ie.b)),X=new G(b.j);X.a<X.c.c.length;)H=c(Q(X),12),lr(pi(new jt(null,new Tt(H.g,16)),new fNe(b)),new hNe(n));if(z)for(X=new G(z.j);X.a<X.c.c.length;)H=c(Q(X),12),lr(pi(new jt(null,new Tt(H.g,16)),new dNe(z)),new gNe(n));for(se=c(ke(P,W1),225),d=new G(n);d.a<d.c.c.length;)a=c(Q(d),17),NZt(a,se,M);for(bWt(t),v=new G(t.a);v.a<v.c.c.length;)b=c(Q(v),9),S=b.e,S&&ist(e,S)}}function rst(e,t){var n,i,r,o,a,d,b,v,x,S,M,L;if(!c(c(Si(e.r,t),24),85).dc()){if(a=c(Zs(e.b,t),129),b=a.i,d=a.n,x=nie(e,t),i=b.b-d.b-d.c,r=a.a.a,o=b.c+d.b,L=e.w,(x==(_x(),ap)||x==IP)&&c(c(Si(e.r,t),24),85).gc()==1&&(r=x==ap?r-2*e.w:r,x=PC),i<r&&!e.B.Gc((uu(),ZJ)))x==ap?(L+=(i-r)/(c(c(Si(e.r,t),24),85).gc()+1),o+=L):L+=(i-r)/(c(c(Si(e.r,t),24),85).gc()-1);else switch(i<r&&(r=x==ap?r-2*e.w:r,x=PC),x.g){case 3:o+=(i-r)/2;break;case 4:o+=i-r;break;case 0:n=(i-r)/(c(c(Si(e.r,t),24),85).gc()+1),L+=p.Math.max(0,n),o+=L;break;case 1:n=(i-r)/(c(c(Si(e.r,t),24),85).gc()-1),L+=p.Math.max(0,n)}for(M=c(c(Si(e.r,t),24),85).Jc();M.Ob();)S=c(M.Pb(),116),S.e.a=o+S.d.b,S.e.b=(v=S.b,v.nf((Dn(),fu))?v.$f()==(Je(),Kt)?-v.Kf().b-ue(he(v.mf(fu))):ue(he(v.mf(fu))):v.$f()==(Je(),Kt)?-v.Kf().b:0),o+=S.d.b+S.b.Kf().a+S.d.c+L}}function sst(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P;if(!c(c(Si(e.r,t),24),85).dc()){if(a=c(Zs(e.b,t),129),b=a.i,d=a.n,S=nie(e,t),i=b.a-d.d-d.a,r=a.a.b,o=b.d+d.d,P=e.w,v=e.o.a,(S==(_x(),ap)||S==IP)&&c(c(Si(e.r,t),24),85).gc()==1&&(r=S==ap?r-2*e.w:r,S=PC),i<r&&!e.B.Gc((uu(),ZJ)))S==ap?(P+=(i-r)/(c(c(Si(e.r,t),24),85).gc()+1),o+=P):P+=(i-r)/(c(c(Si(e.r,t),24),85).gc()-1);else switch(i<r&&(r=S==ap?r-2*e.w:r,S=PC),S.g){case 3:o+=(i-r)/2;break;case 4:o+=i-r;break;case 0:n=(i-r)/(c(c(Si(e.r,t),24),85).gc()+1),P+=p.Math.max(0,n),o+=P;break;case 1:n=(i-r)/(c(c(Si(e.r,t),24),85).gc()-1),P+=p.Math.max(0,n)}for(L=c(c(Si(e.r,t),24),85).Jc();L.Ob();)M=c(L.Pb(),116),M.e.a=(x=M.b,x.nf((Dn(),fu))?x.$f()==(Je(),Yt)?-x.Kf().a-ue(he(x.mf(fu))):v+ue(he(x.mf(fu))):x.$f()==(Je(),Yt)?-x.Kf().a:v),M.e.b=o+M.d.d,o+=M.d.d+M.b.Kf().b+M.d.a+P}}function hen(e,t){var n,i,r,o,a;for(t.Tg("Processor determine the coords for each level",1),i=new Fe,a=_n(e.b,0);a.b!=a.d.c;){for(r=c(An(a),41);c(R(r,(Uo(),xd)),15).a>i.c.length-1;)qe(i,new Ps(Vx,r4e));n=c(R(r,xd),15).a,O1(c(R(e,Iw),87))?(r.e.a<ue(he((ht(n,i.c.length),c(i.c[n],49)).a))&&H4((ht(n,i.c.length),c(i.c[n],49)),r.e.a),r.e.a+r.f.a>ue(he((ht(n,i.c.length),c(i.c[n],49)).b))&&qN((ht(n,i.c.length),c(i.c[n],49)),r.e.a+r.f.a)):(r.e.b<ue(he((ht(n,i.c.length),c(i.c[n],49)).a))&&H4((ht(n,i.c.length),c(i.c[n],49)),r.e.b),r.e.b+r.f.b>ue(he((ht(n,i.c.length),c(i.c[n],49)).b))&&qN((ht(n,i.c.length),c(i.c[n],49)),r.e.b+r.f.b))}for(o=_n(e.b,0);o.b!=o.d.c;)r=c(An(o),41),n=c(R(r,(Uo(),xd)),15).a,Ee(r,(Li(),oh),he((ht(n,i.c.length),c(i.c[n],49)).a)),Ee(r,Af,he((ht(n,i.c.length),c(i.c[n],49)).b));t.Ug()}function den(e){var t,n,i,r,o,a,d,b,v,x,S,M,L,P,z;for(e.o=ue(he(R(e.i,(Ge(),$b)))),e.f=ue(he(R(e.i,ip))),e.j=e.i.b.c.length,d=e.j-1,M=0,e.k=0,e.n=0,e.b=mf(ye(Lr,Be,15,e.j,0,1)),e.c=mf(ye(kr,Be,347,e.j,7,1)),a=new G(e.i.b);a.a<a.c.c.length;){for(r=c(Q(a),26),r.p=d,S=new G(r.a);S.a<S.c.c.length;)x=c(Q(S),9),x.p=M,++M;--d}for(e.g=ye(Fn,ci,30,M,15,1),e.d=H2(Fn,[Be,ci],[54,30],15,[M,3],2),e.p=new Fe,e.q=new Fe,t=0,e.e=0,o=new G(e.i.b);o.a<o.c.c.length;){for(r=c(Q(o),26),d=r.p,i=0,z=0,b=r.a.c.length,v=0,S=new G(r.a);S.a<S.c.c.length;)x=c(Q(S),9),M=x.p,e.g[M]=x.c.p,v+=x.o.b+e.o,n=Vf(new Ht(Vt(pr(x).a.Jc(),new U))),P=Vf(new Ht(Vt($i(x).a.Jc(),new U))),e.d[M][0]=P-n,e.d[M][1]=n,e.d[M][2]=P,i+=n,z+=P,n>0&&qe(e.q,x),qe(e.p,x);t-=i,L=b+t,v+=t*e.f,Su(e.b,d,Pe(L)),Su(e.c,d,v),e.k=p.Math.max(e.k,L),e.n=p.Math.max(e.n,v),e.e+=t,t+=z}}function ost(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se;if(t.b!=0){for(L=new Ai,d=null,P=null,i=xs(p.Math.floor(p.Math.log(t.b)*p.Math.LOG10E)+1),b=0,se=_n(t,0);se.b!=se.d.c;)for(X=c(An(se),41),ve(P)!==ve(R(X,(Li(),gC)))&&(P=zn(R(X,gC)),b=0),P!=null?d=P+yQe(b++,i):d=yQe(b++,i),Ee(X,gC,d),H=(r=_n(new k1(X).a.d,0),new ix(r));XN(H.a);)z=c(An(H.a),65).c,tr(L,z,L.c.b,L.c),Ee(z,gC,d);for(M=new wn,a=0;a<d.length-i;a++)for(ie=_n(t,0);ie.b!=ie.d.c;)X=c(An(ie),41),v=Fa(zn(R(X,(Li(),gC))),0,a+1),n=(v==null?Ao(co(M.f,null)):f7(M.i,v))!=null?c(v==null?Ao(co(M.f,null)):f7(M.i,v),15).a+1:1,lo(M,v,Pe(n));for(S=new sv(new Bp(M).a);S.b;)x=Ex(S),o=Pe(Ut(e.a,x.jd())!=null?c(Ut(e.a,x.jd()),15).a:0),lo(e.a,zn(x.jd()),Pe(c(x.kd(),15).a+o.a)),o=c(Ut(e.b,x.jd()),15),(!o||o.a<c(x.kd(),15).a)&&lo(e.b,zn(x.jd()),c(x.kd(),15));ost(e,L)}}function gen(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X;for(n.Tg("Breadth first model order layering",1),e.a=t,H=new Fe,z=new G(e.a.a);z.a<z.c.c.length;)L=c(Q(z),9),L.k==(Jt(),or)&&It(H.c,L);for(Ct(),Rr(H,new sa),b=!0,r=new hc(e.a),i=null,qe(e.a.b,r),P=new G(H);P.a<P.c.c.length;)if(L=c(Q(P),9),b)zr(L,r),b=!1;else{for(d=new Ht(Vt(pr(L).a.Jc(),new U));hn(d);)o=c(sn(d),17),(o.c.i.k==(Jt(),or)&&o.c.i.c==r||o.c.i.k==lc&&c(sn(new Ht(Vt(pr(o.c.i).a.Jc(),new U))),17).c.i.c==r)&&(i=new hc(e.a),qe(e.a.b,i),r=new hc(e.a),qe(e.a.b,r));for(a=new Ht(Vt(pr(L).a.Jc(),new U));hn(a);)o=c(sn(a),17),o.c.i.k==(Jt(),lc)&&!o.c.i.c&&zr(o.c.i,i);zr(L,r)}for(e.a.a.c.length=0,X=new Fe,S=new G(e.a.b);S.a<S.c.c.length;)v=c(Q(S),26),v.a.c.length==0&&It(X.c,v);for(hwe(e.a.b,X),M=0,x=new G(e.a.b);x.a<x.c.c.length;)v=c(Q(x),26),v.p=M,++M;n.Ug()}function Je(){Je=te;var e;$o=new g_(nE,0),Kt=new g_("NORTH",1),nn=new g_("EAST",2),bn=new g_("SOUTH",3),Yt=new g_("WEST",4),Qh=(Ct(),new w6((e=c(Jf($s),10),new ha(e,c(gf(e,e.length),10),0)))),Pf=Lg(_i(Kt,W(V($s,1),cc,64,0,[]))),Ma=Lg(_i(nn,W(V($s,1),cc,64,0,[]))),Wu=Lg(_i(bn,W(V($s,1),cc,64,0,[]))),Za=Lg(_i(Yt,W(V($s,1),cc,64,0,[]))),vl=Lg(_i(Kt,W(V($s,1),cc,64,0,[bn]))),ol=Lg(_i(nn,W(V($s,1),cc,64,0,[Yt]))),If=Lg(_i(Kt,W(V($s,1),cc,64,0,[Yt]))),Xl=Lg(_i(Kt,W(V($s,1),cc,64,0,[nn]))),Ku=Lg(_i(bn,W(V($s,1),cc,64,0,[Yt]))),Aa=Lg(_i(nn,W(V($s,1),cc,64,0,[bn]))),Vl=Lg(_i(Kt,W(V($s,1),cc,64,0,[nn,Yt]))),wl=Lg(_i(nn,W(V($s,1),cc,64,0,[bn,Yt]))),yl=Lg(_i(Kt,W(V($s,1),cc,64,0,[bn,Yt]))),Il=Lg(_i(Kt,W(V($s,1),cc,64,0,[nn,bn]))),Pc=Lg(_i(Kt,W(V($s,1),cc,64,0,[nn,bn,Yt])))}function pen(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z;for(i=c(R(e,(De(),Oi)),19),P=c(R(e,(Ge(),YU)),15).a,o=c(R(e,YE),15).a,ii(i,YU,Pe(P)),ii(i,YE,Pe(o)),Cc(i,e.n.a+t.a),Nl(i,e.n.b+t.b),(c(ke(i,Pb),185).gc()!=0||e.e||ve(R(Jr(e),oJ))===ve((ST(),rC))&&T$e((hv(),(e.q?e.q:(Ct(),Ct(),Yd))._b(Dw)?M=c(R(e,Dw),205):M=c(R(Jr(e),eC),205),M)))&&(ob(i,e.o.a),sb(i,e.o.b)),S=new G(e.j);S.a<S.c.c.length;)v=c(Q(S),12),z=R(v,Oi),oe(z,196)&&(r=c(z,127),aa(r,v.n.a,v.n.b),ii(r,B9,v.j));for(L=c(R(e,_w),185).gc()!=0,b=new G(e.b);b.a<b.c.c.length;)a=c(Q(b),70),(L||c(R(a,_w),185).gc()!=0)&&(n=c(R(a,Oi),158),_m(n,a.o.a,a.o.b),aa(n,a.n.a,a.n.b));if(!$7(c(R(e,Gv),24)))for(x=new G(e.j);x.a<x.c.c.length;)for(v=c(Q(x),12),d=new G(v.f);d.a<d.c.c.length;)a=c(Q(d),70),n=c(R(a,Oi),158),ob(n,a.o.a),sb(n,a.o.b),aa(n,a.n.a,a.n.b)}function ben(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt;for(t.Tg("Calculate Graph Size",1),t.bh(e,g4e),S=Vx,M=Vx,v=mse,x=mse,z=new cn((!e.a&&(e.a=new Me(Mn,e,10,11)),e.a));z.e!=z.i.gc();)L=c(un(z),19),ie=L.i,se=L.j,bt=L.g,d=L.f,b=c(ke(L,(Dn(),Y1)),125),S=p.Math.min(S,ie-b.b),M=p.Math.min(M,se-b.d),v=p.Math.max(v,ie+bt+b.c),x=p.Math.max(x,se+d+b.a);for(X=c(ke(e,(Dn(),zh)),100),H=new $e(S-X.b,M-X.d),pt=v-S+(X.b+X.c),a=x-M+(X.d+X.a),et(Ze(ke(e,(F0(),v8e))))&&(de=c(ke(e,(vx(),k3)),19),Se=c(ke(de,Y1),125),xe=de.i+de.g/2+(Se.b+Se.c)/2-H.a,We=de.j+de.f/2+(Se.d+Se.a)/2-H.b,r=pt-xe,o=a-We,r<pt/2?(n=r-xe,pt+=n,H.a-=n):(n=xe-r,pt+=n),o<a/2?(i=o-We,a+=i,H.b-=i):(i=We-o,a+=i)),P=new cn((!e.a&&(e.a=new Me(Mn,e,10,11)),e.a));P.e!=P.i.gc();)L=c(un(P),19),Cc(L,L.i-H.a),Nl(L,L.j-H.b);et(Ze(ke(e,ny)))||(ob(e,pt),sb(e,a)),ii(e,ty,pt-(X.b+X.c)),ii(e,ey,a-(X.d+X.a)),t.bh(e,kG)}function men(e,t,n){var i,r,o,a,d,b,v,x,S,M,L;if(e.e.a.$b(),e.f.a.$b(),e.c.c.length=0,e.i.c.length=0,e.g.a.$b(),t)for(a=new G(t.a);a.a<a.c.c.length;)for(o=c(Q(a),9),S=Bg(o,(Je(),nn)).Jc();S.Ob();)for(x=c(S.Pb(),12),Sr(e.e,x),r=new G(x.g);r.a<r.c.c.length;)i=c(Q(r),17),!vs(i)&&(qe(e.c,i),ZKe(e,i),d=i.c.i.k,(d==(Jt(),or)||d==Dc||d==Cr||d==Ih)&&qe(e.j,i),L=i.d,M=L.i.c,M==n?Sr(e.f,L):M==t?Sr(e.e,L):fl(e.c,i));if(n)for(a=new G(n.a);a.a<a.c.c.length;){for(o=c(Q(a),9),v=new G(o.j);v.a<v.c.c.length;)for(b=c(Q(v),12),r=new G(b.g);r.a<r.c.c.length;)i=c(Q(r),17),vs(i)&&Sr(e.g,i);for(S=Bg(o,(Je(),Yt)).Jc();S.Ob();)for(x=c(S.Pb(),12),Sr(e.f,x),r=new G(x.g);r.a<r.c.c.length;)i=c(Q(r),17),!vs(i)&&(qe(e.c,i),ZKe(e,i),d=i.c.i.k,(d==(Jt(),or)||d==Dc||d==Cr||d==Ih)&&qe(e.j,i),L=i.d,M=L.i.c,M==n?Sr(e.f,L):M==t?Sr(e.e,L):fl(e.c,i))}}function wen(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de;for(n.Tg("Polyline edge routing",1),H=ue(he(R(t,(Ge(),bSe)))),L=ue(he(R(t,Vv))),r=ue(he(R(t,Jv))),i=p.Math.min(1,r/L),se=0,b=0,t.b.c.length!=0&&(de=Wtt(c(Xe(t.b,0),26)),se=.4*i*de),d=new os(t.b,0);d.b<d.d.gc();){for(a=(dn(d.b<d.d.gc()),c(d.d.Xb(d.c=d.b++),26)),o=pF(a,pP),o&&se>0&&(se-=L),Pye(a,se),x=0,M=new G(a.a);M.a<M.c.c.length;){for(S=c(Q(M),9),v=0,z=new Ht(Vt($i(S).a.Jc(),new U));hn(z);)P=c(sn(z),17),X=xh(P.c).b,ie=xh(P.d).b,a==P.d.i.c&&!vs(P)&&(NGt(P,se,.4*i*p.Math.abs(X-ie)),P.c.j==(Je(),Yt)&&(X=0,ie=0)),v=p.Math.max(v,p.Math.abs(ie-X));switch(S.k.g){case 0:case 4:case 1:case 3:case 5:LYt(e,S,se,H)}x=p.Math.max(x,v)}d.b<d.d.gc()&&(de=Wtt((dn(d.b<d.d.gc()),c(d.d.Xb(d.c=d.b++),26))),x=p.Math.max(x,de),dn(d.b>0),d.a.Xb(d.c=--d.b)),b=.4*i*x,!o&&d.b<d.d.gc()&&(b+=L),se+=a.c.a+b}e.a.a.$b(),t.f.a=se,n.Ug()}function ven(e){var t,n,i,r,o;switch($_(e,Ult),(!e.b&&(e.b=new Et(vn,e,4,7)),e.b).i+(!e.c&&(e.c=new Et(vn,e,5,8)),e.c).i){case 0:throw J(new qt("The edge must have at least one source or target."));case 1:return(!e.b&&(e.b=new Et(vn,e,4,7)),e.b).i==0?Xi(to(c(re((!e.c&&(e.c=new Et(vn,e,5,8)),e.c),0),83))):Xi(to(c(re((!e.b&&(e.b=new Et(vn,e,4,7)),e.b),0),83)))}if((!e.b&&(e.b=new Et(vn,e,4,7)),e.b).i==1&&(!e.c&&(e.c=new Et(vn,e,5,8)),e.c).i==1){if(r=to(c(re((!e.b&&(e.b=new Et(vn,e,4,7)),e.b),0),83)),o=to(c(re((!e.c&&(e.c=new Et(vn,e,5,8)),e.c),0),83)),Xi(r)==Xi(o))return Xi(r);if(r==Xi(o))return r;if(o==Xi(r))return o}for(i=Bd(ma(W(V(Ta,1),Lt,22,0,[(!e.b&&(e.b=new Et(vn,e,4,7)),e.b),(!e.c&&(e.c=new Et(vn,e,5,8)),e.c)]))),t=to(c(sn(i),83));hn(i);)if(n=to(c(sn(i),83)),n!=t&&!nv(n,t)){if(Xi(n)==Xi(t))t=Xi(n);else if(t=HUt(t,n),!t)return null}return t}function Uye(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se;if(M=t.length,M>0&&(b=(en(0,t.length),t.charCodeAt(0)),b!=64)){if(b==37&&(S=t.lastIndexOf("%"),v=!1,S!=0&&(S==M-1||(v=(en(S+1,t.length),t.charCodeAt(S+1)==46))))){if(a=(fs(1,S,t.length),t.substr(1,S-1)),se=Ot("%",a)?null:Jye(a),i=0,v)try{i=Hu((en(S+2,t.length+1),t.substr(S+2)),ls,di)}catch(de){throw de=vr(de),oe(de,133)?(d=de,J(new Uq(d))):J(de)}for(H=ame(e.Dh());H.Ob();)if(P=wH(H),oe(P,508)&&(r=c(P,594),ie=r.d,(se==null?ie==null:Ot(se,ie))&&i--==0))return r;return null}if(x=t.lastIndexOf("."),L=x==-1?t:(fs(0,x,t.length),t.substr(0,x)),n=0,x!=-1)try{n=Hu((en(x+1,t.length+1),t.substr(x+1)),ls,di)}catch(de){if(de=vr(de),oe(de,133))L=t;else throw J(de)}for(L=Ot("%",L)?null:Jye(L),z=ame(e.Dh());z.Ob();)if(P=wH(z),oe(P,199)&&(o=c(P,199),X=o.ve(),(L==null?X==null:Ot(L,X))&&n--==0))return o;return null}return Qrt(e,t)}function yen(e){var t,n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie;for(x=new wn,b=new Qm,i=new G(e.a.a.b);i.a<i.c.c.length;)if(t=c(Q(i),60),v=kx(t),v)gl(x.f,v,t);else if(ie=j5(t),ie)for(o=new G(ie.k);o.a<o.c.c.length;)r=c(Q(o),17),St(b,r,t);for(n=new G(e.a.a.b);n.a<n.c.c.length;)if(t=c(Q(n),60),v=kx(t),v){for(d=new Ht(Vt($i(v).a.Jc(),new U));hn(d);)if(a=c(sn(d),17),!vs(a)&&(P=a.c,X=a.d,!((Je(),vl).Gc(a.c.j)&&vl.Gc(a.d.j)))){if(z=c(Ut(x,a.d.i),60),Of(uf(ff(hf(af(new Ra,0),100),e.c[t.a.d]),e.c[z.a.d])),P.j==Yt&&eqe((_l(),P))){for(M=c(Si(b,a),24).Jc();M.Ob();)if(S=c(M.Pb(),60),S.d.c<t.d.c){if(L=e.c[S.a.d],H=e.c[t.a.d],L==H)continue;Of(uf(ff(hf(af(new Ra,1),100),L),H))}}if(X.j==nn&&tqe((_l(),X))){for(M=c(Si(b,a),24).Jc();M.Ob();)if(S=c(M.Pb(),60),S.d.c>t.d.c){if(L=e.c[t.a.d],H=e.c[S.a.d],L==H)continue;Of(uf(ff(hf(af(new Ra,1),100),L),H))}}}}}function xen(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe;if(M=c(c(Si(e.r,t),24),85),t==(Je(),nn)||t==Yt){est(e,t);return}for(o=t==Kt?(Ym(),qL):(Ym(),HL),de=t==Kt?(hl(),rh):(hl(),Ef),n=c(Zs(e.b,t),129),i=n.i,r=i.c+jx(W(V(ns,1),no,30,15,[n.n.b,e.C.b,e.k])),X=i.c+i.b-jx(W(V(ns,1),no,30,15,[n.n.c,e.C.c,e.k])),a=t1e(p0e(o),e.t),ie=t==Kt?Qr:nr,S=M.Jc();S.Ob();)v=c(S.Pb(),116),!(!v.c||v.c.d.c.length<=0)&&(H=v.b.Kf(),z=v.e,L=v.c,P=L.i,P.b=(b=L.n,L.e.a+b.b+b.c),P.a=(d=L.n,L.e.b+d.d+d.a),$_(de,wxe),L.f=de,Kf(L,(Hl(),Tf)),P.c=z.a-(P.b-H.a)/2,Se=p.Math.min(r,z.a),xe=p.Math.max(X,z.a+H.a),P.c<Se?P.c=Se:P.c+P.b>xe&&(P.c=xe-P.b),qe(a.d,new PZ(P,awe(a,P))),ie=t==Kt?p.Math.max(ie,z.b+v.b.Kf().b):p.Math.min(ie,z.b));for(ie+=t==Kt?e.t:-e.t,se=Ewe((a.e=ie,a)),se>0&&(c(Zs(e.b,t),129).a.b=se),x=M.Jc();x.Ob();)v=c(x.Pb(),116),!(!v.c||v.c.d.c.length<=0)&&(P=v.c.i,P.c-=v.e.a,P.d-=v.e.b)}function ken(e,t){vie();var n,i,r,o,a,d,b,v,x,S,M,L,P,z;if(b=Mc(e,0)<0,b&&(e=Ng(e)),Mc(e,0)==0)switch(t){case 0:return"0";case 1:return JS;case 2:return"0.00";case 3:return"0.000";case 4:return"0.0000";case 5:return"0.00000";case 6:return"0.000000";default:return L=new b0,t<0?L.a+="0E+":L.a+="0E",L.a+=t==ls?"2147483648":""+-t,L.a}x=18,S=ye(Na,fd,30,x+1,15,1),n=x,z=e;do v=z,z=ID(z,10),S[--n]=Hn(As(48,Ha(v,Ss(z,10))))&_r;while(Mc(z,0)!=0);if(r=Ha(Ha(Ha(x,n),t),1),t==0)return b&&(S[--n]=45),od(S,n,x-n);if(t>0&&Mc(r,-6)>=0){if(Mc(r,0)>=0){for(o=n+Hn(r),d=x-1;d>=o;d--)S[d+1]=S[d];return S[++o]=46,b&&(S[--n]=45),od(S,n,x-n+1)}for(a=2;dY(a,As(Ng(r),1));a++)S[--n]=48;return S[--n]=46,S[--n]=48,b&&(S[--n]=45),od(S,n,x-n)}return P=n+1,i=x,M=new Z4,b&&(M.a+="-"),i-P>=1?(Kp(M,S[n]),M.a+=".",M.a+=od(S,n+1,x-n-1)):M.a+=od(S,n,x-n),M.a+="E",Mc(r,0)>0&&(M.a+="+"),M.a+=""+R7(r),M.a}function cst(e){Am(e,new mb(JN(Em(Sm(Tm(jm(new b1,Oa),"ELK Radial"),'A radial layout provider which is based on the algorithm of Peter Eades published in "Drawing free trees.", published by International Institute for Advanced Study of Social Information Science, Fujitsu Limited in 1991. The radial layouter takes a tree and places the nodes in radial order around the root. The nodes of the same tree level are placed on the same radius.'),new NA),Oa))),Ie(e,Oa,mG,Ve(Rbt)),Ie(e,Oa,dw,Ve($bt)),Ie(e,Oa,Jx,Ve(Dbt)),Ie(e,Oa,ok,Ve(Lbt)),Ie(e,Oa,sk,Ve(Pbt)),Ie(e,Oa,i9,Ve(_bt)),Ie(e,Oa,t9,Ve(y8e)),Ie(e,Oa,r9,Ve(Ibt)),Ie(e,Oa,Tse,Ve(oue)),Ie(e,Oa,jse,Ve(cue)),Ie(e,Oa,OG,Ve(k8e)),Ie(e,Oa,Ese,Ve(lue)),Ie(e,Oa,Cse,Ve(O8e)),Ie(e,Oa,O4e,Ve(S8e)),Ie(e,Oa,k4e,Ve(x8e)),Ie(e,Oa,w4e,Ve(MJ)),Ie(e,Oa,v4e,Ve(AJ)),Ie(e,Oa,y4e,Ve(yP)),Ie(e,Oa,x4e,Ve(j8e)),Ie(e,Oa,m4e,Ve(v8e))}function uw(e,t,n,i,r){var o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe;if(H=new $e(e.g,e.f),z=nve(e),z.a=p.Math.max(z.a,t),z.b=p.Math.max(z.b,n),xe=z.a/H.a,x=z.b/H.b,de=z.a-H.a,b=z.b-H.b,i)for(a=Xi(e)?c(ke(Xi(e),(Dn(),Fb)),87):c(ke(e,(Dn(),Fb)),87),d=ve(ke(e,(Dn(),Y9)))===ve((Zr(),xc)),ie=new cn((!e.c&&(e.c=new Me(hu,e,9,9)),e.c));ie.e!=ie.i.gc();)switch(X=c(un(ie),127),se=c(ke(X,M3),64),se==(Je(),$o)&&(se=Sye(X,a),ii(X,M3,se)),se.g){case 1:d||Cc(X,X.i*xe);break;case 2:Cc(X,X.i+de),d||Nl(X,X.j*x);break;case 3:d||Cc(X,X.i*xe),Nl(X,X.j+b);break;case 4:d||Nl(X,X.j*x)}if(_m(e,z.a,z.b),r)for(M=new cn((!e.n&&(e.n=new Me(Bo,e,1,7)),e.n));M.e!=M.i.gc();)S=c(un(M),158),L=S.i+S.g/2,P=S.j+S.f/2,Se=L/H.a,v=P/H.b,Se+v>=1&&(Se-v>0&&P>=0?(Cc(S,S.i+de),Nl(S,S.j+b*v)):Se-v<0&&L>=0&&(Cc(S,S.i+de*Se),Nl(S,S.j+b)));return ii(e,(Dn(),qb),(Cu(),o=c(Jf(BC),10),new ha(o,c(gf(o,o.length),10),0))),new $e(xe,x)}function BQ(e){var t,n,i,r,o,a,d,b,v,x,S;if(e==null)throw J(new Yh(pl));if(v=e,o=e.length,b=!1,o>0&&(t=(en(0,e.length),e.charCodeAt(0)),(t==45||t==43)&&(e=(en(1,e.length+1),e.substr(1)),--o,b=t==45)),o==0)throw J(new Yh(hw+v+'"'));for(;e.length>0&&(en(0,e.length),e.charCodeAt(0)==48);)e=(en(1,e.length+1),e.substr(1)),--o;if(o>(Pit(),$at)[10])throw J(new Yh(hw+v+'"'));for(r=0;r<o;r++)if(PKe((en(r,e.length),e.charCodeAt(r)))==-1)throw J(new Yh(hw+v+'"'));for(S=0,a=nke[10],x=_oe[10],d=Ng(ike[10]),n=!0,i=o%a,i>0&&(S=-parseInt((fs(0,i,e.length),e.substr(0,i)),10),e=(en(i,e.length+1),e.substr(i)),o-=i,n=!1);o>=a;){if(i=parseInt((fs(0,a,e.length),e.substr(0,a)),10),e=(en(a,e.length+1),e.substr(a)),o-=a,n)n=!1;else{if(Mc(S,d)<0)throw J(new Yh(hw+v+'"'));S=Ss(S,x)}S=Ha(S,i)}if(Mc(S,0)>0)throw J(new Yh(hw+v+'"'));if(!b&&(S=Ng(S),Mc(S,0)<0))throw J(new Yh(hw+v+'"'));return S}function Jye(e){jie();var t,n,i,r,o,a,d,b;if(e==null)return null;if(r=Zh(e,dl(37)),r<0)return e;for(b=new Lu((fs(0,r,e.length),e.substr(0,r))),t=ye(Rl,Yx,30,4,15,1),d=0,i=0,a=e.length;r<a;r++)if(en(r,e.length),e.charCodeAt(r)==37&&e.length>r+2&&Ste((en(r+1,e.length),e.charCodeAt(r+1)),kTe,OTe)&&Ste((en(r+2,e.length),e.charCodeAt(r+2)),kTe,OTe))if(n=ACt((en(r+1,e.length),e.charCodeAt(r+1)),(en(r+2,e.length),e.charCodeAt(r+2))),r+=2,i>0?(n&192)==128?t[d++]=n<<24>>24:i=0:n>=128&&((n&224)==192?(t[d++]=n<<24>>24,i=2):(n&240)==224?(t[d++]=n<<24>>24,i=3):(n&248)==240&&(t[d++]=n<<24>>24,i=4)),i>0){if(d==i){switch(d){case 2:{Kp(b,((t[0]&31)<<6|t[1]&63)&_r);break}case 3:{Kp(b,((t[0]&15)<<12|(t[1]&63)<<6|t[2]&63)&_r);break}}d=0,i=0}}else{for(o=0;o<d;++o)Kp(b,t[o]&_r);d=0,b.a+=String.fromCharCode(n)}else{for(o=0;o<d;++o)Kp(b,t[o]&_r);d=0,Kp(b,(en(r,e.length),e.charCodeAt(r)))}return b.a}function lst(e){var t,n,i,r,o,a,d,b,v,x,S,M,L,P;if(L=Xi(to(c(re((!e.b&&(e.b=new Et(vn,e,4,7)),e.b),0),83))),P=Xi(to(c(re((!e.c&&(e.c=new Et(vn,e,5,8)),e.c),0),83))),S=L==P,d=new as,t=c(ke(e,(SH(),F7e)),79),t&&t.b>=2){if((!e.a&&(e.a=new Me(Hi,e,6,6)),e.a).i==0)n=(w0(),r=new VO,r),Nn((!e.a&&(e.a=new Me(Hi,e,6,6)),e.a),n);else if((!e.a&&(e.a=new Me(Hi,e,6,6)),e.a).i>1)for(M=new f5((!e.a&&(e.a=new Me(Hi,e,6,6)),e.a));M.e!=M.i.gc();)MT(M);Tye(t,c(re((!e.a&&(e.a=new Me(Hi,e,6,6)),e.a),0),171))}if(S)for(i=new cn((!e.a&&(e.a=new Me(Hi,e,6,6)),e.a));i.e!=i.i.gc();)for(n=c(un(i),171),v=new cn((!n.a&&(n.a=new Ar(Yu,n,5)),n.a));v.e!=v.i.gc();)b=c(un(v),373),d.a=p.Math.max(d.a,b.a),d.b=p.Math.max(d.b,b.b);for(a=new cn((!e.n&&(e.n=new Me(Bo,e,1,7)),e.n));a.e!=a.i.gc();)o=c(un(a),158),x=c(ke(o,DC),8),x&&aa(o,x.a,x.b),S&&(d.a=p.Math.max(d.a,o.i+o.g),d.b=p.Math.max(d.b,o.j+o.f));return d}function ust(e,t,n,i,r){var o,a,d;if(MJe(e,t),a=t[0],o=ms(n.c,0),d=-1,Bme(n))if(i>0){if(a+i>e.length)return!1;d=gQ((fs(0,a+i,e.length),e.substr(0,a+i)),t)}else d=gQ(e,t);switch(o){case 71:return d=Rx(e,a,W(V(nt,1),Be,2,6,[Vst,Wst]),t),r.e=d,!0;case 77:return BXt(e,t,r,d,a);case 76:return zXt(e,t,r,d,a);case 69:return BQt(e,t,a,r);case 99:return zQt(e,t,a,r);case 97:return d=Rx(e,a,W(V(nt,1),Be,2,6,["AM","PM"]),t),r.b=d,!0;case 121:return FXt(e,t,a,d,n,r);case 100:return d<=0?!1:(r.c=d,!0);case 83:return d<0?!1:Z$t(d,a,t[0],r);case 104:d==12&&(d=0);case 75:case 72:return d<0?!1:(r.f=d,r.g=!1,!0);case 107:return d<0?!1:(r.f=d,r.g=!0,!0);case 109:return d<0?!1:(r.j=d,!0);case 115:return d<0?!1:(r.n=d,!0);case 90:if(a<e.length&&(en(a,e.length),e.charCodeAt(a)==90))return++t[0],r.o=0,!0;case 122:case 118:return fHt(e,a,t,r);default:return!1}}function Oen(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt;for(se=t.c.length,r=new zx(e.a,n,null,null),pt=ye(ns,no,30,se,15,1),z=ye(ns,no,30,se,15,1),P=ye(ns,no,30,se,15,1),H=0,d=0;d<se;d++)z[d]=di,P[d]=ls;for(b=0;b<se;b++)for(i=(ht(b,t.c.length),c(t.c[b],188)),pt[b]=Yne(i),pt[H]>pt[b]&&(H=b),S=new G(e.a.b);S.a<S.c.c.length;)for(x=c(Q(S),26),ie=new G(x.a);ie.a<ie.c.c.length;)X=c(Q(ie),9),xe=ue(i.p[X.p])+ue(i.d[X.p]),z[b]=p.Math.min(z[b],xe),P[b]=p.Math.max(P[b],xe+X.o.b);for(We=ye(ns,no,30,se,15,1),v=0;v<se;v++)(ht(v,t.c.length),c(t.c[v],188)).o==(vh(),Bb)?We[v]=z[H]-z[v]:We[v]=P[H]-P[v];for(o=ye(ns,no,30,se,15,1),L=new G(e.a.b);L.a<L.c.c.length;)for(M=c(Q(L),26),Se=new G(M.a);Se.a<Se.c.c.length;){for(de=c(Q(Se),9),a=0;a<se;a++)o[a]=ue((ht(a,t.c.length),c(t.c[a],188)).p[de.p])+ue((ht(a,t.c.length),c(t.c[a],188)).d[de.p])+We[a];ZDe(o,gXe(He.prototype.Ke,He,[])),r.p[de.p]=(o[1]+o[2])/2,r.d[de.p]=0}return r}function Sen(e,t,n){var i,r,o,a,d;switch(i=t.i,o=e.i.o,r=e.i.d,d=e.n,a=Lo(W(V(Vr,1),Be,8,0,[d,e.a])),e.j.g){case 1:ed(t,(hl(),Ef)),i.d=-r.d-n-i.a,c(c(Xe(t.d,0),190).mf((De(),xk)),293)==(qu(),n1)?(Kf(t,(Hl(),Tf)),i.c=a.a-ue(he(R(e,f3)))-n-i.b):(Kf(t,(Hl(),wd)),i.c=a.a+ue(he(R(e,f3)))+n);break;case 2:Kf(t,(Hl(),wd)),i.c=o.a+r.c+n,c(c(Xe(t.d,0),190).mf((De(),xk)),293)==(qu(),n1)?(ed(t,(hl(),Ef)),i.d=a.b-ue(he(R(e,f3)))-n-i.a):(ed(t,(hl(),rh)),i.d=a.b+ue(he(R(e,f3)))+n);break;case 3:ed(t,(hl(),rh)),i.d=o.b+r.a+n,c(c(Xe(t.d,0),190).mf((De(),xk)),293)==(qu(),n1)?(Kf(t,(Hl(),Tf)),i.c=a.a-ue(he(R(e,f3)))-n-i.b):(Kf(t,(Hl(),wd)),i.c=a.a+ue(he(R(e,f3)))+n);break;case 4:Kf(t,(Hl(),Tf)),i.c=-r.b-n-i.b,c(c(Xe(t.d,0),190).mf((De(),xk)),293)==(qu(),n1)?(ed(t,(hl(),Ef)),i.d=a.b-ue(he(R(e,f3)))-n-i.a):(ed(t,(hl(),rh)),i.d=a.b+ue(he(R(e,f3)))+n)}}function jen(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie;for(t.Tg("Interactive node layering",1),n=new Fe,M=new G(e.a);M.a<M.c.c.length;){for(x=c(Q(M),9),b=x.n.a,d=b+x.o.a,d=p.Math.max(b+1,d),ie=new os(n,0),i=null;ie.b<ie.d.gc();)if(H=(dn(ie.b<ie.d.gc()),c(ie.d.Xb(ie.c=ie.b++),571)),H.c>=d){dn(ie.b>0),ie.a.Xb(ie.c=--ie.b);break}else H.a>b&&(i?(yr(i.b,H.b),i.a=p.Math.max(i.a,H.a),iu(ie)):(qe(H.b,x),H.c=p.Math.min(H.c,b),H.a=p.Math.max(H.a,d),i=H));i||(i=new pLe,i.c=b,i.a=d,z2(ie,i),qe(i.b,x))}for(a=e.b,v=0,X=new G(n);X.a<X.c.c.length;)for(H=c(Q(X),571),r=new hc(e),r.p=v++,It(a.c,r),L=new G(H.b);L.a<L.c.c.length;)x=c(Q(L),9),zr(x,r),x.p=0;for(S=new G(e.a);S.a<S.c.c.length;)if(x=c(Q(S),9),x.p==0)for(z=Unt(x,e);z.a.gc()!=0;)P=c(z.a.ec().Jc().Pb(),9),z.a.Ac(P)!=null,Os(z,Unt(P,e));for(o=new os(a,0);o.b<o.d.gc();)(dn(o.b<o.d.gc()),c(o.d.Xb(o.c=o.b++),26)).a.c.length==0&&iu(o);e.a.c.length=0,t.Ug()}function Ten(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z;for(n.Tg(Lct,1),!t.a&&(t.a=new Me(Mn,t,10,11)),i=ue(he(ke(t,(Ah(),LJ)))),x=ue(he(ke(t,xC))),M=c(ke(t,yC),100),L=new V1e(i,x),o=Tst(L,t,M),lXe(t,L),d=c(ke(t,Q8e),15).a;d>1;){if(r=_Jt(t),S=o.g,P=c(ke(t,yC),100),z=ue(he(ke(t,LJ))),(!t.a&&(t.a=new Me(Mn,t,10,11)),t.a).i>1&&ue(he(ke(t,(Gd(),mue))))!=nr&&(o.c+(P.b+P.c))/(o.b+(P.d+P.a))<z?ii(r,(Gd(),Yv),ue(he(ke(t,Yv)))+ue(he(ke(t,mue)))):(!t.a&&(t.a=new Me(Mn,t,10,11)),t.a).i>1&&ue(he(ke(t,(Gd(),bue))))!=nr&&(o.c+(P.b+P.c))/(o.b+(P.d+P.a))>z&&ii(r,(Gd(),Yv),p.Math.max(ue(he(ke(t,vC))),ue(he(ke(r,Yv)))-ue(he(ke(t,bue))))),L=new V1e(i,x),b=Tst(L,r,M),v=b.g,v>=S&&v==v){for(a=0;a<(!r.a&&(r.a=new Me(Mn,r,10,11)),r.a).i;a++)Uet(e,c(re((!r.a&&(r.a=new Me(Mn,r,10,11)),r.a),a),19),c(re((!t.a&&(t.a=new Me(Mn,t,10,11)),t.a),a),19));lXe(t,L),dNt(o,b.c),gNt(o,b.b)}--d}ii(t,(Gd(),J9),o.b),ii(t,Ck,o.c),n.Ug()}function Een(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt;for(t.Tg("Compound graph postprocessor",1),n=et(Ze(R(e,(Ge(),ble)))),d=c(R(e,(De(),b6e)),231),x=new Or,X=d.ec().Jc();X.Ob();){for(H=c(X.Pb(),17),a=new Fl(d.cc(H)),Ct(),Rr(a,new wde(e)),Se=pIt((ht(0,a.c.length),c(a.c[0],253))),We=sVe(c(Xe(a,a.c.length-1),253)),se=Se.i,sS(We.i,se)?ie=se.e:ie=Jr(se),S=izt(H,a),Ou(H.a),M=null,o=new G(a);o.a<o.c.c.length;)r=c(Q(o),253),z=new as,Z2e(z,r.a,ie),L=r.b,i=new nu,Lte(i,0,L.a),rv(i,z),de=new Cs(xh(L.c)),xe=new Cs(xh(L.d)),ki(de,z),ki(xe,z),M&&(i.b==0?P=xe:P=(dn(i.b!=0),c(i.a.a.c,8)),pt=p.Math.abs(M.a-P.a)>dd,bt=p.Math.abs(M.b-P.b)>dd,(!n&&pt&&bt||n&&(pt||bt))&&ei(H.a,de)),Os(H.a,i),i.b==0?M=de:M=(dn(i.b!=0),c(i.c.b.c,8)),zIt(L,S,z),sVe(r)==We&&(Jr(We.i)!=r.a&&(z=new as,Z2e(z,Jr(We.i),ie)),Ee(H,Wce,z)),nQt(L,H,ie),x.a.yc(L,x);ks(H,Se),ss(H,We)}for(v=x.a.ec().Jc();v.Ob();)b=c(v.Pb(),17),ks(b,null),ss(b,null);t.Ug()}function Cen(e,t){var n,i,r,o,a,d,b,v,x,S,M;for(r=c(R(e,(Uo(),Iw)),87),x=r==(Nr(),go)||r==yo?Fh:yo,n=c(ql(pi(new jt(null,new Tt(e.b,16)),new Vy),su(new Ls,new rs,new mo,W(V(ml,1),_e,132,0,[(va(),bl)]))),16),b=c(ql(qc(n.Mc(),new $_e(t)),su(new Ls,new rs,new mo,W(V(ml,1),_e,132,0,[bl]))),16),b.Fc(c(ql(qc(n.Mc(),new B_e(t)),su(new Ls,new rs,new mo,W(V(ml,1),_e,132,0,[bl]))),18)),b.gd(new z_e(x)),M=new kg(new F_e(r)),i=new wn,d=b.Jc();d.Ob();)a=c(d.Pb(),243),v=c(a.a,41),et(Ze(a.c))?(M.a.yc(v,(Bt(),K0))==null,new h6(M.a.Xc(v,!1)).a.gc()>0&&oi(i,v,c(new h6(M.a.Xc(v,!1)).a.Tc(),41)),new h6(M.a.$c(v,!0)).a.gc()>1&&oi(i,bKe(M,v),v)):(new h6(M.a.Xc(v,!1)).a.gc()>0&&(o=c(new h6(M.a.Xc(v,!1)).a.Tc(),41),ve(o)===ve(Ao(co(i.f,v)))&&c(R(v,(Li(),Fle)),16).Ec(o)),new h6(M.a.$c(v,!0)).a.gc()>1&&(S=bKe(M,v),ve(Ao(co(i.f,S)))===ve(v)&&c(R(S,(Li(),Fle)),16).Ec(v)),M.a.Ac(v)!=null)}function ast(e){var t,n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de;if(e.gc()==1)return c(e.Xb(0),238);if(e.gc()<=0)return new Rq;for(r=e.Jc();r.Ob();){for(n=c(r.Pb(),238),P=0,x=di,S=di,b=ls,v=ls,L=new G(n.e);L.a<L.c.c.length;)M=c(Q(L),156),P+=c(R(M,(Sf(),dk)),15).a,x=p.Math.min(x,M.d.a-M.e.a/2),S=p.Math.min(S,M.d.b-M.e.b/2),b=p.Math.max(b,M.d.a+M.e.a/2),v=p.Math.max(v,M.d.b+M.e.b/2);Ee(n,(Sf(),dk),Pe(P)),Ee(n,(N0(),DE),new $e(x,S)),Ee(n,QL,new $e(b,v))}for(Ct(),e.gd(new M8),z=new Rq,ec(z,c(e.Xb(0),105)),d=0,ie=0,o=e.Jc();o.Ob();)n=c(o.Pb(),238),H=Hr(Ms(c(R(n,(N0(),QL)),8)),c(R(n,DE),8)),d=p.Math.max(d,H.a),ie+=H.a*H.b;for(d=p.Math.max(d,p.Math.sqrt(ie)*ue(he(R(z,(Sf(),Kft))))),X=ue(he(R(z,cU))),se=0,de=0,a=0,t=X,i=e.Jc();i.Ob();)n=c(i.Pb(),238),H=Hr(Ms(c(R(n,(N0(),QL)),8)),c(R(n,DE),8)),se+H.a>d&&(se=0,de+=a+X,a=0),ZVt(z,n,se,de),t=p.Math.max(t,se+H.a),a=p.Math.max(a,H.b),se+=H.a+X;return z}function Men(e){Oye();var t,n,i,r,o,a,d,b,v,x,S,M,L,P,z,H;if(e==null||(o=Xq(e),P=d$t(o),P%4!=0))return null;if(z=P/4|0,z==0)return ye(Rl,Yx,30,0,15,1);for(S=null,t=0,n=0,i=0,r=0,a=0,d=0,b=0,v=0,L=0,M=0,x=0,S=ye(Rl,Yx,30,z*3,15,1);L<z-1;L++){if(!KN(a=o[x++])||!KN(d=o[x++])||!KN(b=o[x++])||!KN(v=o[x++]))return null;t=Uh[a],n=Uh[d],i=Uh[b],r=Uh[v],S[M++]=(t<<2|n>>4)<<24>>24,S[M++]=((n&15)<<4|i>>2&15)<<24>>24,S[M++]=(i<<6|r)<<24>>24}return!KN(a=o[x++])||!KN(d=o[x++])?null:(t=Uh[a],n=Uh[d],b=o[x++],v=o[x++],Uh[b]==-1||Uh[v]==-1?b==61&&v==61?(n&15)!=0?null:(H=ye(Rl,Yx,30,L*3+1,15,1),mc(S,0,H,0,L*3),H[M]=(t<<2|n>>4)<<24>>24,H):b!=61&&v==61?(i=Uh[b],(i&3)!=0?null:(H=ye(Rl,Yx,30,L*3+2,15,1),mc(S,0,H,0,L*3),H[M++]=(t<<2|n>>4)<<24>>24,H[M]=((n&15)<<4|i>>2&15)<<24>>24,H)):null:(i=Uh[b],r=Uh[v],S[M++]=(t<<2|n>>4)<<24>>24,S[M++]=((n&15)<<4|i>>2&15)<<24>>24,S[M++]=(i<<6|r)<<24>>24,S))}function Aen(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se;for(t.Tg(tct,1),P=c(R(e,(Ge(),W1)),225),r=new G(e.b);r.a<r.c.c.length;)for(i=c(Q(r),26),v=q_(i.a),a=v,d=0,b=a.length;d<b;++d)if(o=a[d],o.k==(Jt(),Dc)){if(P==($1(),Ik))for(S=new G(o.j);S.a<S.c.c.length;)x=c(Q(S),12),x.e.c.length==0||RBt(x),x.g.c.length==0||$Bt(x);else if(oe(R(o,(De(),Oi)),17))H=c(R(o,Oi),17),X=c(Bg(o,(Je(),Yt)).Jc().Pb(),12),ie=c(Bg(o,nn).Jc().Pb(),12),se=c(R(X,Oi),12),de=c(R(ie,Oi),12),ks(H,de),ss(H,se),Se=new Cs(ie.i.n),Se.a=Lo(W(V(Vr,1),Be,8,0,[de.i.n,de.n,de.a])).a,ei(H.a,Se),Se=new Cs(X.i.n),Se.a=Lo(W(V(Vr,1),Be,8,0,[se.i.n,se.n,se.a])).a,ei(H.a,Se);else{if(o.j.c.length>=2){for(z=!0,M=new G(o.j),n=c(Q(M),12),L=null;M.a<M.c.c.length;)if(L=n,n=c(Q(M),12),!yi(R(L,Oi),R(n,Oi))){z=!1;break}}else z=!1;for(S=new G(o.j);S.a<S.c.c.length;)x=c(Q(S),12),x.e.c.length==0||oXt(x,z),x.g.c.length==0||cXt(x,z)}zr(o,null)}t.Ug()}function Nen(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se;for(d=new G(e.a.b);d.a<d.c.c.length;)for(o=c(Q(d),26),se=new G(o.a);se.a<se.c.c.length;)ie=c(Q(se),9),t.g[ie.p]=ie,t.a[ie.p]=ie,t.d[ie.p]=0;for(b=e.a.b,t.c==(td(),Wg)&&(b=Eu(b)),a=b.Jc();a.Ob();)for(o=c(a.Pb(),26),L=-1,M=o.a,t.o==(vh(),Rh)&&(L=di,M=Eu(M)),Se=M.Jc();Se.Ob();)if(de=c(Se.Pb(),9),S=null,t.c==Wg?S=c(Xe(e.b.f,de.p),16):S=c(Xe(e.b.b,de.p),16),S.gc()>0)if(i=S.gc(),v=xs(p.Math.floor((i+1)/2))-1,r=xs(p.Math.ceil((i+1)/2))-1,t.o==Rh)for(x=r;x>=v;x--)t.a[de.p]==de&&(z=c(S.Xb(x),49),P=c(z.a,9),!$a(n,z.b)&&L>e.b.e[P.p]&&(t.a[P.p]=de,t.g[de.p]=t.g[P.p],t.a[de.p]=t.g[de.p],t.f[t.g[de.p].p]=(Bt(),!!(et(t.f[t.g[de.p].p])&de.k==(Jt(),jr))),L=e.b.e[P.p]));else for(x=v;x<=r;x++)t.a[de.p]==de&&(X=c(S.Xb(x),49),H=c(X.a,9),!$a(n,X.b)&&L<e.b.e[H.p]&&(t.a[H.p]=de,t.g[de.p]=t.g[H.p],t.a[de.p]=t.g[de.p],t.f[t.g[de.p].p]=(Bt(),!!(et(t.f[t.g[de.p].p])&de.k==(Jt(),jr))),L=e.b.e[H.p]))}function fst(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt;return se=e.c[(ht(0,t.c.length),c(t.c[0],17)).p],We=e.c[(ht(1,t.c.length),c(t.c[1],17)).p],se.a.e.e-se.a.a-(se.b.e.e-se.b.a)==0&&We.a.e.e-We.a.a-(We.b.e.e-We.b.a)==0||(X=se.b.e.f,!oe(X,9))?!1:(H=c(X,9),Se=e.i[H.p],xe=H.c?Do(H.c.a,H,0):-1,o=nr,xe>0&&(r=c(Xe(H.c.a,xe-1),9),a=e.i[r.p],pt=p.Math.ceil(px(e.n,r,H)),o=Se.a.e-H.d.d-(a.a.e+r.o.b+r.d.a)-pt),v=nr,xe<H.c.a.c.length-1&&(b=c(Xe(H.c.a,xe+1),9),x=e.i[b.p],pt=p.Math.ceil(px(e.n,b,H)),v=x.a.e-b.d.d-(Se.a.e+H.o.b+H.d.a)-pt),n&&(mh(),vf(pd),p.Math.abs(o-v)<=pd||o==v||isNaN(o)&&isNaN(v))?!0:(i=JZ(se.a),d=-JZ(se.b),S=-JZ(We.a),ie=JZ(We.b),z=se.a.e.e-se.a.a-(se.b.e.e-se.b.a)>0&&We.a.e.e-We.a.a-(We.b.e.e-We.b.a)<0,P=se.a.e.e-se.a.a-(se.b.e.e-se.b.a)<0&&We.a.e.e-We.a.a-(We.b.e.e-We.b.a)>0,L=se.a.e.e+se.b.a<We.b.e.e+We.a.a,M=se.a.e.e+se.b.a>We.b.e.e+We.a.a,de=0,!z&&!P&&(M?o+S>0?de=S:v-i>0&&(de=i):L&&(o+d>0?de=d:v-ie>0&&(de=ie))),Se.a.e+=de,Se.b&&(Se.d.e+=de),!1))}function hst(e,t,n){var i,r,o,a,d,b,v,x,S,M;if(i=new pf(t.Jf().a,t.Jf().b,t.Kf().a,t.Kf().b),r=new c5,e.c)for(a=new G(t.Pf());a.a<a.c.c.length;)o=c(Q(a),190),r.c=o.Jf().a+t.Jf().a,r.d=o.Jf().b+t.Jf().b,r.b=o.Kf().a,r.a=o.Kf().b,AT(i,r);for(v=new G(t.Vf());v.a<v.c.c.length;){if(b=c(Q(v),844),x=b.Jf().a+t.Jf().a,S=b.Jf().b+t.Jf().b,e.e&&(r.c=x,r.d=S,r.b=b.Kf().a,r.a=b.Kf().b,AT(i,r)),e.d)for(a=new G(b.Pf());a.a<a.c.c.length;)o=c(Q(a),190),r.c=o.Jf().a+x,r.d=o.Jf().b+S,r.b=o.Kf().a,r.a=o.Kf().b,AT(i,r);if(e.b){if(M=new $e(-n,-n),c(t.mf((Dn(),iy)),185).Gc((Ql(),hp)))for(a=new G(b.Pf());a.a<a.c.c.length;)o=c(Q(a),190),M.a+=o.Kf().a+n,M.b+=o.Kf().b+n;M.a=p.Math.max(M.a,0),M.b=p.Math.max(M.b,0),Ait(i,b.Uf(),b.Sf(),t,b,M,n)}}e.b&&Ait(i,t.Uf(),t.Sf(),t,null,null,n),d=new kZ(t.Tf()),d.d=p.Math.max(0,t.Jf().b-i.d),d.a=p.Math.max(0,i.d+i.a-(t.Jf().b+t.Kf().b)),d.b=p.Math.max(0,t.Jf().a-i.c),d.c=p.Math.max(0,i.c+i.b-(t.Jf().a+t.Kf().a)),t.Xf(d)}function _en(){var e=["\\u0000","\\u0001","\\u0002","\\u0003","\\u0004","\\u0005","\\u0006","\\u0007","\\b","\\t","\\n","\\u000B","\\f","\\r","\\u000E","\\u000F","\\u0010","\\u0011","\\u0012","\\u0013","\\u0014","\\u0015","\\u0016","\\u0017","\\u0018","\\u0019","\\u001A","\\u001B","\\u001C","\\u001D","\\u001E","\\u001F"];return e[34]='\\"',e[92]="\\\\",e[173]="\\u00ad",e[1536]="\\u0600",e[1537]="\\u0601",e[1538]="\\u0602",e[1539]="\\u0603",e[1757]="\\u06dd",e[1807]="\\u070f",e[6068]="\\u17b4",e[6069]="\\u17b5",e[8203]="\\u200b",e[8204]="\\u200c",e[8205]="\\u200d",e[8206]="\\u200e",e[8207]="\\u200f",e[8232]="\\u2028",e[8233]="\\u2029",e[8234]="\\u202a",e[8235]="\\u202b",e[8236]="\\u202c",e[8237]="\\u202d",e[8238]="\\u202e",e[8288]="\\u2060",e[8289]="\\u2061",e[8290]="\\u2062",e[8291]="\\u2063",e[8292]="\\u2064",e[8298]="\\u206a",e[8299]="\\u206b",e[8300]="\\u206c",e[8301]="\\u206d",e[8302]="\\u206e",e[8303]="\\u206f",e[65279]="\\ufeff",e[65529]="\\ufff9",e[65530]="\\ufffa",e[65531]="\\ufffb",e}function dst(e){Am(e,new mb(rY(JN(Em(Sm(Tm(jm(new b1,il),"ELK Force"),"Force-based algorithm provided by the Eclipse Layout Kernel. Implements methods that follow physical analogies by simulating forces that move the nodes into a balanced distribution. Currently the original Eades model and the Fruchterman - Reingold model are supported."),new bO),il),_i((V5(),XP),W(V(VP,1),_e,235,0,[JP]))))),Ie(e,il,wL,Pe(1)),Ie(e,il,dw,80),Ie(e,il,Ore,5),Ie(e,il,ZS,YS),Ie(e,il,WQ,Pe(1)),Ie(e,il,rE,(Bt(),!0)),Ie(e,il,gw,Ake),Ie(e,il,e9,Ve(Eke)),Ie(e,il,KQ,Ve(Nke)),Ie(e,il,vL,!1),Ie(e,il,t9,Ve(Mke)),Ie(e,il,n9,Ve(tht)),Ie(e,il,sk,Ve(nht)),Ie(e,il,Jx,Ve(eht)),Ie(e,il,i9,Ve(Zft)),Ie(e,il,r9,Ve(rht)),Ie(e,il,VQ,Ve(Cke)),Ie(e,il,xre,Ve(Voe)),Ie(e,il,Oxe,Ve(oU)),Ie(e,il,kre,Ve(Xoe)),Ie(e,il,Sxe,Ve(_ke)),Ie(e,il,yL,Ve(aht)),Ie(e,il,xL,Ve(fht)),Ie(e,il,kL,Ve(uht)),Ie(e,il,OL,Ve(lht)),Ie(e,il,pw,Dke)}function Den(e,t,n,i){var r,o,a,d,b,v,x,S,M,L,P,z,H,X;for(L=c(Xe((ht(0,t.c.length),c(t.c[0],26)).a,i),9),n>0&&zr(L,(ht(n,t.c.length),c(t.c[n],26))),o=0,M=!0,X=Eu(tb(pr(L))),b=X.Jc();b.Ob();){for(d=c(b.Pb(),17),M=!1,S=d,v=0;v<n;v++)r=IWe(e,S),i+o>(ht(v,t.c.length),c(t.c[v],26)).a.c.length?zr(r,(ht(v,t.c.length),c(t.c[v],26))):B0(r,i+o,(ht(v,t.c.length),c(t.c[v],26))),S=tie(S,r);n>0&&(o+=1)}if(M){for(v=0;v<n;v++)r=new Eh(e),mu(r,(Jt(),UL)),i+o>(ht(v,t.c.length),c(t.c[v],26)).a.c.length?zr(r,(ht(v,t.c.length),c(t.c[v],26))):B0(r,i+o,(ht(v,t.c.length),c(t.c[v],26)));n>0&&(o+=1)}for(a=!1,z=new Ht(Vt($i(L).a.Jc(),new U));hn(z);){for(P=c(sn(z),17),S=P,x=n+1;x<t.c.length;x++)r=IWe(e,S),zr(r,(ht(x,t.c.length),c(t.c[x],26))),S=tie(S,r);for(v=0;v<=n;v++)a&&(H=new Eh(e),mu(H,(Jt(),PE)),i+1>(ht(v,t.c.length),c(t.c[v],26)).a.c.length?zr(H,(ht(v,t.c.length),c(t.c[v],26))):B0(H,i+1,(ht(v,t.c.length),c(t.c[v],26))));a&&(o+=1),a=!0}return o>0?o-1:0}function Q0(e,t){wi();var n,i,r,o,a,d,b,v,x,S,M,L,P;if(r7(l8)==0){for(S=ye(unn,Be,122,Ovt.length,0,1),a=0;a<S.length;a++)S[a]=new $u(4);for(i=new t7,o=0;o<XTe.length;o++){if(x=new $u(4),o<84?(d=o*2,L=(en(d,yoe.length),yoe.charCodeAt(d)),M=(en(d+1,yoe.length),yoe.charCodeAt(d+1)),Ac(x,L,M)):(d=(o-84)*2,Ac(x,VTe[d],VTe[d+1])),b=XTe[o],Ot(b,"Specials")&&Ac(x,65520,65533),Ot(b,mat)&&(Ac(x,983040,1048573),Ac(x,1048576,1114109)),lo(l8,b,x),lo(WC,b,yv(x)),v=i.a.length,0<v?i.a=Fa(i.a,0,0):0>v&&(i.a+=J$e(ye(Na,fd,30,-v,15,1))),i.a+="Is",Zh(b,dl(32))>=0)for(r=0;r<b.length;r++)en(r,b.length),b.charCodeAt(r)!=32&&z6(i,(en(r,b.length),b.charCodeAt(r)));else i.a+=""+b;Lwe(i.a,b,!0)}Lwe(voe,"Cn",!1),Lwe(B5e,"Cn",!0),n=new $u(4),Ac(n,0,y9),lo(l8,"ALL",n),lo(WC,"ALL",yv(n)),!gy&&(gy=new wn),lo(gy,voe,voe),!gy&&(gy=new wn),lo(gy,B5e,B5e),!gy&&(gy=new wn),lo(gy,"ALL","ALL")}return P=c(Tc(t?l8:WC,e),140),P}function gst(e){Am(e,new mb(rY(JN(Em(Sm(Tm(jm(new b1,sl),"ELK Mr. Tree"),"Tree-based algorithm provided by the Eclipse Layout Kernel. Computes a spanning tree of the input graph and arranges all nodes according to the resulting parent-children hierarchy. I pity the fool who doesn't use Mr. Tree Layout."),new lj),h4e),gt((V5(),yae))))),Ie(e,sl,gw,t8e),Ie(e,sl,dw,20),Ie(e,sl,fse,3),Ie(e,sl,ZS,YS),Ie(e,sl,wL,Pe(1)),Ie(e,sl,rE,(Bt(),!0)),Ie(e,sl,AL,Ve(W9e)),Ie(e,sl,hse,K9e),Ie(e,sl,e9,Ve(Wpt)),Ie(e,sl,wG,Ve(Kpt)),Ie(e,sl,Jx,Ve(Zpt)),Ie(e,sl,n9,Ve(ebt)),Ie(e,sl,ok,Ve(tbt)),Ie(e,sl,sk,Ve(nbt)),Ie(e,sl,i9,Ve(Ypt)),Ie(e,sl,t9,Ve(Z9e)),Ie(e,sl,r9,Ve(ibt)),Ie(e,sl,u4e,Ve(s8e)),Ie(e,sl,f4e,Ve(n8e)),Ie(e,sl,yL,Ve(cbt)),Ie(e,sl,xL,Ve(lbt)),Ie(e,sl,kL,Ve(obt)),Ie(e,sl,OL,Ve(sbt)),Ie(e,sl,pw,r8e),Ie(e,sl,l4e,Ve(x3)),Ie(e,sl,a4e,Ve(Xle)),Ie(e,sl,c4e,Ve(xd)),Ie(e,sl,s4e,Ve(V9e)),Ie(e,sl,o4e,Ve(Y9e))}function pst(e,t){var n,i,r,o,a,d,b,v,x,S,M;for(v=c(c(Si(e.r,t),24),85),a=kHt(e,t),n=e.u.Gc((Ql(),RC)),b=v.Jc();b.Ob();)if(d=c(b.Pb(),116),!(!d.c||d.c.d.c.length<=0)){switch(M=d.b.Kf(),x=d.c,S=x.i,S.b=(o=x.n,x.e.a+o.b+o.c),S.a=(r=x.n,x.e.b+r.d+r.a),t.g){case 1:d.a?(S.c=(M.a-S.b)/2,Kf(x,(Hl(),Y0))):a||n?(S.c=-S.b-e.s,Kf(x,(Hl(),Tf))):(S.c=M.a+e.s,Kf(x,(Hl(),wd))),S.d=-S.a-e.t,ed(x,(hl(),Ef));break;case 3:d.a?(S.c=(M.a-S.b)/2,Kf(x,(Hl(),Y0))):a||n?(S.c=-S.b-e.s,Kf(x,(Hl(),Tf))):(S.c=M.a+e.s,Kf(x,(Hl(),wd))),S.d=M.b+e.t,ed(x,(hl(),rh));break;case 2:d.a?(i=e.v?S.a:c(Xe(x.d,0),190).Kf().b,S.d=(M.b-i)/2,ed(x,(hl(),Z0))):a||n?(S.d=-S.a-e.t,ed(x,(hl(),Ef))):(S.d=M.b+e.t,ed(x,(hl(),rh))),S.c=M.a+e.s,Kf(x,(Hl(),wd));break;case 4:d.a?(i=e.v?S.a:c(Xe(x.d,0),190).Kf().b,S.d=(M.b-i)/2,ed(x,(hl(),Z0))):a||n?(S.d=-S.a-e.t,ed(x,(hl(),Ef))):(S.d=M.b+e.t,ed(x,(hl(),rh))),S.c=-S.b-e.s,Kf(x,(Hl(),Tf))}a=!1}}function Len(e,t,n,i){var r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie;if(M=!1,S=!1,dx(c(R(i,(Ge(),cr)),103))){a=!1,d=!1;e:for(P=new G(i.j);P.a<P.c.c.length;)for(L=c(Q(P),12),H=Bd(ma(W(V(Ta,1),Lt,22,0,[new p6(L),new Q4(L)])));hn(H);)if(z=c(sn(H),12),!et(Ze(R(z.i,JE)))){if(L.j==(Je(),Kt)){a=!0;break e}if(L.j==bn){d=!0;break e}}M=d&&!a,S=a&&!d}if(!M&&!S&&i.b.c.length!=0){for(x=0,v=new G(i.b);v.a<v.c.c.length;)b=c(Q(v),70),x+=b.n.b+b.o.b/2;x/=i.b.c.length,ie=x>=i.o.b/2}else ie=!S;ie?(X=c(R(i,(De(),Sk)),16),X?M?o=X:(r=c(R(i,mk),16),r?X.gc()<=r.gc()?o=X:o=r:(o=new Fe,Ee(i,mk,o))):(o=new Fe,Ee(i,Sk,o))):(r=c(R(i,(De(),mk)),16),r?S?o=r:(X=c(R(i,Sk),16),X?r.gc()<=X.gc()?o=r:o=X:(o=new Fe,Ee(i,Sk,o))):(o=new Fe,Ee(i,mk,o))),o.Ec(e),Ee(e,(De(),qU),n),t.d==n?(ss(t,null),n.e.c.length+n.g.c.length==0&&_o(n,null),pRt(n)):(ks(t,null),n.e.c.length+n.g.c.length==0&&_o(n,null)),Ou(t.a)}function Pen(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt,Rt,fn,ti,Zi;for(n.Tg("MinWidth layering",1),L=t.b,We=t.a,Zi=c(R(t,(Ge(),TSe)),15).a,d=c(R(t,ESe),15).a,e.b=ue(he(R(t,Mf))),e.d=nr,de=new G(We);de.a<de.c.c.length;)ie=c(Q(de),9),ie.k==(Jt(),or)&&(Dt=ie.o.b,e.d=p.Math.min(e.d,Dt));for(e.d=p.Math.max(1,e.d),pt=We.c.length,e.c=ye(Fn,ci,30,pt,15,1),e.f=ye(Fn,ci,30,pt,15,1),e.e=ye(ns,no,30,pt,15,1),v=0,e.a=0,Se=new G(We);Se.a<Se.c.c.length;)ie=c(Q(Se),9),ie.p=v++,e.c[ie.p]=SWe(pr(ie)),e.f[ie.p]=SWe($i(ie)),e.e[ie.p]=ie.o.b/e.d,e.a+=e.e[ie.p];for(e.b/=e.d,e.a/=pt,xe=EGt(We),Rr(We,vpe(new n_e(e))),z=nr,P=di,a=null,ti=Zi,fn=Zi,o=d,r=d,Zi<0&&(ti=c(j9e.a.Gd(),15).a,fn=c(j9e.b.Gd(),15).a),d<0&&(o=c(S9e.a.Gd(),15).a,r=c(S9e.b.Gd(),15).a),Rt=ti;Rt<=fn;Rt++)for(i=o;i<=r;i++)bt=gKt(e,Rt,i,We,xe),X=ue(he(bt.a)),M=c(bt.b,16),H=M.gc(),(X<z||X==z&&H<P)&&(z=X,P=H,a=M);for(S=a.Jc();S.Ob();){for(x=c(S.Pb(),16),b=new hc(t),se=x.Jc();se.Ob();)ie=c(se.Pb(),9),zr(ie,b);It(L.c,b)}NT(L),We.c.length=0,n.Ug()}function Ien(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We;for(t.Tg(tct,1),z=new Fe,xe=new Fe,v=new G(e.b);v.a<v.c.c.length;)for(b=c(Q(v),26),X=-1,P=q_(b.a),S=P,M=0,L=S.length;M<L;++M)if(x=S[M],++X,!!(x.k==(Jt(),or)&&dx(c(R(x,(Ge(),cr)),103)))){for(!d5(c(R(x,(Ge(),cr)),103))&&ve(R(Jr(x),t1))===ve((B1(),rp))&&JJt(x),Ee(x,(De(),Mw),x),z.c.length=0,xe.c.length=0,n=new Fe,de=new Ai,fte(de,Bg(x,(Je(),Kt))),ve(R(Jr(x),t1))!==ve((B1(),rp))&&(de=TZe(de)),wst(e,de,z,xe,n),d=X,We=x,o=new G(z);o.a<o.c.c.length;)i=c(Q(o),9),B0(i,d,b),++X,Ee(i,Mw,x),a=c(Xe(i.j,0),12),H=c(R(a,Oi),12),et(Ze(R(H,Zce)))||c(R(i,yk),16).Ec(We);for(Ou(de),se=Bg(x,bn).Jc();se.Ob();)ie=c(se.Pb(),12),tr(de,ie,de.a,de.a.a);for(ve(R(Jr(x),t1))!==ve(rp)&&(de=TZe(de)),wst(e,de,xe,null,n),Se=x,r=new G(xe);r.a<r.c.c.length;)i=c(Q(r),9),B0(i,++X,b),Ee(i,Mw,x),a=c(Xe(i.j,0),12),H=c(R(a,Oi),12),et(Ze(R(H,Zce)))||c(R(Se,yk),16).Ec(i);n.c.length==0||Ee(x,d6e,n)}t.Ug()}function Ren(e,t,n,i,r,o,a){var d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt,Rt,fn,ti,Zi;for(L=0,Dt=0,b=new G(e);b.a<b.c.c.length;)d=c(Q(b),19),Grt(d),L=p.Math.max(L,d.g),Dt+=d.g*d.f;for(P=Dt/e.c.length,bt=yFt(e,P),Dt+=e.c.length*bt,Dt+=p.Math.sqrt(Dt)*(n.a+n.d),Dt+=p.Math.sqrt(Dt)*n.c,L=p.Math.max(L,p.Math.sqrt(Dt*a))+n.b,ti=n.b,Zi=n.d,M=0,x=n.b+n.c,pt=new Ai,ei(pt,Pe(0)),xe=new Ai,v=new os(e,0);v.b<v.d.gc();)d=(dn(v.b<v.d.gc()),c(v.d.Xb(v.c=v.b++),19)),fn=d.g,S=d.f,ti+fn>L&&(o&&(Es(xe,M),Es(pt,Pe(v.b-1))),ti=n.b,Zi+=M+t,M=0,x=p.Math.max(x,n.b+n.c+fn)),Cc(d,ti),Nl(d,Zi),x=p.Math.max(x,ti+fn+n.c),M=p.Math.max(M,S),ti+=fn+t;if(x=p.Math.max(x,i),Rt=Zi+M+n.a,Rt<r&&(M+=r-Rt,Rt=r),o)for(ti=n.b,v=new os(e,0),Es(pt,Pe(e.c.length)),We=_n(pt,0),X=c(An(We),15).a,Es(xe,M),Se=_n(xe,0),de=0;v.b<v.d.gc();)v.b==X&&(ti=n.b,de=ue(he(An(Se))),X=c(An(We),15).a),d=(dn(v.b<v.d.gc()),c(v.d.Xb(v.c=v.b++),19)),ie=d.f,sb(d,de),z=de,v.b==X&&(H=x-ti-n.c,se=d.g,ob(d,H),rve(d,new $e(H,z),new $e(se,ie))),ti+=d.g+t;return new $e(x,Rt)}function $en(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt,Rt,fn;if(n.Tg("Spline edge routing",1),t.b.c.length==0){t.f.a=0,n.Ug();return}ie=ue(he(R(t,(Ge(),Vv)))),d=ue(he(R(t,ip))),a=ue(he(R(t,Jv))),X=c(R(t,cle),350),pt=X==(dS(),cC),We=ue(he(R(t,wSe))),e.d=t,e.j.c.length=0,e.a.c.length=0,sc(e.k),b=c(Xe(t.b,0),26),x=pF(b.a,(jQ(),pP)),P=c(Xe(t.b,t.b.c.length-1),26),S=pF(P.a,pP),z=new G(t.b),H=null,fn=0;do{for(se=z.a<z.c.c.length?c(Q(z),26):null,men(e,H,se),BWt(e),bt=N9t(gIt(fq(pi(new jt(null,new Tt(e.i,16)),new g1),new gg))),Rt=0,de=fn,M=!H||x&&H==b,L=!se||S&&se==P,bt>0?(v=0,H&&(v+=d),v+=(bt-1)*a,se&&(v+=d),pt&&se&&(v=p.Math.max(v,YJt(se,a,ie,We))),v<ie&&!M&&!L&&(Rt=(ie-v)/2,v=ie),de+=v):!M&&!L&&(de+=ie),se&&Pye(se,de),xe=new G(e.i);xe.a<xe.c.c.length;)Se=c(Q(xe),134),Se.a.c=fn,Se.a.b=de-fn,Se.F=Rt,Se.p=!H;yr(e.a,e.i),fn=de,se&&(fn+=se.c.a),H=se,M=L}while(se);for(r=new G(e.j);r.a<r.c.c.length;)i=c(Q(r),17),o=tIt(e,i),Ee(i,(De(),g3),o),Dt=hXt(e,i),Ee(i,_b,Dt);t.f.a=fn,e.d=null,n.Ug()}function Ben(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt;for(e.b=t,e.a=c(R(t,(Ge(),ySe)),15).a,e.c=c(R(t,kSe),15).a,e.c==0&&(e.c=di),H=new os(t.b,0);H.b<H.d.gc();){for(z=(dn(H.b<H.d.gc()),c(H.d.Xb(H.c=H.b++),26)),d=new Fe,x=-1,de=-1,se=new G(z.a);se.a<se.c.c.length;)ie=c(Q(se),9),Vf((C_(),new Ht(Vt(sd(ie).a.Jc(),new U))))>=e.a&&(i=bKt(e,ie),x=p.Math.max(x,i.b),de=p.Math.max(de,i.d),qe(d,new Ps(ie,i)));for(pt=new Fe,v=0;v<x;++v)Up(pt,0,(dn(H.b>0),H.a.Xb(H.c=--H.b),bt=new hc(e.b),z2(H,bt),dn(H.b<H.d.gc()),H.d.Xb(H.c=H.b++),bt));for(a=new G(d);a.a<a.c.c.length;)if(r=c(Q(a),49),L=c(r.b,573).a,!!L)for(M=new G(L);M.a<M.c.c.length;)S=c(Q(M),9),s2e(e,S,aU,pt);for(n=new Fe,b=0;b<de;++b)qe(n,(Dt=new hc(e.b),z2(H,Dt),Dt));for(o=new G(d);o.a<o.c.c.length;)if(r=c(Q(o),49),We=c(r.b,573).c,!!We)for(xe=new G(We);xe.a<xe.c.c.length;)Se=c(Q(xe),9),s2e(e,Se,fU,n)}for(X=new os(t.b,0);X.b<X.d.gc();)P=(dn(X.b<X.d.gc()),c(X.d.Xb(X.c=X.b++),26)),P.a.c.length==0&&iu(X)}function bst(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de;if(z=e.i!=0,se=!1,X=null,wu(e.e)){if(x=t.gc(),x>0){for(M=x<100?null:new m0(x),v=new vme(t),P=v.g,X=ye(Fn,ci,30,x,15,1),i=0,de=new Um(x),r=0;r<e.i;++r){d=e.g[r],L=d;e:for(ie=0;ie<2;++ie){for(b=x;--b>=0;)if(L!=null?yi(L,P[b]):ve(L)===ve(P[b])){X.length<=i&&(H=X,X=ye(Fn,ci,30,2*X.length,15,1),mc(H,0,X,0,i)),X[i++]=r,Nn(de,P[b]);break e}if(L=L,ve(L)===ve(d))break}}if(v=de,P=de.g,x=i,i>X.length&&(H=X,X=ye(Fn,ci,30,i,15,1),mc(H,0,X,0,i)),i>0){for(se=!0,o=0;o<i;++o)L=P[o],M=Aze(e,c(L,76),M);for(a=i;--a>=0;)F5(e,X[a]);if(i!=x){for(r=x;--r>=i;)F5(v,r);H=X,X=ye(Fn,ci,30,i,15,1),mc(H,0,X,0,i)}t=v}}}else for(t=aFt(e,t),r=e.i;--r>=0;)t.Gc(e.g[r])&&(F5(e,r),se=!0);if(se){if(X!=null){for(n=t.gc(),S=n==1?X7(e,4,t.Jc().Pb(),null,X[0],z):X7(e,6,t,X,X[0],z),M=n<100?null:new m0(n),r=t.Jc();r.Ob();)L=r.Pb(),M=f0e(e,c(L,76),M);M?(M.lj(S),M.mj()):vi(e.e,S)}else{for(M=X7t(t.gc()),r=t.Jc();r.Ob();)L=r.Pb(),M=f0e(e,c(L,76),M);M&&M.mj()}return!0}else return!1}function zen(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se;for(n=new lYe(t),n.a||aWt(t),v=lVt(t),b=new Qm,H=new Tnt,z=new G(t.a);z.a<z.c.c.length;)for(P=c(Q(z),9),r=new Ht(Vt($i(P).a.Jc(),new U));hn(r);)i=c(sn(r),17),(i.c.i.k==(Jt(),Cr)||i.d.i.k==Cr)&&(x=AZt(e,i,v,H),St(b,one(x.d),x.a));for(a=new Fe,se=c(R(n.c,(De(),X1)),24).Jc();se.Ob();){switch(ie=c(se.Pb(),64),L=H.c[ie.g],M=H.b[ie.g],d=H.a[ie.g],o=null,X=null,ie.g){case 4:o=new pf(e.d.a,L,v.b.a-e.d.a,M-L),X=new pf(e.d.a,L,d,M-L),Pm(v,new $e(o.c+o.b,o.d)),Pm(v,new $e(o.c+o.b,o.d+o.a));break;case 2:o=new pf(v.a.a,L,e.c.a-v.a.a,M-L),X=new pf(e.c.a-d,L,d,M-L),Pm(v,new $e(o.c,o.d)),Pm(v,new $e(o.c,o.d+o.a));break;case 1:o=new pf(L,e.d.b,M-L,v.b.b-e.d.b),X=new pf(L,e.d.b,M-L,d),Pm(v,new $e(o.c,o.d+o.a)),Pm(v,new $e(o.c+o.b,o.d+o.a));break;case 3:o=new pf(L,v.a.b,M-L,e.c.b-v.a.b),X=new pf(L,e.c.b-d,M-L,d),Pm(v,new $e(o.c,o.d)),Pm(v,new $e(o.c+o.b,o.d))}o&&(S=new hLe,S.d=ie,S.b=o,S.c=X,S.a=aee(c(Si(b,one(ie)),24)),It(a.c,S))}return yr(n.b,a),n.d=RRt(zYt(v)),n}function mst(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z;if(n.p[t.p]==null){d=!0,n.p[t.p]=0,a=t,z=n.o==(vh(),Bb)?Qr:nr;do r=e.b.e[a.p],o=a.c.a.c.length,n.o==Bb&&r>0||n.o==Rh&&r<o-1?(b=null,v=null,n.o==Rh?b=c(Xe(a.c.a,r+1),9):b=c(Xe(a.c.a,r-1),9),v=n.g[b.p],mst(e,v,n),z=e.e.vg(z,t,a),n.j[t.p]==t&&(n.j[t.p]=n.j[v.p]),n.j[t.p]==n.j[v.p]?(P=px(e.d,a,b),n.o==Rh?(i=ue(n.p[t.p]),S=ue(n.p[v.p])+ue(n.d[b.p])-b.d.d-P-a.d.a-a.o.b-ue(n.d[a.p]),d?(d=!1,n.p[t.p]=p.Math.min(S,z)):n.p[t.p]=p.Math.min(i,p.Math.min(S,z))):(i=ue(n.p[t.p]),S=ue(n.p[v.p])+ue(n.d[b.p])+b.o.b+b.d.a+P+a.d.d-ue(n.d[a.p]),d?(d=!1,n.p[t.p]=p.Math.max(S,z)):n.p[t.p]=p.Math.max(i,p.Math.max(S,z)))):(P=ue(he(R(e.a,(Ge(),$b)))),L=WXe(e,n.j[t.p]),x=WXe(e,n.j[v.p]),n.o==Rh?(M=ue(n.p[t.p])+ue(n.d[a.p])+a.o.b+a.d.a+P-(ue(n.p[v.p])+ue(n.d[b.p])-b.d.d),wQe(L,x,M)):(M=ue(n.p[t.p])+ue(n.d[a.p])-a.d.d-ue(n.p[v.p])-ue(n.d[b.p])-b.o.b-b.d.a-P,wQe(L,x,M)))):z=e.e.vg(z,t,a),a=n.a[a.p];while(a!=t);n9t(e.e,t)}}function Fen(e){var t,n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt;if(n=ue(he(R(e.a.j,(Ge(),hSe)))),n<-1||!e.a.i||d5(c(R(e.a.o,cr),103))||Po(e.a.o,(Je(),nn)).gc()<2&&Po(e.a.o,Yt).gc()<2)return!0;if(e.a.c.ig())return!1;for(Se=0,de=0,se=new Fe,b=e.a.e,v=0,x=b.length;v<x;++v){for(d=b[v],M=d,L=0,z=M.length;L<z;++L){if(S=M[L],S.k==(Jt(),Dc)){It(se.c,S);continue}for(i=e.b[S.c.p][S.p],S.k==Cr?(i.b=1,c(R(S,(De(),Oi)),12).j==(Je(),nn)&&(de+=i.a)):(bt=Po(S,(Je(),Yt)),bt.dc()||!iZ(bt,new b4)?i.c=1:(r=Po(S,nn),(r.dc()||!iZ(r,new p4))&&(Se+=i.a))),a=new Ht(Vt($i(S).a.Jc(),new U));hn(a);)o=c(sn(a),17),Se+=i.c,de+=i.b,pt=o.d.i,Abe(e,i,pt);for(X=ma(W(V(Ta,1),Lt,22,0,[Po(S,(Je(),Kt)),Po(S,bn)])),We=new Ht(new Oge(X.a.length,X.a));hn(We);)xe=c(sn(We),12),ie=c(R(xe,(De(),Ul)),9),ie&&(Se+=i.c,de+=i.b,Abe(e,i,ie))}for(P=new G(se);P.a<P.c.c.length;)for(S=c(Q(P),9),i=e.b[S.c.p][S.p],a=new Ht(Vt($i(S).a.Jc(),new U));hn(a);)o=c(sn(a),17),Se+=i.c,de+=i.b,pt=o.d.i,Abe(e,i,pt);se.c.length=0}return t=Se+de,H=t==0?nr:(Se-de)/t,H>=n}function qen(e){var t,n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt;for(se=e.a,de=0,Se=se.length;de<Se;++de){for(ie=se[de],v=di,x=di,P=new G(ie.e);P.a<P.c.c.length;)M=c(Q(P),9),a=M.c?Do(M.c.a,M,0):-1,a>0?(S=c(Xe(M.c.a,a-1),9),pt=px(e.b,M,S),H=M.n.b-M.d.d-(S.n.b+S.o.b+S.d.a+pt)):H=M.n.b-M.d.d,v=p.Math.min(H,v),a<M.c.a.c.length-1?(S=c(Xe(M.c.a,a+1),9),pt=px(e.b,M,S),X=S.n.b-S.d.d-(M.n.b+M.o.b+M.d.a+pt)):X=2*M.n.b,x=p.Math.min(X,x);for(b=di,o=!1,r=c(Xe(ie.e,0),9),Dt=new G(r.j);Dt.a<Dt.c.c.length;)for(bt=c(Q(Dt),12),z=r.n.b+bt.n.b+bt.a.b,i=new G(bt.e);i.a<i.c.c.length;)n=c(Q(i),17),xe=n.c,t=xe.i.n.b+xe.n.b+xe.a.b-z,p.Math.abs(t)<p.Math.abs(b)&&p.Math.abs(t)<(t<0?v:x)&&(b=t,o=!0);for(d=c(Xe(ie.e,ie.e.c.length-1),9),We=new G(d.j);We.a<We.c.c.length;)for(xe=c(Q(We),12),z=d.n.b+xe.n.b+xe.a.b,i=new G(xe.g);i.a<i.c.c.length;)n=c(Q(i),17),bt=n.d,t=bt.i.n.b+bt.n.b+bt.a.b-z,p.Math.abs(t)<p.Math.abs(b)&&p.Math.abs(t)<(t<0?v:x)&&(b=t,o=!0);if(o&&b!=0)for(L=new G(ie.e);L.a<L.c.c.length;)M=c(Q(L),9),M.n.b+=b}}function Hen(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt,Rt,fn;for(se=t,ie=new Qm,de=new Qm,x=Gm(se,eoe),i=new iHe(e,n,ie,de),iet(i.a,i.b,i.c,i.d,x),b=(We=ie.i,We||(ie.i=new wx(ie,ie.c))),bt=b.Jc();bt.Ob();)for(pt=c(bt.Pb(),171),r=c(Si(ie,pt),24),z=r.Jc();z.Ob();)if(P=z.Pb(),Se=c(Tx(e.f,P),171),Se)d=(!pt.e&&(pt.e=new Et(Hi,pt,10,9)),pt.e),Nn(d,Se);else throw a=M1(se,bd),M=Flt+P+qlt+a,L=M+w9,J(new Kh(L));for(v=(xe=de.i,xe||(de.i=new wx(de,de.c))),Rt=v.Jc();Rt.Ob();)for(Dt=c(Rt.Pb(),171),o=c(Si(de,Dt),24),X=o.Jc();X.Ob();)if(H=X.Pb(),Se=c(Tx(e.f,H),171),Se)S=(!Dt.g&&(Dt.g=new Et(Hi,Dt,9,10)),Dt.g),Nn(S,Se);else throw a=M1(se,bd),M=Flt+H+qlt+a,L=M+w9,J(new Kh(L));!n.b&&(n.b=new Et(vn,n,4,7)),n.b.i!=0&&(!n.c&&(n.c=new Et(vn,n,5,8)),n.c.i!=0)&&(!n.b&&(n.b=new Et(vn,n,4,7)),n.b.i<=1&&(!n.c&&(n.c=new Et(vn,n,5,8)),n.c.i<=1))&&(!n.a&&(n.a=new Me(Hi,n,6,6)),n.a).i==1&&(fn=c(re((!n.a&&(n.a=new Me(Hi,n,6,6)),n.a),0),171),!fne(fn)&&!hne(fn)&&(lH(fn,c(re((!n.b&&(n.b=new Et(vn,n,4,7)),n.b),0),83)),uH(fn,c(re((!n.c&&(n.c=new Et(vn,n,5,8)),n.c),0),83))))}function Qen(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X;if(i=new Fe,r=di,o=di,a=di,n)for(r=e.f.a,z=new G(t.j);z.a<z.c.c.length;)for(P=c(Q(z),12),b=new G(P.g);b.a<b.c.c.length;)d=c(Q(b),17),d.a.b!=0&&(x=c(N6(d.a),8),x.a<r&&(o=r-x.a,a=di,i.c.length=0,r=x.a),x.a<=r&&(It(i.c,d),d.a.b>1&&(a=p.Math.min(a,p.Math.abs(c(pc(d.a,1),8).b-x.b)))));else for(z=new G(t.j);z.a<z.c.c.length;)for(P=c(Q(z),12),b=new G(P.e);b.a<b.c.c.length;)d=c(Q(b),17),d.a.b!=0&&(M=c(df(d.a),8),M.a>r&&(o=M.a-r,a=di,i.c.length=0,r=M.a),M.a>=r&&(It(i.c,d),d.a.b>1&&(a=p.Math.min(a,p.Math.abs(c(pc(d.a,d.a.b-2),8).b-M.b)))));if(i.c.length!=0&&o>t.o.a/2&&a>t.o.b/2){for(L=new bc,_o(L,t),$r(L,(Je(),Kt)),L.n.a=t.o.a/2,X=new bc,_o(X,t),$r(X,bn),X.n.a=t.o.a/2,X.n.b=t.o.b,b=new G(i);b.a<b.c.c.length;)d=c(Q(b),17),n?(v=c(TZ(d.a),8),H=d.a.b==0?xh(d.d):c(N6(d.a),8),H.b>=v.b?ks(d,X):ks(d,L)):(v=c(yCt(d.a),8),H=d.a.b==0?xh(d.c):c(df(d.a),8),H.b>=v.b?ss(d,X):ss(d,L)),S=c(R(d,(Ge(),ho)),79),S&&uv(S,v,!0);t.n.a=r-t.o.a/2}}function Gen(e,t,n){var i,r,o,a,d,b,v,x,S,M;for(d=_n(e.b,0);d.b!=d.d.c;)if(a=c(An(d),41),!Ot(a.c,yG))for(v=gUt(a,e),t==(Nr(),go)||t==yo?Rr(v,new YR):Rr(v,new LW),b=v.c.length,i=0;i<b;i++)x=(ht(i,v.c.length),c(v.c[i],65)).c,Ot(x.c,"n11"),!(et(Ze(R(a,(Li(),F9e))))&&!UVe((ht(i,v.c.length),c(v.c[i],65)),e))&&(r=b==1?.5:(i+1)/(b+1),t==go?(o=ue(he(R(a,oh))),M=a.e.b+a.f.b*r,ax((ht(i,v.c.length),c(v.c[i],65)).a,new $e(p.Math.min(o,a.e.a-n),M)),ax((ht(i,v.c.length),c(v.c[i],65)).a,new $e(a.e.a,M))):t==yo?(o=ue(he(R(a,Af)))+n,M=a.e.b+a.f.b*r,ax((ht(i,v.c.length),c(v.c[i],65)).a,new $e(o,M)),ax((ht(i,v.c.length),c(v.c[i],65)).a,new $e(a.e.a+a.f.a,M))):t==Ca?(o=ue(he(R(a,oh))),S=a.e.a+a.f.a*r,ax((ht(i,v.c.length),c(v.c[i],65)).a,new $e(S,p.Math.min(a.e.b-n,o))),ax((ht(i,v.c.length),c(v.c[i],65)).a,new $e(S,a.e.b))):(o=ue(he(R(a,Af)))+n,S=a.e.a+a.f.a*r,ax((ht(i,v.c.length),c(v.c[i],65)).a,new $e(S,o)),ax((ht(i,v.c.length),c(v.c[i],65)).a,new $e(S,a.e.b+a.f.b))))}function tL(e,t,n,i,r,o,a,d,b){var v,x,S,M,L,P,z;switch(L=n,x=new Eh(b),mu(x,(Jt(),Cr)),Ee(x,(De(),m6e),a),Ee(x,(Ge(),cr),(Zr(),xc)),z=ue(he(e.mf(Qv))),Ee(x,Qv,z),S=new bc,_o(S,x),t!=Hh&&t!=fp||(i>=0?L=I5(d):L=jD(I5(d)),e.of(B9,L)),v=new as,M=!1,e.nf(Lw)?(Pge(v,c(e.mf(Lw),8)),M=!0):Rjt(v,a.a/2,a.b/2),L.g){case 4:Ee(x,Ro,(Tu(),V1)),Ee(x,QU,(ab(),l3)),x.o.b=a.b,z<0&&(x.o.a=-z),$r(S,(Je(),nn)),M||(v.a=a.a),v.a-=a.a;break;case 2:Ee(x,Ro,(Tu(),Db)),Ee(x,QU,(ab(),_9)),x.o.b=a.b,z<0&&(x.o.a=-z),$r(S,(Je(),Yt)),M||(v.a=0);break;case 1:Ee(x,Nb,(D1(),a3)),x.o.a=a.a,z<0&&(x.o.b=-z),$r(S,(Je(),bn)),M||(v.b=a.b),v.b-=a.b;break;case 3:Ee(x,Nb,(D1(),bk)),x.o.a=a.a,z<0&&(x.o.b=-z),$r(S,(Je(),Kt)),M||(v.b=0)}if(Pge(S.n,v),Ee(x,Lw,v),t==Hb||t==r1||t==xc){if(P=0,t==Hb&&e.nf(Vg))switch(L.g){case 1:case 2:P=c(e.mf(Vg),15).a;break;case 3:case 4:P=-c(e.mf(Vg),15).a}else switch(L.g){case 4:case 2:P=o.b,t==r1&&(P/=r.b);break;case 1:case 3:P=o.a,t==r1&&(P/=r.a)}Ee(x,Aw,P)}return Ee(x,Ko,L),x}function Uen(){r1e();function e(i){var r=this;this.dispatch=function(o){var a=o.data;switch(a.cmd){case"algorithms":var d=Awe((Ct(),new f6(new x1(gp.b))));i.postMessage({id:a.id,data:d});break;case"categories":var b=Awe((Ct(),new f6(new x1(gp.c))));i.postMessage({id:a.id,data:b});break;case"options":var v=Awe((Ct(),new f6(new x1(gp.d))));i.postMessage({id:a.id,data:v});break;case"register":UYt(a.algorithms),i.postMessage({id:a.id});break;case"layout":fYt(a.graph,a.layoutOptions||{},a.options||{}),i.postMessage({id:a.id,data:a.graph});break}},this.saveDispatch=function(o){try{r.dispatch(o)}catch(a){i.postMessage({id:o.data.id,error:a})}}}function t(i){var r=this;this.dispatcher=new e({postMessage:function(o){r.onmessage({data:o})}}),this.postMessage=function(o){setTimeout(function(){r.dispatcher.saveDispatch({data:o})},0)}}if(typeof document===bre&&typeof self!==bre){var n=new e(self);self.onmessage=n.saveDispatch}else typeof h!==bre&&h.exports&&(Object.defineProperty(g,"__esModule",{value:!0}),h.exports={default:t,Worker:t})}function _ie(e,t,n,i,r,o,a){var d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt,Rt,fn,ti,Zi;for(z=0,Dt=0,v=new G(e.b);v.a<v.c.c.length;)b=c(Q(v),168),b.c&&Grt(b.c),z=p.Math.max(z,Ml(b)),Dt+=Ml(b)*ku(b);for(H=Dt/e.b.c.length,bt=eqt(e.b,H),Dt+=e.b.c.length*bt,z=p.Math.max(z,p.Math.sqrt(Dt*a))+n.b,ti=n.b,Zi=n.d,L=0,S=n.b+n.c,pt=new Ai,ei(pt,Pe(0)),xe=new Ai,x=new os(e.b,0),P=null,d=new Fe;x.b<x.d.gc();)b=(dn(x.b<x.d.gc()),c(x.d.Xb(x.c=x.b++),168)),fn=Ml(b),M=ku(b),ti+fn>z&&(o&&(Es(xe,L),Es(pt,Pe(x.b-1)),qe(e.d,P),d.c.length=0),ti=n.b,Zi+=L+t,L=0,S=p.Math.max(S,n.b+n.c+fn)),It(d.c,b),nYe(b,ti,Zi),S=p.Math.max(S,ti+fn+n.c),L=p.Math.max(L,M),ti+=fn+t,P=b;if(yr(e.a,d),qe(e.d,c(Xe(d,d.c.length-1),168)),S=p.Math.max(S,i),Rt=Zi+L+n.a,Rt<r&&(L+=r-Rt,Rt=r),o)for(ti=n.b,x=new os(e.b,0),Es(pt,Pe(e.b.c.length)),We=_n(pt,0),ie=c(An(We),15).a,Es(xe,L),Se=_n(xe,0),de=0;x.b<x.d.gc();)x.b==ie&&(ti=n.b,de=ue(he(An(Se))),ie=c(An(We),15).a),b=(dn(x.b<x.d.gc()),c(x.d.Xb(x.c=x.b++),168)),IKe(b,de),x.b==ie&&(X=S-ti-n.c,se=Ml(b),RKe(b,X),nKe(b,(X-se)/2,0)),ti+=Ml(b)+t;return new $e(S,Rt)}function Jen(e){e.N||(e.N=!0,e.b=Go(e,0),sr(e.b,0),sr(e.b,1),sr(e.b,2),e.bb=Go(e,1),sr(e.bb,0),sr(e.bb,1),e.fb=Go(e,2),sr(e.fb,3),sr(e.fb,4),zi(e.fb,5),e.qb=Go(e,3),sr(e.qb,0),zi(e.qb,1),zi(e.qb,2),sr(e.qb,3),sr(e.qb,4),zi(e.qb,5),sr(e.qb,6),e.a=fi(e,4),e.c=fi(e,5),e.d=fi(e,6),e.e=fi(e,7),e.f=fi(e,8),e.g=fi(e,9),e.i=fi(e,10),e.j=fi(e,11),e.k=fi(e,12),e.n=fi(e,13),e.o=fi(e,14),e.p=fi(e,15),e.q=fi(e,16),e.s=fi(e,17),e.r=fi(e,18),e.t=fi(e,19),e.u=fi(e,20),e.v=fi(e,21),e.w=fi(e,22),e.B=fi(e,23),e.A=fi(e,24),e.C=fi(e,25),e.D=fi(e,26),e.F=fi(e,27),e.G=fi(e,28),e.H=fi(e,29),e.J=fi(e,30),e.I=fi(e,31),e.K=fi(e,32),e.M=fi(e,33),e.L=fi(e,34),e.P=fi(e,35),e.Q=fi(e,36),e.R=fi(e,37),e.S=fi(e,38),e.T=fi(e,39),e.U=fi(e,40),e.V=fi(e,41),e.X=fi(e,42),e.W=fi(e,43),e.Y=fi(e,44),e.Z=fi(e,45),e.$=fi(e,46),e._=fi(e,47),e.ab=fi(e,48),e.cb=fi(e,49),e.db=fi(e,50),e.eb=fi(e,51),e.gb=fi(e,52),e.hb=fi(e,53),e.ib=fi(e,54),e.jb=fi(e,55),e.kb=fi(e,56),e.lb=fi(e,57),e.mb=fi(e,58),e.nb=fi(e,59),e.ob=fi(e,60),e.pb=fi(e,61))}function Xen(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de;if(ie=0,t.f.a==0)for(H=new G(e);H.a<H.c.c.length;)P=c(Q(H),9),ie=p.Math.max(ie,P.n.a+P.o.a+P.d.c);else ie=t.f.a-t.c.a;for(ie-=t.c.a,z=new G(e);z.a<z.c.c.length;){switch(P=c(Q(z),9),Xj(P.n,ie-P.o.a),C0e(P.f),_Ye(P),(P.q?P.q:(Ct(),Ct(),Yd))._b((Ge(),Uv))&&Xj(c(R(P,Uv),8),ie-P.o.a),c(R(P,vd),259).g){case 1:Ee(P,vd,(Hd(),EP));break;case 2:Ee(P,vd,(Hd(),TP))}for(X=P.o,de=new G(P.j);de.a<de.c.c.length;){for(se=c(Q(de),12),Xj(se.n,X.a-se.o.a),Xj(se.a,se.o.a),$r(se,oVe(se.j)),a=c(R(se,Vg),15),a&&Ee(se,Vg,Pe(-a.a)),o=new G(se.g);o.a<o.c.c.length;){for(r=c(Q(o),17),i=_n(r.a,0);i.b!=i.d.c;)n=c(An(i),8),n.a=ie-n.a;if(v=c(R(r,ho),79),v)for(b=_n(v,0);b.b!=b.d.c;)d=c(An(b),8),d.a=ie-d.a;for(M=new G(r.b);M.a<M.c.c.length;)x=c(Q(M),70),Xj(x.n,ie-x.o.a)}for(L=new G(se.f);L.a<L.c.c.length;)x=c(Q(L),70),Xj(x.n,se.o.a-x.o.a)}for(P.k==(Jt(),Cr)&&(Ee(P,(De(),Ko),oVe(c(R(P,Ko),64))),QHt(P)),S=new G(P.b);S.a<S.c.c.length;)x=c(Q(S),70),_Ye(x),Xj(x.n,X.a-x.o.a)}}function Ven(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de;if(ie=0,t.f.b==0)for(H=new G(e);H.a<H.c.c.length;)P=c(Q(H),9),ie=p.Math.max(ie,P.n.b+P.o.b+P.d.a);else ie=t.f.b-t.c.b;for(ie-=t.c.b,z=new G(e);z.a<z.c.c.length;){switch(P=c(Q(z),9),Jj(P.n,ie-P.o.b),E0e(P.f),DYe(P),(P.q?P.q:(Ct(),Ct(),Yd))._b((Ge(),Uv))&&Jj(c(R(P,Uv),8),ie-P.o.b),c(R(P,vd),259).g){case 3:Ee(P,vd,(Hd(),FJ));break;case 4:Ee(P,vd,(Hd(),HJ))}for(X=P.o,de=new G(P.j);de.a<de.c.c.length;){for(se=c(Q(de),12),Jj(se.n,X.b-se.o.b),Jj(se.a,se.o.b),$r(se,cVe(se.j)),a=c(R(se,Vg),15),a&&Ee(se,Vg,Pe(-a.a)),o=new G(se.g);o.a<o.c.c.length;){for(r=c(Q(o),17),i=_n(r.a,0);i.b!=i.d.c;)n=c(An(i),8),n.b=ie-n.b;if(v=c(R(r,ho),79),v)for(b=_n(v,0);b.b!=b.d.c;)d=c(An(b),8),d.b=ie-d.b;for(M=new G(r.b);M.a<M.c.c.length;)x=c(Q(M),70),Jj(x.n,ie-x.o.b)}for(L=new G(se.f);L.a<L.c.c.length;)x=c(Q(L),70),Jj(x.n,se.o.b-x.o.b)}for(P.k==(Jt(),Cr)&&(Ee(P,(De(),Ko),cVe(c(R(P,Ko),64))),b$t(P)),S=new G(P.b);S.a<S.c.c.length;)x=c(Q(S),70),DYe(x),Jj(x.n,X.b-x.o.b)}}function Wen(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt,Rt,fn,ti;for(ie=new os(e.b,0),x=t.Jc(),P=0,v=c(x.Pb(),15).a,Se=0,n=new Or,We=new Ld;ie.b<ie.d.gc();){for(X=(dn(ie.b<ie.d.gc()),c(ie.d.Xb(ie.c=ie.b++),26)),de=new G(X.a);de.a<de.c.c.length;){for(se=c(Q(de),9),L=new Ht(Vt($i(se).a.Jc(),new U));hn(L);)S=c(sn(L),17),We.a.yc(S,We);for(M=new Ht(Vt(pr(se).a.Jc(),new U));hn(M);)S=c(sn(M),17),We.a.Ac(S)!=null}if(P+1==v){for(r=new hc(e),z2(ie,r),o=new hc(e),z2(ie,o),bt=We.a.ec().Jc();bt.Ob();)pt=c(bt.Pb(),17),n.a._b(pt)||(++Se,n.a.yc(pt,n)),a=new Eh(e),Ee(a,(Ge(),cr),(Zr(),r8)),zr(a,r),mu(a,(Jt(),Ih)),z=new bc,_o(z,a),$r(z,(Je(),Yt)),Dt=new bc,_o(Dt,a),$r(Dt,nn),i=new Eh(e),Ee(i,cr,r8),zr(i,o),mu(i,Ih),H=new bc,_o(H,i),$r(H,Yt),Rt=new bc,_o(Rt,i),$r(Rt,nn),xe=new qm,ks(xe,pt.c),ss(xe,z),Ee(xe,(De(),Pi),c(R(pt,Pi),15)),ti=new qm,ks(ti,Dt),ss(ti,H),Ee(ti,Pi,c(R(pt,Pi),15)),ks(pt,Rt),d=new ibe(a,i,xe,ti,pt),Ee(a,Cw,d),Ee(i,Cw,d),fn=xe.c.i,fn.k==Ih&&(b=c(R(fn,Cw),318),b.d=d,d.g=b);if(x.Ob())v=c(x.Pb(),15).a;else break}++P}return Pe(Se)}function Ken(e){var t,n,i,r,o,a,d,b,v,x,S,M,L,P,z,H;for(z=new Fe,M=new G(e.d.b);M.a<M.c.c.length;)for(S=c(Q(M),26),P=new G(S.a);P.a<P.c.c.length;){for(L=c(Q(P),9),r=c(Ut(e.f,L),60),b=new Ht(Vt($i(L).a.Jc(),new U));hn(b);)if(a=c(sn(b),17),i=_n(a.a,0),v=!0,x=null,i.b!=i.d.c){for(t=c(An(i),8),n=null,a.c.j==(Je(),Kt)&&(H=new QT(t,new $e(t.a,r.d.d),r,a),H.f.a=!0,H.a=a.c,It(z.c,H)),a.c.j==bn&&(H=new QT(t,new $e(t.a,r.d.d+r.d.a),r,a),H.f.d=!0,H.a=a.c,It(z.c,H));i.b!=i.d.c;)n=c(An(i),8),Gbe(t.b,n.b)||(x=new QT(t,n,null,a),It(z.c,x),v&&(v=!1,n.b<r.d.d?x.f.a=!0:n.b>r.d.d+r.d.a?x.f.d=!0:(x.f.d=!0,x.f.a=!0))),i.b!=i.d.c&&(t=n);x&&(o=c(Ut(e.f,a.d.i),60),t.b<o.d.d?x.f.a=!0:t.b>o.d.d+o.d.a?x.f.d=!0:(x.f.d=!0,x.f.a=!0))}for(d=new Ht(Vt(pr(L).a.Jc(),new U));hn(d);)a=c(sn(d),17),a.a.b!=0&&(t=c(df(a.a),8),a.d.j==(Je(),Kt)&&(H=new QT(t,new $e(t.a,r.d.d),r,a),H.f.a=!0,H.a=a.d,It(z.c,H)),a.d.j==bn&&(H=new QT(t,new $e(t.a,r.d.d+r.d.a),r,a),H.f.d=!0,H.a=a.d,It(z.c,H)))}return z}function Yen(e,t,n){var i,r,o,a,d,b,v,x,S,M;for(b=new Fe,S=t.length,a=Ime(n),v=0;v<S;++v){switch(x=jge(t,dl(61),v),i=w$t(a,(fs(v,x,t.length),t.substr(v,x-v))),r=vte(i),o=r.hk().ti(),ms(t,++x)){case 39:{d=A6(t,39,++x),qe(b,new hF(i,oee((fs(x,d,t.length),t.substr(x,d-x)),o,r))),v=d+1;break}case 34:{d=A6(t,34,++x),qe(b,new hF(i,oee((fs(x,d,t.length),t.substr(x,d-x)),o,r))),v=d+1;break}case 91:{M=new Fe,qe(b,new hF(i,M));e:for(;;){switch(ms(t,++x)){case 39:{d=A6(t,39,++x),qe(M,oee((fs(x,d,t.length),t.substr(x,d-x)),o,r)),x=d+1;break}case 34:{d=A6(t,34,++x),qe(M,oee((fs(x,d,t.length),t.substr(x,d-x)),o,r)),x=d+1;break}case 110:{if(++x,t.indexOf("ull",x)==x)M.c.push(null);else throw J(new Mo(_lt));x+=3;break}}if(x<S)switch(en(x,t.length),t.charCodeAt(x)){case 44:break;case 93:break e;default:throw J(new Mo("Expecting , or ]"))}else break}v=x+1;break}case 110:{if(++x,t.indexOf("ull",x)==x)qe(b,new hF(i,null));else throw J(new Mo(_lt));v=x+3;break}}if(v<S){if(en(v,t.length),t.charCodeAt(v)!=44)throw J(new Mo("Expecting ,"))}else break}return LXt(e,b,n)}function Zen(e){var t,n,i,r,o;switch(t=e.c,o=null,t){case 6:return e.Cm();case 13:return e.Dm();case 23:return e.um();case 22:return e.zm();case 18:return e.wm();case 8:bi(e),o=(wi(),WTe);break;case 9:return e.cm(!0);case 19:return e.dm();case 10:switch(e.a){case 100:case 68:case 119:case 87:case 115:case 83:return o=e.bm(e.a),bi(e),o;case 101:case 102:case 110:case 114:case 116:case 117:case 118:case 120:n=e.am(),n<Is?o=(wi(),wi(),new Rd(0,n)):o=UFe(dwe(n));break;case 99:return e.mm();case 67:return e.hm();case 105:return e.pm();case 73:return e.im();case 103:return e.nm();case 88:return e.jm();case 49:case 50:case 51:case 52:case 53:case 54:case 55:case 56:case 57:return e.em();case 80:case 112:if(o=pve(e,e.a),!o)throw J(new Qn(Vn((Bn(),soe))));break;default:o=uFe(e.a)}bi(e);break;case 0:if(e.a==93||e.a==123||e.a==125)throw J(new Qn(Vn((Bn(),y5e))));o=uFe(e.a),i=e.a,bi(e),(i&64512)==hL&&e.c==0&&(e.a&64512)==56320&&(r=ye(Na,fd,30,2,15,1),r[0]=i&_r,r[1]=e.a&_r,o=qZ(UFe(od(r,0,r.length)),0),bi(e));break;default:throw J(new Qn(Vn((Bn(),y5e))))}return o}function etn(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt,Rt;for(bt=new Ai,xe=new Ai,H=-1,b=new G(e);b.a<b.c.c.length;){for(a=c(Q(b),134),a.s=H--,x=0,se=0,o=new G(a.t);o.a<o.c.c.length;)i=c(Q(o),275),se+=i.c;for(r=new G(a.i);r.a<r.c.c.length;)i=c(Q(r),275),x+=i.c;a.n=x,a.u=se,se==0?tr(xe,a,xe.c.b,xe.c):x==0&&tr(bt,a,bt.c.b,bt.c)}for(Rt=Dq(e),S=e.c.length,z=S+1,X=S-1,L=new Fe;Rt.a.gc()!=0;){for(;xe.b!=0;)Se=(dn(xe.b!=0),c(ba(xe,xe.a.a),134)),Rt.a.Ac(Se)!=null,Se.s=X--,Ive(Se,bt,xe);for(;bt.b!=0;)We=(dn(bt.b!=0),c(ba(bt,bt.a.a),134)),Rt.a.Ac(We)!=null,We.s=z++,Ive(We,bt,xe);for(P=ls,v=Rt.a.ec().Jc();v.Ob();)a=c(v.Pb(),134),ie=a.u-a.n,ie>=P&&(ie>P&&(L.c.length=0,P=ie),It(L.c,a));L.c.length!=0&&(M=c(Xe(L,VH(t,L.c.length)),134),Rt.a.Ac(M)!=null,M.s=z++,Ive(M,bt,xe),L.c.length=0)}for(de=e.c.length+1,d=new G(e);d.a<d.c.c.length;)a=c(Q(d),134),a.s<S&&(a.s+=de);for(pt=new G(e);pt.a<pt.c.c.length;)for(We=c(Q(pt),134),n=new os(We.t,0);n.b<n.d.gc();)i=(dn(n.b<n.d.gc()),c(n.d.Xb(n.c=n.b++),275)),Dt=i.b,We.s>Dt.s&&(iu(n),fl(Dt.i,i),i.c>0&&(i.a=Dt,qe(Dt.t,i),i.b=We,qe(We.i,i)))}function wst(e,t,n,i,r){var o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt,Rt;for(z=new Hc(t.b),de=new Hc(t.b),M=new Hc(t.b),pt=new Hc(t.b),H=new Hc(t.b),We=_n(t,0);We.b!=We.d.c;)for(Se=c(An(We),12),d=new G(Se.g);d.a<d.c.c.length;)if(o=c(Q(d),17),o.c.i==o.d.i){if(Se.j==o.d.j){It(pt.c,o);continue}else if(Se.j==(Je(),Kt)&&o.d.j==bn){It(H.c,o);continue}}for(b=new G(H);b.a<b.c.c.length;)o=c(Q(b),17),xWt(e,o,n,i,(Je(),nn));for(a=new G(pt);a.a<a.c.c.length;)o=c(Q(a),17),bt=new Eh(e),mu(bt,(Jt(),Dc)),Ee(bt,(Ge(),cr),(Zr(),xc)),Ee(bt,(De(),Oi),o),Dt=new bc,Ee(Dt,Oi,o.d),$r(Dt,(Je(),Yt)),_o(Dt,bt),Rt=new bc,Ee(Rt,Oi,o.c),$r(Rt,nn),_o(Rt,bt),Ee(o.c,Ul,bt),Ee(o.d,Ul,bt),ks(o,null),ss(o,null),It(n.c,bt),Ee(bt,HU,Pe(2));for(xe=_n(t,0);xe.b!=xe.d.c;)Se=c(An(xe),12),v=Se.e.c.length>0,X=Se.g.c.length>0,v&&X?It(M.c,Se):v?It(z.c,Se):X&&It(de.c,Se);for(P=new G(z);P.a<P.c.c.length;)L=c(Q(P),12),qe(r,Mye(e,L,null,n));for(se=new G(de);se.a<se.c.c.length;)ie=c(Q(se),12),qe(r,Mye(e,null,ie,n));for(S=new G(M);S.a<S.c.c.length;)x=c(Q(S),12),qe(r,Mye(e,x,x,n))}function Die(e){var t,n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se;for(M=nr,L=nr,x=0,S=0,b=new Fe,d=new cn((!e.b&&(e.b=new Me(Ii,e,12,3)),e.b));d.e!=d.i.gc();)o=c(un(d),74),b=ma(W(V(Ta,1),Lt,22,0,[b,(!o.n&&(o.n=new Me(Bo,o,1,7)),o.n)]));for(se=Bd(ma(W(V(Ta,1),Lt,22,0,[(!e.n&&(e.n=new Me(Bo,e,1,7)),e.n),(!e.a&&(e.a=new Me(Mn,e,10,11)),e.a),b])));hn(se);)ie=c(sn(se),278),v=c(ie.mf((Dn(),Y1)),125),M>ie.mh()-v.b&&(M=ie.mh()-v.b),L>ie.nh()-v.d&&(L=ie.nh()-v.d),x<ie.mh()+ie.lh()+v.c&&(x=ie.mh()+ie.lh()+v.c),S<ie.nh()+ie.kh()+v.a&&(S=ie.nh()+ie.kh()+v.a);for(a=new cn((!e.b&&(e.b=new Me(Ii,e,12,3)),e.b));a.e!=a.i.gc();)for(o=c(un(a),74),X=new cn((!o.a&&(o.a=new Me(Hi,o,6,6)),o.a));X.e!=X.i.gc();)for(H=c(un(X),171),P=H.j,i=H.b,z=H.k,r=H.c,M=p.Math.min(M,P),M=p.Math.min(M,i),x=p.Math.max(x,P),x=p.Math.max(x,i),L=p.Math.min(L,z),L=p.Math.min(L,r),S=p.Math.max(S,z),S=p.Math.max(S,r),n=new cn((!H.a&&(H.a=new Ar(Yu,H,5)),H.a));n.e!=n.i.gc();)t=c(un(n),373),M=p.Math.min(M,t.a),x=p.Math.max(x,t.a),L=p.Math.min(L,t.b),S=p.Math.max(S,t.b);ii(e,(Dn(),ty),x-M),ii(e,ey,S-L)}function vst(e){var t,n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt,Rt,fn,ti,Zi;for(L=c(R(e,(N0(),gk)),19),se=di,de=di,X=ls,ie=ls,xe=new G(e.e);xe.a<xe.c.c.length;)Se=c(Q(xe),156),Rt=Se.d,fn=Se.e,se=p.Math.min(se,Rt.a-fn.a/2),de=p.Math.min(de,Rt.b-fn.b/2),X=p.Math.max(X,Rt.a+fn.a/2),ie=p.Math.max(ie,Rt.b+fn.b/2);for(n=new G(e.b);n.a<n.c.c.length;)t=c(Q(n),254),Rt=t.d,fn=t.e,se=p.Math.min(se,Rt.a-fn.a/2),de=p.Math.min(de,Rt.b-fn.b/2),X=p.Math.max(X,Rt.a+fn.a/2),ie=p.Math.max(ie,Rt.b+fn.b/2);for(Dt=c(ke(L,(Sf(),iht)),100),bt=new $e(Dt.b-se,Dt.d-de),v=new G(e.e);v.a<v.c.c.length;)b=c(Q(v),156),pt=R(b,gk),oe(pt,209)&&(z=c(pt,19),We=ki(new Cs(b.d),bt),aa(z,We.a-z.g/2,We.b-z.f/2));for(o=new G(e.c);o.a<o.c.c.length;)r=c(Q(o),292),S=c(R(r,gk),74),M=$T(S),ti=new Cs(Ybe(r)),ki(ti,bt),m_(M,ti.a,ti.b),Qc(r.a,new JIe(bt,M)),i=new Cs(Zbe(r)),ki(i,bt),b_(M,i.a,i.b);for(d=new G(e.d);d.a<d.c.c.length;)a=c(Q(d),448),P=c(R(a,gk),158),H=ki(new Cs(a.d),bt),aa(P,H.a,H.b);Zi=X-se+(Dt.b+Dt.c),x=ie-de+(Dt.d+Dt.a),et(Ze(ke(L,(Dn(),ny))))||uw(L,Zi,x,!1,!0),ii(L,ty,Zi-(Dt.b+Dt.c)),ii(L,ey,x-(Dt.d+Dt.a))}function ttn(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se;for(n.Tg("Depth first model order layering",1),e.d=t,H=new Fe,z=new G(e.d.a);z.a<z.c.c.length;)L=c(Q(z),9),L.k==(Jt(),or)&&It(H.c,L);for(Ct(),Rr(H,new aA),a=!0,e.b=new hc(e.d),e.a=null,qe(e.d.b,e.b),e.b.p=0,e.c=0,e.f=new Ai,P=new G(H);P.a<P.c.c.length;)if(L=c(Q(P),9),a)zr(L,e.b),a=!1;else if(dKt(e,L))if(M=e.c,M=oYe(M,L),i=M+2,x=M-e.c,e.f.b==0)Kve(e,i,L);else if(x>0){for(se=_n(e.f,0);se.b!=se.d.c;)ie=c(An(se),9),ie.p+=M-e.e;Y2e(e),Ou(e.f),Kve(e,i,L)}else{for(ei(e.f,L),L.p=i,e.e=p.Math.max(e.e,i),o=new Ht(Vt(pr(L).a.Jc(),new U));hn(o);)r=c(sn(o),17),!r.c.i.c&&r.c.i.k==(Jt(),lc)&&(ei(e.f,r.c.i),r.c.i.p=i-1);e.c=i}else Y2e(e),Ou(e.f),i=0,hn(new Ht(Vt(pr(L).a.Jc(),new U)))?(M=0,M=oYe(M,L),i=M+2,Kve(e,i,L)):(ei(e.f,L),L.p=0,e.e=p.Math.max(e.e,0),e.b=c(Xe(e.d.b,0),26),e.c=0);for(e.f.b==0||Y2e(e),e.d.a.c.length=0,X=new Fe,v=new G(e.d.b);v.a<v.c.c.length;)d=c(Q(v),26),d.a.c.length==0&&It(X.c,d);for(hwe(e.d.b,X),S=0,b=new G(e.d.b);b.a<b.c.c.length;)d=c(Q(b),26),d.p=S,++S;n.Ug()}function ntn(e,t,n){var i,r,o,a,d,b,v,x,S;if(n.Tg("Network simplex node placement",1),e.e=t,e.n=c(R(t,(De(),d3)),317),dYt(e),Fqt(e),lr(So(new jt(null,new Tt(e.e.b,16)),new m4),new O_e(e)),lr(pi(So(pi(So(new jt(null,new Tt(e.e.b,16)),new RR),new Xy),new $R),new g2),new k_e(e)),et(Ze(R(e.e,(Ge(),ZE))))&&(a=n.dh(1),a.Tg("Straight Edges Pre-Processing",1),$Zt(e),a.Ug()),jzt(e.f),o=c(R(t,nC),15).a*e.f.a.c.length,fie(Yde(Zde(xZ(e.f),o),!1),n.dh(1)),e.d.a.gc()!=0){for(a=n.dh(1),a.Tg("Flexible Where Space Processing",1),d=c(vu(m5(qc(new jt(null,new Tt(e.f.a,16)),new dA),new _R)),15).a,b=c(vu(Q2(qc(new jt(null,new Tt(e.f.a,16)),new ej),new Gy)),15).a,v=b-d,x=Dm(new Fp,e.f),S=Dm(new Fp,e.f),Of(uf(ff(af(hf(new Ra,2e4),v),x),S)),lr(pi(pi(QZ(e.i),new LR),new Uy),new Vqe(d,x,v,S)),r=e.d.a.ec().Jc();r.Ob();)i=c(r.Pb(),220),i.g=1;fie(Yde(Zde(xZ(e.f),o),!1),a.dh(1)),a.Ug()}et(Ze(R(t,ZE)))&&(a=n.dh(1),a.Tg("Straight Edges Post-Processing",1),AQt(e),a.Ug()),yZt(e),e.e=null,e.f=null,e.i=null,e.c=null,sc(e.k),e.j=null,e.a=null,e.o=null,e.d.a.$b(),n.Ug()}function yst(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt;return S=FWt(ul(e,(Je(),Qh)),t),P=Lx(ul(e,Pf),t),de=Lx(ul(e,Wu),t),pt=eQ(ul(e,Za),t),M=eQ(ul(e,Ma),t),ie=Lx(ul(e,If),t),z=Lx(ul(e,Xl),t),xe=Lx(ul(e,Ku),t),Se=Lx(ul(e,Aa),t),bt=eQ(ul(e,ol),t),X=Lx(ul(e,vl),t),se=Lx(ul(e,Vl),t),We=Lx(ul(e,wl),t),Dt=eQ(ul(e,yl),t),L=eQ(ul(e,Il),t),H=Lx(ul(e,Pc),t),n=jx(W(V(ns,1),no,30,15,[ie.a,pt.a,xe.a,Dt.a])),i=jx(W(V(ns,1),no,30,15,[P.a,S.a,de.a,H.a])),r=X.a,o=jx(W(V(ns,1),no,30,15,[z.a,M.a,Se.a,L.a])),v=jx(W(V(ns,1),no,30,15,[ie.b,P.b,z.b,se.b])),b=jx(W(V(ns,1),no,30,15,[pt.b,S.b,M.b,H.b])),x=bt.b,d=jx(W(V(ns,1),no,30,15,[xe.b,de.b,Se.b,We.b])),Ag(ul(e,Qh),n+r,v+x),Ag(ul(e,Pc),n+r,v+x),Ag(ul(e,Pf),n+r,0),Ag(ul(e,Wu),n+r,v+x+b),Ag(ul(e,Za),0,v+x),Ag(ul(e,Ma),n+r+i,v+x),Ag(ul(e,Xl),n+r+i,0),Ag(ul(e,Ku),0,v+x+b),Ag(ul(e,Aa),n+r+i,v+x+b),Ag(ul(e,ol),0,v),Ag(ul(e,vl),n,0),Ag(ul(e,wl),0,v+x+b),Ag(ul(e,Il),n+r+i,0),a=new as,a.a=jx(W(V(ns,1),no,30,15,[n+i+r+o,bt.a,se.a,We.a])),a.b=jx(W(V(ns,1),no,30,15,[v+b+x+d,X.b,Dt.b,L.b])),a}function itn(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt,Rt,fn,ti,Zi,Wl,po;if(Dt=null,fn=t,Rt=jXe(e,gGe(n),fn),nS(Rt,M1(fn,bd)),ti=c(Tx(e.n,G5(C1(fn,Jse))),19),M=C1(fn,"sourcePort"),i=null,M&&(i=G5(M)),Zi=c(Tx(e.p,i),127),!ti)throw d=kS(fn),P="An edge must have a source node (edge id: '"+d,z=P+w9,J(new Kh(z));if(Zi&&!dc(yh(Zi),ti))throw b=M1(fn,bd),H="The source port of an edge must be a port of the edge's source node (edge id: '"+b,X=H+w9,J(new Kh(X));if(pt=(!Rt.b&&(Rt.b=new Et(vn,Rt,4,7)),Rt.b),o=null,Zi?o=Zi:o=ti,Nn(pt,o),Wl=c(Tx(e.n,G5(C1(fn,w5e))),19),L=C1(fn,"targetPort"),r=null,L&&(r=G5(L)),po=c(Tx(e.p,r),127),!Wl)throw S=kS(fn),ie="An edge must have a target node (edge id: '"+S,se=ie+w9,J(new Kh(se));if(po&&!dc(yh(po),Wl))throw v=M1(fn,bd),de="The target port of an edge must be a port of the edge's target node (edge id: '"+v,Se=de+w9,J(new Kh(Se));if(bt=(!Rt.c&&(Rt.c=new Et(vn,Rt,5,8)),Rt.c),a=null,po?a=po:a=Wl,Nn(bt,a),(!Rt.b&&(Rt.b=new Et(vn,Rt,4,7)),Rt.b).i==0||(!Rt.c&&(Rt.c=new Et(vn,Rt,5,8)),Rt.c).i==0)throw x=M1(fn,bd),xe=zlt+x,We=xe+w9,J(new Kh(We));return lQ(fn,Rt),SUt(fn,Rt),Dt=Tte(e,fn,Rt),Dt}function xst(e){var t,n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt;for(ie=new $e(nr,nr),t=new $e(Qr,Qr),pt=new G(e);pt.a<pt.c.c.length;)We=c(Q(pt),8),ie.a=p.Math.min(ie.a,We.a),ie.b=p.Math.min(ie.b,We.b),t.a=p.Math.max(t.a,We.a),t.b=p.Math.max(t.b,We.b);for(M=new $e(t.a-ie.a,t.b-ie.b),v=new $e(ie.a-50,ie.b-M.a-50),x=new $e(ie.a-50,t.b+M.a+50),S=new $e(t.a+M.b/2+50,ie.b+M.b/2),L=new Eye(v,x,S),xe=new Or,o=new Fe,n=new Fe,xe.a.yc(L,xe),Dt=new G(e);Dt.a<Dt.c.c.length;){for(bt=c(Q(Dt),8),o.c.length=0,Se=xe.a.ec().Jc();Se.Ob();)se=c(Se.Pb(),322),i=se.d,A0(i,se.a),ew(A0(se.d,bt),A0(se.d,se.a))<0&&It(o.c,se);for(n.c.length=0,de=new G(o);de.a<de.c.c.length;)for(se=c(Q(de),322),H=new G(se.e);H.a<H.c.c.length;){for(P=c(Q(H),180),a=!0,b=new G(o);b.a<b.c.c.length;)d=c(Q(b),322),d!=se&&(dc(P,Xe(d.e,0))||dc(P,Xe(d.e,1))||dc(P,Xe(d.e,2)))&&(a=!1);a&&It(n.c,P)}for(DZe(xe,o),ws(xe,new eu),z=new G(n);z.a<z.c.c.length;)P=c(Q(z),180),Sr(xe,new Eye(bt,P.a,P.b))}for(X=new Or,ws(xe,new KAe(X)),r=X.a.ec().Jc();r.Ob();)P=c(r.Pb(),180),(Jq(L,P.a)||Jq(L,P.b))&&r.Qb();return ws(X,new Un),X}function oc(){oc=te,EPe(),T2t=Wr.a,c(re(Ne(Wr.a),0),20),S2t=Wr.f,c(re(Ne(Wr.f),0),20),c(re(Ne(Wr.f),1),38),j2t=Wr.n,c(re(Ne(Wr.n),0),38),c(re(Ne(Wr.n),1),38),c(re(Ne(Wr.n),2),38),c(re(Ne(Wr.n),3),38),dTe=Wr.g,c(re(Ne(Wr.g),0),20),c(re(Ne(Wr.g),1),38),O2t=Wr.c,c(re(Ne(Wr.c),0),20),c(re(Ne(Wr.c),1),20),gTe=Wr.i,c(re(Ne(Wr.i),0),20),c(re(Ne(Wr.i),1),20),c(re(Ne(Wr.i),2),20),c(re(Ne(Wr.i),3),20),c(re(Ne(Wr.i),4),38),pTe=Wr.j,c(re(Ne(Wr.j),0),20),hTe=Wr.d,c(re(Ne(Wr.d),0),20),c(re(Ne(Wr.d),1),20),c(re(Ne(Wr.d),2),20),c(re(Ne(Wr.d),3),20),c(re(Ne(Wr.d),4),38),c(re(Ne(Wr.d),5),38),c(re(Ne(Wr.d),6),38),c(re(Ne(Wr.d),7),38),k2t=Wr.b,c(re(Ne(Wr.b),0),38),c(re(Ne(Wr.b),1),38),iX=Wr.e,c(re(Ne(Wr.e),0),38),c(re(Ne(Wr.e),1),38),c(re(Ne(Wr.e),2),38),c(re(Ne(Wr.e),3),38),c(re(Ne(Wr.e),4),20),c(re(Ne(Wr.e),5),20),c(re(Ne(Wr.e),6),20),c(re(Ne(Wr.e),7),20),c(re(Ne(Wr.e),8),20),c(re(Ne(Wr.e),9),20),c(re(Ne(Wr.e),10),38),s1=Wr.k,c(re(Ne(Wr.k),0),38),c(re(Ne(Wr.k),1),38)}function Xye(e){var t,n,i,r,o;switch(t=e.c,t){case 11:return e.tm();case 12:return e.vm();case 14:return e.xm();case 15:return e.Am();case 16:return e.ym();case 17:return e.Bm();case 21:return bi(e),wi(),wi(),KC;case 10:switch(e.a){case 65:return e.fm();case 90:return e.km();case 122:return e.rm();case 98:return e.lm();case 66:return e.gm();case 60:return e.qm();case 62:return e.om()}}switch(o=Zen(e),t=e.c,t){case 3:return e.Gm(o);case 4:return e.Em(o);case 5:return e.Fm(o);case 0:if(e.a==123&&e.d<e.j){if(r=e.d,i=0,n=-1,(t=ms(e.i,r++))>=48&&t<=57){for(i=t-48;r<e.j&&(t=ms(e.i,r++))>=48&&t<=57;)if(i=i*10+t-48,i<0)throw J(new Qn(Vn((Bn(),S5e))))}else throw J(new Qn(Vn((Bn(),put))));if(n=i,t==44){if(r>=e.j)throw J(new Qn(Vn((Bn(),mut))));if((t=ms(e.i,r++))>=48&&t<=57){for(n=t-48;r<e.j&&(t=ms(e.i,r++))>=48&&t<=57;)if(n=n*10+t-48,n<0)throw J(new Qn(Vn((Bn(),S5e))));if(i>n)throw J(new Qn(Vn((Bn(),wut))))}else n=-1}if(t!=125)throw J(new Qn(Vn((Bn(),but))));e._l(r)?(o=(wi(),wi(),new Z2(9,o)),e.d=r+1):(o=(wi(),wi(),new Z2(3,o)),e.d=r),o.Mm(i),o.Lm(n),bi(e)}}return o}function rtn(e){var t,n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se;for(r=1,L=new Fe,i=0;i<e.b.c.length;i++){if(t=TQt(c(Xe(e.b,i),26)),se=Zzt(c(Xe(e.b,i),26)),x=Kzt(c(Xe(e.b,i),26)),x){for(v=0,n=0,z=new G(c(Xe(e.b,i),26).a);z.a<z.c.c.length;)P=c(Q(z),9),v=p.Math.max(v,P.o.a),n+=P.o.b;if(n/=c(Xe(e.b,i),26).a.c.length,v+=p.Math.max(2*ue(he(R(e,(Ge(),ip)))),p.Math.max(c(Xe(e.b,i),26).a.c.length*ue(he(R(e,Jv))),ue(he(R(e,Vv))))),n+=p.Math.max(ue(he(R(e,$b))),ue(he(R(e,Rb)))),v/n>=c(Xe(e.b,i),26).a.c.length/4)continue}if(c(Xe(e.b,i),26).a.c.length>t){for(de=new Fe,qe(de,c(Xe(e.b,i),26)),a=0;a<t-1;a++)S=new hc(e),qe(L,new Ps(S,Pe(i+a+r))),It(de.c,S);for(r+=t-1,ie=(ht(0,de.c.length),c(de.c[0],26)).a.c.length,o=0,H=0,Se=0;o<ie;++o,++H,Se++)P=c(Xe((ht(0,de.c.length),c(de.c[0],26)).a,H),9),P.k!=(Jt(),PE)?H+=Den(e,de,Se%t,H):(o-=1,Se-=1),se&&P.k==jr&&(Se=-1)}}for(M=new G(L);M.a<M.c.c.length;)S=c(Q(M),49),Up(e.b,c(S.b,15).a,c(S.a,26));for(b=new G(e.b);b.a<b.c.c.length;)for(d=c(Q(b),26),X=new os(d.a,0);X.b<X.d.gc();)P=(dn(X.b<X.d.gc()),c(X.d.Xb(X.c=X.b++),9)),(P.k==(Jt(),UL)||P.k==PE)&&iu(X)}function aw(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H;if(n==null)return null;if(e.a!=t.hk())throw J(new qt(p9+t.ve()+xw));if(oe(t,462)){if(H=JXt(c(t,682),n),!H)throw J(new qt(Gse+n+"' is not a valid enumerator of '"+t.ve()+"'"));return H}switch(Pg((Dl(),ps),t).Ll()){case 2:{n=Nc(n,!1);break}case 3:{n=Nc(n,!0);break}}if(i=Pg(ps,t).Hl(),i)return i.hk().ti().qi(i,n);if(M=Pg(ps,t).Jl(),M){for(H=new Fe,v=_te(n),x=0,S=v.length;x<S;++x)b=v[x],qe(H,M.hk().ti().qi(M,b));return H}if(z=Pg(ps,t).Kl(),!z.dc()){for(P=z.Jc();P.Ob();){L=c(P.Pb(),160);try{if(H=L.hk().ti().qi(L,n),H!=null)return H}catch(X){if(X=vr(X),!oe(X,63))throw J(X)}}throw J(new qt(Gse+n+"' does not match any member types of the union datatype '"+t.ve()+"'"))}if(c(t,839).mk(),r=DRt(t.ik()),!r)return null;if(r==CE){a=0;try{a=Hu(n,ls,di)&_r}catch(X){if(X=vr(X),oe(X,133))o=Xq(n),a=o[0];else throw J(X)}return dD(a)}if(r==KG){for(d=0;d<qC.length;++d)try{return PIe(qC[d],n)}catch(X){if(X=vr(X),!oe(X,33))throw J(X)}throw J(new qt(Gse+n+"' is not a date formatted string of the form yyyy-MM-dd'T'HH:mm:ss'.'SSSZ or a valid subset thereof"))}throw J(new qt(Gse+n+"' is invalid. "))}function Lie(){Lie=te,Ni=new Qm,St(Ni,(Je(),Qh),Pc),St(Ni,Za,Pc),St(Ni,Za,yl),St(Ni,Ma,Il),St(Ni,Ma,Pc),St(Ni,Pf,Pc),St(Ni,Pf,Vl),St(Ni,Wu,wl),St(Ni,Wu,Pc),St(Ni,vl,ol),St(Ni,vl,Pc),St(Ni,vl,Vl),St(Ni,vl,wl),St(Ni,ol,vl),St(Ni,ol,yl),St(Ni,ol,Il),St(Ni,ol,Pc),St(Ni,If,If),St(Ni,If,Vl),St(Ni,If,yl),St(Ni,Xl,Xl),St(Ni,Xl,Vl),St(Ni,Xl,Il),St(Ni,Ku,Ku),St(Ni,Ku,wl),St(Ni,Ku,yl),St(Ni,Aa,Aa),St(Ni,Aa,wl),St(Ni,Aa,Il),St(Ni,Vl,Pf),St(Ni,Vl,vl),St(Ni,Vl,If),St(Ni,Vl,Xl),St(Ni,Vl,Pc),St(Ni,Vl,Vl),St(Ni,Vl,yl),St(Ni,Vl,Il),St(Ni,wl,Wu),St(Ni,wl,vl),St(Ni,wl,Ku),St(Ni,wl,Aa),St(Ni,wl,wl),St(Ni,wl,yl),St(Ni,wl,Il),St(Ni,wl,Pc),St(Ni,yl,Za),St(Ni,yl,ol),St(Ni,yl,If),St(Ni,yl,Ku),St(Ni,yl,Vl),St(Ni,yl,wl),St(Ni,yl,yl),St(Ni,yl,Pc),St(Ni,Il,Ma),St(Ni,Il,ol),St(Ni,Il,Xl),St(Ni,Il,Aa),St(Ni,Il,Vl),St(Ni,Il,wl),St(Ni,Il,Il),St(Ni,Il,Pc),St(Ni,Pc,Qh),St(Ni,Pc,Za),St(Ni,Pc,Ma),St(Ni,Pc,Pf),St(Ni,Pc,Wu),St(Ni,Pc,vl),St(Ni,Pc,ol),St(Ni,Pc,Vl),St(Ni,Pc,wl),St(Ni,Pc,yl),St(Ni,Pc,Il),St(Ni,Pc,Pc)}function Vye(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt;for(e.d=new $e(nr,nr),e.c=new $e(Qr,Qr),M=t.Jc();M.Ob();)for(x=c(M.Pb(),37),se=new G(x.a);se.a<se.c.c.length;)ie=c(Q(se),9),e.d.a=p.Math.min(e.d.a,ie.n.a-ie.d.b),e.d.b=p.Math.min(e.d.b,ie.n.b-ie.d.d),e.c.a=p.Math.max(e.c.a,ie.n.a+ie.o.a+ie.d.c),e.c.b=p.Math.max(e.c.b,ie.n.b+ie.o.b+ie.d.a);for(d=new aLe,S=t.Jc();S.Ob();)x=c(S.Pb(),37),i=zen(e,x),qe(d.a,i),i.a=i.a|!c(R(i.c,(De(),X1)),24).dc();for(e.b=(Dte(),pt=new ph,pt.f=new LXe(n),pt.b=JYt(pt.f,d),pt),lZt((P=e.b,new V4,P)),e.e=new as,e.a=e.b.f.e,a=new G(d.a);a.a<a.c.c.length;)for(r=c(Q(a),847),de=bNt(e.b,r),MVt(r.c,de.a,de.b),H=new G(r.c.a);H.a<H.c.c.length;)z=c(Q(H),9),z.k==(Jt(),Cr)&&(X=Rve(e,z.n,c(R(z,(De(),Ko)),64)),ki(Xf(z.n),X));for(o=new G(d.a);o.a<o.c.c.length;)for(r=c(Q(o),847),v=new G(h$t(r));v.a<v.c.c.length;)for(b=c(Q(v),17),We=new Ez(b.a),M6(We,0,xh(b.c)),ei(We,xh(b.d)),L=null,xe=_n(We,0);xe.b!=xe.d.c;){if(Se=c(An(xe),8),!L){L=Se;continue}Ube(L.a,Se.a)?(e.e.a=p.Math.min(e.e.a,L.a),e.a.a=p.Math.max(e.a.a,L.a)):Ube(L.b,Se.b)&&(e.e.b=p.Math.min(e.e.b,L.b),e.a.b=p.Math.max(e.a.b,L.b)),L=Se}MF(e.e),ki(e.a,e.e)}function stn(e,t){var n,i,r,o,a,d,b,v;if(n=0,a=0,o=t.length,d=null,v=new Z4,a<o&&(en(a,t.length),t.charCodeAt(a)==43)&&(++a,++n,a<o&&(en(a,t.length),t.charCodeAt(a)==43||(en(a,t.length),t.charCodeAt(a)==45))))throw J(new Yh(hw+t+'"'));for(;a<o&&(en(a,t.length),t.charCodeAt(a)!=46)&&(en(a,t.length),t.charCodeAt(a)!=101)&&(en(a,t.length),t.charCodeAt(a)!=69);)++a;if(v.a+=""+Fa(t==null?pl:(zt(t),t),n,a),a<o&&(en(a,t.length),t.charCodeAt(a)==46)){for(++a,n=a;a<o&&(en(a,t.length),t.charCodeAt(a)!=101)&&(en(a,t.length),t.charCodeAt(a)!=69);)++a;e.e=a-n,v.a+=""+Fa(t==null?pl:(zt(t),t),n,a)}else e.e=0;if(a<o&&(en(a,t.length),t.charCodeAt(a)==101||(en(a,t.length),t.charCodeAt(a)==69))&&(++a,n=a,a<o&&(en(a,t.length),t.charCodeAt(a)==43)&&(++a,a<o&&(en(a,t.length),t.charCodeAt(a)!=45)&&++n),d=(fs(n,o,t.length),t.substr(n,o-n)),e.e=e.e-Hu(d,ls,di),e.e!=xs(e.e)))throw J(new Yh("Scale out of range."));if(b=v.a,b.length<16){if(e.f=(fke==null&&(fke=new RegExp("^[+-]?\\d*$","i")),fke.test(b)?parseInt(b,10):NaN),isNaN(e.f))throw J(new Yh(hw+t+'"'));e.a=ave(e.f)}else r$t(e,new O0(b));for(e.d=v.a.length,r=0;r<v.a.length&&(i=ms(v.a,r),!(i!=45&&i!=48));++r)--e.d;e.d==0&&(e.d=1)}function otn(e){In(e.b,Ja,W(V(nt,1),Be,2,6,[kw,"ConsistentTransient"])),In(e.a,Ja,W(V(nt,1),Be,2,6,[kw,"WellFormedSourceURI"])),In(e.o,Ja,W(V(nt,1),Be,2,6,[kw,"InterfaceIsAbstract AtMostOneID UniqueFeatureNames UniqueOperationSignatures NoCircularSuperTypes WellFormedMapEntryClass ConsistentSuperTypes DisjointFeatureAndOperationSignatures"])),In(e.p,Ja,W(V(nt,1),Be,2,6,[kw,"WellFormedInstanceTypeName UniqueTypeParameterNames"])),In(e.v,Ja,W(V(nt,1),Be,2,6,[kw,"UniqueEnumeratorNames UniqueEnumeratorLiterals"])),In(e.R,Ja,W(V(nt,1),Be,2,6,[kw,"WellFormedName"])),In(e.T,Ja,W(V(nt,1),Be,2,6,[kw,"UniqueParameterNames UniqueTypeParameterNames NoRepeatingVoid"])),In(e.U,Ja,W(V(nt,1),Be,2,6,[kw,"WellFormedNsURI WellFormedNsPrefix UniqueSubpackageNames UniqueClassifierNames UniqueNsURIs"])),In(e.W,Ja,W(V(nt,1),Be,2,6,[kw,"ConsistentOpposite SingleContainer ConsistentKeys ConsistentUnique ConsistentContainer"])),In(e.bb,Ja,W(V(nt,1),Be,2,6,[kw,"ValidDefaultValueLiteral"])),In(e.eb,Ja,W(V(nt,1),Be,2,6,[kw,"ValidLowerBound ValidUpperBound ConsistentBounds ValidType"])),In(e.H,Ja,W(V(nt,1),Be,2,6,[kw,"ConsistentType ConsistentBounds ConsistentArguments"]))}function ctn(e){var t,n,i,r,o;switch(n=c(R(e,(De(),Lc)),24),t=vF(Oht),r=c(R(e,(Ge(),Fv)),348),r==(R1(),Zg)&&Fu(t,Sht),et(Ze(R(e,lle)))?Wn(t,(es(),Cf),(cs(),lce)):Wn(t,(es(),vc),(cs(),lce)),R(e,(Bq(),jC))!=null&&Fu(t,jht),(et(Ze(R(e,OSe)))||et(Ze(R(e,vSe))))&&Fc(t,(es(),Vs),(cs(),lOe)),c(R(e,Xu),87).g){case 2:case 3:case 4:Fc(Wn(t,(es(),Cf),(cs(),aOe)),Vs,uOe)}switch(n.Gc((Gs(),BU))&&Fc(Wn(Wn(t,(es(),Cf),(cs(),cOe)),yc,sOe),Vs,oOe),ve(R(e,cP))!==ve((H0(),gJ))&&Wn(t,(es(),vc),(cs(),jOe)),n.Gc(FU)&&(Wn(t,(es(),Cf),(cs(),MOe)),Wn(t,Zd,EOe),Wn(t,vc,COe)),ve(R(e,WU))!==ve((MS(),BE))&&ve(R(e,W1))!==ve(($1(),DP))&&Fc(t,(es(),Vs),(cs(),vOe)),et(Ze(R(e,xSe)))&&Wn(t,(es(),vc),(cs(),wOe)),et(Ze(R(e,sle)))&&Wn(t,(es(),vc),(cs(),AOe)),pJt(e)&&(ve(R(e,Fv))===ve(Zg)?i=c(R(e,oP),303):i=c(R(e,rle),303),o=i==(cS(),$ce)?(cs(),TOe):(cs(),DOe),Wn(t,(es(),yc),o)),c(R(e,MSe),428).g==1&&Wn(t,(es(),yc),(cs(),eOe)),c(R(e,WSe),383).g){case 1:Wn(t,(es(),yc),(cs(),NOe));break;case 2:Fc(Wn(Wn(t,(es(),vc),(cs(),tOe)),yc,nOe),Vs,iOe)}return ve(R(e,t1))!==ve((B1(),rp))&&Wn(t,(es(),vc),(cs(),_Oe)),t}function ltn(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt;if(!t.dc()){if(r=new nu,d=n||c(t.Xb(0),17),P=d.c,BT(),M=P.i.k,!(M==(Jt(),or)||M==Dc||M==Cr||M==Ih))throw J(new qt("The target node of the edge must be a normal node or a northSouthPort."));for(Es(r,Lo(W(V(Vr,1),Be,8,0,[P.i.n,P.n,P.a]))),(Je(),vl).Gc(P.j)&&(H=ue(he(R(P,(De(),I9)))),S=new $e(Lo(W(V(Vr,1),Be,8,0,[P.i.n,P.n,P.a])).a,H),tr(r,S,r.c.b,r.c)),x=null,i=!1,b=t.Jc();b.Ob();)a=c(b.Pb(),17),o=a.a,o.b!=0&&(i?(v=S1(ki(x,(dn(o.b!=0),c(o.a.a.c,8))),.5),tr(r,v,r.c.b,r.c),i=!1):i=!0,x=Ms((dn(o.b!=0),c(o.c.b.c,8))),Os(r,o),Ou(o));z=d.d,vl.Gc(z.j)&&(H=ue(he(R(z,(De(),I9)))),S=new $e(Lo(W(V(Vr,1),Be,8,0,[z.i.n,z.n,z.a])).a,H),tr(r,S,r.c.b,r.c)),Es(r,Lo(W(V(Vr,1),Be,8,0,[z.i.n,z.n,z.a]))),e.d==(dS(),Ple)&&(X=(dn(r.b!=0),c(r.a.a.c,8)),ie=c(pc(r,1),8),se=new wee(qme(P.j)),se.a*=5,se.b*=5,de=Hr(new $e(ie.a,ie.b),X),Se=new $e(bee(se.a,de.a),bee(se.b,de.b)),ki(Se,X),xe=_n(r,1),oq(xe,Se),We=(dn(r.b!=0),c(r.c.b.c,8)),pt=c(pc(r,r.b-2),8),se=new wee(qme(z.j)),se.a*=5,se.b*=5,de=Hr(new $e(pt.a,pt.b),We),bt=new $e(bee(se.a,de.a),bee(se.b,de.b)),ki(bt,We),M6(r,r.b-1,bt)),L=new Cye(r),Os(d.a,vYe(L))}}function utn(e,t,n,i){var r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt,Rt,fn,ti,Zi,Wl,po,Zu,P3,o0,Rf,ng;if(se=c(re((!e.b&&(e.b=new Et(vn,e,4,7)),e.b),0),83),Se=se.mh(),xe=se.nh(),de=se.lh()/2,z=se.kh()/2,oe(se,196)&&(ie=c(se,127),Se+=yh(ie).i,Se+=yh(ie).i),Se+=de,xe+=z,Rt=c(re((!e.b&&(e.b=new Et(vn,e,4,7)),e.b),0),83),ti=Rt.mh(),Zi=Rt.nh(),fn=Rt.lh()/2,We=Rt.kh()/2,oe(Rt,196)&&(Dt=c(Rt,127),ti+=yh(Dt).i,ti+=yh(Dt).i),ti+=fn,Zi+=We,(!e.a&&(e.a=new Me(Hi,e,6,6)),e.a).i==0)d=(w0(),v=new VO,v),Nn((!e.a&&(e.a=new Me(Hi,e,6,6)),e.a),d);else if((!e.a&&(e.a=new Me(Hi,e,6,6)),e.a).i>1)for(P=new f5((!e.a&&(e.a=new Me(Hi,e,6,6)),e.a));P.e!=P.i.gc();)MT(P);for(a=c(re((!e.a&&(e.a=new Me(Hi,e,6,6)),e.a),0),171),H=ti,ti>Se+de?H=Se+de:ti<Se-de&&(H=Se-de),X=Zi,Zi>xe+z?X=xe+z:Zi<xe-z&&(X=xe-z),H>Se-de&&H<Se+de&&X>xe-z&&X<xe+z&&(H=Se+de),Vm(a,H),Wm(a,X),pt=Se,Se>ti+fn?pt=ti+fn:Se<ti-fn&&(pt=ti-fn),bt=xe,xe>Zi+We?bt=Zi+We:xe<Zi-We&&(bt=Zi-We),pt>ti-fn&&pt<ti+fn&&bt>Zi-We&&bt<Zi+We&&(bt=Zi+We),Jm(a,pt),Xm(a,bt),En((!a.a&&(a.a=new Ar(Yu,a,5)),a.a)),o=VH(t,5),se==Rt&&++o,Zu=pt-H,Rf=bt-X,Wl=p.Math.sqrt(Zu*Zu+Rf*Rf),S=Wl*.20000000298023224,P3=Zu/(o+1),ng=Rf/(o+1),po=H,o0=X,x=0;x<o;x++)po+=P3,o0+=ng,M=po+lu(t,24)*gL*S-S/2,M<0?M=1:M>n&&(M=n-1),L=o0+lu(t,24)*gL*S-S/2,L<0?L=1:L>i&&(L=i-1),r=(w0(),b=new y2,b),nH(r,M),tH(r,L),Nn((!a.a&&(a.a=new Ar(Yu,a,5)),a.a),r)}function Pie(e,t){vie();var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We;if(se=e.e,x=e.d,r=e.a,se==0)switch(t){case 0:return"0";case 1:return JS;case 2:return"0.00";case 3:return"0.000";case 4:return"0.0000";case 5:return"0.00000";case 6:return"0.000000";default:return X=new b0,X.a+="0E",X.a+=-t,X.a}if(z=x*10+1+7,H=ye(Na,fd,30,z+1,15,1),n=z,x==1)if(o=r[0],o<0){We=Yr(o,Us);do S=We,We=ID(We,10),H[--n]=48+Hn(Ha(S,Ss(We,10)))&_r;while(Mc(We,0)!=0)}else{We=o;do S=We,We=We/10|0,H[--n]=48+(S-We*10)&_r;while(We!=0)}else{de=ye(Fn,ci,30,x,15,1),xe=x,mc(r,0,de,0,xe);e:for(;;){for(ie=0,d=xe-1;d>=0;d--)Se=As($d(ie,32),Yr(de[d],Us)),L=iHt(Se),de[d]=Hn(L),ie=Hn(Im(L,32));P=Hn(ie),M=n;do H[--n]=48+P%10&_r;while((P=P/10|0)!=0&&n!=0);for(i=9-M+n,a=0;a<i&&n>0;a++)H[--n]=48;for(b=xe-1;de[b]==0;b--)if(b==0)break e;xe=b+1}for(;H[n]==48;)++n}return v=se<0,v&&(H[--n]=45),od(H,n,z-n)}function kst(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe;switch(e.c=t,e.g=new wn,n=(v0(),new wg(e.c)),i=new fz(n),jwe(i),se=zn(ke(e.c,($D(),bje))),b=c(ke(e.c,_ue),331),Se=c(ke(e.c,Due),432),a=c(ke(e.c,dje),480),de=c(ke(e.c,Nue),433),e.j=ue(he(ke(e.c,Emt))),d=e.a,b.g){case 0:d=e.a;break;case 1:d=e.b;break;case 2:d=e.i;break;case 3:d=e.e;break;case 4:d=e.f;break;default:throw J(new qt(jG+(b.f!=null?b.f:""+b.g)))}if(e.d=new RHe(d,Se,a),Ee(e.d,(rS(),_E),Ze(ke(e.c,jmt))),e.d.c=et(Ze(ke(e.c,gje))),gq(e.c).i==0)return e.d;for(S=new cn(gq(e.c));S.e!=S.i.gc();){for(x=c(un(S),19),L=x.g/2,M=x.f/2,xe=new $e(x.i+L,x.j+M);jc(e.g,xe);)$2(xe,(p.Math.random()-.5)*dd,(p.Math.random()-.5)*dd);z=c(ke(x,(Dn(),Y1)),125),H=new cQe(xe,new pf(xe.a-L-e.j/2-z.b,xe.b-M-e.j/2-z.d,x.g+e.j+(z.b+z.c),x.f+e.j+(z.d+z.a))),qe(e.d.i,H),oi(e.g,xe,new Ps(H,x))}switch(de.g){case 0:if(se==null)e.d.d=c(Xe(e.d.i,0),68);else for(ie=new G(e.d.i);ie.a<ie.c.c.length;)H=c(Q(ie),68),P=c(c(Ut(e.g,H.a),49).b,19).ih(),P!=null&&Ot(P,se)&&(e.d.d=H);break;case 1:for(r=new $e(e.c.g,e.c.f),r.a*=.5,r.b*=.5,$2(r,e.c.i,e.c.j),o=nr,X=new G(e.d.i);X.a<X.c.c.length;)H=c(Q(X),68),v=A0(H.a,r),v<o&&(o=v,e.d.d=H);break;default:throw J(new qt(jG+(de.f!=null?de.f:""+de.g)))}return e.d}function Ost(e){Am(e,new mb(Em(Sm(Tm(jm(new b1,Gl),"ELK Rectangle Packing"),"Algorithm for packing of unconnected boxes, i.e. graphs without edges. The given order of the boxes is always preserved and the main reading direction of the boxes is left to right. The algorithm is divided into two phases. One phase approximates the width in which the rectangles can be placed. The next phase places the rectangles in rows using the previously calculated width as bounding width and bundles rectangles with a similar height in blocks. A compaction step reduces the size of the drawing. Finally, the rectangles are expanded to fill their bounding box and eliminate empty unused spaces."),new w$))),Ie(e,Gl,ZS,1.3),Ie(e,Gl,n9,(Bt(),!1)),Ie(e,Gl,gw,U8e),Ie(e,Gl,dw,15),Ie(e,Gl,bG,Ve(omt)),Ie(e,Gl,Jx,Ve(umt)),Ie(e,Gl,ok,Ve(fmt)),Ie(e,Gl,sk,Ve(hmt)),Ie(e,Gl,i9,Ve(lmt)),Ie(e,Gl,t9,Ve(vue)),Ie(e,Gl,r9,Ve(dmt)),Ie(e,Gl,D4e,Ve(W8e)),Ie(e,Gl,L4e,Ve(V8e)),Ie(e,Gl,_4e,Ve(xue)),Ie(e,Gl,N4e,Ve(K8e)),Ie(e,Gl,P4e,Ve(G8e)),Ie(e,Gl,I4e,Ve(yue)),Ie(e,Gl,R4e,Ve(Q8e)),Ie(e,Gl,$4e,Ve(X8e)),Ie(e,Gl,e9,Ve(q8e)),Ie(e,Gl,wG,Ve(cmt)),Ie(e,Gl,C4e,Ve(xP)),Ie(e,Gl,E4e,Ve(F8e)),Ie(e,Gl,M4e,Ve(kP)),Ie(e,Gl,T4e,Ve(J8e)),Ie(e,Gl,A4e,Ve(H8e))}function atn(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt,Rt,fn,ti,Zi,Wl,po,Zu;for(n.Tg("Greedy cycle removal",1),e.b=t,se=t.a,Zu=se.c.length,e.a=ye(Fn,ci,30,Zu,15,1),e.d=ye(Fn,ci,30,Zu,15,1),e.c=ye(Fn,ci,30,Zu,15,1),v=0,X=new G(se);X.a<X.c.c.length;){for(z=c(Q(X),9),z.p=v,bt=new G(z.j);bt.a<bt.c.c.length;){for(xe=c(Q(bt),12),d=new G(xe.e);d.a<d.c.c.length;)i=c(Q(d),17),i.c.i!=z&&(fn=c(R(i,(Ge(),z9)),15).a,e.a[v]+=fn>0?fn+1:1);for(a=new G(xe.g);a.a<a.c.c.length;)i=c(Q(a),17),i.d.i!=z&&(fn=c(R(i,(Ge(),z9)),15).a,e.d[v]+=fn>0?fn+1:1)}e.d[v]==0?ei(e.f,z):e.a[v]==0&&ei(e.g,z),++v}for(P=-1,L=1,S=new Fe,e.e=c(R(t,(De(),kk)),237);Zu>0;){for(;e.f.b!=0;)Zi=c(TZ(e.f),9),e.c[Zi.p]=P--,gye(e,Zi),--Zu;for(;e.g.b!=0;)Wl=c(TZ(e.g),9),e.c[Wl.p]=L++,gye(e,Wl),--Zu;if(Zu>0){for(M=ls,ie=new G(se);ie.a<ie.c.c.length;)z=c(Q(ie),9),e.c[z.p]==0&&(de=e.d[z.p]-e.a[z.p],de>=M&&(de>M&&(S.c.length=0,M=de),It(S.c,z)));x=e.qg(S),e.c[x.p]=L++,gye(e,x),--Zu}}for(ti=se.c.length+1,v=0;v<se.c.length;v++)e.c[v]<0&&(e.c[v]+=ti);for(H=new G(se);H.a<H.c.c.length;)for(z=c(Q(H),9),Rt=YQe(z.j),We=Rt,pt=0,Dt=We.length;pt<Dt;++pt)for(xe=We[pt],Se=rd(xe.g),r=Se,o=0,b=r.length;o<b;++o)i=r[o],po=i.d.i.p,e.c[z.p]>e.c[po]&&(zg(i,!0),Ee(t,wk,(Bt(),!0)));e.a=null,e.d=null,e.c=null,Ou(e.g),Ou(e.f),n.Ug()}function Sst(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe;for(Se=c(re((!e.a&&(e.a=new Me(Hi,e,6,6)),e.a),0),171),x=new nu,de=new wn,xe=_it(Se),gl(de.f,Se,xe),M=new wn,i=new Ai,P=Bd(ma(W(V(Ta,1),Lt,22,0,[(!t.d&&(t.d=new Et(Ii,t,8,5)),t.d),(!t.e&&(t.e=new Et(Ii,t,7,4)),t.e)])));hn(P);){if(L=c(sn(P),74),(!e.a&&(e.a=new Me(Hi,e,6,6)),e.a).i!=1)throw J(new qt(Olt+(!e.a&&(e.a=new Me(Hi,e,6,6)),e.a).i));L!=e&&(H=c(re((!L.a&&(L.a=new Me(Hi,L,6,6)),L.a),0),171),tr(i,H,i.c.b,i.c),z=c(Ao(co(de.f,H)),13),z||(z=_it(H),gl(de.f,H,z)),S=n?Hr(new Cs(c(Xe(xe,xe.c.length-1),8)),c(Xe(z,z.c.length-1),8)):Hr(new Cs((ht(0,xe.c.length),c(xe.c[0],8))),(ht(0,z.c.length),c(z.c[0],8))),gl(M.f,H,S))}if(i.b!=0)for(X=c(Xe(xe,n?xe.c.length-1:0),8),v=1;v<xe.c.length;v++){for(ie=c(Xe(xe,n?xe.c.length-1-v:v),8),r=_n(i,0);r.b!=r.d.c;)H=c(An(r),171),z=c(Ao(co(de.f,H)),13),z.c.length<=v?tte(r):(se=ki(new Cs(c(Xe(z,n?z.c.length-1-v:v),8)),c(Ao(co(M.f,H)),8)),(ie.a!=se.a||ie.b!=se.b)&&(o=ie.a-X.a,d=ie.b-X.b,a=se.a-X.a,b=se.b-X.b,a*d==b*o&&(o==0||isNaN(o)?o:o<0?-1:1)==(a==0||isNaN(a)?a:a<0?-1:1)&&(d==0||isNaN(d)?d:d<0?-1:1)==(b==0||isNaN(b)?b:b<0?-1:1)?(p.Math.abs(o)<p.Math.abs(a)||p.Math.abs(d)<p.Math.abs(b))&&tr(x,ie,x.c.b,x.c):v>1&&tr(x,X,x.c.b,x.c),tte(r)));X=ie}return x}function jst(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt;for(n.Tg(Mct,1),Dt=c(ql(pi(new jt(null,new Tt(t,16)),new JR),su(new Ls,new rs,new mo,W(V(ml,1),_e,132,0,[(va(),bl)]))),16),x=c(ql(pi(new jt(null,new Tt(t,16)),new H_e(t)),su(new Ls,new rs,new mo,W(V(ml,1),_e,132,0,[bl]))),16),P=c(ql(pi(new jt(null,new Tt(t,16)),new q_e(t)),su(new Ls,new rs,new mo,W(V(ml,1),_e,132,0,[bl]))),16),z=ye(kJ,xG,41,t.gc(),0,1),a=0;a<x.gc();a++)r=c(x.Xb(a),41),bt=c(R(r,(Uo(),x3)),15).a,bt>=0&&bt<x.gc()&&!z[bt]&&(z[bt]=r,x.ed(a),--a);for(d=0;d<x.gc();d++)for(r=c(x.Xb(d),41),bt=c(R(r,(Uo(),x3)),15).a,M=0;;M++){if(L=bt+M,L<z.length&&L>=0&&!z[L]){z[L]=r,x.ed(d),--d;break}if(L=bt-M,L<z.length&&L>=0&&!z[L]){z[L]=r,x.ed(d),--d;break}}for(P.gd(new XR),b=z.length-1;b>=0;b--)!z[b]&&!P.dc()&&(z[b]=c(P.Xb(0),41),P.ed(0));for(v=0;v<z.length;v++)!z[v]&&!Dt.dc()&&(z[v]=c(Dt.Xb(0),41),Dt.ed(0));for(o=0;o<z.length;o++)Ee(z[o],(Li(),bC),Pe(o));for(S=c(fBt(pi(new jt(null,new Tt(t,16)),new VR)),526),xe=S,We=0,pt=xe.length;We<pt;++We){for(Se=xe[We],i=xte(Se),jst(e,i,n.dh(1/S.length|0)),Ct(),cb(i,new IK((Li(),bC))),H=new Ai,de=_n(i,0);de.b!=de.d.c;)for(se=c(An(de),41),ie=_n(Se.d,0);ie.b!=ie.d.c;)X=c(An(ie),65),X.c==se&&tr(H,X,H.c.b,H.c);Ou(Se.d),Os(Se.d,H)}n.Ug()}function Tst(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de;for(se=ue(he(ke(t,(Gd(),Yv)))),L=ue(he(ke(t,vC))),M=ue(he(ke(t,_J))),gme((!t.a&&(t.a=new Me(Mn,t,10,11)),t.a)),X=brt((!t.a&&(t.a=new Me(Mn,t,10,11)),t.a),se,e.b),H=0;H<X.c.length;H++)if(b=(ht(H,X.c.length),c(X.c[H],189)),H!=0&&(P=(ht(H-1,X.c.length),c(X.c[H-1],189)),EWe(b,P.f+P.b+e.b)),z=dtn(H,X,se,e.b,et(Ze(ke(t,(Ah(),yue))))),et(Ze(z.b))){for(o=new G(b.a);o.a<o.c.c.length;)r=c(Q(o),175),r.c=!1,r.k=!1,lrt(r);b.d=new Fe,b.e=se,--H}else if(qFt(e,b),H+1<X.c.length&&(e.e=p.Math.max(b.e+e.b+c(Xe((ht(H+1,X.c.length),c(X.c[H+1],189)).a,0),175).r-se,e.c),e.f=p.Math.min(b.e+e.b+c(Xe((ht(H+1,X.c.length),c(X.c[H+1],189)).a,0),175).r-se,e.d),b.d.c.length!=0&&(e.c=p.Math.max(e.c,c(Xe(b.d,b.d.c.length-1),320).d+(b.d.c.length<=1?0:e.b)),e.d=p.Math.min(e.c,c(Xe(b.d,b.d.c.length-1),320).d+(b.d.c.length<=1?0:e.b)))),X.c.length==1)for(S=c(Xe(b.d,b.d.c.length-1),320),x=c(Xe(S.a,S.a.c.length-1),175),d=new G(x.n);d.a<d.c.c.length;)a=c(Q(d),211),e.c=p.Math.max(e.c,x.r-a.d),e.d=p.Math.min(e.d,x.r-a.d),e.e=p.Math.max(e.e,a.d+e.b),e.f=p.Math.min(e.f,a.d+e.b);return ie=JYe(X,e.b),de=p.Math.max(ie.a,L-(n.b+n.c)),v=p.Math.max(ie.b,M-(n.d+n.a)),i=v-ie.b,ii(t,wC,i),ii(t,DJ,X),new I0e(e.a,de,ie.b+i,(RT(),OP))}function ftn(e){var t,n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt,Rt,fn;if(We=c(R(e,(Ge(),cr)),103),We!=(Zr(),Hh)&&We!=fp){for(P=e.b,L=P.c.length,x=new Hc((zu(L+2,Fie),Kq(As(As(5,L+2),(L+2)/10|0)))),z=new Hc((zu(L+2,Fie),Kq(As(As(5,L+2),(L+2)/10|0)))),qe(x,new wn),qe(x,new wn),qe(z,new Fe),qe(z,new Fe),xe=new Fe,t=0;t<L;t++)for(n=(ht(t,P.c.length),c(P.c[t],26)),pt=(ht(t,x.c.length),c(x.c[t],93)),H=new wn,It(x.c,H),Dt=(ht(t,z.c.length),c(z.c[t],16)),ie=new Fe,It(z.c,ie),r=new G(n.a);r.a<r.c.c.length;){if(i=c(Q(r),9),uwe(i)){It(xe.c,i);continue}for(v=new Ht(Vt(pr(i).a.Jc(),new U));hn(v);)d=c(sn(v),17),Rt=d.c.i,uwe(Rt)&&(bt=c(pt.xc(R(Rt,(De(),Oi))),9),bt||(bt=$et(e,Rt),pt.yc(R(Rt,Oi),bt),Dt.Ec(bt)),ks(d,c(Xe(bt.j,1),12)));for(b=new Ht(Vt($i(i).a.Jc(),new U));hn(b);)d=c(sn(b),17),fn=d.d.i,uwe(fn)&&(X=c(Ut(H,R(fn,(De(),Oi))),9),X||(X=$et(e,fn),oi(H,R(fn,Oi),X),It(ie.c,X)),ss(d,c(Xe(X.j,0),12)))}for(S=0;S<z.c.length;S++)if(se=(ht(S,z.c.length),c(z.c[S],16)),!se.dc())for(M=null,S==0?(M=new hc(e),K2(0,P.c.length),h7(P.c,0,M)):S==x.c.length-1?(M=new hc(e),It(P.c,M)):M=(ht(S-1,P.c.length),c(P.c[S-1],26)),a=se.Jc();a.Ob();)o=c(a.Pb(),9),zr(o,M);for(Se=new G(xe);Se.a<Se.c.c.length;)de=c(Q(Se),9),zr(de,null);Ee(e,(De(),Hce),xe)}}function htn(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt,Rt,fn,ti,Zi,Wl,po;for(Zi=new Fe,P=new G(t.b);P.a<P.c.c.length;)for(M=c(Q(P),26),Se=new G(M.a);Se.a<Se.c.c.length;){for(de=c(Q(Se),9),de.p=-1,S=ls,pt=ls,Dt=new G(de.j);Dt.a<Dt.c.c.length;){for(bt=c(Q(Dt),12),r=new G(bt.e);r.a<r.c.c.length;)n=c(Q(r),17),Rt=c(R(n,(Ge(),Ek)),15).a,S=p.Math.max(S,Rt);for(i=new G(bt.g);i.a<i.c.c.length;)n=c(Q(i),17),Rt=c(R(n,(Ge(),Ek)),15).a,pt=p.Math.max(pt,Rt)}Ee(de,vJ,Pe(S)),Ee(de,yJ,Pe(pt))}for(X=0,L=new G(t.b);L.a<L.c.c.length;)for(M=c(Q(L),26),Se=new G(M.a);Se.a<Se.c.c.length;)de=c(Q(Se),9),de.p<0&&(ti=new Pde,ti.b=X++,eit(e,de,ti),It(Zi.c,ti));for(We=Pd(Zi.c.length),x=Pd(Zi.c.length),a=0;a<Zi.c.length;a++)qe(We,new Fe),qe(x,Pe(0));for(_Zt(t,Zi,We,x),Wl=c(jh(Zi,ye(upt,yct,264,Zi.c.length,0,1)),846),xe=c(jh(We,ye(Ju,Tv,16,We.c.length,0,1)),200),v=ye(Fn,ci,30,x.c.length,15,1),d=0;d<v.length;d++)v[d]=(ht(d,x.c.length),c(x.c[d],15)).a;for(ie=0,se=new Fe,b=0;b<Wl.length;b++)v[b]==0&&It(se.c,Wl[b]);for(H=ye(Fn,ci,30,Wl.length,15,1);se.c.length!=0;)for(ti=c(Mg(se,0),264),H[ti.b]=ie++;!xe[ti.b].dc();)po=c(xe[ti.b].ed(0),264),--v[po.b],v[po.b]==0&&It(se.c,po);for(e.a=ye(upt,yct,264,Wl.length,0,1),o=0;o<Wl.length;o++)for(z=Wl[o],fn=H[o],e.a[fn]=z,z.b=fn,Se=new G(z.e);Se.a<Se.c.c.length;)de=c(Q(Se),9),de.p=fn;return e.a}function dtn(e,t,n,i,r){var o,a,d,b,v,x,S,M,L,P,z,H,X;for(z=!1,b=!1,M=e+1,P=(ht(e,t.c.length),c(t.c[e],189)),d=P.a,v=null,a=0;a<P.a.c.length;a++)if(o=(ht(a,d.c.length),c(d.c[a],175)),!o.c){if(o.b.c.length==0){Og(),LD(P,o),--a,z=!0;continue}if(o.k||(v&&ZH(v),v=new Dpe(v?v.e+v.d+i:0,P.f,i),AD(o,v.e+v.d,P.f),qe(P.d,v),yme(v,o),o.k=!0),x=null,x=(X=null,a<P.a.c.length-1?X=c(Xe(P.a,a+1),175):M<t.c.length&&(ht(M,t.c.length),c(t.c[M],189)).a.c.length!=0&&(X=c(Xe((ht(M,t.c.length),c(t.c[M],189)).a,0),175)),X),H=!1,x&&(H=!yi(x.j,P)),x){if(x.b.c.length!=0&&!et(Ze(c(Xe(x.b,0),19).mf((Ah(),kP)))))K_(o,n-o.s),ZH(o.q),z=z|UHt(P,o,x,n,i);else{LD(P,x);break}if(x.b.c.length==0)for(t.c.length>M&&LD((ht(M,t.c.length),c(t.c[M],189)),x),x=null;t.c.length>M&&(ht(M,t.c.length),c(t.c[M],189)).a.c.length==0;)fl(t,(ht(M,t.c.length),t.c[M]));if(!x){--a;continue}if(!et(Ze(c(Xe(x.b,0),19).mf((Ah(),kP))))&&OWt(t,P,o,x,H,n,M,i)){z=!0;continue}if(H){if(L=P.b,S=x.f,!et(Ze(c(Xe(x.b,0),19).mf(kP)))&&GYt(t,P,o,x,n,M,i,r)){if(z=!0,L<S){b=!0,x.j=P;break}continue}else if(Wme(P,o)){o.c=!0,z=!0;continue}}else if(Wme(P,o)){o.c=!0,z=!0;continue}if(z)continue}if(Wme(P,o)){o.c=!0,z=!0,x&&(x.k=!1);continue}else ZH(o.q)}return new Ps((Bt(),!!z),!!b)}function bi(e){var t,n,i;if(e.d>=e.j){e.a=-1,e.c=1;return}if(t=ms(e.i,e.d++),e.a=t,e.b==1){switch(t){case 92:if(i=10,e.d>=e.j)throw J(new Qn(Vn((Bn(),DG))));e.a=ms(e.i,e.d++);break;case 45:(e.e&512)==512&&e.d<e.j&&ms(e.i,e.d)==91?(++e.d,i=24):i=0;break;case 91:if((e.e&512)!=512&&e.d<e.j&&ms(e.i,e.d)==58){++e.d,i=20;break}default:(t&64512)==hL&&e.d<e.j&&(n=ms(e.i,e.d),(n&64512)==56320&&(e.a=Is+(t-hL<<10)+n-56320,++e.d)),i=0}e.c=i;return}switch(t){case 124:i=2;break;case 42:i=3;break;case 43:i=4;break;case 63:i=5;break;case 41:i=7;break;case 46:i=8;break;case 91:i=9;break;case 94:i=11;break;case 36:i=12;break;case 40:if(i=6,e.d>=e.j||ms(e.i,e.d)!=63)break;if(++e.d>=e.j)throw J(new Qn(Vn((Bn(),roe))));switch(t=ms(e.i,e.d++),t){case 58:i=13;break;case 61:i=14;break;case 33:i=15;break;case 91:i=19;break;case 62:i=18;break;case 60:if(e.d>=e.j)throw J(new Qn(Vn((Bn(),roe))));if(t=ms(e.i,e.d++),t==61)i=16;else if(t==33)i=17;else throw J(new Qn(Vn((Bn(),Klt))));break;case 35:for(;e.d<e.j&&(t=ms(e.i,e.d++),t!=41););if(t!=41)throw J(new Qn(Vn((Bn(),Ylt))));i=21;break;default:if(t==45||97<=t&&t<=122||65<=t&&t<=90){--e.d,i=22;break}else if(t==40){i=23;break}throw J(new Qn(Vn((Bn(),roe))))}break;case 92:if(i=10,e.d>=e.j)throw J(new Qn(Vn((Bn(),DG))));e.a=ms(e.i,e.d++);break;default:i=0}e.c=i}function gtn(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H;if(n.Tg("Process compaction",1),!!et(Ze(R(t,(Uo(),V9e))))){for(r=c(R(t,Iw),87),L=ue(he(R(t,Vle))),$Kt(e,t,r),Cen(t,L/2/2),P=t.b,cb(P,new P_e(r)),v=_n(P,0);v.b!=v.d.c;)if(b=c(An(v),41),!et(Ze(R(b,(Li(),cp))))){if(i=uVt(b,r),z=rKt(b,t),S=0,M=0,i)switch(H=i.e,r.g){case 2:S=H.a-L-b.f.a,z.e.a-L-b.f.a<S&&(S=z.e.a-L-b.f.a),M=S+b.f.a;break;case 1:S=H.a+i.f.a+L,z.e.a+L>S&&(S=z.e.a+z.f.a+L),M=S+b.f.a;break;case 4:S=H.b-L-b.f.b,z.e.b-L-b.f.b<S&&(S=z.e.b-L-b.f.b),M=S+b.f.b;break;case 3:S=H.b+i.f.b+L,z.e.b+L>S&&(S=z.e.b+z.f.b+L),M=S+b.f.b}else if(z)switch(r.g){case 2:S=z.e.a-L-b.f.a,M=S+b.f.a;break;case 1:S=z.e.a+z.f.a+L,M=S+b.f.a;break;case 4:S=z.e.b-L-b.f.b,M=S+b.f.b;break;case 3:S=z.e.b+z.f.b+L,M=S+b.f.b}ve(R(t,Xle))===ve((fT(),bP))?(o=S,a=M,d=I1(pi(new jt(null,new Tt(e.a,16)),new vRe(o,a))),d.a!=null?r==(Nr(),go)||r==yo?b.e.a=S:b.e.b=S:(r==(Nr(),go)||r==Ca?d=I1(pi(dXe(new jt(null,new Tt(e.a,16))),new I_e(o))):d=I1(pi(dXe(new jt(null,new Tt(e.a,16))),new R_e(o))),d.a!=null&&(r==go||r==yo?b.e.a=ue(he((dn(d.a!=null),c(d.a,49)).a)):b.e.b=ue(he((dn(d.a!=null),c(d.a,49)).a)))),d.a!=null&&(x=Do(e.a,(dn(d.a!=null),d.a),0),x>0&&x!=c(R(b,xd),15).a&&(Ee(b,F9e,(Bt(),!0)),Ee(b,xd,Pe(x))))):r==(Nr(),go)||r==yo?b.e.a=S:b.e.b=S}n.Ug()}}function ptn(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se;if(n.Tg("Coffman-Graham Layering",1),t.a.c.length==0){n.Ug();return}for(Se=c(R(t,(Ge(),jSe)),15).a,b=0,a=0,M=new G(t.a);M.a<M.c.c.length;)for(S=c(Q(M),9),S.p=b++,o=new Ht(Vt($i(S).a.Jc(),new U));hn(o);)r=c(sn(o),17),r.p=a++;for(e.d=ye(kl,eh,30,b,16,1),e.a=ye(kl,eh,30,a,16,1),e.b=ye(Fn,ci,30,b,15,1),e.e=ye(Fn,ci,30,b,15,1),e.f=ye(Fn,ci,30,b,15,1),sH(e.c),kqt(e,t),P=new nq(new e_e(e)),de=new G(t.a);de.a<de.c.c.length;){for(ie=c(Q(de),9),o=new Ht(Vt(pr(ie).a.Jc(),new U));hn(o);)r=c(sn(o),17),e.a[r.p]||++e.b[ie.p];e.b[ie.p]==0&&p5(CS(P,ie),XS)}for(d=0;P.b.c.length!=0;)for(ie=c(Zee(P),9),e.f[ie.p]=d++,o=new Ht(Vt($i(ie).a.Jc(),new U));hn(o);)r=c(sn(o),17),!e.a[r.p]&&(H=r.d.i,--e.b[H.p],St(e.c,H,Pe(e.f[ie.p])),e.b[H.p]==0&&p5(CS(P,H),XS));for(L=new nq(new t_e(e)),se=new G(t.a);se.a<se.c.c.length;){for(ie=c(Q(se),9),o=new Ht(Vt($i(ie).a.Jc(),new U));hn(o);)r=c(sn(o),17),e.a[r.p]||++e.e[ie.p];e.e[ie.p]==0&&p5(CS(L,ie),XS)}for(x=new Fe,i=Uqe(t,x);L.b.c.length!=0;)for(X=c(Zee(L),9),(i.a.c.length>=Se||!wBt(X,i))&&(i=Uqe(t,x)),zr(X,i),o=new Ht(Vt(pr(X).a.Jc(),new U));hn(o);)r=c(sn(o),17),!e.a[r.p]&&(z=r.c.i,--e.e[z.p],e.e[z.p]==0&&p5(CS(L,z),XS));for(v=x.c.length-1;v>=0;--v)qe(t.b,(ht(v,x.c.length),c(x.c[v],26)));t.a.c.length=0,n.Ug()}function Est(e){var t,n,i,r,o,a,d,b,v;for(e.b=1,bi(e),t=null,e.c==0&&e.a==94?(bi(e),t=(wi(),wi(),new $u(4)),Ac(t,0,y9),d=new $u(4)):d=(wi(),wi(),new $u(4)),r=!0;(v=e.c)!=1;){if(v==0&&e.a==93&&!r){t&&(WT(t,d),d=t);break}if(n=e.a,i=!1,v==10)switch(n){case 100:case 68:case 119:case 87:case 115:case 83:kv(d,RS(n)),i=!0;break;case 105:case 73:case 99:case 67:n=(kv(d,RS(n)),-1),n<0&&(i=!0);break;case 112:case 80:if(b=pve(e,n),!b)throw J(new Qn(Vn((Bn(),soe))));kv(d,b),i=!0;break;default:n=Zve(e)}else if(v==24&&!r){if(t&&(WT(t,d),d=t),o=Est(e),WT(d,o),e.c!=0||e.a!=93)throw J(new Qn(Vn((Bn(),cut))));break}if(bi(e),!i){if(v==0){if(n==91)throw J(new Qn(Vn((Bn(),k5e))));if(n==93)throw J(new Qn(Vn((Bn(),O5e))));if(n==45&&!r&&e.a!=93)throw J(new Qn(Vn((Bn(),ooe))))}if(e.c!=0||e.a!=45||n==45&&r)Ac(d,n,n);else{if(bi(e),(v=e.c)==1)throw J(new Qn(Vn((Bn(),LG))));if(v==0&&e.a==93)Ac(d,n,n),Ac(d,45,45);else{if(v==0&&e.a==93||v==24)throw J(new Qn(Vn((Bn(),ooe))));if(a=e.a,v==0){if(a==91)throw J(new Qn(Vn((Bn(),k5e))));if(a==93)throw J(new Qn(Vn((Bn(),O5e))));if(a==45)throw J(new Qn(Vn((Bn(),ooe))))}else v==10&&(a=Zve(e));if(bi(e),n>a)throw J(new Qn(Vn((Bn(),aut))));Ac(d,n,a)}}}r=!1}if(e.c==1)throw J(new Qn(Vn((Bn(),LG))));return $x(d),JT(d),e.b=0,bi(e),d}function Cst(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de;de=!1;do for(de=!1,o=t?new an(e.a.b).a.gc()-2:1;t?o>=0:o<new an(e.a.b).a.gc();o+=t?-1:1)for(r=ebe(e.a,Pe(o)),L=0;L<r.b;L++)if(S=c(pc(r,L),9),!!xi(S,(De(),Pi))&&!(Cqt(e.a,Pe(o))&&e.r==(H0(),H9)||Mqt(e.a,Pe(o))&&e.r==(H0(),sC))){for(se=!0,X=0;X<r.b;X++)H=c(pc(r,X),9),xi(H,Pi)&&(t&&c(R(S,Pi),15).a<c(R(H,Pi),15).a||!t&&c(R(S,Pi),15).a>c(R(H,Pi),15).a)&&(se=!1);if(se){for(b=t?o+1:o-1,d=ebe(e.a,Pe(b)),a=!1,ie=!0,i=!1,x=_n(d,0);x.b!=x.d.c;)v=c(An(x),9),xi(v,Pi)?v.p!=S.p&&(a=a|(t?c(R(v,Pi),15).a<c(R(S,Pi),15).a:c(R(v,Pi),15).a>c(R(S,Pi),15).a),ie=!1):!a&&ie&&v.k==(Jt(),lc)&&(i=!0,t?M=c(sn(new Ht(Vt(pr(v).a.Jc(),new U))),17).c.i:M=c(sn(new Ht(Vt($i(v).a.Jc(),new U))),17).d.i,M==S&&(t?n=c(sn(new Ht(Vt($i(v).a.Jc(),new U))),17).d.i:n=c(sn(new Ht(Vt(pr(v).a.Jc(),new U))),17).c.i,(t?c(R2(e.a,n),15).a-c(R2(e.a,M),15).a:c(R2(e.a,M),15).a-c(R2(e.a,n),15).a)<=2&&(ie=!1)));if(i&&ie&&(t?n=c(sn(new Ht(Vt($i(S).a.Jc(),new U))),17).d.i:n=c(sn(new Ht(Vt(pr(S).a.Jc(),new U))),17).c.i,(t?c(R2(e.a,n),15).a-c(R2(e.a,S),15).a:c(R2(e.a,S),15).a-c(R2(e.a,n),15).a)<=2&&n.k==(Jt(),or)&&(ie=!1)),a||ie){for(z=nnt(e,S,t);z.a.gc()!=0;)P=c(z.a.ec().Jc().Pb(),9),z.a.Ac(P)!=null,Os(z,nnt(e,P,t));--L,de=!0}}}while(de)}function btn(e){In(e.c,Kn,W(V(nt,1),Be,2,6,[ys,"http://www.w3.org/2001/XMLSchema#decimal"])),In(e.d,Kn,W(V(nt,1),Be,2,6,[ys,"http://www.w3.org/2001/XMLSchema#integer"])),In(e.e,Kn,W(V(nt,1),Be,2,6,[ys,"http://www.w3.org/2001/XMLSchema#boolean"])),In(e.f,Kn,W(V(nt,1),Be,2,6,[ys,"EBoolean",hi,"EBoolean:Object"])),In(e.i,Kn,W(V(nt,1),Be,2,6,[ys,"http://www.w3.org/2001/XMLSchema#byte"])),In(e.g,Kn,W(V(nt,1),Be,2,6,[ys,"http://www.w3.org/2001/XMLSchema#hexBinary"])),In(e.j,Kn,W(V(nt,1),Be,2,6,[ys,"EByte",hi,"EByte:Object"])),In(e.n,Kn,W(V(nt,1),Be,2,6,[ys,"EChar",hi,"EChar:Object"])),In(e.t,Kn,W(V(nt,1),Be,2,6,[ys,"http://www.w3.org/2001/XMLSchema#double"])),In(e.u,Kn,W(V(nt,1),Be,2,6,[ys,"EDouble",hi,"EDouble:Object"])),In(e.F,Kn,W(V(nt,1),Be,2,6,[ys,"http://www.w3.org/2001/XMLSchema#float"])),In(e.G,Kn,W(V(nt,1),Be,2,6,[ys,"EFloat",hi,"EFloat:Object"])),In(e.I,Kn,W(V(nt,1),Be,2,6,[ys,"http://www.w3.org/2001/XMLSchema#int"])),In(e.J,Kn,W(V(nt,1),Be,2,6,[ys,"EInt",hi,"EInt:Object"])),In(e.N,Kn,W(V(nt,1),Be,2,6,[ys,"http://www.w3.org/2001/XMLSchema#long"])),In(e.O,Kn,W(V(nt,1),Be,2,6,[ys,"ELong",hi,"ELong:Object"])),In(e.Z,Kn,W(V(nt,1),Be,2,6,[ys,"http://www.w3.org/2001/XMLSchema#short"])),In(e.$,Kn,W(V(nt,1),Be,2,6,[ys,"EShort",hi,"EShort:Object"])),In(e._,Kn,W(V(nt,1),Be,2,6,[ys,"http://www.w3.org/2001/XMLSchema#string"]))}function Ge(){Ge=te,dle=(Dn(),Lwt),FSe=Pwt,uP=Iwt,Mf=Rwt,m3=O7e,Rb=S7e,Xv=j7e,F9=T7e,q9=E7e,gle=UJ,$b=lh,ple=$wt,tC=A7e,lJ=Lk,lP=(Kye(),jgt),Jv=Tgt,ip=Egt,Vv=Cgt,g0t=new Gr(NP,Pe(0)),z9=kgt,zSe=Ogt,Ek=Sgt,WSe=Wgt,HSe=Ngt,QSe=Lgt,mle=Fgt,GSe=Rgt,USe=Bgt,uJ=e0t,wle=Kgt,XSe=Ugt,JSe=Qgt,VSe=Xgt,MSe=rgt,ule=egt,iJ=Z1t,ale=ngt,Dw=bgt,eC=mgt,cle=C1t,wSe=A1t,v0t=e8,y0t=JJ,w0t=sy,m0t=Z9,qSe=(P5(),ly),new Gr(Pk,qSe),PSe=new Qp(12),LSe=new Gr(zh,PSe),pSe=($1(),i8),W1=new Gr(e7e,pSe),Qv=new Gr(fu,0),p0t=new Gr(uae,Pe(1)),XU=new Gr(K9,YS),Ib=GJ,cr=Y9,B9=M3,c0t=MP,vd=xwt,Fv=j3,b0t=new Gr(aae,(Bt(),!0)),qv=AP,Lb=tae,Pb=qb,cJ=lp,hle=ny,gSe=(Nr(),qh),Xu=new Gr(Fb,gSe),_w=E3,sJ=l7e,Gv=iy,d0t=lae,$Se=x7e,RSe=(_x(),IP),new Gr(b7e,RSe),a0t=rae,f0t=sae,h0t=oae,u0t=iae,ble=Agt,nJ=Y1t,cP=K1t,nC=Mgt,Ro=Q1t,Tk=y1t,KE=v1t,R9=r1t,fSe=s1t,rle=u1t,oP=o1t,sle=m1t,ASe=sgt,NSe=ogt,SSe=$1t,oJ=ygt,fle=ugt,lle=D1t,DSe=ggt,mSe=T1t,ole=E1t,ile=CP,_Se=cgt,WU=zdt,cSe=Bdt,VU=$dt,xSe=I1t,ySe=P1t,kSe=R1t,$9=C3,ho=T3,Xg=jwt,yd=eae,b3=QJ,hSe=f1t,Vg=cae,JE=Swt,tJ=Ewt,Lw=w7e,ISe=Awt,Hv=Nwt,TSe=U1t,ESe=X1t,Uv=Dk,Zce=Rdt,CSe=W1t,eJ=O1t,ZU=k1t,rJ=Y1,jSe=F1t,ZE=fgt,aP=C7e,dSe=x1t,BSe=xgt,bSe=S1t,r0t=d1t,s0t=g1t,l0t=H1t,o0t=p1t,OSe=nae,YE=G1t,YU=b1t,t1=i1t,tle=e1t,sP=qdt,ele=Hdt,KU=t1t,XE=Fdt,nle=n1t,zv=Zdt,WE=Ydt,i0t=Kdt,jk=Qdt,VE=Wdt,aSe=Vdt,lSe=Gdt,uSe=Jdt,vSe=L1t}function mtn(e,t,n,i,r,o,a){var d,b,v,x,S,M,L,P;return M=c(i.a,15).a,L=c(i.b,15).a,S=e.b,P=e.c,d=0,x=0,t==(Nr(),go)||t==yo?(x=c_(tKe(X2(qc(new jt(null,new Tt(n.b,16)),new n$),new EA))),S.e.b+S.f.b/2>x?(v=++L,d=ue(he(vu(Q2(qc(new jt(null,new Tt(n.b,16)),new kRe(r,v)),new dm))))):(b=++M,d=ue(he(vu(m5(qc(new jt(null,new Tt(n.b,16)),new ORe(r,b)),new aj)))))):(x=c_(tKe(X2(qc(new jt(null,new Tt(n.b,16)),new MA),new qO))),S.e.a+S.f.a/2>x?(v=++L,d=ue(he(vu(Q2(qc(new jt(null,new Tt(n.b,16)),new xRe(r,v)),new CA))))):(b=++M,d=ue(he(vu(m5(qc(new jt(null,new Tt(n.b,16)),new yRe(r,b)),new WR)))))),t==go?(Es(e.a,new $e(ue(he(R(S,(Li(),oh))))-r,d)),Es(e.a,new $e(P.e.a+P.f.a+r+o,d)),Es(e.a,new $e(P.e.a+P.f.a+r+o,P.e.b+P.f.b/2)),Es(e.a,new $e(P.e.a+P.f.a,P.e.b+P.f.b/2))):t==yo?(Es(e.a,new $e(ue(he(R(S,(Li(),Af))))+r,S.e.b+S.f.b/2)),Es(e.a,new $e(S.e.a+S.f.a+r,d)),Es(e.a,new $e(P.e.a-r-o,d)),Es(e.a,new $e(P.e.a-r-o,P.e.b+P.f.b/2)),Es(e.a,new $e(P.e.a,P.e.b+P.f.b/2))):t==Ca?(Es(e.a,new $e(d,ue(he(R(S,(Li(),oh))))-r)),Es(e.a,new $e(d,P.e.b+P.f.b+r+o)),Es(e.a,new $e(P.e.a+P.f.a/2,P.e.b+P.f.b+r+o)),Es(e.a,new $e(P.e.a+P.f.a/2,P.e.b+P.f.b+r))):(e.a.b==0||(c(df(e.a),8).b=ue(he(R(S,(Li(),Af))))+r*c(a.b,15).a),Es(e.a,new $e(d,ue(he(R(S,(Li(),Af))))+r*c(a.b,15).a)),Es(e.a,new $e(d,P.e.b-r*c(a.a,15).a-o))),new Ps(Pe(M),Pe(L))}function wtn(e){var t,n,i,r,o,a,d,b,v,x,S,M,L;if(a=!0,S=null,i=null,r=null,t=!1,L=R2t,v=null,o=null,d=0,b=rne(e,d,STe,jTe),b<e.length&&(en(b,e.length),e.charCodeAt(b)==58)&&(S=(fs(d,b,e.length),e.substr(d,b-d)),d=b+1),n=S!=null&&i7(lX,S.toLowerCase()),n){if(b=e.lastIndexOf("!/"),b==-1)throw J(new qt("no archive separator"));a=!0,i=Fa(e,d,++b),d=b}else d>=0&&Ot(e.substr(d,2),"//")?(d+=2,b=rne(e,d,HC,QC),i=(fs(d,b,e.length),e.substr(d,b-d)),d=b):S!=null&&(d==e.length||(en(d,e.length),e.charCodeAt(d)!=47))&&(a=!1,b=jge(e,dl(35),d),b==-1&&(b=e.length),i=(fs(d,b,e.length),e.substr(d,b-d)),d=b);if(!n&&d<e.length&&(en(d,e.length),e.charCodeAt(d)==47)&&(b=rne(e,d+1,HC,QC),x=(fs(d+1,b,e.length),e.substr(d+1,b-(d+1))),x.length>0&&ms(x,x.length-1)==58&&(r=x,d=b)),d<e.length&&(en(d,e.length),e.charCodeAt(d)==47)&&(++d,t=!0),d<e.length&&(en(d,e.length),e.charCodeAt(d)!=63)&&(en(d,e.length),e.charCodeAt(d)!=35)){for(M=new Fe;d<e.length&&(en(d,e.length),e.charCodeAt(d)!=63)&&(en(d,e.length),e.charCodeAt(d)!=35);)b=rne(e,d,HC,QC),qe(M,(fs(d,b,e.length),e.substr(d,b-d))),d=b,d<e.length&&(en(d,e.length),e.charCodeAt(d)==47)&&(PRt(e,++d)||M.c.push(""));L=ye(nt,Be,2,M.c.length,6,1),jh(M,L)}return d<e.length&&(en(d,e.length),e.charCodeAt(d)==63)&&(b=A6(e,35,++d),b==-1&&(b=e.length),v=(fs(d,b,e.length),e.substr(d,b-d)),d=b),d<e.length&&(o=hpe(e,++d)),WYt(a,S,i,r,L,v),new rie(a,S,i,r,t,L,v,o)}function nL(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de;if(jc(e.b,t)){if($a(c(Ut(e.b,t),47),n))return 1}else oi(e.b,t,new Or);if(jc(e.b,n)){if($a(c(Ut(e.b,n),47),t))return-1}else oi(e.b,n,new Or);if(jc(e.g,t)){if($a(c(Ut(e.g,t),47),n))return-1}else oi(e.g,t,new Or);if(jc(e.g,n)){if($a(c(Ut(e.b,n),47),t))return 1}else oi(e.g,n,new Or);if(e.e==(B1(),Cle)||!xi(t,(De(),Pi))||!xi(n,(De(),Pi))){for(M=null,x=new G(t.j);x.a<x.c.c.length;)if(b=c(Q(x),12),b.e.c.length!=0&&c(Xe(b.e,0),17).c.i.c.p==t.c.p-1){M=c(Xe(b.e,0),17).c;break}for(P=null,v=new G(n.j);v.a<v.c.c.length;)if(b=c(Q(v),12),b.e.c.length!=0&&c(Xe(b.e,0),17).c.i.c.p==n.c.p-1){P=c(Xe(b.e,0),17).c;break}if(M&&P){if(S=M.i,L=P.i,S&&S==L){for(H=new G(S.j);H.a<H.c.c.length;){if(z=c(Q(H),12),z==M)return Mu(e,n,t),-1;if(z==P)return Mu(e,t,n),1}return r=Nne(e,t),a=Nne(e,n),r>a?(Mu(e,t,n),1):(Mu(e,n,t),-1)}for(ie=e.f,se=0,de=ie.length;se<de;++se){if(X=ie[se],X==S)return Mu(e,n,t),-1;if(X==L)return Mu(e,t,n),1}}if(M&&!P||!M&&P){if(i=Ast(e,t,n),i!=0)return i>0?Mu(e,t,n):Mu(e,n,t),i;if(!xi(t,(De(),Pi))||!xi(n,Pi))return o=Nne(e,t),d=Nne(e,n),o>d?(Mu(e,t,n),1):(Mu(e,n,t),-1)}if(!M&&!P&&(i=Ast(e,t,n),i!=0))return i>0?Mu(e,t,n):Mu(e,n,t),i}return xi(t,(De(),Pi))&&xi(n,Pi)?(o=cw(t,n,e.c,c(R(e.c,np),15).a),d=cw(n,t,e.c,c(R(e.c,np),15).a),o>d?(Mu(e,t,n),1):(Mu(e,n,t),-1)):(Mu(e,n,t),-1)}function Mst(){Mst=te,Lie(),ri=new Qm,St(ri,(Je(),Pf),Qh),St(ri,Za,Qh),St(ri,Xl,Qh),St(ri,If,Qh),St(ri,yl,Qh),St(ri,Vl,Qh),St(ri,If,Pf),St(ri,Qh,Ma),St(ri,Pf,Ma),St(ri,Za,Ma),St(ri,Xl,Ma),St(ri,vl,Ma),St(ri,If,Ma),St(ri,yl,Ma),St(ri,Vl,Ma),St(ri,ol,Ma),St(ri,Qh,Wu),St(ri,Pf,Wu),St(ri,Ma,Wu),St(ri,Za,Wu),St(ri,Xl,Wu),St(ri,vl,Wu),St(ri,If,Wu),St(ri,ol,Wu),St(ri,Ku,Wu),St(ri,yl,Wu),St(ri,Il,Wu),St(ri,Vl,Wu),St(ri,Pf,Za),St(ri,Xl,Za),St(ri,If,Za),St(ri,Vl,Za),St(ri,Pf,Xl),St(ri,Za,Xl),St(ri,If,Xl),St(ri,Xl,Xl),St(ri,yl,Xl),St(ri,Qh,Aa),St(ri,Pf,Aa),St(ri,Ma,Aa),St(ri,Wu,Aa),St(ri,Za,Aa),St(ri,Xl,Aa),St(ri,vl,Aa),St(ri,If,Aa),St(ri,Ku,Aa),St(ri,ol,Aa),St(ri,Vl,Aa),St(ri,yl,Aa),St(ri,Pc,Aa),St(ri,Qh,Ku),St(ri,Pf,Ku),St(ri,Ma,Ku),St(ri,Za,Ku),St(ri,Xl,Ku),St(ri,vl,Ku),St(ri,If,Ku),St(ri,ol,Ku),St(ri,Vl,Ku),St(ri,Il,Ku),St(ri,Pc,Ku),St(ri,Pf,ol),St(ri,Za,ol),St(ri,Xl,ol),St(ri,If,ol),St(ri,Ku,ol),St(ri,Vl,ol),St(ri,yl,ol),St(ri,Qh,wl),St(ri,Pf,wl),St(ri,Ma,wl),St(ri,Za,wl),St(ri,Xl,wl),St(ri,vl,wl),St(ri,If,wl),St(ri,ol,wl),St(ri,Vl,wl),St(ri,Pf,yl),St(ri,Ma,yl),St(ri,Wu,yl),St(ri,Xl,yl),St(ri,Qh,Il),St(ri,Pf,Il),St(ri,Wu,Il),St(ri,Za,Il),St(ri,Xl,Il),St(ri,vl,Il),St(ri,If,Il),St(ri,If,Pc),St(ri,Xl,Pc),St(ri,ol,Qh),St(ri,ol,Za),St(ri,ol,Ma),St(ri,vl,Qh),St(ri,vl,Pf),St(ri,vl,Wu)}function vtn(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe;switch(n.Tg("Brandes & Koepf node placement",1),e.a=t,e.c=VWt(t),i=c(R(t,(Ge(),fle)),284),L=et(Ze(R(t,ZE))),e.d=i==(RD(),$U)&&!L||i==Ice,HYt(e,t),Se=null,xe=null,X=null,ie=null,H=(zu(4,Sv),new Hc(4)),c(R(t,fle),284).g){case 3:X=new zx(t,e.c.d,(vh(),Bb),(td(),Wg)),It(H.c,X);break;case 1:ie=new zx(t,e.c.d,(vh(),Rh),(td(),Wg)),It(H.c,ie);break;case 4:Se=new zx(t,e.c.d,(vh(),Bb),(td(),Pw)),It(H.c,Se);break;case 2:xe=new zx(t,e.c.d,(vh(),Rh),(td(),Pw)),It(H.c,xe);break;default:X=new zx(t,e.c.d,(vh(),Bb),(td(),Wg)),ie=new zx(t,e.c.d,Rh,Wg),Se=new zx(t,e.c.d,Bb,Pw),xe=new zx(t,e.c.d,Rh,Pw),It(H.c,Se),It(H.c,xe),It(H.c,X),It(H.c,ie)}for(r=new gRe(t,e.c),d=new G(H);d.a<d.c.c.length;)o=c(Q(d),188),Nen(r,o,e.b),EKt(o);for(M=new UYe(t,e.c),b=new G(H);b.a<b.c.c.length;)o=c(Q(b),188),nZt(M,o);if(n.$g())for(v=new G(H);v.a<v.c.c.length;)o=c(Q(v),188),n.ah(o+" size is "+Yne(o));if(S=null,e.d&&(x=Oen(e,H,e.c.d),rrt(t,x,n)&&(S=x)),!S)for(v=new G(H);v.a<v.c.c.length;)o=c(Q(v),188),rrt(t,o,n)&&(!S||Yne(S)>Yne(o))&&(S=o);for(!S&&(S=(ht(0,H.c.length),c(H.c[0],188))),z=new G(t.b);z.a<z.c.c.length;)for(P=c(Q(z),26),de=new G(P.a);de.a<de.c.c.length;)se=c(Q(de),9),se.n.b=ue(S.p[se.p])+ue(S.d[se.p]);for(n.$g()&&(n.ah("Chosen node placement: "+S),n.ah("Blocks: "+htt(S)),n.ah("Classes: "+fUt(S,n)),n.ah("Marked edges: "+e.b)),a=new G(H);a.a<a.c.c.length;)o=c(Q(a),188),o.g=null,o.b=null,o.a=null,o.d=null,o.j=null,o.i=null,o.p=null;EDt(e.c),e.b.a.$b(),n.Ug()}function Ast(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt;if(t.k==(Jt(),jr)&&n.k==or)return o=c(Xe(c(u5(I1(pi(new jt(null,new Tt(t.j,16)),new d4))),12).e,0),17).c,r=o.i,d=c(Xe(c(u5(I1(pi(new jt(null,new Tt(t.j,16)),new f2))),12).g,0),17).d,a=d.i,i=t.c.p,r.c.p!=i&&a.c.p!=i?0:r==n||a==n?(Mu(e,t,n),1):nL(e,r,n);if(t.k==or&&n.k==jr)return o=c(Xe(c(u5(I1(pi(new jt(null,new Tt(n.j,16)),new d4))),12).e,0),17).c,r=o.i,d=c(Xe(c(u5(I1(pi(new jt(null,new Tt(n.j,16)),new f2))),12).g,0),17).d,a=d.i,i=t.c.p,r.c.p!=i&&a.c.p!=i?0:r==t||a==t?(Mu(e,n,t),-1):nL(e,t,r);if(t.k==jr&&n.k==jr){if(M=c(Xe(c(u5(I1(pi(new jt(null,new Tt(t.j,16)),new d4))),12).e,0),17).c,L=c(Xe(c(u5(I1(pi(new jt(null,new Tt(t.j,16)),new f2))),12).g,0),17).d,P=M.i,z=L.i,b=t.c.p,x=!1,S=!1,de=c(Xe(c(u5(I1(pi(new jt(null,new Tt(n.j,16)),new d4))),12).e,0),17).c,Se=c(Xe(c(u5(I1(pi(new jt(null,new Tt(n.j,16)),new f2))),12).g,0),17).d,xe=de.i,We=Se.i,H=n.c.p,ie=!1,se=!1,v=t,X=n,P.c.p==b?(x=!0,v=P):z.c.p==b&&(S=!0,v=z),xe.c.p==H?(ie=!0,X=xe):We.c.p==H&&(se=!0,X=We),v==X)if(e.a){if(x&&ie)return Dt=Lst(new Lbe(e.c,e.f,e.e,null,se),M,de),Dt>0?(Mu(e,n,t),1):(Mu(e,t,n),-1);if(x&&se)return Mu(e,n,t),1;if(S&&ie)return Mu(e,t,n),-1;if(S&&se)return 0}else for(bt=new G(v.j);bt.a<bt.c.c.length;){if(pt=c(Q(bt),12),M==pt)return Mu(e,n,t),-1;if(de==pt)return Mu(e,t,n),1}return nL(e,v,X)}else return 0}function ytn(e){var t,n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt,Rt,fn;if(e.c.length==1)return aYe((ht(0,e.c.length),c(e.c[0],121))),ht(0,e.c.length),c(e.c[0],121);if(e.c.length<=0)return new J_;for(b=new G(e);b.a<b.c.c.length;){for(a=c(Q(b),121),ie=0,P=di,z=di,M=ls,L=ls,X=_n(a.b,0);X.b!=X.d.c;)H=c(An(X),41),ie+=c(R(H,(Uo(),jJ)),15).a,P=p.Math.min(P,H.e.a),z=p.Math.min(z,H.e.b),M=p.Math.max(M,H.e.a+H.f.a),L=p.Math.max(L,H.e.b+H.f.b);Ee(a,(Uo(),jJ),Pe(ie)),Ee(a,(Li(),G9),new $e(P,z)),Ee(a,mP,new $e(M,L))}for(Ct(),Rr(e,new qR),Se=new J_,ec(Se,(ht(0,e.c.length),c(e.c[0],105))),S=0,Dt=0,v=new G(e);v.a<v.c.c.length;)a=c(Q(v),121),xe=Hr(Ms(c(R(a,(Li(),mP)),8)),c(R(a,G9),8)),S=p.Math.max(S,xe.a),Dt+=xe.a*xe.b;for(S=p.Math.max(S,p.Math.sqrt(Dt)*ue(he(R(Se,(Uo(),Vpt))))),We=ue(he(R(Se,Vle))),Rt=0,fn=0,x=0,t=We,d=new G(e);d.a<d.c.c.length;)a=c(Q(d),121),xe=Hr(Ms(c(R(a,(Li(),mP)),8)),c(R(a,G9),8)),Rt+xe.a>S&&(Rt=0,fn+=x+We,x=0),mit(Se,a,Rt,fn),t=p.Math.max(t,Rt+xe.a),x=p.Math.max(x,xe.b),Rt+=xe.a+We;for(de=new wn,n=new wn,bt=new G(e);bt.a<bt.c.c.length;)for(pt=c(Q(bt),121),i=et(Ze(R(pt,(Dn(),MP)))),se=pt.q?pt.q:Yd,o=se.vc().Jc();o.Ob();)r=c(o.Pb(),45),jc(de,r.jd())?ve(c(r.jd(),149).Rg())!==ve(r.kd())&&(i&&jc(n,r.jd())?(Og(),""+c(r.jd(),149).Og()):(oi(de,c(r.jd(),149),r.kd()),Ee(Se,c(r.jd(),149),r.kd()),i&&oi(n,c(r.jd(),149),r.kd()))):(oi(de,c(r.jd(),149),r.kd()),Ee(Se,c(r.jd(),149),r.kd()));return $nt(Se,new VA),aYe(Se),Se}function zQ(e,t){switch(e.e){case 0:case 2:case 4:case 6:case 42:case 44:case 46:case 48:case 8:case 10:case 12:case 14:case 16:case 18:case 20:case 22:case 24:case 26:case 28:case 30:case 32:case 34:case 36:case 38:return new bHe(e.b,e.a,t,e.c);case 1:return new OF(e.a,t,Vi(t.Ah(),e.c));case 43:return new tBe(e.a,t,Vi(t.Ah(),e.c));case 3:return new Ar(e.a,t,Vi(t.Ah(),e.c));case 45:return new El(e.a,t,Vi(t.Ah(),e.c));case 41:return new Al(c(Qa(e.c),29),e.a,t,Vi(t.Ah(),e.c));case 50:return new _Xe(c(Qa(e.c),29),e.a,t,Vi(t.Ah(),e.c));case 5:return new r0e(e.a,t,Vi(t.Ah(),e.c),e.d.n);case 47:return new mze(e.a,t,Vi(t.Ah(),e.c),e.d.n);case 7:return new Me(e.a,t,Vi(t.Ah(),e.c),e.d.n);case 49:return new h5(e.a,t,Vi(t.Ah(),e.c),e.d.n);case 9:return new nBe(e.a,t,Vi(t.Ah(),e.c));case 11:return new rBe(e.a,t,Vi(t.Ah(),e.c));case 13:return new wge(e.a,t,Vi(t.Ah(),e.c));case 15:return new BF(e.a,t,Vi(t.Ah(),e.c));case 17:return new iBe(e.a,t,Vi(t.Ah(),e.c));case 19:return new mx(e.a,t,Vi(t.Ah(),e.c));case 21:return new mge(e.a,t,Vi(t.Ah(),e.c));case 23:return new __(e.a,t,Vi(t.Ah(),e.c));case 25:return new yze(e.a,t,Vi(t.Ah(),e.c),e.d.n);case 27:return new Et(e.a,t,Vi(t.Ah(),e.c),e.d.n);case 29:return new vze(e.a,t,Vi(t.Ah(),e.c),e.d.n);case 31:return new wze(e.a,t,Vi(t.Ah(),e.c),e.d.n);case 33:return new o0e(e.a,t,Vi(t.Ah(),e.c),e.d.n);case 35:return new s0e(e.a,t,Vi(t.Ah(),e.c),e.d.n);case 37:return new bZ(e.a,t,Vi(t.Ah(),e.c),e.d.n);case 39:return new rq(e.a,t,Vi(t.Ah(),e.c),e.d.n);case 40:return new ar(t,Vi(t.Ah(),e.c));default:throw J(new Mo("Unknown feature style: "+e.e))}}function xtn(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt,Rt,fn,ti;for(d=new Ai,We=c(R(n,(Ge(),Xu)),87),H=0,i=new Or,Os(d,(!t.a&&(t.a=new Me(Mn,t,10,11)),t.a));d.b!=0;)S=c(d.b==0?null:(dn(d.b!=0),ba(d,d.a.a)),19),x=Xi(S),DQ(x)&&!et(Ze(ke(S,KU)))&&(ii(S,(De(),Pi),Pe(H++)),ga(S,zv)&&Sr(i,c(ke(S,zv),15))),ie=!et(Ze(ke(S,Ib))),ie&&(L=(!S.a&&(S.a=new Me(Mn,S,10,11)),S.a).i!=0,z=uHt(S),P=ve(ke(S,Fv))===ve((R1(),Zg)),ti=!ga(S,(Dn(),_k))||eUe(zn(ke(S,_k))),Se=null,ti&&P&&(L||z)&&(Se=Qit(S),Ee(Se,Xu,We),xi(Se,lP)&&ePe(new ywe(ue(he(R(Se,lP)))),Se),c(ke(S,Pb),185).gc()!=0&&(M=Se,lr(new jt(null,(!S.c&&(S.c=new Me(hu,S,9,9)),new Tt(S.c,16))),new lNe(M)),Ant(S,Se))),pt=n,bt=c(Ut(e.a,Xi(S)),9),bt&&(pt=bt.e),de=Zrt(e,S,pt),Se&&(de.e=Se,Se.e=de,Os(d,(!S.a&&(S.a=new Me(Mn,S,10,11)),S.a))));for(Ee(n,(De(),np),Pe(H)),Ee(n,tP,Pe(i.a.gc())),H=0,tr(d,t,d.c.b,d.c);d.b!=0;){for(a=c(d.b==0?null:(dn(d.b!=0),ba(d,d.a.a)),19),v=new cn((!a.b&&(a.b=new Me(Ii,a,12,3)),a.b));v.e!=v.i.gc();)b=c(un(v),74),rit(b),DQ(t)&&ii(b,Pi,Pe(H++)),Rt=to(c(re((!b.b&&(b.b=new Et(vn,b,4,7)),b.b),0),83)),fn=to(c(re((!b.c&&(b.c=new Et(vn,b,5,8)),b.c),0),83)),!(et(Ze(ke(b,Ib)))||et(Ze(ke(Rt,Ib)))||et(Ze(ke(fn,Ib))))&&(X=sw(b)&&et(Ze(ke(Rt,qv)))&&et(Ze(ke(b,Lb))),xe=a,X||nv(fn,Rt)?xe=Rt:nv(Rt,fn)&&(xe=fn),pt=n,bt=c(Ut(e.a,xe),9),bt&&(pt=bt.e),se=Wye(e,b,xe,pt),Ee(se,p6e,xXt(e,b,t,n)));if(P=ve(ke(a,Fv))===ve((R1(),Zg)),P)for(o=new cn((!a.a&&(a.a=new Me(Mn,a,10,11)),a.a));o.e!=o.i.gc();)r=c(un(o),19),ti=!ga(r,(Dn(),_k))||eUe(zn(ke(r,_k))),Dt=ve(ke(r,Fv))===ve(Zg),ti&&Dt&&tr(d,r,d.c.b,d.c)}}function Nst(e){var t,n,i,r,o,a,d,b;for(o=0,r=e.a.b,b=_n(e.a,0);b.b!=b.d.c;){if(d=c(An(b),243),a=(o+1)/(r+1),!e.c&&!e.d)return;e.c&&!e.d?(e.g=!0,e.b==(Nr(),go)?(i=e.c.e.b+e.c.f.b+e.e*(o+1),t=new $e(ue(he(R(e.c,(Li(),Af))))+e.e,i),n=new $e(ue(he(R(e.c,oh)))-e.e,i)):e.b==yo?(i=e.c.e.b+e.c.f.b+e.e*(o+1),t=new $e(ue(he(R(e.c,(Li(),oh))))-e.e,i),n=new $e(ue(he(R(e.c,Af)))+e.e,i)):e.b==Ca?(i=e.c.e.a+e.c.f.a+e.e*(o+1),t=new $e(i,ue(he(R(e.c,(Li(),Af))))+e.e),n=new $e(i,ue(he(R(e.c,oh)))-e.e)):(i=e.c.e.a+e.c.f.a+e.e*(o+1),t=new $e(i,ue(he(R(e.c,(Li(),oh))))-e.e),n=new $e(i,ue(he(R(e.c,Af)))+e.e))):e.c&&e.d?e.b==(Nr(),go)?(i=e.d.e.b*a+(e.c.e.b+e.c.f.b)*(1-a),t=new $e(ue(he(R(e.c,(Li(),Af))))+e.e,i),n=new $e(ue(he(R(e.c,oh)))-e.e,i)):e.b==yo?(i=e.d.e.b*a+(e.c.e.b+e.c.f.b)*(1-a),t=new $e(ue(he(R(e.c,(Li(),oh))))-e.e,i),n=new $e(ue(he(R(e.c,Af)))+e.e,i)):e.b==Ca?(i=e.d.e.a*a+(e.c.e.a+e.c.f.a)*(1-a),t=new $e(i,ue(he(R(e.c,(Li(),Af))))+e.e),n=new $e(i,ue(he(R(e.c,oh)))-e.e)):(i=e.d.e.a*a+(e.c.e.a+e.c.f.a)*(1-a),t=new $e(i,ue(he(R(e.c,(Li(),oh))))-e.e),n=new $e(i,ue(he(R(e.c,Af)))+e.e)):(e.f=!0,e.b==(Nr(),go)?(i=e.d.e.b-e.e*(o+1),t=new $e(ue(he(R(e.d,(Li(),Af))))+e.e,i),n=new $e(ue(he(R(e.d,oh)))-e.e,i)):e.b==yo?(i=e.d.e.b-e.e*(o+1),t=new $e(ue(he(R(e.d,(Li(),oh))))-e.e,i),n=new $e(ue(he(R(e.d,Af)))+e.e,i)):e.b==Ca?(i=e.d.e.a-e.e*(o+1),t=new $e(i,ue(he(R(e.d,(Li(),Af))))+e.e),n=new $e(i,ue(he(R(e.d,oh)))-e.e)):(i=e.d.e.a-e.e*(o+1),t=new $e(i,ue(he(R(e.d,(Li(),oh))))-e.e),n=new $e(i,ue(he(R(e.d,Af)))+e.e))),c(d.a,8).a=t.a,c(d.a,8).b=t.b,d.b.a=n.a,d.b.b=n.b,++o}}function ktn(e,t,n,i,r,o){var a,d,b,v,x,S,M,L,P,z,H,X;switch(t){case 71:d=i.q.getFullYear()-G0>=-1900?1:0,n>=4?Zn(e,W(V(nt,1),Be,2,6,[Vst,Wst])[d]):Zn(e,W(V(nt,1),Be,2,6,["BC","AD"])[d]);break;case 121:WBt(e,n,i);break;case 77:YVt(e,n,i);break;case 107:b=r.q.getHours(),b==0?qd(e,24,n):qd(e,b,n);break;case 83:gJt(e,n,r);break;case 69:x=i.q.getDay(),n==5?Zn(e,W(V(nt,1),Be,2,6,["S","M","T","W","T","F","S"])[x]):n==4?Zn(e,W(V(nt,1),Be,2,6,[tre,nre,ire,rre,sre,ore,cre])[x]):Zn(e,W(V(nt,1),Be,2,6,["Sun","Mon","Tue","Wed","Thu","Fri","Sat"])[x]);break;case 97:r.q.getHours()>=12&&r.q.getHours()<24?Zn(e,W(V(nt,1),Be,2,6,["AM","PM"])[1]):Zn(e,W(V(nt,1),Be,2,6,["AM","PM"])[0]);break;case 104:S=r.q.getHours()%12,S==0?qd(e,12,n):qd(e,S,n);break;case 75:M=r.q.getHours()%12,qd(e,M,n);break;case 72:L=r.q.getHours(),qd(e,L,n);break;case 99:P=i.q.getDay(),n==5?Zn(e,W(V(nt,1),Be,2,6,["S","M","T","W","T","F","S"])[P]):n==4?Zn(e,W(V(nt,1),Be,2,6,[tre,nre,ire,rre,sre,ore,cre])[P]):n==3?Zn(e,W(V(nt,1),Be,2,6,["Sun","Mon","Tue","Wed","Thu","Fri","Sat"])[P]):qd(e,P,1);break;case 76:z=i.q.getMonth(),n==5?Zn(e,W(V(nt,1),Be,2,6,["J","F","M","A","M","J","J","A","S","O","N","D"])[z]):n==4?Zn(e,W(V(nt,1),Be,2,6,[Qie,Gie,Uie,Jie,Z5,Xie,Vie,Wie,Kie,Yie,Zie,ere])[z]):n==3?Zn(e,W(V(nt,1),Be,2,6,["Jan","Feb","Mar","Apr",Z5,"Jun","Jul","Aug","Sep","Oct","Nov","Dec"])[z]):qd(e,z+1,n);break;case 81:H=i.q.getMonth()/3|0,n<4?Zn(e,W(V(nt,1),Be,2,6,["Q1","Q2","Q3","Q4"])[H]):Zn(e,W(V(nt,1),Be,2,6,["1st quarter","2nd quarter","3rd quarter","4th quarter"])[H]);break;case 100:X=i.q.getDate(),qd(e,X,n);break;case 109:v=r.q.getMinutes(),qd(e,v,n);break;case 115:a=r.q.getSeconds(),qd(e,a,n);break;case 122:n<4?Zn(e,o.c[0]):Zn(e,o.c[1]);break;case 118:Zn(e,o.b);break;case 90:n<3?Zn(e,gGt(o)):n==3?Zn(e,wGt(o)):Zn(e,kGt(o.a));break;default:return!1}return!0}function Wye(e,t,n,i){var r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt,Rt,fn,ti;if(rit(t),b=c(re((!t.b&&(t.b=new Et(vn,t,4,7)),t.b),0),83),x=c(re((!t.c&&(t.c=new Et(vn,t,5,8)),t.c),0),83),d=to(b),v=to(x),a=(!t.a&&(t.a=new Me(Hi,t,6,6)),t.a).i==0?null:c(re((!t.a&&(t.a=new Me(Hi,t,6,6)),t.a),0),171),We=c(Ut(e.a,d),9),Rt=c(Ut(e.a,v),9),pt=null,fn=null,oe(b,196)&&(xe=c(Ut(e.a,b),248),oe(xe,12)?pt=c(xe,12):oe(xe,9)&&(We=c(xe,9),pt=c(Xe(We.j,0),12))),oe(x,196)&&(Dt=c(Ut(e.a,x),248),oe(Dt,12)?fn=c(Dt,12):oe(Dt,9)&&(Rt=c(Dt,9),fn=c(Xe(Rt.j,0),12))),!We||!Rt)throw J(new Y4("The source or the target of edge "+t+" could not be found. This usually happens when an edge connects a node laid out by ELK Layered to a node in another level of hierarchy laid out by either another instance of ELK Layered or another layout algorithm alltogether. The former can be solved by setting the hierarchyHandling option to INCLUDE_CHILDREN."));for(z=new qm,ec(z,t),Ee(z,(De(),Oi),t),Ee(z,(Ge(),ho),null),L=c(R(i,Lc),24),We==Rt&&L.Ec((Gs(),FE)),pt||(Se=(Qs(),Wc),bt=null,a&&dx(c(R(We,cr),103))&&(bt=new $e(a.j,a.k),yGe(bt,V2(t)),JGe(bt,n),nv(v,d)&&(Se=Jl,ki(bt,We.n))),pt=art(We,bt,Se,i)),fn||(Se=(Qs(),Jl),ti=null,a&&dx(c(R(Rt,cr),103))&&(ti=new $e(a.b,a.c),yGe(ti,V2(t)),JGe(ti,n)),fn=art(Rt,ti,Se,Jr(Rt))),ks(z,pt),ss(z,fn),(pt.e.c.length>1||pt.g.c.length>1||fn.e.c.length>1||fn.g.c.length>1)&&L.Ec((Gs(),zE)),M=new cn((!t.n&&(t.n=new Me(Bo,t,1,7)),t.n));M.e!=M.i.gc();)if(S=c(un(M),158),!et(Ze(ke(S,Ib)))&&S.a)switch(H=Rte(S),qe(z.b,H),c(R(H,yd),281).g){case 1:case 2:L.Ec((Gs(),L9));break;case 0:L.Ec((Gs(),D9)),Ee(H,yd,(Sh(),t8))}if(o=c(R(i,KE),302),X=c(R(i,oJ),329),r=o==(xT(),WL)||X==(ST(),Tle),a&&(!a.a&&(a.a=new Ar(Yu,a,5)),a.a).i!=0&&r){for(ie=dQt(a),P=new nu,de=_n(ie,0);de.b!=de.d.c;)se=c(An(de),8),ei(P,new Cs(se));Ee(z,v6e,P)}return z}function Otn(e,t,n,i){var r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt,Rt,fn,ti,Zi;for(bt=0,Dt=0,We=new wn,Se=c(vu(Q2(qc(new jt(null,new Tt(e.b,16)),new KR),new uj)),15).a+1,pt=ye(Fn,ci,30,Se,15,1),H=ye(Fn,ci,30,Se,15,1),z=0;z<Se;z++)pt[z]=0,H[z]=0;for(b=c(ql($pe(new jt(null,new Tt(e.a,16))),su(new Ls,new rs,new mo,W(V(ml,1),_e,132,0,[(va(),bl)]))),16),x=b.Jc();x.Ob();)if(v=c(x.Pb(),65),fn=c(R(v.b,(Uo(),xd)),15).a,Zi=c(R(v.c,xd),15).a,de=Zi-fn,de>1)for(d=fn+1;d<Zi;d++){if(S=d,xe=c(ql(pi(new jt(null,new Tt(e.b,16)),new Q_e(S)),su(new Ls,new rs,new mo,W(V(ml,1),_e,132,0,[bl]))),16),P=0,t==(Nr(),go)||t==yo){for(xe.gd(new t$),P=0;P<xe.gc()&&(X=(d-fn)/(Zi-fn),!(c(xe.Xb(P),41).e.b>v.b.e.b*(1-X)+v.c.e.b*X));P++);if(xe.gc()>0&&(ti=v.a.b==0?Ms(v.b.e):c(df(v.a),8),se=ki(Ms(c(xe.Xb(xe.gc()-1),41).e),c(xe.Xb(xe.gc()-1),41).f),M=ki(Ms(c(xe.Xb(0),41).e),c(xe.Xb(0),41).f),P>=xe.gc()-1&&ti.b>se.b&&v.c.e.b>se.b||P<=0&&ti.b<M.a&&v.c.e.b<M.b))continue}else{for(xe.gd(new AA),P=0;P<xe.gc()&&(X=(d-fn)/(Zi-fn),!(c(xe.Xb(P),41).e.a>v.b.e.a*(1-X)+v.c.e.a*X));P++);if(xe.gc()>0&&(ti=v.a.b==0?Ms(v.b.e):c(df(v.a),8),se=ki(Ms(c(xe.Xb(xe.gc()-1),41).e),c(xe.Xb(xe.gc()-1),41).f),M=ki(Ms(c(xe.Xb(0),41).e),c(xe.Xb(0),41).f),P>=xe.gc()-1&&ti.a>se.a&&v.c.e.a>se.a||P<=0&&ti.a<M.a&&v.c.e.a<M.a))continue}r=new as,o=new as,ei(v.a,r),ei(v.a,o),a=new SZ(r,o,v),ie=id($d(d,32),Yr(P,Us)),jc(We,fv(ie))?(L=c(Ut(We,fv(ie)),669),ei(L.a,a),O1(L.b)?cb(L.a,new i$):cb(L.a,new r$),Nst(L)):(L=new jYe(P==0?null:c(xe.Xb(P-1),41),P==xe.gc()?null:c(xe.Xb(P),41),a,e),oi(We,fv(ie),L)),t==go||t==yo?(L.f&&L.d.e.b<=ue(he(R(e,(Li(),Gle))))&&++bt,L.g&&L.c.e.b+L.c.f.b>=ue(he(R(e,(Li(),Q9e))))&&++Dt):(L.f&&L.d.e.a<=ue(he(R(e,(Li(),Qle))))&&++bt,L.g&&L.c.e.a+L.c.f.a>=ue(he(R(e,(Li(),H9e))))&&++Dt)}else de==0?hve(v):de<0&&(++pt[fn],++H[Zi],Rt=mtn(v,t,e,new Ps(Pe(bt),Pe(Dt)),n,i,new Ps(Pe(H[Zi]),Pe(pt[fn]))),bt=c(Rt.a,15).a,Dt=c(Rt.b,15).a)}function Stn(e){e.gb||(e.gb=!0,e.b=Go(e,0),sr(e.b,18),zi(e.b,19),e.a=Go(e,1),sr(e.a,1),zi(e.a,2),zi(e.a,3),zi(e.a,4),zi(e.a,5),e.o=Go(e,2),sr(e.o,8),sr(e.o,9),zi(e.o,10),zi(e.o,11),zi(e.o,12),zi(e.o,13),zi(e.o,14),zi(e.o,15),zi(e.o,16),zi(e.o,17),zi(e.o,18),zi(e.o,19),zi(e.o,20),zi(e.o,21),zi(e.o,22),zi(e.o,23),ao(e.o),ao(e.o),ao(e.o),ao(e.o),ao(e.o),ao(e.o),ao(e.o),ao(e.o),ao(e.o),ao(e.o),e.p=Go(e,3),sr(e.p,2),sr(e.p,3),sr(e.p,4),sr(e.p,5),zi(e.p,6),zi(e.p,7),ao(e.p),ao(e.p),e.q=Go(e,4),sr(e.q,8),e.v=Go(e,5),zi(e.v,9),ao(e.v),ao(e.v),ao(e.v),e.w=Go(e,6),sr(e.w,2),sr(e.w,3),sr(e.w,4),zi(e.w,5),e.B=Go(e,7),zi(e.B,1),ao(e.B),ao(e.B),ao(e.B),e.Q=Go(e,8),zi(e.Q,0),ao(e.Q),e.R=Go(e,9),sr(e.R,1),e.S=Go(e,10),ao(e.S),ao(e.S),ao(e.S),ao(e.S),ao(e.S),ao(e.S),ao(e.S),ao(e.S),ao(e.S),ao(e.S),ao(e.S),ao(e.S),ao(e.S),ao(e.S),ao(e.S),e.T=Go(e,11),zi(e.T,10),zi(e.T,11),zi(e.T,12),zi(e.T,13),zi(e.T,14),ao(e.T),ao(e.T),e.U=Go(e,12),sr(e.U,2),sr(e.U,3),zi(e.U,4),zi(e.U,5),zi(e.U,6),zi(e.U,7),ao(e.U),e.V=Go(e,13),zi(e.V,10),e.W=Go(e,14),sr(e.W,18),sr(e.W,19),sr(e.W,20),zi(e.W,21),zi(e.W,22),zi(e.W,23),e.bb=Go(e,15),sr(e.bb,10),sr(e.bb,11),sr(e.bb,12),sr(e.bb,13),sr(e.bb,14),sr(e.bb,15),sr(e.bb,16),zi(e.bb,17),ao(e.bb),ao(e.bb),e.eb=Go(e,16),sr(e.eb,2),sr(e.eb,3),sr(e.eb,4),sr(e.eb,5),sr(e.eb,6),sr(e.eb,7),zi(e.eb,8),zi(e.eb,9),e.ab=Go(e,17),sr(e.ab,0),sr(e.ab,1),e.H=Go(e,18),zi(e.H,0),zi(e.H,1),zi(e.H,2),zi(e.H,3),zi(e.H,4),zi(e.H,5),ao(e.H),e.db=Go(e,19),zi(e.db,2),e.c=fi(e,20),e.d=fi(e,21),e.e=fi(e,22),e.f=fi(e,23),e.i=fi(e,24),e.g=fi(e,25),e.j=fi(e,26),e.k=fi(e,27),e.n=fi(e,28),e.r=fi(e,29),e.s=fi(e,30),e.t=fi(e,31),e.u=fi(e,32),e.fb=fi(e,33),e.A=fi(e,34),e.C=fi(e,35),e.D=fi(e,36),e.F=fi(e,37),e.G=fi(e,38),e.I=fi(e,39),e.J=fi(e,40),e.L=fi(e,41),e.M=fi(e,42),e.N=fi(e,43),e.O=fi(e,44),e.P=fi(e,45),e.X=fi(e,46),e.Y=fi(e,47),e.Z=fi(e,48),e.$=fi(e,49),e._=fi(e,50),e.cb=fi(e,51),e.K=fi(e,52))}function _st(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se;if(srt(e,t),(!t.e&&(t.e=new Et(Ii,t,7,4)),t.e).i!=0){for(d=new Fe,L=0;L<(!t.e&&(t.e=new Et(Ii,t,7,4)),t.e).i;L++)r=c(re(H6(c(re((!t.e&&(t.e=new Et(Ii,t,7,4)),t.e),L),74)),0),19),_st(e,r),It(d.c,r);for(b=d.c.length,P=0;P<d.c.length-1;P++)Vrt((ht(0,d.c.length),c(d.c[0],19)),(ht(P,d.c.length),c(d.c[P],19)),(ht(P+1,d.c.length),c(d.c[P+1],19)));for(H=((ht(0,d.c.length),c(d.c[0],19)).mh()+(ht(0,d.c.length),c(d.c[0],19)).lh()/2+c(Xe(d,d.c.length-1),19).mh()+c(Xe(d,d.c.length-1),19).lh()/2-t.g)/2-t.i,a=new G(d);a.a<a.c.c.length;)r=c(Q(a),19),Cc(r,r.i-H),ii(r,(Qd(),Rw),c(ke(r,zb),107).a);for(M=0;M<b-1&&(ht(M,d.c.length),c(d.c[M],19)).mh()+(ht(M,d.c.length),c(d.c[M],19)).lh()+c((ht(M,d.c.length),c(d.c[M],19)).mf((Dn(),Y1)),125).c-t.g/2<=0;)++M;for(v=ue(he((ht(M,d.c.length),c(d.c[M],19)).mf((Qd(),Rw)))),i=0;i<b;i++)v<ue(he((ht(i,d.c.length),c(d.c[i],19)).mf(Rw)))?(ht(i,d.c.length),c(d.c[i],19)).of(Rw,v):v=ue(he((ht(i,d.c.length),c(d.c[i],19)).mf(Rw)));for(M=b-1;M>0&&(ht(M,d.c.length),c(d.c[M],19)).mh()-c((ht(M,d.c.length),c(d.c[M],19)).mf((Dn(),Y1)),125).b-t.g/2>=0;)--M;if(M<b)for(n=M;n>=0;n--)v<ue(he((ht(n,d.c.length),c(d.c[n],19)).mf(Rw)))?(ht(n,d.c.length),c(d.c[n],19)).of(Rw,v):v=ue(he((ht(n,d.c.length),c(d.c[n],19)).mf(Rw)));for(z=c((ht(0,d.c.length),c(d.c[0],19)).mf(zb),107),x=c(ke(t,zb),107),ie=(ht(0,d.c.length),c(d.c[0],19)).mh()+z.c-x.c,X=new xu(0,z.a,z.b),q4(x.b.b.b,new xu(ie,ue(he((ht(0,d.c.length),c(d.c[0],19)).mf(Rw))),X)),S=c(ke(t,Zv),107),se=c((ht(b-1,d.c.length),c(d.c[b-1],19)).mf(Zv),107),ie=(ht(b-1,d.c.length),c(d.c[b-1],19)).mh()+se.c-S.c,X=new xu(0,se.a,se.b),q4(S.b.b.b,new xu(ie,ue(he((ht(b-1,d.c.length),c(d.c[b-1],19)).mf(Rw))),X)),o=new G(d);o.a<o.c.c.length;)r=c(Q(o),19),ii(t,kd,p.Math.max(ue(he(ke(t,kd))),ue(he(ke(r,kd))))),ii(t,V9,p.Math.min(ue(he(ke(t,V9))),r.i+ue(he(ke(r,V9))))),ii(t,X9,p.Math.max(ue(he(ke(t,X9))),r.i+ue(he(ke(r,X9)))));ii(t,Pue,he(ke(t,kd)))}}function Dst(e,t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt;if(srt(e,t),(!t.e&&(t.e=new Et(Ii,t,7,4)),t.e).i!=0){for(a=new Fe,x=0;x<(!t.e&&(t.e=new Et(Ii,t,7,4)),t.e).i;x++)i=c(re(H6(c(re((!t.e&&(t.e=new Et(Ii,t,7,4)),t.e),x),74)),0),19),Dst(e,i),It(a.c,i);for(sKt(e,a),S=0;S<a.c.length-1;S++)Vrt((ht(0,a.c.length),c(a.c[0],19)),(ht(S,a.c.length),c(a.c[S],19)),(ht(S+1,a.c.length),c(a.c[S+1],19)));for(Se=0,H=0,X=0;Se<a.c.length&&(ht(Se,a.c.length),c(a.c[Se],19)).nh()>=H;)(ht(Se,a.c.length),c(a.c[Se],19)).nh()>H&&(X=Se,H=(ht(Se,a.c.length),c(a.c[Se],19)).nh()),Se+=1;if(ie=0,Se>0&&(ie=((ht(X,a.c.length),c(a.c[X],19)).mh()+(ht(Se-1,a.c.length),c(a.c[Se-1],19)).mh()+(ht(Se-1,a.c.length),c(a.c[Se-1],19)).lh())/2-t.i-t.g/2),!et(Ze(ke(t,(q5(),zue))))){if(n=((ht(0,a.c.length),c(a.c[0],19)).mh()+c(Xe(a,a.c.length-1),19).mh()+c(Xe(a,a.c.length-1),19).lh()-t.g)/2-t.i,n<ie){for(v=0;v<X;v++)for(M=v+1;M<X+1;M++)for(pt=c((ht(v,a.c.length),c(a.c[v],19)).mf((Qd(),Zv)),107),bt=(ht(v,a.c.length),c(a.c[v],19)).mh()+pt.c,xe=(ht(M,a.c.length),c(a.c[M],19)).mh()+(ht(M,a.c.length),c(a.c[M],19)).lh()/2;pt&&pt.a<H;)se=xe-t.g/2+(xe-bt)*(t.j+t.f-H)/(H-pt.a),n=p.Math.max(n,se),pt=pt.b,pt&&(bt+=pt.c);ie=n}if(n>ie){for(v=Se;v<a.c.length;v++)for(M=Se-1;M<v;M++)for(P=c((ht(v,a.c.length),c(a.c[v],19)).mf((Qd(),zb)),107),z=(ht(v,a.c.length),c(a.c[v],19)).mh()+P.c,xe=(ht(M,a.c.length),c(a.c[M],19)).mh()+(ht(M,a.c.length),c(a.c[M],19)).lh()/2;P&&P.a<H;)se=xe-t.g/2+(xe-z)*(t.j+t.f-H)/(H-P.a),n=p.Math.min(n,se),P=P.b,P&&(z+=P.c);ie=n}}for(o=new G(a);o.a<o.c.c.length;)i=c(Q(o),19),Cc(i,i.i-ie);for(d=c(ke(t,(Qd(),zb)),107),L=c((ht(0,a.c.length),c(a.c[0],19)).mf(zb),107),de=(ht(0,a.c.length),c(a.c[0],19)).mh()+L.c-d.c,q4(d.b.b.b,new xu(de,L.a,L.b)),b=c(ke(t,Zv),107),We=c(c(Xe(a,a.c.length-1),19).mf(Zv),107),de=c(Xe(a,a.c.length-1),19).mh()+We.c-b.c,q4(b.b.b.b,new xu(de,We.a,We.b)),r=new G(a);r.a<r.c.c.length;)i=c(Q(r),19),ii(t,kd,p.Math.max(ue(he(ke(t,kd))),ue(he(ke(i,kd))))),ii(t,V9,p.Math.min(ue(he(ke(t,V9))),i.i+ue(he(ke(i,V9))))),ii(t,X9,p.Math.max(ue(he(ke(t,X9))),i.i+ue(he(ke(i,X9)))));ii(t,Pue,he(ke(t,kd)))}}function jtn(e,t,n,i){var r,o,a,d,b,v,x,S,M,L,P;for(S=_n(e.b,0);S.b!=S.d.c;)if(x=c(An(S),41),!Ot(x.c,yG))for(o=c(ql(new jt(null,new Tt(_Gt(x,e),16)),su(new Ls,new rs,new mo,W(V(ml,1),_e,132,0,[(va(),bl)]))),16),t==(Nr(),go)||t==yo?o.gd(new ZR):o.gd(new e$),P=o.gc(),r=0;r<P;r++)a=P==1?.5:(1+r)/(P+1),t==go?(v=ue(he(R(x,(Li(),Af)))),x.e.a+x.f.a+i<v?Es(c(o.Xb(r),65).a,new $e(v+n,x.e.b+x.f.b*a)):c(o.Xb(r),65).a.b>0&&(d=c(df(c(o.Xb(r),65).a),8).a,M=x.e.a+x.f.a/2,b=c(df(c(o.Xb(r),65).a),8).b,L=x.e.b+x.f.b/2,i>0&&p.Math.abs(b-L)/(p.Math.abs(d-M)/40)>50&&(L>b?Es(c(o.Xb(r),65).a,new $e(x.e.a+x.f.a+i/5.3,x.e.b+x.f.b*a-i/2)):Es(c(o.Xb(r),65).a,new $e(x.e.a+x.f.a+i/5.3,x.e.b+x.f.b*a+i/2)))),Es(c(o.Xb(r),65).a,new $e(x.e.a+x.f.a,x.e.b+x.f.b*a))):t==yo?(v=ue(he(R(x,(Li(),oh)))),x.e.a-i>v?Es(c(o.Xb(r),65).a,new $e(v-n,x.e.b+x.f.b*a)):c(o.Xb(r),65).a.b>0&&(d=c(df(c(o.Xb(r),65).a),8).a,M=x.e.a+x.f.a/2,b=c(df(c(o.Xb(r),65).a),8).b,L=x.e.b+x.f.b/2,i>0&&p.Math.abs(b-L)/(p.Math.abs(d-M)/40)>50&&(L>b?Es(c(o.Xb(r),65).a,new $e(x.e.a-i/5.3,x.e.b+x.f.b*a-i/2)):Es(c(o.Xb(r),65).a,new $e(x.e.a-i/5.3,x.e.b+x.f.b*a+i/2)))),Es(c(o.Xb(r),65).a,new $e(x.e.a,x.e.b+x.f.b*a))):t==Ca?(v=ue(he(R(x,(Li(),Af)))),x.e.b+x.f.b+i<v?Es(c(o.Xb(r),65).a,new $e(x.e.a+x.f.a*a,v+n)):c(o.Xb(r),65).a.b>0&&(d=c(df(c(o.Xb(r),65).a),8).a,M=x.e.a+x.f.a/2,b=c(df(c(o.Xb(r),65).a),8).b,L=x.e.b+x.f.b/2,i>0&&p.Math.abs(d-M)/(p.Math.abs(b-L)/40)>50&&(M>d?Es(c(o.Xb(r),65).a,new $e(x.e.a+x.f.a*a-i/2,x.e.b+i/5.3+x.f.b)):Es(c(o.Xb(r),65).a,new $e(x.e.a+x.f.a*a+i/2,x.e.b+i/5.3+x.f.b)))),Es(c(o.Xb(r),65).a,new $e(x.e.a+x.f.a*a,x.e.b+x.f.b))):(v=ue(he(R(x,(Li(),oh)))),UVe(c(o.Xb(r),65),e)?Es(c(o.Xb(r),65).a,new $e(x.e.a+x.f.a*a,c(df(c(o.Xb(r),65).a),8).b)):x.e.b-i>v?Es(c(o.Xb(r),65).a,new $e(x.e.a+x.f.a*a,v-n)):c(o.Xb(r),65).a.b>0&&(d=c(df(c(o.Xb(r),65).a),8).a,M=x.e.a+x.f.a/2,b=c(df(c(o.Xb(r),65).a),8).b,L=x.e.b+x.f.b/2,i>0&&p.Math.abs(d-M)/(p.Math.abs(b-L)/40)>50&&(M>d?Es(c(o.Xb(r),65).a,new $e(x.e.a+x.f.a*a-i/2,x.e.b-i/5.3)):Es(c(o.Xb(r),65).a,new $e(x.e.a+x.f.a*a+i/2,x.e.b-i/5.3)))),Es(c(o.Xb(r),65).a,new $e(x.e.a+x.f.a*a,x.e.b)))}function Lst(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe;if(a=t,M=n,jc(e.a,a)){if($a(c(Ut(e.a,a),47),M))return 1}else oi(e.a,a,new Or);if(jc(e.a,M)){if($a(c(Ut(e.a,M),47),a))return-1}else oi(e.a,M,new Or);if(jc(e.e,a)){if($a(c(Ut(e.e,a),47),M))return-1}else oi(e.e,a,new Or);if(jc(e.e,M)){if($a(c(Ut(e.a,M),47),a))return 1}else oi(e.e,M,new Or);if(a.j!=M.j)return Se=Q8t(a.j,M.j),Se>0?ka(e,a,M,1):ka(e,M,a,1),Se;if(xe=1,a.e.c.length!=0&&M.e.c.length!=0){if((a.j==(Je(),Yt)&&M.j==Yt||a.j==Kt&&M.j==Kt||a.j==bn&&M.j==bn)&&(xe=-xe),x=c(Xe(a.e,0),17).c,H=c(Xe(M.e,0),17).c,b=x.i,P=H.i,b==P)for(se=new G(b.j);se.a<se.c.c.length;){if(ie=c(Q(se),12),x==ie)return ka(e,M,a,xe),-xe;if(H==ie)return ka(e,a,M,xe),xe}if(x.i.k==(Jt(),jr)&&H.i.k==jr&&b.c.p==P.c.p&&b.c.p==a.i.c.p&&(de=b.c,r=RWe(de,b,P),r!=0))return a.j==nn&&M.j==nn&&(xe=-xe),r>0?(ka(e,a,M,xe),xe):(ka(e,M,a,xe),-xe);if(i=RWe(c(ql(QZ(e.d),su(new Ls,new rs,new mo,W(V(ml,1),_e,132,0,[(va(),bl)]))),22),b,P),i!=0)return i>0?(ka(e,a,M,xe),xe):(ka(e,M,a,xe),-xe);if(e.c&&(Se=dYe(e,a,M),Se!=0))return Se>0?(ka(e,a,M,xe),xe):(ka(e,M,a,xe),-xe)}return a.g.c.length!=0&&M.g.c.length!=0?((a.j==(Je(),Yt)&&M.j==Yt||a.j==bn&&M.j==bn)&&(xe=-xe),S=c(R(a,(De(),Uce)),9),X=c(R(M,Uce),9),e.f==(B1(),Mle)&&S&&X&&xi(S,Pi)&&xi(X,Pi)?(d=cw(S,X,e.b,c(R(e.b,np),15).a),L=cw(X,S,e.b,c(R(e.b,np),15).a),d>L?(ka(e,a,M,xe),xe):(ka(e,M,a,xe),-xe)):e.c&&(Se=dYe(e,a,M),Se!=0)?Se>0?(ka(e,a,M,xe),xe):(ka(e,M,a,xe),-xe):(v=0,z=0,xi(c(Xe(a.g,0),17),Pi)&&(v=cw(c(Xe(a.g,0),248),c(Xe(M.g,0),248),e.b,a.g.c.length+a.e.c.length)),xi(c(Xe(M.g,0),17),Pi)&&(z=cw(c(Xe(M.g,0),248),c(Xe(a.g,0),248),e.b,M.g.c.length+M.e.c.length)),S&&S==X||e.g&&(e.g._b(S)&&(v=c(e.g.xc(S),15).a),e.g._b(X)&&(z=c(e.g.xc(X),15).a)),v>z?(ka(e,a,M,xe),xe):(ka(e,M,a,xe),-xe))):a.e.c.length!=0&&M.g.c.length!=0?(ka(e,a,M,xe),1):a.g.c.length!=0&&M.e.c.length!=0?(ka(e,M,a,xe),-1):xi(a,(De(),Pi))&&xi(M,Pi)?(o=a.i.j.c.length,d=cw(a,M,e.b,o),L=cw(M,a,e.b,o),(a.j==(Je(),Yt)&&M.j==Yt||a.j==bn&&M.j==bn)&&(xe=-xe),d>L?(ka(e,a,M,xe),xe):(ka(e,M,a,xe),-xe)):(ka(e,M,a,xe),-xe)}function De(){De=te;var e,t;Oi=new gi(jxe),p6e=new gi("coordinateOrigin"),Xce=new gi("processors"),g6e=new qi("compoundNode",(Bt(),!1)),nP=new qi("insideConnections",!1),v6e=new gi("originalBendpoints"),y6e=new gi("originalDummyNodePosition"),x6e=new gi("originalLabelEdge"),HE=new gi("representedLabels"),qE=new gi("endLabels"),vk=new gi("endLabel.origin"),xk=new qi("labelSide",(qu(),PP)),f3=new qi("maxEdgeThickness",0),Jg=new qi("reversed",!1),kk=new gi(Dot),sh=new qi("longEdgeSource",null),Wa=new qi("longEdgeTarget",null),Bv=new qi("longEdgeHasLabelDummies",!1),iP=new qi("longEdgeBeforeLabelDummy",!1),QU=new qi("edgeConstraint",(ab(),Ace)),Mw=new gi("inLayerLayoutUnit"),Nb=new qi("inLayerConstraint",(D1(),eP)),yk=new qi("inLayerSuccessorConstraint",new Fe),w6e=new qi("inLayerSuccessorConstraintBetweenNonDummies",!1),Ul=new gi("portDummy"),HU=new qi("crossingHint",Pe(0)),Lc=new qi("graphProperties",(t=c(Jf(Rce),10),new ha(t,c(gf(t,t.length),10),0))),Ko=new qi("externalPortSide",(Je(),$o)),m6e=new qi("externalPortSize",new as),Hce=new gi("externalPortReplacedDummies"),GU=new gi("externalPortReplacedDummy"),X1=new qi("externalPortConnections",(e=c(Jf($s),10),new ha(e,c(gf(e,e.length),10),0))),Aw=new qi(Cot,0),d6e=new gi("barycenterAssociates"),Sk=new gi("TopSideComments"),mk=new gi("BottomSideComments"),qU=new gi("CommentConnectionPort"),Gce=new qi("inputCollect",!1),Jce=new qi("outputCollect",!1),wk=new qi("cyclic",!1),b6e=new gi("crossHierarchyMap"),Wce=new gi("targetOffset"),new qi("splineLabelSize",new as),d3=new gi("spacings"),UU=new qi("partitionConstraint",!1),Cw=new gi("breakingPoint.info"),S6e=new gi("splines.survivingEdge"),_b=new gi("splines.route.start"),g3=new gi("splines.edgeChain"),O6e=new gi("originalPortConstraints"),Nw=new gi("selfLoopHolder"),I9=new gi("splines.nsPortY"),Pi=new gi("modelOrder"),np=new gi("modelOrder.maximum"),tP=new gi("modelOrderGroups.cb.number"),Uce=new gi("longEdgeTargetNode"),tp=new qi(sct,!1),h3=new qi(sct,!1),Qce=new gi("layerConstraints.hiddenNodes"),k6e=new gi("layerConstraints.opposidePort"),Vce=new gi("targetNode.modelOrder"),Ok=new qi("tarjan.lowlink",Pe(di)),QE=new qi("tarjan.id",Pe(-1)),JU=new qi("tarjan.onstack",!1),Ldt=new qi("partOfCycle",!1),p3=new gi("medianHeuristic.weight")}function Dn(){Dn=te;var e,t;_k=new gi(elt),ry=new gi(tlt),Vje=(Hd(),Vue),xwt=new wt(P3e,Vje),K9=new wt(ZS,null),kwt=new gi(n5e),Kje=(bb(),_i(Yue,W(V(Zue,1),_e,300,0,[Kue]))),CP=new wt(bG,Kje),MP=new wt(AL,(Bt(),!1)),Yje=(Nr(),qh),Fb=new wt(hse,Yje),t7e=($1(),fae),e7e=new wt(ML,t7e),Twt=new wt(e5e,!1),i7e=(R1(),WJ),j3=new wt(pG,i7e),g7e=new Qp(12),zh=new wt(gw,g7e),AC=new wt(e9,!1),nae=new wt(wG,!1),NC=new wt(t9,!1),v7e=(Zr(),fp),Y9=new wt(KQ,v7e),Dk=new gi(mG),NP=new gi(wL),uae=new gi(WQ),aae=new gi(rE),o7e=new nu,T3=new wt(U3e,o7e),Swt=new wt(W3e,!1),Ewt=new wt(K3e,!1),new wt(nlt,0),c7e=new Vj,Y1=new wt(pse,c7e),GJ=new wt(D3e,!1),Dwt=new wt(ilt,1),ty=new gi(rlt),ey=new gi(slt),e8=new wt(yL,!1),new wt(olt,!0),Pe(0),new wt(clt,Pe(100)),new wt(llt,!1),Pe(0),new wt(ult,Pe(4e3)),Pe(0),new wt(alt,Pe(400)),new wt(flt,!1),new wt(hlt,!1),new wt(dlt,!0),new wt(glt,!1),Wje=(PH(),mae),Owt=new wt(t5e,Wje),s7e=(iT(),$P),Mwt=new wt(plt,s7e),r7e=(gS(),_P),Cwt=new wt(blt,r7e),Lwt=new wt(x3e,10),Pwt=new wt(k3e,10),Iwt=new wt(O3e,20),Rwt=new wt(S3e,10),O7e=new wt(Ore,2),S7e=new wt(fse,10),j7e=new wt(j3e,0),UJ=new wt(C3e,5),T7e=new wt(T3e,1),E7e=new wt(E3e,1),lh=new wt(dw,20),$wt=new wt(M3e,10),A7e=new wt(A3e,10),Lk=new gi(N3e),M7e=new C$e,C7e=new wt(Z3e,M7e),Nwt=new gi(gse),p7e=!1,Awt=new wt(dse,p7e),u7e=new Qp(5),l7e=new wt($3e,u7e),a7e=(mv(),t=c(Jf(Ws),10),new ha(t,c(gf(t,t.length),10),0)),E3=new wt(i9,a7e),m7e=(_x(),ap),b7e=new wt(F3e,m7e),rae=new gi(q3e),sae=new gi(H3e),oae=new gi(Q3e),iae=new gi(G3e),f7e=(e=c(Jf(BC),10),new ha(e,c(gf(e,e.length),10),0)),qb=new wt(Jx,f7e),d7e=gt((uu(),s8)),lp=new wt(sk,d7e),h7e=new $e(0,0),C3=new wt(ok,h7e),ny=new wt(n9,!1),Zje=(Sh(),t8),eae=new wt(X3e,Zje),QJ=new wt(vL,!1),Pe(1),new wt(mlt,null),w7e=new gi(Y3e),cae=new gi(V3e),k7e=(Je(),$o),M3=new wt(L3e,k7e),fu=new gi(_3e),y7e=(Ql(),gt(hp)),iy=new wt(r9,y7e),lae=new wt(B3e,!1),x7e=new wt(z3e,!0),Pe(1),Hwt=new wt(zse,Pe(3)),Pe(1),Gwt=new wt(i5e,Pe(4)),JJ=new wt(xL,1),XJ=new wt(Fse,null),sy=new wt(kL,150),Z9=new wt(OL,1.414),Pk=new wt(pw,null),Bwt=new wt(r5e,1),AP=new wt(I3e,!1),tae=new wt(R3e,!1),jwt=new wt(J3e,1),n7e=(aQ(),dae),new wt(wlt,n7e),_wt=!0,Qwt=(_q(),bae),Fwt=(P5(),ly),qwt=ly,zwt=ly}function cs(){cs=te,aOe=new Er("DIRECTION_PREPROCESSOR",0),cOe=new Er("COMMENT_PREPROCESSOR",1),r3=new Er("EDGE_AND_LAYER_CONSTRAINT_EDGE_REVERSER",2),cce=new Er("INTERACTIVE_EXTERNAL_PORT_POSITIONER",3),MOe=new Er("PARTITION_PREPROCESSOR",4),bU=new Er("LABEL_DUMMY_INSERTER",5),TU=new Er("SELF_LOOP_PREPROCESSOR",6),Pv=new Er("LAYER_CONSTRAINT_PREPROCESSOR",7),EOe=new Er("PARTITION_MIDPROCESSOR",8),wOe=new Er("HIGH_DEGREE_NODE_LAYER_PROCESSOR",9),jOe=new Er("NODE_PROMOTION",10),Lv=new Er("LAYER_CONSTRAINT_POSTPROCESSOR",11),COe=new Er("PARTITION_POSTPROCESSOR",12),pOe=new Er("HIERARCHICAL_PORT_CONSTRAINT_PROCESSOR",13),AOe=new Er("SEMI_INTERACTIVE_CROSSMIN_PROCESSOR",14),tOe=new Er("BREAKING_POINT_INSERTER",15),yU=new Er("LONG_EDGE_SPLITTER",16),lce=new Er("PORT_SIDE_PROCESSOR",17),gU=new Er("INVERTED_PORT_PROCESSOR",18),OU=new Er("PORT_LIST_SORTER",19),_Oe=new Er("SORT_BY_INPUT_ORDER_OF_MODEL",20),kU=new Er("NORTH_SOUTH_PORT_PREPROCESSOR",21),nOe=new Er("BREAKING_POINT_PROCESSOR",22),TOe=new Er(Kot,23),DOe=new Er(Yot,24),SU=new Er("SELF_LOOP_PORT_RESTORER",25),eOe=new Er("ALTERNATING_LAYER_UNZIPPER",26),NOe=new Er("SINGLE_EDGE_GRAPH_WRAPPER",27),pU=new Er("IN_LAYER_CONSTRAINT_PROCESSOR",28),hOe=new Er("END_NODE_PORT_LABEL_MANAGEMENT_PROCESSOR",29),OOe=new Er("LABEL_AND_NODE_SIZE_PROCESSOR",30),kOe=new Er("INNERMOST_NODE_MARGIN_CALCULATOR",31),EU=new Er("SELF_LOOP_ROUTER",32),sOe=new Er("COMMENT_NODE_MARGIN_CALCULATOR",33),dU=new Er("END_LABEL_PREPROCESSOR",34),wU=new Er("LABEL_DUMMY_SWITCHER",35),rOe=new Er("CENTER_LABEL_MANAGEMENT_PROCESSOR",36),T9=new Er("LABEL_SIDE_SELECTOR",37),yOe=new Er("HYPEREDGE_DUMMY_MERGER",38),bOe=new Er("HIERARCHICAL_PORT_DUMMY_SIZE_PROCESSOR",39),SOe=new Er("LAYER_SIZE_AND_GRAPH_HEIGHT_CALCULATOR",40),IE=new Er("HIERARCHICAL_PORT_POSITION_PROCESSOR",41),lOe=new Er("CONSTRAINTS_POSTPROCESSOR",42),oOe=new Er("COMMENT_POSTPROCESSOR",43),xOe=new Er("HYPERNODE_PROCESSOR",44),mOe=new Er("HIERARCHICAL_PORT_ORTHOGONAL_EDGE_ROUTER",45),vU=new Er("LONG_EDGE_JOINER",46),jU=new Er("SELF_LOOP_POSTPROCESSOR",47),iOe=new Er("BREAKING_POINT_REMOVER",48),xU=new Er("NORTH_SOUTH_PORT_POSTPROCESSOR",49),vOe=new Er("HORIZONTAL_COMPACTOR",50),mU=new Er("LABEL_DUMMY_REMOVER",51),dOe=new Er("FINAL_SPLINE_BENDPOINTS_CALCULATOR",52),fOe=new Er("END_LABEL_SORTER",53),pk=new Er("REVERSED_EDGE_RESTORER",54),hU=new Er("END_LABEL_POSTPROCESSOR",55),gOe=new Er("HIERARCHICAL_NODE_RESIZER",56),uOe=new Er("DIRECTION_POSTPROCESSOR",57)}function Ttn(e,t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt,Rt,fn,ti,Zi,Wl,po,Zu,P3,o0,Rf,ng,_a,qk,YC,ig,fh,c0,Ub,Jb,Hk,Xb,Vb,rg,by,sEe,Hw,ZC,Lae,Qk,eM,my,tM,Pae,Lvt;for(sEe=0,ti=t,po=0,o0=ti.length;po<o0;++po)for(Rt=ti[po],c0=new G(Rt.j);c0.a<c0.c.c.length;){for(fh=c(Q(c0),12),Jb=0,d=new G(fh.g);d.a<d.c.c.length;)a=c(Q(d),17),Rt.c!=a.d.i.c&&++Jb;Jb>0&&(e.a[fh.p]=sEe++)}for(eM=0,Zi=n,Zu=0,Rf=Zi.length;Zu<Rf;++Zu){for(Rt=Zi[Zu],ng=0,c0=new G(Rt.j);c0.a<c0.c.c.length&&(fh=c(Q(c0),12),fh.j==(Je(),Kt));)for(d=new G(fh.e);d.a<d.c.c.length;)if(a=c(Q(d),17),Rt.c!=a.c.i.c){++ng;break}for(qk=0,Hk=new os(Rt.j,Rt.j.c.length);Hk.b>0;){for(fh=(dn(Hk.b>0),c(Hk.a.Xb(Hk.c=--Hk.b),12)),Jb=0,d=new G(fh.e);d.a<d.c.c.length;)a=c(Q(d),17),Rt.c!=a.c.i.c&&++Jb;Jb>0&&(fh.j==(Je(),Kt)?(e.a[fh.p]=eM,++eM):(e.a[fh.p]=eM+ng+qk,++qk))}eM+=qk}for(Ub=new wn,P=new Ld,fn=t,Wl=0,P3=fn.length;Wl<P3;++Wl)for(Rt=fn[Wl],Lae=new G(Rt.j);Lae.a<Lae.c.c.length;)for(ZC=c(Q(Lae),12),d=new G(ZC.g);d.a<d.c.c.length;)if(a=c(Q(d),17),tM=a.d,Rt.c!=tM.i.c)if(Hw=c(Ao(co(Ub.f,ZC)),470),my=c(Ao(co(Ub.f,tM)),470),!Hw&&!my)L=new hze,P.a.yc(L,P),qe(L.a,a),qe(L.d,ZC),gl(Ub.f,ZC,L),qe(L.d,tM),gl(Ub.f,tM,L);else if(!Hw)qe(my.a,a),qe(my.d,ZC),gl(Ub.f,ZC,my);else if(!my)qe(Hw.a,a),qe(Hw.d,tM),gl(Ub.f,tM,Hw);else if(Hw==my)qe(Hw.a,a);else{for(qe(Hw.a,a),ig=new G(my.d);ig.a<ig.c.c.length;)YC=c(Q(ig),12),gl(Ub.f,YC,Hw);yr(Hw.a,my.a),yr(Hw.d,my.d),P.a.Ac(my)!=null}for(z=c(jT(P,ye(Wtn,{3:1,4:1,5:1,2024:1},470,P.a.gc(),0,1)),2024),Dt=t[0].c,by=n[0].c,x=z,S=0,M=x.length;S<M;++S)for(v=x[S],v.e=sEe,v.f=eM,c0=new G(v.d);c0.a<c0.c.c.length;)fh=c(Q(c0),12),Xb=e.a[fh.p],fh.i.c==Dt?(Xb<v.e&&(v.e=Xb),Xb>v.b&&(v.b=Xb)):fh.i.c==by&&(Xb<v.f&&(v.f=Xb),Xb>v.c&&(v.c=Xb));for(K6(z,0,z.length,null),Qk=ye(Fn,ci,30,z.length,15,1),i=ye(Fn,ci,30,eM+1,15,1),X=0;X<z.length;X++)Qk[X]=z[X].f,i[Qk[X]]=1;for(o=0,ie=0;ie<i.length;ie++)i[ie]==1?i[ie]=o:--o;for(Vb=0,se=0;se<Qk.length;se++)Qk[se]+=i[Qk[se]],Vb=p.Math.max(Vb,Qk[se]+1);for(b=1;b<Vb;)b*=2;for(Lvt=2*b-1,b-=1,Pae=ye(Fn,ci,30,Lvt,15,1),r=0,pt=0;pt<Qk.length;pt++)for(We=Qk[pt]+b,++Pae[We];We>0;)We%2>0&&(r+=Pae[We+1]),We=(We-1)/2|0,++Pae[We];for(bt=ye(rpt,Lt,371,z.length*2,0,1),de=0;de<z.length;de++)bt[2*de]=new hq(z[de],z[de].e,z[de].b,(Z7(),aC)),bt[2*de+1]=new hq(z[de],z[de].b,z[de].e,uC);for(K6(bt,0,bt.length,null),_a=0,Se=0;Se<bt.length;Se++)switch(bt[Se].d.g){case 0:++_a;break;case 1:--_a,r+=_a}for(rg=ye(rpt,Lt,371,z.length*2,0,1),xe=0;xe<z.length;xe++)rg[2*xe]=new hq(z[xe],z[xe].f,z[xe].c,(Z7(),aC)),rg[2*xe+1]=new hq(z[xe],z[xe].c,z[xe].f,uC);for(K6(rg,0,rg.length,null),_a=0,H=0;H<rg.length;H++)switch(rg[H].d.g){case 0:++_a;break;case 1:--_a,r+=_a}return r}function wi(){wi=te,KC=new km(7),KTe=new Rd(8,94),new Rd(8,64),YTe=new Rd(8,36),jvt=new Rd(8,65),Tvt=new Rd(8,122),Evt=new Rd(8,90),Mvt=new Rd(8,98),Svt=new Rd(8,66),Cvt=new Rd(8,60),Avt=new Rd(8,62),WTe=new km(11),pX=new $u(4),Ac(pX,48,57),u8=new $u(4),Ac(u8,48,57),Ac(u8,65,90),Ac(u8,95,95),Ac(u8,97,122),Fk=new $u(4),Ac(Fk,9,9),Ac(Fk,10,10),Ac(Fk,12,12),Ac(Fk,13,13),Ac(Fk,32,32),ZTe=yv(pX),tEe=yv(u8),eEe=yv(Fk),l8=new wn,WC=new wn,Ovt=W(V(nt,1),Be,2,6,["Cn","Lu","Ll","Lt","Lm","Lo","Mn","Me","Mc","Nd","Nl","No","Zs","Zl","Zp","Cc","Cf",null,"Co","Cs","Pd","Ps","Pe","Pc","Po","Sm","Sc","Sk","So","Pi","Pf","L","M","N","Z","C","P","S"]),XTe=W(V(nt,1),Be,2,6,["Basic Latin","Latin-1 Supplement","Latin Extended-A","Latin Extended-B","IPA Extensions","Spacing Modifier Letters","Combining Diacritical Marks","Greek","Cyrillic","Armenian","Hebrew","Arabic","Syriac","Thaana","Devanagari","Bengali","Gurmukhi","Gujarati","Oriya","Tamil","Telugu","Kannada","Malayalam","Sinhala","Thai","Lao","Tibetan","Myanmar","Georgian","Hangul Jamo","Ethiopic","Cherokee","Unified Canadian Aboriginal Syllabics","Ogham","Runic","Khmer","Mongolian","Latin Extended Additional","Greek Extended","General Punctuation","Superscripts and Subscripts","Currency Symbols","Combining Marks for Symbols","Letterlike Symbols","Number Forms","Arrows","Mathematical Operators","Miscellaneous Technical","Control Pictures","Optical Character Recognition","Enclosed Alphanumerics","Box Drawing","Block Elements","Geometric Shapes","Miscellaneous Symbols","Dingbats","Braille Patterns","CJK Radicals Supplement","Kangxi Radicals","Ideographic Description Characters","CJK Symbols and Punctuation","Hiragana","Katakana","Bopomofo","Hangul Compatibility Jamo","Kanbun","Bopomofo Extended","Enclosed CJK Letters and Months","CJK Compatibility","CJK Unified Ideographs Extension A","CJK Unified Ideographs","Yi Syllables","Yi Radicals","Hangul Syllables",mat,"CJK Compatibility Ideographs","Alphabetic Presentation Forms","Arabic Presentation Forms-A","Combining Half Marks","CJK Compatibility Forms","Small Form Variants","Arabic Presentation Forms-B","Specials","Halfwidth and Fullwidth Forms","Old Italic","Gothic","Deseret","Byzantine Musical Symbols","Musical Symbols","Mathematical Alphanumeric Symbols","CJK Unified Ideographs Extension B","CJK Compatibility Ideographs Supplement","Tags"]),VTe=W(V(Fn,1),ci,30,15,[66304,66351,66352,66383,66560,66639,118784,119039,119040,119295,119808,120831,131072,173782,194560,195103,917504,917631])}function FQ(){FQ=te,Ift=new wa("OUT_T_L",0,(Hl(),wd),(hl(),Ef),(Yf(),Vo),Vo,W(V(Va,1),Lt,24,0,[_i((mv(),Df),W(V(Ws,1),_e,96,0,[Lf,Nf]))])),Pft=new wa("OUT_T_C",1,Y0,Ef,Vo,Vc,W(V(Va,1),Lt,24,0,[_i(Df,W(V(Ws,1),_e,96,0,[Lf,Z1])),_i(Df,W(V(Ws,1),_e,96,0,[Lf,Z1,Ka]))])),Rft=new wa("OUT_T_R",2,Tf,Ef,Vo,Wo,W(V(Va,1),Lt,24,0,[_i(Df,W(V(Ws,1),_e,96,0,[Lf,_f]))])),Eft=new wa("OUT_B_L",3,wd,rh,Wo,Vo,W(V(Va,1),Lt,24,0,[_i(Df,W(V(Ws,1),_e,96,0,[Ya,Nf]))])),Tft=new wa("OUT_B_C",4,Y0,rh,Wo,Vc,W(V(Va,1),Lt,24,0,[_i(Df,W(V(Ws,1),_e,96,0,[Ya,Z1])),_i(Df,W(V(Ws,1),_e,96,0,[Ya,Z1,Ka]))])),Cft=new wa("OUT_B_R",5,Tf,rh,Wo,Wo,W(V(Va,1),Lt,24,0,[_i(Df,W(V(Ws,1),_e,96,0,[Ya,_f]))])),Nft=new wa("OUT_L_T",6,Tf,rh,Vo,Vo,W(V(Va,1),Lt,24,0,[_i(Df,W(V(Ws,1),_e,96,0,[Nf,Lf,Ka]))])),Aft=new wa("OUT_L_C",7,Tf,Z0,Vc,Vo,W(V(Va,1),Lt,24,0,[_i(Df,W(V(Ws,1),_e,96,0,[Nf,i1])),_i(Df,W(V(Ws,1),_e,96,0,[Nf,i1,Ka]))])),Mft=new wa("OUT_L_B",8,Tf,Ef,Wo,Vo,W(V(Va,1),Lt,24,0,[_i(Df,W(V(Ws,1),_e,96,0,[Nf,Ya,Ka]))])),Lft=new wa("OUT_R_T",9,wd,rh,Vo,Wo,W(V(Va,1),Lt,24,0,[_i(Df,W(V(Ws,1),_e,96,0,[_f,Lf,Ka]))])),Dft=new wa("OUT_R_C",10,wd,Z0,Vc,Wo,W(V(Va,1),Lt,24,0,[_i(Df,W(V(Ws,1),_e,96,0,[_f,i1])),_i(Df,W(V(Ws,1),_e,96,0,[_f,i1,Ka]))])),_ft=new wa("OUT_R_B",11,wd,Ef,Wo,Wo,W(V(Va,1),Lt,24,0,[_i(Df,W(V(Ws,1),_e,96,0,[_f,Ya,Ka]))])),Sft=new wa("IN_T_L",12,wd,rh,Vo,Vo,W(V(Va,1),Lt,24,0,[_i(Vu,W(V(Ws,1),_e,96,0,[Lf,Nf])),_i(Vu,W(V(Ws,1),_e,96,0,[Lf,Nf,Ka]))])),Oft=new wa("IN_T_C",13,Y0,rh,Vo,Vc,W(V(Va,1),Lt,24,0,[_i(Vu,W(V(Ws,1),_e,96,0,[Lf,Z1])),_i(Vu,W(V(Ws,1),_e,96,0,[Lf,Z1,Ka]))])),jft=new wa("IN_T_R",14,Tf,rh,Vo,Wo,W(V(Va,1),Lt,24,0,[_i(Vu,W(V(Ws,1),_e,96,0,[Lf,_f])),_i(Vu,W(V(Ws,1),_e,96,0,[Lf,_f,Ka]))])),xft=new wa("IN_C_L",15,wd,Z0,Vc,Vo,W(V(Va,1),Lt,24,0,[_i(Vu,W(V(Ws,1),_e,96,0,[i1,Nf])),_i(Vu,W(V(Ws,1),_e,96,0,[i1,Nf,Ka]))])),yft=new wa("IN_C_C",16,Y0,Z0,Vc,Vc,W(V(Va,1),Lt,24,0,[_i(Vu,W(V(Ws,1),_e,96,0,[i1,Z1])),_i(Vu,W(V(Ws,1),_e,96,0,[i1,Z1,Ka]))])),kft=new wa("IN_C_R",17,Tf,Z0,Vc,Wo,W(V(Va,1),Lt,24,0,[_i(Vu,W(V(Ws,1),_e,96,0,[i1,_f])),_i(Vu,W(V(Ws,1),_e,96,0,[i1,_f,Ka]))])),wft=new wa("IN_B_L",18,wd,Ef,Wo,Vo,W(V(Va,1),Lt,24,0,[_i(Vu,W(V(Ws,1),_e,96,0,[Ya,Nf])),_i(Vu,W(V(Ws,1),_e,96,0,[Ya,Nf,Ka]))])),mft=new wa("IN_B_C",19,Y0,Ef,Wo,Vc,W(V(Va,1),Lt,24,0,[_i(Vu,W(V(Ws,1),_e,96,0,[Ya,Z1])),_i(Vu,W(V(Ws,1),_e,96,0,[Ya,Z1,Ka]))])),vft=new wa("IN_B_R",20,Tf,Ef,Wo,Wo,W(V(Va,1),Lt,24,0,[_i(Vu,W(V(Ws,1),_e,96,0,[Ya,_f])),_i(Vu,W(V(Ws,1),_e,96,0,[Ya,_f,Ka]))])),Qoe=new wa(nE,21,null,null,null,null,W(V(Va,1),Lt,24,0,[]))}function Kye(){Kye=te,B6e=(oD(),PU),x1t=new wt(Dxe,B6e),D1t=new wt(Lxe,(Bt(),!1)),G6e=(Cq(),qce),$1t=new wt(nG,G6e),sgt=new wt(Pxe,!1),ogt=new wt(Ixe,!0),Rdt=new wt(Rxe,!1),nSe=(rD(),Ale),xgt=new wt($xe,nSe),Pe(1),Mgt=new wt(Bxe,Pe(7)),Agt=new wt(zxe,!1),L1t=new wt(Fxe,!1),$6e=(QD(),jce),y1t=new wt(TL,$6e),X6e=(UD(),kle),Y1t=new wt(EL,X6e),U6e=(Tu(),rP),Q1t=new wt(qxe,U6e),Pe(-1),H1t=new wt(Hxe,null),Pe(-1),G1t=new wt(Qxe,Pe(-1)),Pe(-1),U1t=new wt(Are,Pe(4)),Pe(-1),X1t=new wt(Nre,Pe(2)),J6e=(H0(),gJ),K1t=new wt(_re,J6e),Pe(0),W1t=new wt(Dre,Pe(0)),F1t=new wt(Lre,Pe(di)),R6e=(xT(),$E),v1t=new wt(lE,R6e),r1t=new wt(Gxe,!1),f1t=new wt(Pre,.1),m1t=new wt(Ire,!1),d1t=new wt(Uxe,null),g1t=new wt(Jxe,null),Pe(-1),p1t=new wt(Xxe,null),Pe(-1),b1t=new wt(Vxe,Pe(-1)),Pe(0),s1t=new wt(Wxe,Pe(40)),I6e=(cS(),Bce),u1t=new wt(Rre,I6e),P6e=YL,o1t=new wt(iG,P6e),tSe=(ST(),iC),ygt=new wt(Xx,tSe),fgt=new gi(rG),Y6e=(Z_(),RU),cgt=new wt($re,Y6e),Z6e=(RD(),$U),ugt=new wt(Bre,Z6e),ggt=new wt(zre,.3),bgt=new gi(Fre),eSe=(hv(),dJ),mgt=new wt(qre,eSe),q6e=(vH(),_le),T1t=new wt(Kxe,q6e),H6e=(dT(),Lle),E1t=new wt(Yxe,H6e),Q6e=(dS(),cC),C1t=new wt(sG,Q6e),A1t=new wt(oG,.2),S1t=new wt(Hre,2),jgt=new wt(Zxe,null),Egt=new wt(e3e,10),Tgt=new wt(t3e,10),Cgt=new wt(n3e,20),Pe(0),kgt=new wt(i3e,Pe(0)),Pe(0),Ogt=new wt(r3e,Pe(0)),Pe(0),Sgt=new wt(s3e,Pe(0)),$dt=new wt(Qre,!1),C6e=(MS(),BE),zdt=new wt(o3e,C6e),E6e=(qq(),xce),Bdt=new wt(c3e,E6e),I1t=new wt(cG,!1),Pe(0),P1t=new wt(Gre,Pe(16)),Pe(0),R1t=new wt(Ure,Pe(5)),sSe=(yH(),Rle),Wgt=new wt(G1,sSe),Ngt=new wt(lG,10),Lgt=new wt(uG,1),rSe=(rH(),LU),Fgt=new wt(uE,rSe),Rgt=new gi(Jre),iSe=Pe(1),Pe(0),Bgt=new wt(Xre,iSe),oSe=(iH(),Ile),e0t=new wt(aG,oSe),Kgt=new gi(fG),Ugt=new wt(hG,!0),Qgt=new wt(dG,2),Xgt=new wt(Vre,!0),K6e=(Nq(),Yce),rgt=new wt(Wre,K6e),egt=new wt(Kre,!1),V6e=Pe(2),Pe(1),Z1t=new wt(Yre,V6e),W6e=!0,ngt=new wt(Zre,W6e),F6e=(hQ(),IU),O1t=new wt(l3e,F6e),z6e=(H5(),A9),k1t=new wt(u3e,z6e),L6e=(B1(),rp),i1t=new wt(gG,L6e),n1t=new wt(a3e,!1),t1t=new wt(CL,!1),M6e=($5(),LE),Fdt=new wt(ese,M6e),D6e=(gT(),Ole),e1t=new wt(f3e,D6e),qdt=new wt(tse,0),Hdt=new wt(nse,0),Zdt=new wt(ise,Pe(0)),Ydt=new wt(rse,Pe(0)),Kdt=new wt(sse,Pe(0)),A6e=(D0(),ZL),Qdt=new wt(h3e,A6e),Gdt=new gi(ose),Jdt=new gi(cse),_6e=ZL,Wdt=new wt(d3e,_6e),N6e=bq(jAt(W(V(Lr,1),Be,15,0,[Pe(1),Pe(2),Pe(6),Pe(7),Pe(10),Pe(11)]))),Vdt=new wt(g3e,N6e),z1t=Ece,B1t=WL,J1t=fJ,V1t=fJ,q1t=yle,h1t=(R1(),Zg),w1t=$E,a1t=$E,c1t=$E,l1t=Zg,hgt=rC,dgt=iC,lgt=iC,agt=iC,pgt=Ele,vgt=rC,wgt=rC,M1t=($1(),Ik),N1t=Ik,_1t=cC,j1t=DP,_gt=Q9,Dgt=Wv,Pgt=Q9,Igt=Wv,qgt=Q9,Hgt=Wv,$gt=kce,zgt=LU,t0t=Q9,n0t=Wv,Ygt=Q9,Zgt=Wv,Jgt=Wv,Ggt=Wv,Vgt=Wv,tgt=Pe(2),igt=Kce,Udt=KL,Xdt=KL}function Mt(){Mt=te,hy=(j0(),Gt).b,c(re(Ne(Gt.b),0),38),c(re(Ne(Gt.b),1),20),t0=Gt.a,c(re(Ne(Gt.a),0),38),c(re(Ne(Gt.a),1),20),c(re(Ne(Gt.a),2),20),c(re(Ne(Gt.a),3),20),c(re(Ne(Gt.a),4),20),pp=Gt.o,c(re(Ne(Gt.o),0),38),c(re(Ne(Gt.o),1),38),H2t=c(re(Ne(Gt.o),2),20),c(re(Ne(Gt.o),3),20),c(re(Ne(Gt.o),4),20),c(re(Ne(Gt.o),5),20),c(re(Ne(Gt.o),6),20),c(re(Ne(Gt.o),7),20),c(re(Ne(Gt.o),8),20),c(re(Ne(Gt.o),9),20),c(re(Ne(Gt.o),10),20),c(re(Ne(Gt.o),11),20),c(re(Ne(Gt.o),12),20),c(re(Ne(Gt.o),13),20),c(re(Ne(Gt.o),14),20),c(re(Ne(Gt.o),15),20),c(re(Ei(Gt.o),0),62),c(re(Ei(Gt.o),1),62),c(re(Ei(Gt.o),2),62),c(re(Ei(Gt.o),3),62),c(re(Ei(Gt.o),4),62),c(re(Ei(Gt.o),5),62),c(re(Ei(Gt.o),6),62),c(re(Ei(Gt.o),7),62),c(re(Ei(Gt.o),8),62),c(re(Ei(Gt.o),9),62),q2t=Gt.p,c(re(Ne(Gt.p),0),38),c(re(Ne(Gt.p),1),38),c(re(Ne(Gt.p),2),38),c(re(Ne(Gt.p),3),38),c(re(Ne(Gt.p),4),20),c(re(Ne(Gt.p),5),20),c(re(Ei(Gt.p),0),62),c(re(Ei(Gt.p),1),62),Q2t=Gt.q,c(re(Ne(Gt.q),0),38),bp=Gt.v,c(re(Ne(Gt.v),0),20),c(re(Ei(Gt.v),0),62),c(re(Ei(Gt.v),1),62),c(re(Ei(Gt.v),2),62),n0=Gt.w,c(re(Ne(Gt.w),0),38),c(re(Ne(Gt.w),1),38),c(re(Ne(Gt.w),2),38),c(re(Ne(Gt.w),3),20),mp=Gt.B,c(re(Ne(Gt.B),0),20),c(re(Ei(Gt.B),0),62),c(re(Ei(Gt.B),1),62),c(re(Ei(Gt.B),2),62),G2t=Gt.Q,c(re(Ne(Gt.Q),0),20),c(re(Ei(Gt.Q),0),62),U2t=Gt.R,c(re(Ne(Gt.R),0),38),rf=Gt.S,c(re(Ei(Gt.S),0),62),c(re(Ei(Gt.S),1),62),c(re(Ei(Gt.S),2),62),c(re(Ei(Gt.S),3),62),c(re(Ei(Gt.S),4),62),c(re(Ei(Gt.S),5),62),c(re(Ei(Gt.S),6),62),c(re(Ei(Gt.S),7),62),c(re(Ei(Gt.S),8),62),c(re(Ei(Gt.S),9),62),c(re(Ei(Gt.S),10),62),c(re(Ei(Gt.S),11),62),c(re(Ei(Gt.S),12),62),c(re(Ei(Gt.S),13),62),c(re(Ei(Gt.S),14),62),i0=Gt.T,c(re(Ne(Gt.T),0),20),c(re(Ne(Gt.T),2),20),J2t=c(re(Ne(Gt.T),3),20),c(re(Ne(Gt.T),4),20),c(re(Ei(Gt.T),0),62),c(re(Ei(Gt.T),1),62),c(re(Ne(Gt.T),1),20),r0=Gt.U,c(re(Ne(Gt.U),0),38),c(re(Ne(Gt.U),1),38),c(re(Ne(Gt.U),2),20),c(re(Ne(Gt.U),3),20),c(re(Ne(Gt.U),4),20),c(re(Ne(Gt.U),5),20),c(re(Ei(Gt.U),0),62),dy=Gt.V,c(re(Ne(Gt.V),0),20),A3=Gt.W,c(re(Ne(Gt.W),0),38),c(re(Ne(Gt.W),1),38),c(re(Ne(Gt.W),2),38),c(re(Ne(Gt.W),3),20),c(re(Ne(Gt.W),4),20),c(re(Ne(Gt.W),5),20),X2t=Gt.bb,c(re(Ne(Gt.bb),0),38),c(re(Ne(Gt.bb),1),38),c(re(Ne(Gt.bb),2),38),c(re(Ne(Gt.bb),3),38),c(re(Ne(Gt.bb),4),38),c(re(Ne(Gt.bb),5),38),c(re(Ne(Gt.bb),6),38),c(re(Ne(Gt.bb),7),20),c(re(Ei(Gt.bb),0),62),c(re(Ei(Gt.bb),1),62),V2t=Gt.eb,c(re(Ne(Gt.eb),0),38),c(re(Ne(Gt.eb),1),38),c(re(Ne(Gt.eb),2),38),c(re(Ne(Gt.eb),3),38),c(re(Ne(Gt.eb),4),38),c(re(Ne(Gt.eb),5),38),c(re(Ne(Gt.eb),6),20),c(re(Ne(Gt.eb),7),20),Bs=Gt.ab,c(re(Ne(Gt.ab),0),38),c(re(Ne(Gt.ab),1),38),Bw=Gt.H,c(re(Ne(Gt.H),0),20),c(re(Ne(Gt.H),1),20),c(re(Ne(Gt.H),2),20),c(re(Ne(Gt.H),3),20),c(re(Ne(Gt.H),4),20),c(re(Ne(Gt.H),5),20),c(re(Ei(Gt.H),0),62),zw=Gt.db,c(re(Ne(Gt.db),0),20),Gh=Gt.M}function Etn(e){var t;e.O||(e.O=!0,Gc(e,"type"),dH(e,"ecore.xml.type"),gH(e,Cb),t=c(NS((y0(),nf),Cb),2023),Nn(vo(e.fb),e.b),Qo(e.b,eI,"AnyType",!1,!1,!0),gr(c(re(Ne(e.b),0),38),e.wb.D,PL,null,0,-1,eI,!1,!1,!0,!1,!1,!1),gr(c(re(Ne(e.b),1),38),e.wb.D,"any",null,0,-1,eI,!0,!0,!0,!1,!1,!0),gr(c(re(Ne(e.b),2),38),e.wb.D,"anyAttribute",null,0,-1,eI,!1,!1,!0,!1,!1,!1),Qo(e.bb,dX,Yut,!1,!1,!0),gr(c(re(Ne(e.bb),0),38),e.gb,"data",null,0,1,dX,!1,!1,!0,!1,!0,!1),gr(c(re(Ne(e.bb),1),38),e.gb,w5e,null,1,1,dX,!1,!1,!0,!1,!0,!1),Qo(e.fb,tI,Zut,!1,!1,!0),gr(c(re(Ne(e.fb),0),38),t.gb,"rawValue",null,0,1,tI,!0,!0,!0,!1,!0,!0),gr(c(re(Ne(e.fb),1),38),t.a,mE,null,0,1,tI,!0,!0,!0,!1,!0,!0),Fi(c(re(Ne(e.fb),2),20),e.wb.q,null,"instanceType",1,1,tI,!1,!1,!0,!1,!1,!1,!1),Qo(e.qb,QTe,eat,!1,!1,!0),gr(c(re(Ne(e.qb),0),38),e.wb.D,PL,null,0,-1,null,!1,!1,!0,!1,!1,!1),Fi(c(re(Ne(e.qb),1),20),e.wb.ab,null,"xMLNSPrefixMap",0,-1,null,!0,!1,!0,!0,!1,!1,!1),Fi(c(re(Ne(e.qb),2),20),e.wb.ab,null,"xSISchemaLocation",0,-1,null,!0,!1,!0,!0,!1,!1,!1),gr(c(re(Ne(e.qb),3),38),e.gb,"cDATA",null,0,-2,null,!0,!0,!0,!1,!1,!0),gr(c(re(Ne(e.qb),4),38),e.gb,"comment",null,0,-2,null,!0,!0,!0,!1,!1,!0),Fi(c(re(Ne(e.qb),5),20),e.bb,null,dat,0,-2,null,!0,!0,!0,!0,!1,!1,!0),gr(c(re(Ne(e.qb),6),38),e.gb,Kse,null,0,-2,null,!0,!0,!0,!1,!1,!0),ai(e.a,Br,"AnySimpleType",!0),ai(e.c,nt,"AnyURI",!0),ai(e.d,V(Rl,1),"Base64Binary",!0),ai(e.e,kl,"Boolean",!0),ai(e.f,ir,"BooleanObject",!0),ai(e.g,Rl,"Byte",!0),ai(e.i,ak,"ByteObject",!0),ai(e.j,nt,"Date",!0),ai(e.k,nt,"DateTime",!0),ai(e.n,Doe,"Decimal",!0),ai(e.o,ns,"Double",!0),ai(e.p,kr,"DoubleObject",!0),ai(e.q,nt,"Duration",!0),ai(e.s,Ju,"ENTITIES",!0),ai(e.r,Ju,"ENTITIESBase",!0),ai(e.t,nt,L5e,!0),ai(e.u,py,"Float",!0),ai(e.v,O9,"FloatObject",!0),ai(e.w,nt,"GDay",!0),ai(e.B,nt,"GMonth",!0),ai(e.A,nt,"GMonthDay",!0),ai(e.C,nt,"GYear",!0),ai(e.D,nt,"GYearMonth",!0),ai(e.F,V(Rl,1),"HexBinary",!0),ai(e.G,nt,"ID",!0),ai(e.H,nt,"IDREF",!0),ai(e.J,Ju,"IDREFS",!0),ai(e.I,Ju,"IDREFSBase",!0),ai(e.K,Fn,"Int",!0),ai(e.M,t3,"Integer",!0),ai(e.L,Lr,"IntObject",!0),ai(e.P,nt,"Language",!0),ai(e.Q,qw,"Long",!0),ai(e.R,Ow,"LongObject",!0),ai(e.S,nt,"Name",!0),ai(e.T,nt,UG,!0),ai(e.U,t3,"NegativeInteger",!0),ai(e.V,nt,R5e,!0),ai(e.X,Ju,"NMTOKENS",!0),ai(e.W,Ju,"NMTOKENSBase",!0),ai(e.Y,t3,"NonNegativeInteger",!0),ai(e.Z,t3,"NonPositiveInteger",!0),ai(e.$,nt,"NormalizedString",!0),ai(e._,nt,"NOTATION",!0),ai(e.ab,nt,"PositiveInteger",!0),ai(e.cb,nt,"QName",!0),ai(e.db,L3,"Short",!0),ai(e.eb,Sw,"ShortObject",!0),ai(e.gb,nt,rxe,!0),ai(e.hb,nt,"Time",!0),ai(e.ib,nt,"Token",!0),ai(e.jb,L3,"UnsignedByte",!0),ai(e.kb,Sw,"UnsignedByteObject",!0),ai(e.lb,qw,"UnsignedInt",!0),ai(e.mb,Ow,"UnsignedIntObject",!0),ai(e.nb,t3,"UnsignedLong",!0),ai(e.ob,Fn,"UnsignedShort",!0),ai(e.pb,Lr,"UnsignedShortObject",!0),Kme(e,Cb),Ctn(e))}function Yye(e,t,n,i){var r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt,Rt,fn,ti,Zi,Wl,po,Zu,P3,o0,Rf,ng,_a,qk,YC,ig,fh,c0,Ub,Jb,Hk,Xb,Vb,rg,by;if(i.Zg()||et(Ze(ke(t,(Dn(),GJ)))))return Ct(),Ct(),Rs;if(We=(!t.a&&(t.a=new Me(Mn,t,10,11)),t.a).i!=0,bt=KQt(t),pt=!bt.dc(),We||pt){if(r=c(ke(t,ry),144),!r)throw J(new Wh("Resolved algorithm is not set; apply a LayoutAlgorithmResolver before computing layout."));if(Xb=W1e(r,(V5(),oX)),HKe(t),!We&&pt&&!Xb)return Ct(),Ct(),Rs;if(se=new Fe,ve(ke(t,j3))===ve((R1(),Zg))&&(W1e(r,sX)||W1e(r,rX))){if(et(Ze(ke(t,e8))))throw J(new Wh("Topdown layout cannot be used together with hierarchy handling."));for(P3=Knt(e,t),o0=new Ai,Os(o0,(!t.a&&(t.a=new Me(Mn,t,10,11)),t.a));o0.b!=0;)po=c(o0.b==0?null:(dn(o0.b!=0),ba(o0,o0.a.a)),19),HKe(po),Hk=ve(ke(po,j3))===ve(LC),Hk||ga(po,_k)&&!abe(r,ke(po,ry))?(H=Yye(e,po,n,i),yr(se,H),ii(po,j3,LC),pit(po)):Os(o0,(!po.a&&(po.a=new Me(Mn,po,10,11)),po.a))}else{if(P3=(!t.a&&(t.a=new Me(Mn,t,10,11)),t.a).i,et(Ze(ke(t,e8)))){if(Vb=i.dh(1),Vb.Tg(Vct,1),ke(t,Pk)==null)throw J(new Wh(t.k+" has not been assigned a top-down node type."));if(c(ke(t,Pk),283)==(P5(),ly)||c(ke(t,Pk),283)==nX)for(ie=new cn((!t.a&&(t.a=new Me(Mn,t,10,11)),t.a));ie.e!=ie.i.gc();)X=c(un(ie),19),Wl=c(ke(X,ry),144),ng=c(ke(X,zh),100),(!X.a&&(X.a=new Me(Mn,X,10,11)),X.a).i>0&&B_(Wl.f),ke(X,XJ)!=null&&(!X.a&&(X.a=new Me(Mn,X,10,11)),!!X.a)&&(!X.a&&(X.a=new Me(Mn,X,10,11)),X.a).i>0?(d=c(ke(X,XJ),525),Jb=d.Sg(X),_m(X,p.Math.max(X.g,Jb.a+ng.b+ng.c),p.Math.max(X.f,Jb.b+ng.d+ng.a))):(!X.a&&(X.a=new Me(Mn,X,10,11)),X.a).i!=0&&(Jb=new $e(ue(he(ke(X,sy))),ue(he(ke(X,sy)))/ue(he(ke(X,Z9)))),_m(X,p.Math.max(X.g,Jb.a+ng.b+ng.c),p.Math.max(X.f,Jb.b+ng.d+ng.a)));if(Rf=c(ke(t,zh),100),L=t.g-(Rf.b+Rf.c),M=t.f-(Rf.d+Rf.a),Vb.ah("Available Child Area: ("+L+"|"+M+")"),ii(t,K9,L/M),JKe(t,r,i.dh(P3)),c(ke(t,Pk),283)==nX&&(Die(t),_m(t,Rf.b+ue(he(ke(t,ty)))+Rf.c,Rf.d+ue(he(ke(t,ey)))+Rf.a)),Vb.ah("Executed layout algorithm: "+zn(ke(t,_k))+" on node "+t.k),c(ke(t,Pk),283)==ly){if(L<0||M<0)throw J(new Wh("The size defined by the parent parallel node is too small for the space provided by the paddings of the child hierarchical node. "+t.k));for(ga(t,ty)||ga(t,ey)||Die(t),z=ue(he(ke(t,ty))),P=ue(he(ke(t,ey))),Vb.ah("Desired Child Area: ("+z+"|"+P+")"),qk=L/z,YC=M/P,_a=p.Math.min(qk,p.Math.min(YC,ue(he(ke(t,Bwt))))),ii(t,JJ,_a),Vb.ah(t.k+" -- Local Scale Factor (X|Y): ("+qk+"|"+YC+")"),de=c(ke(t,CP),24),o=0,a=0,_a<qk&&(de.Gc((bb(),TC))?o=(L/2-z*_a/2)/_a:de.Gc(EC)&&(o=(L-z*_a)/_a)),_a<YC&&(de.Gc((bb(),MC))?a=(M/2-P*_a/2)/_a:de.Gc(CC)&&(a=(M-P*_a)/_a)),rg=o+(Rf.b/_a-Rf.b),by=a+(Rf.d/_a-Rf.d),Vb.ah("Shift: ("+rg+"|"+by+")"),Zu=new cn((!t.a&&(t.a=new Me(Mn,t,10,11)),t.a));Zu.e!=Zu.i.gc();)po=c(un(Zu),19),Cc(po,po.i+rg),Nl(po,po.j+by);for(xe=new cn((!t.b&&(t.b=new Me(Ii,t,12,3)),t.b));xe.e!=xe.i.gc();){for(Se=c(un(xe),74),fh=new cn((!Se.a&&(Se.a=new Me(Hi,Se,6,6)),Se.a));fh.e!=fh.i.gc();)for(ig=c(un(fh),171),m_(ig,ig.j+rg,ig.k+by),b_(ig,ig.b+rg,ig.c+by),v=new cn((!ig.a&&(ig.a=new Ar(Yu,ig,5)),ig.a));v.e!=v.i.gc();)b=c(un(v),373),YY(b,b.a+rg,b.b+by);for(Zi=new cn((!Se.n&&(Se.n=new Me(Bo,Se,1,7)),Se.n));Zi.e!=Zi.i.gc();)ti=c(un(Zi),158),aa(ti,ti.i+rg,ti.j+by);for(fn=c(ke(Se,T3),79),Rt=_n(fn,0);Rt.b!=Rt.d.c;)Dt=c(An(Rt),8),Dt.a+=rg,Dt.b+=by;ii(Se,T3,fn)}}Vb.Ug()}for(S=new cn((!t.a&&(t.a=new Me(Mn,t,10,11)),t.a));S.e!=S.i.gc();)x=c(un(S),19),H=Yye(e,x,n,i),yr(se,H),pit(x)}if(i.Zg())return Ct(),Ct(),Rs;for(Ub=new G(se);Ub.a<Ub.c.c.length;)c0=c(Q(Ub),74),ii(c0,GJ,(Bt(),!0));return et(Ze(ke(t,e8)))||JKe(t,r,i.dh(P3)),uWt(se),pt&&Xb?bt:(Ct(),Ct(),Rs)}else return Ct(),Ct(),Rs}function Qx(e,t){var n,i;return D3||(D3=new wn,c8=new wn,i=(wi(),wi(),new $u(4)),CD(i,`	
\r\r  `),lo(D3,boe,i),lo(c8,boe,yv(i)),i=new $u(4),CD(i,pat),lo(D3,TE,i),lo(c8,TE,yv(i)),i=new $u(4),CD(i,pat),lo(D3,TE,i),lo(c8,TE,yv(i)),i=new $u(4),CD(i,bat),kv(i,c(Tc(D3,TE),122)),lo(D3,poe,i),lo(c8,poe,yv(i)),i=new $u(4),CD(i,"-.0:AZ__az··ÀÖØöøıĴľŁňŊžƀǃǍǰǴǵǺȗɐʨʻˁːˑ̀͠͡ͅΆΊΌΌΎΡΣώϐϖϚϚϜϜϞϞϠϠϢϳЁЌЎяёќўҁ҃҆ҐӄӇӈӋӌӐӫӮӵӸӹԱՖՙՙաֆֹֻֽֿֿׁׂ֑֣֡ׄׄאתװײءغـْ٠٩ٰڷںھۀێېۓە۪ۭۨ۰۹ँःअह़्॑॔क़ॣ०९ঁঃঅঌএঐওনপরললশহ়়াৄেৈো্ৗৗড়ঢ়য়ৣ০ৱਂਂਅਊਏਐਓਨਪਰਲਲ਼ਵਸ਼ਸਹ਼਼ਾੂੇੈੋ੍ਖ਼ੜਫ਼ਫ਼੦ੴઁઃઅઋઍઍએઑઓનપરલળવહ઼ૅેૉો્ૠૠ૦૯ଁଃଅଌଏଐଓନପରଲଳଶହ଼ୃେୈୋ୍ୖୗଡ଼ଢ଼ୟୡ୦୯ஂஃஅஊஎஐஒகஙசஜஜஞடணதநபமவஷஹாூெைொ்ௗௗ௧௯ఁఃఅఌఎఐఒనపళవహాౄెైొ్ౕౖౠౡ౦౯ಂಃಅಌಎಐಒನಪಳವಹಾೄೆೈೊ್ೕೖೞೞೠೡ೦೯ംഃഅഌഎഐഒനപഹാൃെൈൊ്ൗൗൠൡ൦൯กฮะฺเ๎๐๙ກຂຄຄງຈຊຊຍຍດທນຟມຣລລວວສຫອຮະູົຽເໄໆໆ່ໍ໐໙༘༙༠༩༹༹༵༵༷༷༾ཇཉཀྵ྄ཱ྆ྋྐྕྗྗྙྭྱྷྐྵྐྵႠჅაჶᄀᄀᄂᄃᄅᄇᄉᄉᄋᄌᄎᄒᄼᄼᄾᄾᅀᅀᅌᅌᅎᅎᅐᅐᅔᅕᅙᅙᅟᅡᅣᅣᅥᅥᅧᅧᅩᅩᅭᅮᅲᅳᅵᅵᆞᆞᆨᆨᆫᆫᆮᆯᆷᆸᆺᆺᆼᇂᇫᇫᇰᇰᇹᇹḀẛẠỹἀἕἘἝἠὅὈὍὐὗὙὙὛὛὝὝὟώᾀᾴᾶᾼιιῂῄῆῌῐΐῖΊῠῬῲῴῶῼ⃐⃜⃡⃡ΩΩKÅ℮℮ↀↂ々々〇〇〡〯〱〵ぁゔ゙゚ゝゞァヺーヾㄅㄬ一龥가힣"),lo(D3,moe,i),lo(c8,moe,yv(i)),i=new $u(4),CD(i,bat),Ac(i,95,95),Ac(i,58,58),lo(D3,woe,i),lo(c8,woe,yv(i))),n=c(Tc(t?D3:c8,e),140),n}function Pst(e){Am(e,new mb(rY(JN(Em(Sm(Tm(jm(new b1,Qt),"ELK Layered"),"Layer-based algorithm provided by the Eclipse Layout Kernel. Arranges as many edges as possible into one direction by placing nodes into subsequent layers. This implementation supports different routing styles (straight, orthogonal, splines); if orthogonal routing is selected, arbitrary port constraints are respected, thus enabling the layout of block diagrams such as actor-oriented models or circuit schematics. Furthermore, full layout of compound graphs with cross-hierarchy edges is supported when the respective option is activated on the top level."),new MW),Qt),_i((V5(),kae),W(V(VP,1),_e,235,0,[oX,XP,JP,xae,sX,rX]))))),Ie(e,Qt,x3e,Ve(dle)),Ie(e,Qt,k3e,Ve(FSe)),Ie(e,Qt,O3e,Ve(uP)),Ie(e,Qt,S3e,Ve(Mf)),Ie(e,Qt,Ore,Ve(m3)),Ie(e,Qt,fse,Ve(Rb)),Ie(e,Qt,j3e,Ve(Xv)),Ie(e,Qt,T3e,Ve(F9)),Ie(e,Qt,E3e,Ve(q9)),Ie(e,Qt,C3e,Ve(gle)),Ie(e,Qt,dw,Ve($b)),Ie(e,Qt,M3e,Ve(ple)),Ie(e,Qt,A3e,Ve(tC)),Ie(e,Qt,N3e,Ve(lJ)),Ie(e,Qt,Zxe,Ve(lP)),Ie(e,Qt,t3e,Ve(Jv)),Ie(e,Qt,e3e,Ve(ip)),Ie(e,Qt,n3e,Ve(Vv)),Ie(e,Qt,wL,Pe(0)),Ie(e,Qt,i3e,Ve(z9)),Ie(e,Qt,r3e,Ve(zSe)),Ie(e,Qt,s3e,Ve(Ek)),Ie(e,Qt,G1,Ve(WSe)),Ie(e,Qt,lG,Ve(HSe)),Ie(e,Qt,uG,Ve(QSe)),Ie(e,Qt,uE,Ve(mle)),Ie(e,Qt,Jre,Ve(GSe)),Ie(e,Qt,Xre,Ve(USe)),Ie(e,Qt,aG,Ve(uJ)),Ie(e,Qt,fG,Ve(wle)),Ie(e,Qt,hG,Ve(XSe)),Ie(e,Qt,dG,Ve(JSe)),Ie(e,Qt,Vre,Ve(VSe)),Ie(e,Qt,Wre,Ve(MSe)),Ie(e,Qt,Kre,Ve(ule)),Ie(e,Qt,Yre,Ve(iJ)),Ie(e,Qt,Zre,Ve(ale)),Ie(e,Qt,Fre,Ve(Dw)),Ie(e,Qt,qre,Ve(eC)),Ie(e,Qt,sG,Ve(cle)),Ie(e,Qt,oG,Ve(wSe)),Ie(e,Qt,yL,Ve(v0t)),Ie(e,Qt,xL,Ve(y0t)),Ie(e,Qt,kL,Ve(w0t)),Ie(e,Qt,OL,Ve(m0t)),Ie(e,Qt,pw,qSe),Ie(e,Qt,gw,PSe),Ie(e,Qt,ML,pSe),Ie(e,Qt,_3e,0),Ie(e,Qt,WQ,Pe(1)),Ie(e,Qt,ZS,YS),Ie(e,Qt,D3e,Ve(Ib)),Ie(e,Qt,KQ,Ve(cr)),Ie(e,Qt,L3e,Ve(B9)),Ie(e,Qt,AL,Ve(c0t)),Ie(e,Qt,P3e,Ve(vd)),Ie(e,Qt,pG,Ve(Fv)),Ie(e,Qt,rE,(Bt(),!0)),Ie(e,Qt,I3e,Ve(qv)),Ie(e,Qt,R3e,Ve(Lb)),Ie(e,Qt,Jx,Ve(Pb)),Ie(e,Qt,sk,Ve(cJ)),Ie(e,Qt,n9,Ve(hle)),Ie(e,Qt,hse,gSe),Ie(e,Qt,i9,Ve(_w)),Ie(e,Qt,$3e,Ve(sJ)),Ie(e,Qt,r9,Ve(Gv)),Ie(e,Qt,B3e,Ve(d0t)),Ie(e,Qt,z3e,Ve($Se)),Ie(e,Qt,F3e,RSe),Ie(e,Qt,q3e,Ve(a0t)),Ie(e,Qt,H3e,Ve(f0t)),Ie(e,Qt,Q3e,Ve(h0t)),Ie(e,Qt,G3e,Ve(u0t)),Ie(e,Qt,zxe,Ve(ble)),Ie(e,Qt,EL,Ve(nJ)),Ie(e,Qt,_re,Ve(cP)),Ie(e,Qt,Bxe,Ve(nC)),Ie(e,Qt,qxe,Ve(Ro)),Ie(e,Qt,TL,Ve(Tk)),Ie(e,Qt,lE,Ve(KE)),Ie(e,Qt,Gxe,Ve(R9)),Ie(e,Qt,Wxe,Ve(fSe)),Ie(e,Qt,Rre,Ve(rle)),Ie(e,Qt,iG,Ve(oP)),Ie(e,Qt,Ire,Ve(sle)),Ie(e,Qt,Pxe,Ve(ASe)),Ie(e,Qt,Ixe,Ve(NSe)),Ie(e,Qt,nG,Ve(SSe)),Ie(e,Qt,Xx,Ve(oJ)),Ie(e,Qt,Bre,Ve(fle)),Ie(e,Qt,Lxe,Ve(lle)),Ie(e,Qt,zre,Ve(DSe)),Ie(e,Qt,Kxe,Ve(mSe)),Ie(e,Qt,Yxe,Ve(ole)),Ie(e,Qt,bG,Ve(ile)),Ie(e,Qt,$re,Ve(_Se)),Ie(e,Qt,o3e,Ve(WU)),Ie(e,Qt,c3e,Ve(cSe)),Ie(e,Qt,Qre,Ve(VU)),Ie(e,Qt,cG,Ve(xSe)),Ie(e,Qt,Gre,Ve(ySe)),Ie(e,Qt,Ure,Ve(kSe)),Ie(e,Qt,ok,Ve($9)),Ie(e,Qt,U3e,Ve(ho)),Ie(e,Qt,J3e,Ve(Xg)),Ie(e,Qt,X3e,Ve(yd)),Ie(e,Qt,vL,Ve(b3)),Ie(e,Qt,Pre,Ve(hSe)),Ie(e,Qt,V3e,Ve(Vg)),Ie(e,Qt,W3e,Ve(JE)),Ie(e,Qt,K3e,Ve(tJ)),Ie(e,Qt,Y3e,Ve(Lw)),Ie(e,Qt,dse,Ve(ISe)),Ie(e,Qt,gse,Ve(Hv)),Ie(e,Qt,Are,Ve(TSe)),Ie(e,Qt,Nre,Ve(ESe)),Ie(e,Qt,mG,Ve(Uv)),Ie(e,Qt,Rxe,Ve(Zce)),Ie(e,Qt,Dre,Ve(CSe)),Ie(e,Qt,l3e,Ve(eJ)),Ie(e,Qt,u3e,Ve(ZU)),Ie(e,Qt,pse,Ve(rJ)),Ie(e,Qt,Lre,Ve(jSe)),Ie(e,Qt,rG,Ve(ZE)),Ie(e,Qt,Z3e,Ve(aP)),Ie(e,Qt,Dxe,Ve(dSe)),Ie(e,Qt,$xe,Ve(BSe)),Ie(e,Qt,Hre,Ve(bSe)),Ie(e,Qt,Uxe,Ve(r0t)),Ie(e,Qt,Jxe,Ve(s0t)),Ie(e,Qt,Hxe,Ve(l0t)),Ie(e,Qt,Xxe,Ve(o0t)),Ie(e,Qt,wG,Ve(OSe)),Ie(e,Qt,Qxe,Ve(YE)),Ie(e,Qt,Vxe,Ve(YU)),Ie(e,Qt,gG,Ve(t1)),Ie(e,Qt,f3e,Ve(tle)),Ie(e,Qt,tse,Ve(sP)),Ie(e,Qt,nse,Ve(ele)),Ie(e,Qt,CL,Ve(KU)),Ie(e,Qt,ese,Ve(XE)),Ie(e,Qt,a3e,Ve(nle)),Ie(e,Qt,ise,Ve(zv)),Ie(e,Qt,rse,Ve(WE)),Ie(e,Qt,sse,Ve(i0t)),Ie(e,Qt,h3e,Ve(jk)),Ie(e,Qt,d3e,Ve(VE)),Ie(e,Qt,g3e,Ve(aSe)),Ie(e,Qt,ose,Ve(lSe)),Ie(e,Qt,cse,Ve(uSe)),Ie(e,Qt,Fxe,Ve(vSe))}function Ctn(e){In(e.a,Kn,W(V(nt,1),Be,2,6,[hi,"anySimpleType"])),In(e.b,Kn,W(V(nt,1),Be,2,6,[hi,"anyType",Ua,PL])),In(c(re(Ne(e.b),0),38),Kn,W(V(nt,1),Be,2,6,[Ua,aoe,hi,":mixed"])),In(c(re(Ne(e.b),1),38),Kn,W(V(nt,1),Be,2,6,[Ua,aoe,_5e,hoe,hi,":1",tat,"lax"])),In(c(re(Ne(e.b),2),38),Kn,W(V(nt,1),Be,2,6,[Ua,Kut,_5e,hoe,hi,":2",tat,"lax"])),In(e.c,Kn,W(V(nt,1),Be,2,6,[hi,"anyURI",Xa,ih])),In(e.d,Kn,W(V(nt,1),Be,2,6,[hi,"base64Binary",Xa,ih])),In(e.e,Kn,W(V(nt,1),Be,2,6,[hi,K5,Xa,ih])),In(e.f,Kn,W(V(nt,1),Be,2,6,[hi,"boolean:Object",ys,K5])),In(e.g,Kn,W(V(nt,1),Be,2,6,[hi,vE])),In(e.i,Kn,W(V(nt,1),Be,2,6,[hi,"byte:Object",ys,vE])),In(e.j,Kn,W(V(nt,1),Be,2,6,[hi,"date",Xa,ih])),In(e.k,Kn,W(V(nt,1),Be,2,6,[hi,"dateTime",Xa,ih])),In(e.n,Kn,W(V(nt,1),Be,2,6,[hi,"decimal",Xa,ih])),In(e.o,Kn,W(V(nt,1),Be,2,6,[hi,yE,Xa,ih])),In(e.p,Kn,W(V(nt,1),Be,2,6,[hi,"double:Object",ys,yE])),In(e.q,Kn,W(V(nt,1),Be,2,6,[hi,"duration",Xa,ih])),In(e.s,Kn,W(V(nt,1),Be,2,6,[hi,"ENTITIES",ys,nat,D5e,"1"])),In(e.r,Kn,W(V(nt,1),Be,2,6,[hi,nat,foe,L5e])),In(e.t,Kn,W(V(nt,1),Be,2,6,[hi,L5e,ys,UG])),In(e.u,Kn,W(V(nt,1),Be,2,6,[hi,xE,Xa,ih])),In(e.v,Kn,W(V(nt,1),Be,2,6,[hi,"float:Object",ys,xE])),In(e.w,Kn,W(V(nt,1),Be,2,6,[hi,"gDay",Xa,ih])),In(e.B,Kn,W(V(nt,1),Be,2,6,[hi,"gMonth",Xa,ih])),In(e.A,Kn,W(V(nt,1),Be,2,6,[hi,"gMonthDay",Xa,ih])),In(e.C,Kn,W(V(nt,1),Be,2,6,[hi,"gYear",Xa,ih])),In(e.D,Kn,W(V(nt,1),Be,2,6,[hi,"gYearMonth",Xa,ih])),In(e.F,Kn,W(V(nt,1),Be,2,6,[hi,"hexBinary",Xa,ih])),In(e.G,Kn,W(V(nt,1),Be,2,6,[hi,"ID",ys,UG])),In(e.H,Kn,W(V(nt,1),Be,2,6,[hi,"IDREF",ys,UG])),In(e.J,Kn,W(V(nt,1),Be,2,6,[hi,"IDREFS",ys,iat,D5e,"1"])),In(e.I,Kn,W(V(nt,1),Be,2,6,[hi,iat,foe,"IDREF"])),In(e.K,Kn,W(V(nt,1),Be,2,6,[hi,kE])),In(e.M,Kn,W(V(nt,1),Be,2,6,[hi,P5e])),In(e.L,Kn,W(V(nt,1),Be,2,6,[hi,"int:Object",ys,kE])),In(e.P,Kn,W(V(nt,1),Be,2,6,[hi,"language",ys,doe,goe,rat])),In(e.Q,Kn,W(V(nt,1),Be,2,6,[hi,OE])),In(e.R,Kn,W(V(nt,1),Be,2,6,[hi,"long:Object",ys,OE])),In(e.S,Kn,W(V(nt,1),Be,2,6,[hi,"Name",ys,doe,goe,I5e])),In(e.T,Kn,W(V(nt,1),Be,2,6,[hi,UG,ys,"Name",goe,sat])),In(e.U,Kn,W(V(nt,1),Be,2,6,[hi,"negativeInteger",ys,oat,zL,"-1"])),In(e.V,Kn,W(V(nt,1),Be,2,6,[hi,R5e,ys,doe,goe,"\\c+"])),In(e.X,Kn,W(V(nt,1),Be,2,6,[hi,"NMTOKENS",ys,cat,D5e,"1"])),In(e.W,Kn,W(V(nt,1),Be,2,6,[hi,cat,foe,R5e])),In(e.Y,Kn,W(V(nt,1),Be,2,6,[hi,$5e,ys,P5e,FL,"0"])),In(e.Z,Kn,W(V(nt,1),Be,2,6,[hi,oat,ys,P5e,zL,"0"])),In(e.$,Kn,W(V(nt,1),Be,2,6,[hi,lat,ys,Iie,Xa,"replace"])),In(e._,Kn,W(V(nt,1),Be,2,6,[hi,"NOTATION",Xa,ih])),In(e.ab,Kn,W(V(nt,1),Be,2,6,[hi,"positiveInteger",ys,$5e,FL,"1"])),In(e.bb,Kn,W(V(nt,1),Be,2,6,[hi,"processingInstruction_._type",Ua,"empty"])),In(c(re(Ne(e.bb),0),38),Kn,W(V(nt,1),Be,2,6,[Ua,qG,hi,"data"])),In(c(re(Ne(e.bb),1),38),Kn,W(V(nt,1),Be,2,6,[Ua,qG,hi,w5e])),In(e.cb,Kn,W(V(nt,1),Be,2,6,[hi,"QName",Xa,ih])),In(e.db,Kn,W(V(nt,1),Be,2,6,[hi,SE])),In(e.eb,Kn,W(V(nt,1),Be,2,6,[hi,"short:Object",ys,SE])),In(e.fb,Kn,W(V(nt,1),Be,2,6,[hi,"simpleAnyType",Ua,IL])),In(c(re(Ne(e.fb),0),38),Kn,W(V(nt,1),Be,2,6,[hi,":3",Ua,IL])),In(c(re(Ne(e.fb),1),38),Kn,W(V(nt,1),Be,2,6,[hi,":4",Ua,IL])),In(c(re(Ne(e.fb),2),20),Kn,W(V(nt,1),Be,2,6,[hi,":5",Ua,IL])),In(e.gb,Kn,W(V(nt,1),Be,2,6,[hi,Iie,Xa,"preserve"])),In(e.hb,Kn,W(V(nt,1),Be,2,6,[hi,"time",Xa,ih])),In(e.ib,Kn,W(V(nt,1),Be,2,6,[hi,doe,ys,lat,Xa,ih])),In(e.jb,Kn,W(V(nt,1),Be,2,6,[hi,uat,zL,"255",FL,"0"])),In(e.kb,Kn,W(V(nt,1),Be,2,6,[hi,"unsignedByte:Object",ys,uat])),In(e.lb,Kn,W(V(nt,1),Be,2,6,[hi,aat,zL,"4294967295",FL,"0"])),In(e.mb,Kn,W(V(nt,1),Be,2,6,[hi,"unsignedInt:Object",ys,aat])),In(e.nb,Kn,W(V(nt,1),Be,2,6,[hi,"unsignedLong",ys,$5e,zL,fat,FL,"0"])),In(e.ob,Kn,W(V(nt,1),Be,2,6,[hi,hat,zL,"65535",FL,"0"])),In(e.pb,Kn,W(V(nt,1),Be,2,6,[hi,"unsignedShort:Object",ys,hat])),In(e.qb,Kn,W(V(nt,1),Be,2,6,[hi,"",Ua,PL])),In(c(re(Ne(e.qb),0),38),Kn,W(V(nt,1),Be,2,6,[Ua,aoe,hi,":mixed"])),In(c(re(Ne(e.qb),1),20),Kn,W(V(nt,1),Be,2,6,[Ua,qG,hi,"xmlns:prefix"])),In(c(re(Ne(e.qb),2),20),Kn,W(V(nt,1),Be,2,6,[Ua,qG,hi,"xsi:schemaLocation"])),In(c(re(Ne(e.qb),3),38),Kn,W(V(nt,1),Be,2,6,[Ua,HG,hi,"cDATA",QG,RL])),In(c(re(Ne(e.qb),4),38),Kn,W(V(nt,1),Be,2,6,[Ua,HG,hi,"comment",QG,RL])),In(c(re(Ne(e.qb),5),20),Kn,W(V(nt,1),Be,2,6,[Ua,HG,hi,dat,QG,RL])),In(c(re(Ne(e.qb),6),38),Kn,W(V(nt,1),Be,2,6,[Ua,HG,hi,Kse,QG,RL]))}function Vn(e){return Ot("_UI_EMFDiagnostic_marker",e)?"EMF Problem":Ot("_UI_CircularContainment_diagnostic",e)?"An object may not circularly contain itself":Ot(Vlt,e)?"Wrong character.":Ot(Wlt,e)?"Invalid reference number.":Ot(DG,e)?"A character is required after \\.":Ot(roe,e)?"'?' is not expected.  '(?:' or '(?=' or '(?!' or '(?<' or '(?#' or '(?>'?":Ot(Klt,e)?"'(?<' or '(?<!' is expected.":Ot(Ylt,e)?"A comment is not terminated.":Ot(Eb,e)?"')' is expected.":Ot(v5e,e)?"Unexpected end of the pattern in a modifier group.":Ot(Zlt,e)?"':' is expected.":Ot(eut,e)?"Unexpected end of the pattern in a conditional group.":Ot(tut,e)?"A back reference or an anchor or a lookahead or a look-behind is expected in a conditional pattern.":Ot(nut,e)?"There are more than three choices in a conditional group.":Ot(iut,e)?"A character in U+0040-U+005f must follow \\c.":Ot(rut,e)?"A '{' is required before a character category.":Ot(sut,e)?"A property name is not closed by '}'.":Ot(y5e,e)?"Unexpected meta character.":Ot(soe,e)?"Unknown property.":Ot(x5e,e)?"A POSIX character class must be closed by ':]'.":Ot(LG,e)?"Unexpected end of the pattern in a character class.":Ot(out,e)?"Unknown name for a POSIX character class.":Ot("parser.cc.4",e)?"'-' is invalid here.":Ot(cut,e)?"']' is expected.":Ot(k5e,e)?"'[' is invalid in a character class.  Write '\\['.":Ot(O5e,e)?"']' is invalid in a character class.  Write '\\]'.":Ot(ooe,e)?"'-' is an invalid character range. Write '\\-'.":Ot(lut,e)?"'[' is expected.":Ot(uut,e)?"')' or '-[' or '+[' or '&[' is expected.":Ot(aut,e)?"The range end code point is less than the start code point.":Ot(Gg,e)?"Invalid Unicode hex notation.":Ot(fut,e)?"Overflow in a hex notation.":Ot(hut,e)?"'\\x{' must be closed by '}'.":Ot(dut,e)?"Invalid Unicode code point.":Ot(gut,e)?"An anchor must not be here.":Ot(ja,e)?"This expression is not supported in the current option setting.":Ot(put,e)?"Invalid quantifier. A digit is expected.":Ot(but,e)?"Invalid quantifier. Invalid quantity or a '}' is missing.":Ot(mut,e)?"Invalid quantifier. A digit or '}' is expected.":Ot(wut,e)?"Invalid quantifier. A min quantity must be <= a max quantity.":Ot(S5e,e)?"Invalid quantifier. A quantity value overflow.":Ot("_UI_PackageRegistry_extensionpoint",e)?"Ecore Package Registry for Generated Packages":Ot("_UI_DynamicPackageRegistry_extensionpoint",e)?"Ecore Package Registry for Dynamic Packages":Ot("_UI_FactoryRegistry_extensionpoint",e)?"Ecore Factory Override Registry":Ot("_UI_URIExtensionParserRegistry_extensionpoint",e)?"URI Extension Parser Registry":Ot("_UI_URIProtocolParserRegistry_extensionpoint",e)?"URI Protocol Parser Registry":Ot("_UI_URIContentParserRegistry_extensionpoint",e)?"URI Content Parser Registry":Ot("_UI_ContentHandlerRegistry_extensionpoint",e)?"Content Handler Registry":Ot("_UI_URIMappingRegistry_extensionpoint",e)?"URI Converter Mapping Registry":Ot("_UI_PackageRegistryImplementation_extensionpoint",e)?"Ecore Package Registry Implementation":Ot("_UI_ValidationDelegateRegistry_extensionpoint",e)?"Validation Delegate Registry":Ot("_UI_SettingDelegateRegistry_extensionpoint",e)?"Feature Setting Delegate Factory Registry":Ot("_UI_InvocationDelegateRegistry_extensionpoint",e)?"Operation Invocation Delegate Factory Registry":Ot("_UI_EClassInterfaceNotAbstract_diagnostic",e)?"A class that is an interface must also be abstract":Ot("_UI_EClassNoCircularSuperTypes_diagnostic",e)?"A class may not be a super type of itself":Ot("_UI_EClassNotWellFormedMapEntryNoInstanceClassName_diagnostic",e)?"A class that inherits from a map entry class must have instance class name 'java.util.Map$Entry'":Ot("_UI_EReferenceOppositeOfOppositeInconsistent_diagnostic",e)?"The opposite of the opposite may not be a reference different from this one":Ot("_UI_EReferenceOppositeNotFeatureOfType_diagnostic",e)?"The opposite must be a feature of the reference's type":Ot("_UI_EReferenceTransientOppositeNotTransient_diagnostic",e)?"The opposite of a transient reference must be transient if it is proxy resolving":Ot("_UI_EReferenceOppositeBothContainment_diagnostic",e)?"The opposite of a containment reference must not be a containment reference":Ot("_UI_EReferenceConsistentUnique_diagnostic",e)?"A containment or bidirectional reference must be unique if its upper bound is different from 1":Ot("_UI_ETypedElementNoType_diagnostic",e)?"The typed element must have a type":Ot("_UI_EAttributeNoDataType_diagnostic",e)?"The generic attribute type must not refer to a class":Ot("_UI_EReferenceNoClass_diagnostic",e)?"The generic reference type must not refer to a data type":Ot("_UI_EGenericTypeNoTypeParameterAndClassifier_diagnostic",e)?"A generic type can't refer to both a type parameter and a classifier":Ot("_UI_EGenericTypeNoClass_diagnostic",e)?"A generic super type must refer to a class":Ot("_UI_EGenericTypeNoTypeParameterOrClassifier_diagnostic",e)?"A generic type in this context must refer to a classifier or a type parameter":Ot("_UI_EGenericTypeBoundsOnlyForTypeArgument_diagnostic",e)?"A generic type may have bounds only when used as a type argument":Ot("_UI_EGenericTypeNoUpperAndLowerBound_diagnostic",e)?"A generic type must not have both a lower and an upper bound":Ot("_UI_EGenericTypeNoTypeParameterOrClassifierAndBound_diagnostic",e)?"A generic type with bounds must not also refer to a type parameter or classifier":Ot("_UI_EGenericTypeNoArguments_diagnostic",e)?"A generic type may have arguments only if it refers to a classifier":Ot("_UI_EGenericTypeOutOfScopeTypeParameter_diagnostic",e)?"A generic type may only refer to a type parameter that is in scope":e}function Mtn(e){var t,n,i,r,o,a,d,b,v,x,S,M,L,P,z;e.r||(e.r=!0,Gc(e,"graph"),dH(e,"graph"),gH(e,b9),bD(e.o,"T"),Nn(vo(e.a),e.p),Nn(vo(e.f),e.a),Nn(vo(e.n),e.f),Nn(vo(e.g),e.n),Nn(vo(e.c),e.n),Nn(vo(e.i),e.c),Nn(vo(e.j),e.c),Nn(vo(e.d),e.f),Nn(vo(e.e),e.a),Qo(e.p,Gtn,Not,!0,!0,!1),P=Mx(e.p,e.p,"setProperty"),z=PVe(P),v=E1(e.o),x=(n=(i=new Om,i),n),Nn((!v.d&&(v.d=new Ar(Ks,v,1)),v.d),x),S=see(z),S2e(x,S),iQ(P,v,f5e),v=see(z),iQ(P,v,mE),P=Mx(e.p,null,"getProperty"),z=PVe(P),v=E1(e.o),x=see(z),Nn((!v.d&&(v.d=new Ar(Ks,v,1)),v.d),x),iQ(P,v,f5e),v=see(z),L=Ch(P,v,null),L&&L.mj(),P=Mx(e.p,e.wb.e,"hasProperty"),v=E1(e.o),x=(r=(o=new Om,o),r),Nn((!v.d&&(v.d=new Ar(Ks,v,1)),v.d),x),iQ(P,v,f5e),P=Mx(e.p,e.p,"copyProperties"),fo(P,e.p,Jse),P=Mx(e.p,null,"getAllProperties"),v=E1(e.wb.P),x=E1(e.o),Nn((!v.d&&(v.d=new Ar(Ks,v,1)),v.d),x),S=(a=(d=new Om,d),a),Nn((!x.d&&(x.d=new Ar(Ks,x,1)),x.d),S),x=E1(e.wb.M),Nn((!v.d&&(v.d=new Ar(Ks,v,1)),v.d),x),M=Ch(P,v,null),M&&M.mj(),Qo(e.a,o8,Slt,!0,!1,!0),Fi(c(re(Ne(e.a),0),20),e.k,null,Ilt,0,-1,o8,!1,!1,!0,!0,!1,!1,!1),Qo(e.f,QP,Tlt,!0,!1,!0),Fi(c(re(Ne(e.f),0),20),e.g,c(re(Ne(e.g),0),20),"labels",0,-1,QP,!1,!1,!0,!0,!1,!1,!1),gr(c(re(Ne(e.f),1),38),e.wb._,Rlt,null,0,1,QP,!1,!1,!0,!1,!0,!1),Qo(e.n,GP,"ElkShape",!0,!1,!0),gr(c(re(Ne(e.n),0),38),e.wb.t,Xse,JS,1,1,GP,!1,!1,!0,!1,!0,!1),gr(c(re(Ne(e.n),1),38),e.wb.t,Vse,JS,1,1,GP,!1,!1,!0,!1,!0,!1),gr(c(re(Ne(e.n),2),38),e.wb.t,"x",JS,1,1,GP,!1,!1,!0,!1,!0,!1),gr(c(re(Ne(e.n),3),38),e.wb.t,"y",JS,1,1,GP,!1,!1,!0,!1,!0,!1),P=Mx(e.n,null,"setDimensions"),fo(P,e.wb.t,Vse),fo(P,e.wb.t,Xse),P=Mx(e.n,null,"setLocation"),fo(P,e.wb.t,"x"),fo(P,e.wb.t,"y"),Qo(e.g,Bo,l5e,!1,!1,!0),Fi(c(re(Ne(e.g),0),20),e.f,c(re(Ne(e.f),0),20),Wse,0,1,Bo,!1,!1,!0,!1,!1,!1,!1),gr(c(re(Ne(e.g),1),38),e.wb._,Kse,"",0,1,Bo,!1,!1,!0,!1,!0,!1),Qo(e.c,vn,Elt,!0,!1,!0),Fi(c(re(Ne(e.c),0),20),e.d,c(re(Ne(e.d),1),20),"outgoingEdges",0,-1,vn,!1,!1,!0,!1,!0,!1,!1),Fi(c(re(Ne(e.c),1),20),e.d,c(re(Ne(e.d),2),20),"incomingEdges",0,-1,vn,!1,!1,!0,!1,!0,!1,!1),Qo(e.i,Mn,u5e,!1,!1,!0),Fi(c(re(Ne(e.i),0),20),e.j,c(re(Ne(e.j),0),20),"ports",0,-1,Mn,!1,!1,!0,!0,!1,!1,!1),Fi(c(re(Ne(e.i),1),20),e.i,c(re(Ne(e.i),2),20),Yse,0,-1,Mn,!1,!1,!0,!0,!1,!1,!1),Fi(c(re(Ne(e.i),2),20),e.i,c(re(Ne(e.i),1),20),Wse,0,1,Mn,!1,!1,!0,!1,!1,!1,!1),Fi(c(re(Ne(e.i),3),20),e.d,c(re(Ne(e.d),0),20),"containedEdges",0,-1,Mn,!1,!1,!0,!0,!1,!1,!1),gr(c(re(Ne(e.i),4),38),e.wb.e,$lt,null,0,1,Mn,!0,!0,!1,!1,!0,!0),Qo(e.j,hu,a5e,!1,!1,!0),Fi(c(re(Ne(e.j),0),20),e.i,c(re(Ne(e.i),0),20),Wse,0,1,hu,!1,!1,!0,!1,!1,!1,!1),Qo(e.d,Ii,c5e,!1,!1,!0),Fi(c(re(Ne(e.d),0),20),e.i,c(re(Ne(e.i),3),20),"containingNode",0,1,Ii,!1,!1,!0,!1,!1,!1,!1),Fi(c(re(Ne(e.d),1),20),e.c,c(re(Ne(e.c),0),20),h5e,0,-1,Ii,!1,!1,!0,!1,!0,!1,!1),Fi(c(re(Ne(e.d),2),20),e.c,c(re(Ne(e.c),1),20),Zse,0,-1,Ii,!1,!1,!0,!1,!0,!1,!1),Fi(c(re(Ne(e.d),3),20),e.e,c(re(Ne(e.e),5),20),eoe,0,-1,Ii,!1,!1,!0,!0,!1,!1,!1),gr(c(re(Ne(e.d),4),38),e.wb.e,"hyperedge",null,0,1,Ii,!0,!0,!1,!1,!0,!0),gr(c(re(Ne(e.d),5),38),e.wb.e,$lt,null,0,1,Ii,!0,!0,!1,!1,!0,!0),gr(c(re(Ne(e.d),6),38),e.wb.e,"selfloop",null,0,1,Ii,!0,!0,!1,!1,!0,!0),gr(c(re(Ne(e.d),7),38),e.wb.e,"connected",null,0,1,Ii,!0,!0,!1,!1,!0,!0),Qo(e.b,Yu,jlt,!1,!1,!0),gr(c(re(Ne(e.b),0),38),e.wb.t,"x",JS,1,1,Yu,!1,!1,!0,!1,!0,!1),gr(c(re(Ne(e.b),1),38),e.wb.t,"y",JS,1,1,Yu,!1,!1,!0,!1,!0,!1),P=Mx(e.b,null,"set"),fo(P,e.wb.t,"x"),fo(P,e.wb.t,"y"),Qo(e.e,Hi,Clt,!1,!1,!0),gr(c(re(Ne(e.e),0),38),e.wb.t,"startX",null,0,1,Hi,!1,!1,!0,!1,!0,!1),gr(c(re(Ne(e.e),1),38),e.wb.t,"startY",null,0,1,Hi,!1,!1,!0,!1,!0,!1),gr(c(re(Ne(e.e),2),38),e.wb.t,"endX",null,0,1,Hi,!1,!1,!0,!1,!0,!1),gr(c(re(Ne(e.e),3),38),e.wb.t,"endY",null,0,1,Hi,!1,!1,!0,!1,!0,!1),Fi(c(re(Ne(e.e),4),20),e.b,null,MG,0,-1,Hi,!1,!1,!0,!0,!1,!1,!1),Fi(c(re(Ne(e.e),5),20),e.d,c(re(Ne(e.d),3),20),Wse,0,1,Hi,!1,!1,!0,!1,!1,!1,!1),Fi(c(re(Ne(e.e),6),20),e.c,null,d5e,0,1,Hi,!1,!1,!0,!1,!0,!1,!1),Fi(c(re(Ne(e.e),7),20),e.c,null,g5e,0,1,Hi,!1,!1,!0,!1,!0,!1,!1),Fi(c(re(Ne(e.e),8),20),e.e,c(re(Ne(e.e),9),20),p5e,0,-1,Hi,!1,!1,!0,!1,!0,!1,!1),Fi(c(re(Ne(e.e),9),20),e.e,c(re(Ne(e.e),8),20),b5e,0,-1,Hi,!1,!1,!0,!1,!0,!1,!1),gr(c(re(Ne(e.e),10),38),e.wb._,Rlt,null,0,1,Hi,!1,!1,!0,!1,!0,!1),P=Mx(e.e,null,"setStartLocation"),fo(P,e.wb.t,"x"),fo(P,e.wb.t,"y"),P=Mx(e.e,null,"setEndLocation"),fo(P,e.wb.t,"x"),fo(P,e.wb.t,"y"),Qo(e.k,Mb,"ElkPropertyToValueMapEntry",!1,!1,!1),v=E1(e.o),x=(b=(t=new Om,t),b),Nn((!v.d&&(v.d=new Ar(Ks,v,1)),v.d),x),btt(c(re(Ne(e.k),0),38),v,"key",Mb,!1,!1,!0,!1),gr(c(re(Ne(e.k),1),38),e.s,mE,null,0,1,Mb,!1,!1,!0,!1,!0,!1),ai(e.o,Xue,"IProperty",!0),ai(e.s,Br,"PropertyValue",!0),Kme(e,b9))}function Ist(){Ist=te,ne=ye(Rl,Yx,30,Is,15,1),ne[9]=35,ne[10]=19,ne[13]=19,ne[32]=51,ne[33]=49,ne[34]=33,we(ne,35,38,49),ne[38]=1,we(ne,39,45,49),we(ne,45,47,-71),ne[47]=49,we(ne,48,58,-71),ne[58]=61,ne[59]=49,ne[60]=1,ne[61]=49,ne[62]=33,we(ne,63,65,49),we(ne,65,91,-3),we(ne,91,93,33),ne[93]=1,ne[94]=33,ne[95]=-3,ne[96]=33,we(ne,97,123,-3),we(ne,123,183,33),ne[183]=-87,we(ne,184,192,33),we(ne,192,215,-19),ne[215]=33,we(ne,216,247,-19),ne[247]=33,we(ne,248,306,-19),we(ne,306,308,33),we(ne,308,319,-19),we(ne,319,321,33),we(ne,321,329,-19),ne[329]=33,we(ne,330,383,-19),ne[383]=33,we(ne,384,452,-19),we(ne,452,461,33),we(ne,461,497,-19),we(ne,497,500,33),we(ne,500,502,-19),we(ne,502,506,33),we(ne,506,536,-19),we(ne,536,592,33),we(ne,592,681,-19),we(ne,681,699,33),we(ne,699,706,-19),we(ne,706,720,33),we(ne,720,722,-87),we(ne,722,768,33),we(ne,768,838,-87),we(ne,838,864,33),we(ne,864,866,-87),we(ne,866,902,33),ne[902]=-19,ne[903]=-87,we(ne,904,907,-19),ne[907]=33,ne[908]=-19,ne[909]=33,we(ne,910,930,-19),ne[930]=33,we(ne,931,975,-19),ne[975]=33,we(ne,976,983,-19),we(ne,983,986,33),ne[986]=-19,ne[987]=33,ne[988]=-19,ne[989]=33,ne[990]=-19,ne[991]=33,ne[992]=-19,ne[993]=33,we(ne,994,1012,-19),we(ne,1012,1025,33),we(ne,1025,1037,-19),ne[1037]=33,we(ne,1038,1104,-19),ne[1104]=33,we(ne,1105,1117,-19),ne[1117]=33,we(ne,1118,1154,-19),ne[1154]=33,we(ne,1155,1159,-87),we(ne,1159,1168,33),we(ne,1168,1221,-19),we(ne,1221,1223,33),we(ne,1223,1225,-19),we(ne,1225,1227,33),we(ne,1227,1229,-19),we(ne,1229,1232,33),we(ne,1232,1260,-19),we(ne,1260,1262,33),we(ne,1262,1270,-19),we(ne,1270,1272,33),we(ne,1272,1274,-19),we(ne,1274,1329,33),we(ne,1329,1367,-19),we(ne,1367,1369,33),ne[1369]=-19,we(ne,1370,1377,33),we(ne,1377,1415,-19),we(ne,1415,1425,33),we(ne,1425,1442,-87),ne[1442]=33,we(ne,1443,1466,-87),ne[1466]=33,we(ne,1467,1470,-87),ne[1470]=33,ne[1471]=-87,ne[1472]=33,we(ne,1473,1475,-87),ne[1475]=33,ne[1476]=-87,we(ne,1477,1488,33),we(ne,1488,1515,-19),we(ne,1515,1520,33),we(ne,1520,1523,-19),we(ne,1523,1569,33),we(ne,1569,1595,-19),we(ne,1595,1600,33),ne[1600]=-87,we(ne,1601,1611,-19),we(ne,1611,1619,-87),we(ne,1619,1632,33),we(ne,1632,1642,-87),we(ne,1642,1648,33),ne[1648]=-87,we(ne,1649,1720,-19),we(ne,1720,1722,33),we(ne,1722,1727,-19),ne[1727]=33,we(ne,1728,1743,-19),ne[1743]=33,we(ne,1744,1748,-19),ne[1748]=33,ne[1749]=-19,we(ne,1750,1765,-87),we(ne,1765,1767,-19),we(ne,1767,1769,-87),ne[1769]=33,we(ne,1770,1774,-87),we(ne,1774,1776,33),we(ne,1776,1786,-87),we(ne,1786,2305,33),we(ne,2305,2308,-87),ne[2308]=33,we(ne,2309,2362,-19),we(ne,2362,2364,33),ne[2364]=-87,ne[2365]=-19,we(ne,2366,2382,-87),we(ne,2382,2385,33),we(ne,2385,2389,-87),we(ne,2389,2392,33),we(ne,2392,2402,-19),we(ne,2402,2404,-87),we(ne,2404,2406,33),we(ne,2406,2416,-87),we(ne,2416,2433,33),we(ne,2433,2436,-87),ne[2436]=33,we(ne,2437,2445,-19),we(ne,2445,2447,33),we(ne,2447,2449,-19),we(ne,2449,2451,33),we(ne,2451,2473,-19),ne[2473]=33,we(ne,2474,2481,-19),ne[2481]=33,ne[2482]=-19,we(ne,2483,2486,33),we(ne,2486,2490,-19),we(ne,2490,2492,33),ne[2492]=-87,ne[2493]=33,we(ne,2494,2501,-87),we(ne,2501,2503,33),we(ne,2503,2505,-87),we(ne,2505,2507,33),we(ne,2507,2510,-87),we(ne,2510,2519,33),ne[2519]=-87,we(ne,2520,2524,33),we(ne,2524,2526,-19),ne[2526]=33,we(ne,2527,2530,-19),we(ne,2530,2532,-87),we(ne,2532,2534,33),we(ne,2534,2544,-87),we(ne,2544,2546,-19),we(ne,2546,2562,33),ne[2562]=-87,we(ne,2563,2565,33),we(ne,2565,2571,-19),we(ne,2571,2575,33),we(ne,2575,2577,-19),we(ne,2577,2579,33),we(ne,2579,2601,-19),ne[2601]=33,we(ne,2602,2609,-19),ne[2609]=33,we(ne,2610,2612,-19),ne[2612]=33,we(ne,2613,2615,-19),ne[2615]=33,we(ne,2616,2618,-19),we(ne,2618,2620,33),ne[2620]=-87,ne[2621]=33,we(ne,2622,2627,-87),we(ne,2627,2631,33),we(ne,2631,2633,-87),we(ne,2633,2635,33),we(ne,2635,2638,-87),we(ne,2638,2649,33),we(ne,2649,2653,-19),ne[2653]=33,ne[2654]=-19,we(ne,2655,2662,33),we(ne,2662,2674,-87),we(ne,2674,2677,-19),we(ne,2677,2689,33),we(ne,2689,2692,-87),ne[2692]=33,we(ne,2693,2700,-19),ne[2700]=33,ne[2701]=-19,ne[2702]=33,we(ne,2703,2706,-19),ne[2706]=33,we(ne,2707,2729,-19),ne[2729]=33,we(ne,2730,2737,-19),ne[2737]=33,we(ne,2738,2740,-19),ne[2740]=33,we(ne,2741,2746,-19),we(ne,2746,2748,33),ne[2748]=-87,ne[2749]=-19,we(ne,2750,2758,-87),ne[2758]=33,we(ne,2759,2762,-87),ne[2762]=33,we(ne,2763,2766,-87),we(ne,2766,2784,33),ne[2784]=-19,we(ne,2785,2790,33),we(ne,2790,2800,-87),we(ne,2800,2817,33),we(ne,2817,2820,-87),ne[2820]=33,we(ne,2821,2829,-19),we(ne,2829,2831,33),we(ne,2831,2833,-19),we(ne,2833,2835,33),we(ne,2835,2857,-19),ne[2857]=33,we(ne,2858,2865,-19),ne[2865]=33,we(ne,2866,2868,-19),we(ne,2868,2870,33),we(ne,2870,2874,-19),we(ne,2874,2876,33),ne[2876]=-87,ne[2877]=-19,we(ne,2878,2884,-87),we(ne,2884,2887,33),we(ne,2887,2889,-87),we(ne,2889,2891,33),we(ne,2891,2894,-87),we(ne,2894,2902,33),we(ne,2902,2904,-87),we(ne,2904,2908,33),we(ne,2908,2910,-19),ne[2910]=33,we(ne,2911,2914,-19),we(ne,2914,2918,33),we(ne,2918,2928,-87),we(ne,2928,2946,33),we(ne,2946,2948,-87),ne[2948]=33,we(ne,2949,2955,-19),we(ne,2955,2958,33),we(ne,2958,2961,-19),ne[2961]=33,we(ne,2962,2966,-19),we(ne,2966,2969,33),we(ne,2969,2971,-19),ne[2971]=33,ne[2972]=-19,ne[2973]=33,we(ne,2974,2976,-19),we(ne,2976,2979,33),we(ne,2979,2981,-19),we(ne,2981,2984,33),we(ne,2984,2987,-19),we(ne,2987,2990,33),we(ne,2990,2998,-19),ne[2998]=33,we(ne,2999,3002,-19),we(ne,3002,3006,33),we(ne,3006,3011,-87),we(ne,3011,3014,33),we(ne,3014,3017,-87),ne[3017]=33,we(ne,3018,3022,-87),we(ne,3022,3031,33),ne[3031]=-87,we(ne,3032,3047,33),we(ne,3047,3056,-87),we(ne,3056,3073,33),we(ne,3073,3076,-87),ne[3076]=33,we(ne,3077,3085,-19),ne[3085]=33,we(ne,3086,3089,-19),ne[3089]=33,we(ne,3090,3113,-19),ne[3113]=33,we(ne,3114,3124,-19),ne[3124]=33,we(ne,3125,3130,-19),we(ne,3130,3134,33),we(ne,3134,3141,-87),ne[3141]=33,we(ne,3142,3145,-87),ne[3145]=33,we(ne,3146,3150,-87),we(ne,3150,3157,33),we(ne,3157,3159,-87),we(ne,3159,3168,33),we(ne,3168,3170,-19),we(ne,3170,3174,33),we(ne,3174,3184,-87),we(ne,3184,3202,33),we(ne,3202,3204,-87),ne[3204]=33,we(ne,3205,3213,-19),ne[3213]=33,we(ne,3214,3217,-19),ne[3217]=33,we(ne,3218,3241,-19),ne[3241]=33,we(ne,3242,3252,-19),ne[3252]=33,we(ne,3253,3258,-19),we(ne,3258,3262,33),we(ne,3262,3269,-87),ne[3269]=33,we(ne,3270,3273,-87),ne[3273]=33,we(ne,3274,3278,-87),we(ne,3278,3285,33),we(ne,3285,3287,-87),we(ne,3287,3294,33),ne[3294]=-19,ne[3295]=33,we(ne,3296,3298,-19),we(ne,3298,3302,33),we(ne,3302,3312,-87),we(ne,3312,3330,33),we(ne,3330,3332,-87),ne[3332]=33,we(ne,3333,3341,-19),ne[3341]=33,we(ne,3342,3345,-19),ne[3345]=33,we(ne,3346,3369,-19),ne[3369]=33,we(ne,3370,3386,-19),we(ne,3386,3390,33),we(ne,3390,3396,-87),we(ne,3396,3398,33),we(ne,3398,3401,-87),ne[3401]=33,we(ne,3402,3406,-87),we(ne,3406,3415,33),ne[3415]=-87,we(ne,3416,3424,33),we(ne,3424,3426,-19),we(ne,3426,3430,33),we(ne,3430,3440,-87),we(ne,3440,3585,33),we(ne,3585,3631,-19),ne[3631]=33,ne[3632]=-19,ne[3633]=-87,we(ne,3634,3636,-19),we(ne,3636,3643,-87),we(ne,3643,3648,33),we(ne,3648,3654,-19),we(ne,3654,3663,-87),ne[3663]=33,we(ne,3664,3674,-87),we(ne,3674,3713,33),we(ne,3713,3715,-19),ne[3715]=33,ne[3716]=-19,we(ne,3717,3719,33),we(ne,3719,3721,-19),ne[3721]=33,ne[3722]=-19,we(ne,3723,3725,33),ne[3725]=-19,we(ne,3726,3732,33),we(ne,3732,3736,-19),ne[3736]=33,we(ne,3737,3744,-19),ne[3744]=33,we(ne,3745,3748,-19),ne[3748]=33,ne[3749]=-19,ne[3750]=33,ne[3751]=-19,we(ne,3752,3754,33),we(ne,3754,3756,-19),ne[3756]=33,we(ne,3757,3759,-19),ne[3759]=33,ne[3760]=-19,ne[3761]=-87,we(ne,3762,3764,-19),we(ne,3764,3770,-87),ne[3770]=33,we(ne,3771,3773,-87),ne[3773]=-19,we(ne,3774,3776,33),we(ne,3776,3781,-19),ne[3781]=33,ne[3782]=-87,ne[3783]=33,we(ne,3784,3790,-87),we(ne,3790,3792,33),we(ne,3792,3802,-87),we(ne,3802,3864,33),we(ne,3864,3866,-87),we(ne,3866,3872,33),we(ne,3872,3882,-87),we(ne,3882,3893,33),ne[3893]=-87,ne[3894]=33,ne[3895]=-87,ne[3896]=33,ne[3897]=-87,we(ne,3898,3902,33),we(ne,3902,3904,-87),we(ne,3904,3912,-19),ne[3912]=33,we(ne,3913,3946,-19),we(ne,3946,3953,33),we(ne,3953,3973,-87),ne[3973]=33,we(ne,3974,3980,-87),we(ne,3980,3984,33),we(ne,3984,3990,-87),ne[3990]=33,ne[3991]=-87,ne[3992]=33,we(ne,3993,4014,-87),we(ne,4014,4017,33),we(ne,4017,4024,-87),ne[4024]=33,ne[4025]=-87,we(ne,4026,4256,33),we(ne,4256,4294,-19),we(ne,4294,4304,33),we(ne,4304,4343,-19),we(ne,4343,4352,33),ne[4352]=-19,ne[4353]=33,we(ne,4354,4356,-19),ne[4356]=33,we(ne,4357,4360,-19),ne[4360]=33,ne[4361]=-19,ne[4362]=33,we(ne,4363,4365,-19),ne[4365]=33,we(ne,4366,4371,-19),we(ne,4371,4412,33),ne[4412]=-19,ne[4413]=33,ne[4414]=-19,ne[4415]=33,ne[4416]=-19,we(ne,4417,4428,33),ne[4428]=-19,ne[4429]=33,ne[4430]=-19,ne[4431]=33,ne[4432]=-19,we(ne,4433,4436,33),we(ne,4436,4438,-19),we(ne,4438,4441,33),ne[4441]=-19,we(ne,4442,4447,33),we(ne,4447,4450,-19),ne[4450]=33,ne[4451]=-19,ne[4452]=33,ne[4453]=-19,ne[4454]=33,ne[4455]=-19,ne[4456]=33,ne[4457]=-19,we(ne,4458,4461,33),we(ne,4461,4463,-19),we(ne,4463,4466,33),we(ne,4466,4468,-19),ne[4468]=33,ne[4469]=-19,we(ne,4470,4510,33),ne[4510]=-19,we(ne,4511,4520,33),ne[4520]=-19,we(ne,4521,4523,33),ne[4523]=-19,we(ne,4524,4526,33),we(ne,4526,4528,-19),we(ne,4528,4535,33),we(ne,4535,4537,-19),ne[4537]=33,ne[4538]=-19,ne[4539]=33,we(ne,4540,4547,-19),we(ne,4547,4587,33),ne[4587]=-19,we(ne,4588,4592,33),ne[4592]=-19,we(ne,4593,4601,33),ne[4601]=-19,we(ne,4602,7680,33),we(ne,7680,7836,-19),we(ne,7836,7840,33),we(ne,7840,7930,-19),we(ne,7930,7936,33),we(ne,7936,7958,-19),we(ne,7958,7960,33),we(ne,7960,7966,-19),we(ne,7966,7968,33),we(ne,7968,8006,-19),we(ne,8006,8008,33),we(ne,8008,8014,-19),we(ne,8014,8016,33),we(ne,8016,8024,-19),ne[8024]=33,ne[8025]=-19,ne[8026]=33,ne[8027]=-19,ne[8028]=33,ne[8029]=-19,ne[8030]=33,we(ne,8031,8062,-19),we(ne,8062,8064,33),we(ne,8064,8117,-19),ne[8117]=33,we(ne,8118,8125,-19),ne[8125]=33,ne[8126]=-19,we(ne,8127,8130,33),we(ne,8130,8133,-19),ne[8133]=33,we(ne,8134,8141,-19),we(ne,8141,8144,33),we(ne,8144,8148,-19),we(ne,8148,8150,33),we(ne,8150,8156,-19),we(ne,8156,8160,33),we(ne,8160,8173,-19),we(ne,8173,8178,33),we(ne,8178,8181,-19),ne[8181]=33,we(ne,8182,8189,-19),we(ne,8189,8400,33),we(ne,8400,8413,-87),we(ne,8413,8417,33),ne[8417]=-87,we(ne,8418,8486,33),ne[8486]=-19,we(ne,8487,8490,33),we(ne,8490,8492,-19),we(ne,8492,8494,33),ne[8494]=-19,we(ne,8495,8576,33),we(ne,8576,8579,-19),we(ne,8579,12293,33),ne[12293]=-87,ne[12294]=33,ne[12295]=-19,we(ne,12296,12321,33),we(ne,12321,12330,-19),we(ne,12330,12336,-87),ne[12336]=33,we(ne,12337,12342,-87),we(ne,12342,12353,33),we(ne,12353,12437,-19),we(ne,12437,12441,33),we(ne,12441,12443,-87),we(ne,12443,12445,33),we(ne,12445,12447,-87),we(ne,12447,12449,33),we(ne,12449,12539,-19),ne[12539]=33,we(ne,12540,12543,-87),we(ne,12543,12549,33),we(ne,12549,12589,-19),we(ne,12589,19968,33),we(ne,19968,40870,-19),we(ne,40870,44032,33),we(ne,44032,55204,-19),we(ne,55204,hL,33),we(ne,57344,65534,33)}function Atn(e){var t,n,i,r,o,a,d;e.hb||(e.hb=!0,Gc(e,"ecore"),dH(e,"ecore"),gH(e,Ja),bD(e.fb,"E"),bD(e.L,"T"),bD(e.P,"K"),bD(e.P,"V"),bD(e.cb,"E"),Nn(vo(e.b),e.bb),Nn(vo(e.a),e.Q),Nn(vo(e.o),e.p),Nn(vo(e.p),e.R),Nn(vo(e.q),e.p),Nn(vo(e.v),e.q),Nn(vo(e.w),e.R),Nn(vo(e.B),e.Q),Nn(vo(e.R),e.Q),Nn(vo(e.T),e.eb),Nn(vo(e.U),e.R),Nn(vo(e.V),e.eb),Nn(vo(e.W),e.bb),Nn(vo(e.bb),e.eb),Nn(vo(e.eb),e.R),Nn(vo(e.db),e.R),Qo(e.b,ay,Cut,!1,!1,!0),gr(c(re(Ne(e.b),0),38),e.e,"iD",null,0,1,ay,!1,!1,!0,!1,!0,!1),Fi(c(re(Ne(e.b),1),20),e.q,null,"eAttributeType",1,1,ay,!0,!0,!1,!1,!0,!1,!0),Qo(e.a,si,jut,!1,!1,!0),gr(c(re(Ne(e.a),0),38),e._,Jse,null,0,1,si,!1,!1,!0,!1,!0,!1),Fi(c(re(Ne(e.a),1),20),e.ab,null,"details",0,-1,si,!1,!1,!0,!0,!1,!1,!1),Fi(c(re(Ne(e.a),2),20),e.Q,c(re(Ne(e.Q),0),20),"eModelElement",0,1,si,!0,!1,!0,!1,!1,!1,!1),Fi(c(re(Ne(e.a),3),20),e.S,null,"contents",0,-1,si,!1,!1,!0,!0,!1,!1,!1),Fi(c(re(Ne(e.a),4),20),e.S,null,"references",0,-1,si,!1,!1,!0,!1,!0,!1,!1),Qo(e.o,ef,"EClass",!1,!1,!0),gr(c(re(Ne(e.o),0),38),e.e,"abstract",null,0,1,ef,!1,!1,!0,!1,!0,!1),gr(c(re(Ne(e.o),1),38),e.e,"interface",null,0,1,ef,!1,!1,!0,!1,!0,!1),Fi(c(re(Ne(e.o),2),20),e.o,null,"eSuperTypes",0,-1,ef,!1,!1,!0,!1,!0,!0,!1),Fi(c(re(Ne(e.o),3),20),e.T,c(re(Ne(e.T),0),20),"eOperations",0,-1,ef,!1,!1,!0,!0,!1,!1,!1),Fi(c(re(Ne(e.o),4),20),e.b,null,"eAllAttributes",0,-1,ef,!0,!0,!1,!1,!0,!1,!0),Fi(c(re(Ne(e.o),5),20),e.W,null,"eAllReferences",0,-1,ef,!0,!0,!1,!1,!0,!1,!0),Fi(c(re(Ne(e.o),6),20),e.W,null,"eReferences",0,-1,ef,!0,!0,!1,!1,!0,!1,!0),Fi(c(re(Ne(e.o),7),20),e.b,null,"eAttributes",0,-1,ef,!0,!0,!1,!1,!0,!1,!0),Fi(c(re(Ne(e.o),8),20),e.W,null,"eAllContainments",0,-1,ef,!0,!0,!1,!1,!0,!1,!0),Fi(c(re(Ne(e.o),9),20),e.T,null,"eAllOperations",0,-1,ef,!0,!0,!1,!1,!0,!1,!0),Fi(c(re(Ne(e.o),10),20),e.bb,null,"eAllStructuralFeatures",0,-1,ef,!0,!0,!1,!1,!0,!1,!0),Fi(c(re(Ne(e.o),11),20),e.o,null,"eAllSuperTypes",0,-1,ef,!0,!0,!1,!1,!0,!1,!0),Fi(c(re(Ne(e.o),12),20),e.b,null,"eIDAttribute",0,1,ef,!0,!0,!1,!1,!1,!1,!0),Fi(c(re(Ne(e.o),13),20),e.bb,c(re(Ne(e.bb),7),20),"eStructuralFeatures",0,-1,ef,!1,!1,!0,!0,!1,!1,!1),Fi(c(re(Ne(e.o),14),20),e.H,null,"eGenericSuperTypes",0,-1,ef,!1,!1,!0,!0,!1,!0,!1),Fi(c(re(Ne(e.o),15),20),e.H,null,"eAllGenericSuperTypes",0,-1,ef,!0,!0,!1,!1,!0,!1,!0),d=eo(c(re(Ei(e.o),0),62),e.e,"isSuperTypeOf"),fo(d,e.o,"someClass"),eo(c(re(Ei(e.o),1),62),e.I,"getFeatureCount"),d=eo(c(re(Ei(e.o),2),62),e.bb,zut),fo(d,e.I,"featureID"),d=eo(c(re(Ei(e.o),3),62),e.I,Fut),fo(d,e.bb,jE),d=eo(c(re(Ei(e.o),4),62),e.bb,zut),fo(d,e._,"featureName"),eo(c(re(Ei(e.o),5),62),e.I,"getOperationCount"),d=eo(c(re(Ei(e.o),6),62),e.T,"getEOperation"),fo(d,e.I,"operationID"),d=eo(c(re(Ei(e.o),7),62),e.I,qut),fo(d,e.T,A5e),d=eo(c(re(Ei(e.o),8),62),e.T,"getOverride"),fo(d,e.T,A5e),d=eo(c(re(Ei(e.o),9),62),e.H,"getFeatureType"),fo(d,e.bb,jE),Qo(e.p,ah,Mut,!0,!1,!0),gr(c(re(Ne(e.p),0),38),e._,"instanceClassName",null,0,1,ah,!1,!0,!0,!0,!0,!1),t=E1(e.L),n=Vpe(),Nn((!t.d&&(t.d=new Ar(Ks,t,1)),t.d),n),btt(c(re(Ne(e.p),1),38),t,"instanceClass",ah,!0,!0,!1,!0),gr(c(re(Ne(e.p),2),38),e.M,Hut,null,0,1,ah,!0,!0,!1,!1,!0,!0),gr(c(re(Ne(e.p),3),38),e._,"instanceTypeName",null,0,1,ah,!1,!0,!0,!0,!0,!1),Fi(c(re(Ne(e.p),4),20),e.U,c(re(Ne(e.U),3),20),"ePackage",0,1,ah,!0,!1,!1,!1,!0,!1,!1),Fi(c(re(Ne(e.p),5),20),e.db,null,Qut,0,-1,ah,!1,!1,!0,!0,!0,!1,!1),d=eo(c(re(Ei(e.p),0),62),e.e,Gut),fo(d,e.M,iL),eo(c(re(Ei(e.p),1),62),e.I,"getClassifierID"),Qo(e.q,jae,"EDataType",!1,!1,!0),gr(c(re(Ne(e.q),0),38),e.e,"serializable",h9,0,1,jae,!1,!1,!0,!1,!0,!1),Qo(e.v,uX,"EEnum",!1,!1,!0),Fi(c(re(Ne(e.v),0),20),e.w,c(re(Ne(e.w),3),20),"eLiterals",0,-1,uX,!1,!1,!0,!0,!1,!1,!1),d=eo(c(re(Ei(e.v),0),62),e.w,Uut),fo(d,e._,hi),d=eo(c(re(Ei(e.v),1),62),e.w,Uut),fo(d,e.I,mE),d=eo(c(re(Ei(e.v),2),62),e.w,"getEEnumLiteralByLiteral"),fo(d,e._,"literal"),Qo(e.w,tg,Aut,!1,!1,!0),gr(c(re(Ne(e.w),0),38),e.I,mE,null,0,1,tg,!1,!1,!0,!1,!0,!1),gr(c(re(Ne(e.w),1),38),e.A,"instance",null,0,1,tg,!0,!1,!0,!1,!0,!1),gr(c(re(Ne(e.w),2),38),e._,"literal",null,0,1,tg,!1,!1,!0,!1,!0,!1),Fi(c(re(Ne(e.w),3),20),e.v,c(re(Ne(e.v),0),20),"eEnum",0,1,tg,!0,!1,!1,!1,!1,!1,!1),Qo(e.B,FC,"EFactory",!1,!1,!0),Fi(c(re(Ne(e.B),0),20),e.U,c(re(Ne(e.U),2),20),"ePackage",1,1,FC,!0,!1,!0,!1,!1,!1,!1),d=eo(c(re(Ei(e.B),0),62),e.S,"create"),fo(d,e.o,"eClass"),d=eo(c(re(Ei(e.B),1),62),e.M,"createFromString"),fo(d,e.q,"eDataType"),fo(d,e._,"literalValue"),d=eo(c(re(Ei(e.B),2),62),e._,"convertToString"),fo(d,e.q,"eDataType"),fo(d,e.M,"instanceValue"),Qo(e.Q,UP,Mlt,!0,!1,!0),Fi(c(re(Ne(e.Q),0),20),e.a,c(re(Ne(e.a),2),20),"eAnnotations",0,-1,UP,!1,!1,!0,!0,!1,!1,!1),d=eo(c(re(Ei(e.Q),0),62),e.a,"getEAnnotation"),fo(d,e._,Jse),Qo(e.R,vae,Alt,!0,!1,!0),gr(c(re(Ne(e.R),0),38),e._,hi,null,0,1,vae,!1,!1,!0,!1,!0,!1),Qo(e.S,dp,"EObject",!1,!1,!0),eo(c(re(Ei(e.S),0),62),e.o,"eClass"),eo(c(re(Ei(e.S),1),62),e.e,"eIsProxy"),eo(c(re(Ei(e.S),2),62),e.X,"eResource"),eo(c(re(Ei(e.S),3),62),e.S,"eContainer"),eo(c(re(Ei(e.S),4),62),e.bb,"eContainingFeature"),eo(c(re(Ei(e.S),5),62),e.W,"eContainmentFeature"),d=eo(c(re(Ei(e.S),6),62),null,"eContents"),t=E1(e.fb),n=E1(e.S),Nn((!t.d&&(t.d=new Ar(Ks,t,1)),t.d),n),r=Ch(d,t,null),r&&r.mj(),d=eo(c(re(Ei(e.S),7),62),null,"eAllContents"),t=E1(e.cb),n=E1(e.S),Nn((!t.d&&(t.d=new Ar(Ks,t,1)),t.d),n),o=Ch(d,t,null),o&&o.mj(),d=eo(c(re(Ei(e.S),8),62),null,"eCrossReferences"),t=E1(e.fb),n=E1(e.S),Nn((!t.d&&(t.d=new Ar(Ks,t,1)),t.d),n),a=Ch(d,t,null),a&&a.mj(),d=eo(c(re(Ei(e.S),9),62),e.M,"eGet"),fo(d,e.bb,jE),d=eo(c(re(Ei(e.S),10),62),e.M,"eGet"),fo(d,e.bb,jE),fo(d,e.e,"resolve"),d=eo(c(re(Ei(e.S),11),62),null,"eSet"),fo(d,e.bb,jE),fo(d,e.M,"newValue"),d=eo(c(re(Ei(e.S),12),62),e.e,"eIsSet"),fo(d,e.bb,jE),d=eo(c(re(Ei(e.S),13),62),null,"eUnset"),fo(d,e.bb,jE),d=eo(c(re(Ei(e.S),14),62),e.M,"eInvoke"),fo(d,e.T,A5e),t=E1(e.fb),n=Vpe(),Nn((!t.d&&(t.d=new Ar(Ks,t,1)),t.d),n),iQ(d,t,"arguments"),XMt(d,e.K),Qo(e.T,tf,_ut,!1,!1,!0),Fi(c(re(Ne(e.T),0),20),e.o,c(re(Ne(e.o),3),20),Jut,0,1,tf,!0,!1,!1,!1,!1,!1,!1),Fi(c(re(Ne(e.T),1),20),e.db,null,Qut,0,-1,tf,!1,!1,!0,!0,!0,!1,!1),Fi(c(re(Ne(e.T),2),20),e.V,c(re(Ne(e.V),0),20),"eParameters",0,-1,tf,!1,!1,!0,!0,!1,!1,!1),Fi(c(re(Ne(e.T),3),20),e.p,null,"eExceptions",0,-1,tf,!1,!1,!0,!1,!0,!0,!1),Fi(c(re(Ne(e.T),4),20),e.H,null,"eGenericExceptions",0,-1,tf,!1,!1,!0,!0,!1,!0,!1),eo(c(re(Ei(e.T),0),62),e.I,qut),d=eo(c(re(Ei(e.T),1),62),e.e,"isOverrideOf"),fo(d,e.T,"someOperation"),Qo(e.U,uh,"EPackage",!1,!1,!0),gr(c(re(Ne(e.U),0),38),e._,"nsURI",null,0,1,uh,!1,!1,!0,!1,!0,!1),gr(c(re(Ne(e.U),1),38),e._,"nsPrefix",null,0,1,uh,!1,!1,!0,!1,!0,!1),Fi(c(re(Ne(e.U),2),20),e.B,c(re(Ne(e.B),0),20),"eFactoryInstance",1,1,uh,!0,!1,!0,!1,!1,!1,!1),Fi(c(re(Ne(e.U),3),20),e.p,c(re(Ne(e.p),4),20),"eClassifiers",0,-1,uh,!1,!1,!0,!0,!0,!1,!1),Fi(c(re(Ne(e.U),4),20),e.U,c(re(Ne(e.U),5),20),"eSubpackages",0,-1,uh,!1,!1,!0,!0,!0,!1,!1),Fi(c(re(Ne(e.U),5),20),e.U,c(re(Ne(e.U),4),20),"eSuperPackage",0,1,uh,!0,!1,!1,!1,!0,!1,!1),d=eo(c(re(Ei(e.U),0),62),e.p,"getEClassifier"),fo(d,e._,hi),Qo(e.V,$w,Dut,!1,!1,!0),Fi(c(re(Ne(e.V),0),20),e.T,c(re(Ne(e.T),2),20),"eOperation",0,1,$w,!0,!1,!1,!1,!1,!1,!1),Qo(e.W,fy,Lut,!1,!1,!0),gr(c(re(Ne(e.W),0),38),e.e,"containment",null,0,1,fy,!1,!1,!0,!1,!0,!1),gr(c(re(Ne(e.W),1),38),e.e,"container",null,0,1,fy,!0,!0,!1,!1,!0,!0),gr(c(re(Ne(e.W),2),38),e.e,"resolveProxies",h9,0,1,fy,!1,!1,!0,!1,!0,!1),Fi(c(re(Ne(e.W),3),20),e.W,null,"eOpposite",0,1,fy,!1,!1,!0,!1,!0,!1,!1),Fi(c(re(Ne(e.W),4),20),e.o,null,"eReferenceType",1,1,fy,!0,!0,!1,!1,!0,!1,!0),Fi(c(re(Ne(e.W),5),20),e.b,null,"eKeys",0,-1,fy,!1,!1,!0,!1,!0,!1,!1),Qo(e.bb,xl,Eut,!0,!1,!0),gr(c(re(Ne(e.bb),0),38),e.e,"changeable",h9,0,1,xl,!1,!1,!0,!1,!0,!1),gr(c(re(Ne(e.bb),1),38),e.e,"volatile",null,0,1,xl,!1,!1,!0,!1,!0,!1),gr(c(re(Ne(e.bb),2),38),e.e,"transient",null,0,1,xl,!1,!1,!0,!1,!0,!1),gr(c(re(Ne(e.bb),3),38),e._,"defaultValueLiteral",null,0,1,xl,!1,!1,!0,!1,!0,!1),gr(c(re(Ne(e.bb),4),38),e.M,Hut,null,0,1,xl,!0,!0,!1,!1,!0,!0),gr(c(re(Ne(e.bb),5),38),e.e,"unsettable",null,0,1,xl,!1,!1,!0,!1,!0,!1),gr(c(re(Ne(e.bb),6),38),e.e,"derived",null,0,1,xl,!1,!1,!0,!1,!0,!1),Fi(c(re(Ne(e.bb),7),20),e.o,c(re(Ne(e.o),13),20),Jut,0,1,xl,!0,!1,!1,!1,!1,!1,!1),eo(c(re(Ei(e.bb),0),62),e.I,Fut),d=eo(c(re(Ei(e.bb),1),62),null,"getContainerClass"),t=E1(e.L),n=Vpe(),Nn((!t.d&&(t.d=new Ar(Ks,t,1)),t.d),n),i=Ch(d,t,null),i&&i.mj(),Qo(e.eb,uy,Tut,!0,!1,!0),gr(c(re(Ne(e.eb),0),38),e.e,"ordered",h9,0,1,uy,!1,!1,!0,!1,!0,!1),gr(c(re(Ne(e.eb),1),38),e.e,"unique",h9,0,1,uy,!1,!1,!0,!1,!0,!1),gr(c(re(Ne(e.eb),2),38),e.I,"lowerBound",null,0,1,uy,!1,!1,!0,!1,!0,!1),gr(c(re(Ne(e.eb),3),38),e.I,"upperBound","1",0,1,uy,!1,!1,!0,!1,!0,!1),gr(c(re(Ne(e.eb),4),38),e.e,"many",null,0,1,uy,!0,!0,!1,!1,!0,!0),gr(c(re(Ne(e.eb),5),38),e.e,"required",null,0,1,uy,!0,!0,!1,!1,!0,!0),Fi(c(re(Ne(e.eb),6),20),e.p,null,"eType",0,1,uy,!1,!0,!0,!1,!0,!0,!1),Fi(c(re(Ne(e.eb),7),20),e.H,null,"eGenericType",0,1,uy,!1,!0,!0,!0,!1,!0,!1),Qo(e.ab,Mb,"EStringToStringMapEntry",!1,!1,!1),gr(c(re(Ne(e.ab),0),38),e._,"key",null,0,1,Mb,!1,!1,!0,!1,!0,!1),gr(c(re(Ne(e.ab),1),38),e._,mE,null,0,1,Mb,!1,!1,!0,!1,!0,!1),Qo(e.H,Ks,Nut,!1,!1,!0),Fi(c(re(Ne(e.H),0),20),e.H,null,"eUpperBound",0,1,Ks,!1,!1,!0,!0,!1,!1,!1),Fi(c(re(Ne(e.H),1),20),e.H,null,"eTypeArguments",0,-1,Ks,!1,!1,!0,!0,!1,!1,!1),Fi(c(re(Ne(e.H),2),20),e.p,null,"eRawType",1,1,Ks,!0,!1,!1,!1,!0,!1,!0),Fi(c(re(Ne(e.H),3),20),e.H,null,"eLowerBound",0,1,Ks,!1,!1,!0,!0,!1,!1,!1),Fi(c(re(Ne(e.H),4),20),e.db,null,"eTypeParameter",0,1,Ks,!1,!1,!0,!1,!1,!1,!1),Fi(c(re(Ne(e.H),5),20),e.p,null,"eClassifier",0,1,Ks,!1,!1,!0,!1,!0,!1,!1),d=eo(c(re(Ei(e.H),0),62),e.e,Gut),fo(d,e.M,iL),Qo(e.db,cl,Put,!1,!1,!0),Fi(c(re(Ne(e.db),0),20),e.H,null,"eBounds",0,-1,cl,!1,!1,!0,!0,!1,!1,!1),ai(e.c,Doe,"EBigDecimal",!0),ai(e.d,t3,"EBigInteger",!0),ai(e.e,kl,"EBoolean",!0),ai(e.f,ir,"EBooleanObject",!0),ai(e.i,Rl,"EByte",!0),ai(e.g,V(Rl,1),"EByteArray",!0),ai(e.j,ak,"EByteObject",!0),ai(e.k,Na,"EChar",!0),ai(e.n,CE,"ECharacterObject",!0),ai(e.r,KG,"EDate",!0),ai(e.s,nEe,"EDiagnosticChain",!1),ai(e.t,ns,"EDouble",!0),ai(e.u,kr,"EDoubleObject",!0),ai(e.fb,mTe,"EEList",!1),ai(e.A,yTe,"EEnumerator",!1),ai(e.C,HTe,"EFeatureMap",!1),ai(e.D,aX,"EFeatureMapEntry",!1),ai(e.F,py,"EFloat",!0),ai(e.G,O9,"EFloatObject",!0),ai(e.I,Fn,"EInt",!0),ai(e.J,Lr,"EIntegerObject",!0),ai(e.L,F5e,"EJavaClass",!0),ai(e.M,Br,"EJavaObject",!0),ai(e.N,qw,"ELong",!0),ai(e.O,Ow,"ELongObject",!0),ai(e.P,q5e,"EMap",!1),ai(e.X,BTe,"EResource",!1),ai(e.Y,iEe,"EResourceSet",!1),ai(e.Z,L3,"EShort",!0),ai(e.$,Sw,"EShortObject",!0),ai(e._,nt,"EString",!0),ai(e.cb,vTe,"ETreeIterator",!1),ai(e.K,rEe,"EInvocationTargetException",!1),Kme(e,Ja))}var iL="object",K5="boolean",Zye="number",Iie="string",Rie="function",di=2147483647,Jo="java.lang",rL={3:1},sL="com.google.common.base",Jc=", ",Rst="%s (%s) must not be negative",Lt={3:1,4:1,5:1},$st="negative size: ",exe="no calls to next() since the last call to remove()",Bst="Optional.of(",pl="null",qS={206:1,51:1},xt="com.google.common.collect",HS={206:1,51:1,130:1},vb={231:1,3:1},ts={51:1},yn="java.util",fw={93:1},Ov={22:1,32:1,18:1},Nh=2042,Ll={22:1,32:1,18:1,24:1},q1=2048,txe={93:1,141:1,136:1},zst={22:1,32:1,18:1,24:1,85:1},nxe={22:1,32:1,18:1,279:1,24:1,85:1},Ud={51:1,130:1},$ie={359:1,45:1},Fst="AbstractMapEntry",qst="expectedValuesPerKey",Be={3:1,6:1,4:1,5:1},ad=16384,Gu={163:1},ln={42:1},oL={204:1},cL={l:4194303,m:4194303,h:524287},Bie={257:1,3:1,34:1},Hst="range unbounded on this side",Jd={22:1},Qst={22:1,18:1},ixe={3:1,22:1,32:1,18:1},QS={312:1,3:1,22:1,32:1,18:1,16:1,59:1},qQ={3:1,4:1,5:1,178:1},GS={3:1,93:1},zie={22:1,18:1,24:1},Y5={3:1,22:1,32:1,18:1,24:1},Gst={22:1,18:1,24:1,85:1},Xd=461845907,Vd=-862048943,lL={3:1,6:1,4:1,5:1,178:1},Ust="expectedSize",KT=1073741824,Sv="initialArraySize",_e={3:1,6:1,4:1,10:1,5:1},US={22:1,32:1,56:1,18:1,16:1},Fie="arraySize",Ga=1024,Jst={22:1,32:1,56:1,18:1,16:1,59:1},Jn={48:1},HQ={376:1},Fg=1e-4,ls=-2147483648,Xst="__noinit__",H1={3:1,102:1,63:1,81:1},uL="com.google.gwt.core.client.impl",rxe="String",sxe="com.google.gwt.core.client",qie="anonymous",Hie="fnStack",oxe="Unknown",fd={203:1,3:1,4:1},qg=1e3,_r=65535,Qie="January",Gie="February",Uie="March",Jie="April",Z5="May",Xie="June",Vie="July",Wie="August",Kie="September",Yie="October",Zie="November",ere="December",G0=1900,ci={54:1,3:1,4:1},Vst="Before Christ",Wst="Anno Domini",tre="Sunday",nre="Monday",ire="Tuesday",rre="Wednesday",sre="Thursday",ore="Friday",cre="Saturday",cxe="com.google.gwt.i18n.shared",Kst="DateTimeFormat",lre="com.google.gwt.i18n.client",Yst="DefaultDateTimeFormatInfo",Zst={3:1,4:1,34:1,208:1},ek="com.google.gwt.json.client",au=4194303,Q1=1048575,aL=524288,tk=4194304,yb=17592186044416,QQ=1e9,fL=-17592186044416,lxe="java.io",GQ={3:1,102:1,99:1,63:1,81:1},eot={3:1,298:1,81:1},hw='For input string: "',nr=1/0,Qr=-1/0,jv=4096,tot={3:1,4:1,591:1},Qt="org.eclipse.elk.layered",Is=65536,hL=55296,no={109:1,3:1,4:1},ure=1e5,not=.3010299956639812,Us=4294967295,JS="0.0",are={45:1},XS="Unable to add element to queue",iot={3:1,4:1,22:1,32:1,56:1,13:1,18:1,16:1,59:1},rot={3:1,22:1,32:1,56:1,18:1,16:1,59:1},sot={22:1,18:1,16:1},fre={3:1,50:1},dL={191:1},Gx={3:1,4:1,93:1},uxe={3:1,4:1,22:1,32:1,18:1,47:1,24:1},hre="delete",YT=14901161193847656e-24,ZT=11102230246251565e-32,dre=15525485,gL=5960464477539063e-23,axe=16777216,UQ=16777215,fxe=", length: ",oot={3:1,4:1,22:1,32:1,56:1,18:1,16:1,59:1},hxe="subMap: ",cot=" less than ",gre={3:1,34:1,23:1,310:1},pre="java.util.function",eE="java.util.logging",lot={3:1,4:1,5:1,848:1},bre="undefined",Js="java.util.stream",dxe={524:1,684:1},JQ="fromIndex: ",uot=" > toIndex: ",gxe=", toIndex: ",pxe="Index: ",bxe=", Size: ",VS="org.eclipse.elk.alg.common",Yn={50:1},aot="org.eclipse.elk.alg.common.compaction",fot="Scanline/EventHandler",Wd="org.eclipse.elk.alg.common.compaction.oned",hot="CNode belongs to another CGroup.",dot="ISpacingsHandler/1",mre="The ",wre=" instance has been finished already.",got="The direction ",pot=" is not supported by the CGraph instance.",bot="OneDimensionalCompactor",mot="OneDimensionalCompactor/lambda$0$Type",wot="Quadruplet",vot="ScanlineConstraintCalculator",yot="ScanlineConstraintCalculator/ConstraintsScanlineHandler",xot="ScanlineConstraintCalculator/ConstraintsScanlineHandler/lambda$0$Type",kot="ScanlineConstraintCalculator/Timestamp",Oot="ScanlineConstraintCalculator/lambda$0$Type",hd={181:1,48:1},tE="org.eclipse.elk.alg.common.networksimplex",eh={172:1,3:1,4:1},Sot="org.eclipse.elk.alg.common.nodespacing",xb="org.eclipse.elk.alg.common.nodespacing.cellsystem",WS="CENTER",jot={219:1,338:1},mxe={3:1,4:1,5:1,599:1},nk="LEFT",ik="RIGHT",wxe="Vertical alignment cannot be null",vxe="BOTTOM",XQ="org.eclipse.elk.alg.common.nodespacing.internal",nE="UNDEFINED",_h=.01,pL="org.eclipse.elk.alg.common.nodespacing.internal.algorithm",Tot="LabelPlacer/lambda$0$Type",Eot="LabelPlacer/lambda$1$Type",Cot="portRatioOrPosition",KS="org.eclipse.elk.alg.common.overlaps",vre="DOWN",rk="org.eclipse.elk.alg.common.spore",Tv={3:1,4:1,5:1,200:1},Mot={3:1,6:1,4:1,5:1,91:1,111:1},yre="org.eclipse.elk.alg.force",yxe="ComponentsProcessor",Aot="ComponentsProcessor/1",xxe="ElkGraphImporter/lambda$0$Type",kb={207:1},Ux="org.eclipse.elk.core",bL="org.eclipse.elk.graph.properties",Not="IPropertyHolder",mL="org.eclipse.elk.alg.force.graph",_ot="Component Layout",kxe="org.eclipse.elk.alg.force.model",Io="org.eclipse.elk.core.data",VQ="org.eclipse.elk.force.model",Oxe="org.eclipse.elk.force.iterations",Sxe="org.eclipse.elk.force.repulsivePower",xre="org.eclipse.elk.force.temperature",dd=.001,kre="org.eclipse.elk.force.repulsion",jf={139:1},iE="org.eclipse.elk.alg.force.options",YS=1.600000023841858,il="org.eclipse.elk.force",wL="org.eclipse.elk.priority",dw="org.eclipse.elk.spacing.nodeNode",Ore="org.eclipse.elk.spacing.edgeLabel",ZS="org.eclipse.elk.aspectRatio",WQ="org.eclipse.elk.randomSeed",rE="org.eclipse.elk.separateConnectedComponents",gw="org.eclipse.elk.padding",e9="org.eclipse.elk.interactive",KQ="org.eclipse.elk.portConstraints",vL="org.eclipse.elk.edgeLabels.inline",t9="org.eclipse.elk.omitNodeMicroLayout",n9="org.eclipse.elk.nodeSize.fixedGraphSize",sk="org.eclipse.elk.nodeSize.options",Jx="org.eclipse.elk.nodeSize.constraints",i9="org.eclipse.elk.nodeLabels.placement",r9="org.eclipse.elk.portLabels.placement",yL="org.eclipse.elk.topdownLayout",xL="org.eclipse.elk.topdown.scaleFactor",kL="org.eclipse.elk.topdown.hierarchicalNodeWidth",OL="org.eclipse.elk.topdown.hierarchicalNodeAspectRatio",pw="org.eclipse.elk.topdown.nodeType",jxe="origin",Dot="random",Lot="boundingBox.upLeft",Pot="boundingBox.lowRight",Txe="org.eclipse.elk.stress.fixed",Exe="org.eclipse.elk.stress.desiredEdgeLength",Cxe="org.eclipse.elk.stress.dimension",Mxe="org.eclipse.elk.stress.epsilon",Axe="org.eclipse.elk.stress.iterationLimit",U0="org.eclipse.elk.stress",Iot="ELK Stress",ok="org.eclipse.elk.nodeSize.minimum",YQ="org.eclipse.elk.alg.force.stress",Rot="Layered layout",ck="org.eclipse.elk.alg.layered",SL="org.eclipse.elk.alg.layered.compaction.components",sE="org.eclipse.elk.alg.layered.compaction.oned",ZQ="org.eclipse.elk.alg.layered.compaction.oned.algs",Ob="org.eclipse.elk.alg.layered.compaction.recthull",Dh="org.eclipse.elk.alg.layered.components",th="NONE",Sre="MODEL_ORDER",cc={3:1,6:1,4:1,10:1,5:1,128:1},$ot={3:1,6:1,4:1,5:1,137:1,91:1,111:1},eG="org.eclipse.elk.alg.layered.compound",Di={43:1},wc="org.eclipse.elk.alg.layered.graph",jre=" -> ",Bot="Not supported by LGraph",Nxe="Port side is undefined",s9={3:1,6:1,4:1,5:1,324:1,137:1,91:1,111:1},Hg={3:1,6:1,4:1,5:1,137:1,201:1,212:1,91:1,111:1},zot={3:1,6:1,4:1,5:1,137:1,2021:1,212:1,91:1,111:1},Fot=`([{"' 	\r
`,qot=`)]}"' 	\r
`,Hot="The given string contains parts that cannot be parsed as numbers.",jL="org.eclipse.elk.core.math",Qot={3:1,4:1,125:1,216:1,419:1},Got={3:1,4:1,100:1,216:1,419:1},Qg="org.eclipse.elk.alg.layered.graph.transform",Uot="ElkGraphImporter",Jot="ElkGraphImporter/lambda$1$Type",Xot="ElkGraphImporter/lambda$2$Type",Vot="ElkGraphImporter/lambda$4$Type",tn="org.eclipse.elk.alg.layered.intermediate",Wot="Node margin calculation",Kot="ONE_SIDED_GREEDY_SWITCH",Yot="TWO_SIDED_GREEDY_SWITCH",Tre="No implementation is available for the layout processor ",Ere="IntermediateProcessorStrategy",Cre="Node '",Zot="FIRST_SEPARATE",ect="LAST_SEPARATE",tct="Odd port side processing",xr="org.eclipse.elk.alg.layered.intermediate.compaction",oE="org.eclipse.elk.alg.layered.intermediate.greedyswitch",Kd="org.eclipse.elk.alg.layered.p3order.counting",cE={223:1},lk="org.eclipse.elk.alg.layered.intermediate.loops",Uu="org.eclipse.elk.alg.layered.intermediate.loops.ordering",J0="org.eclipse.elk.alg.layered.intermediate.loops.routing",tG="org.eclipse.elk.alg.layered.intermediate.preserveorder",gd="org.eclipse.elk.alg.layered.intermediate.wrapping",Xo="org.eclipse.elk.alg.layered.options",Mre="INTERACTIVE",_xe="GREEDY",nct="DEPTH_FIRST",ict="EDGE_LENGTH",rct="SELF_LOOPS",sct="firstTryWithInitialOrder",Dxe="org.eclipse.elk.layered.directionCongruency",Lxe="org.eclipse.elk.layered.feedbackEdges",nG="org.eclipse.elk.layered.interactiveReferencePoint",Pxe="org.eclipse.elk.layered.mergeEdges",Ixe="org.eclipse.elk.layered.mergeHierarchyEdges",Rxe="org.eclipse.elk.layered.allowNonFlowPortsToSwitchSides",$xe="org.eclipse.elk.layered.portSortingStrategy",Bxe="org.eclipse.elk.layered.thoroughness",zxe="org.eclipse.elk.layered.unnecessaryBendpoints",Fxe="org.eclipse.elk.layered.generatePositionAndLayerIds",TL="org.eclipse.elk.layered.cycleBreaking.strategy",EL="org.eclipse.elk.layered.layering.strategy",qxe="org.eclipse.elk.layered.layering.layerConstraint",Hxe="org.eclipse.elk.layered.layering.layerChoiceConstraint",Qxe="org.eclipse.elk.layered.layering.layerId",Are="org.eclipse.elk.layered.layering.minWidth.upperBoundOnWidth",Nre="org.eclipse.elk.layered.layering.minWidth.upperLayerEstimationScalingFactor",_re="org.eclipse.elk.layered.layering.nodePromotion.strategy",Dre="org.eclipse.elk.layered.layering.nodePromotion.maxIterations",Lre="org.eclipse.elk.layered.layering.coffmanGraham.layerBound",lE="org.eclipse.elk.layered.crossingMinimization.strategy",Gxe="org.eclipse.elk.layered.crossingMinimization.forceNodeModelOrder",Pre="org.eclipse.elk.layered.crossingMinimization.hierarchicalSweepiness",Ire="org.eclipse.elk.layered.crossingMinimization.semiInteractive",Uxe="org.eclipse.elk.layered.crossingMinimization.inLayerPredOf",Jxe="org.eclipse.elk.layered.crossingMinimization.inLayerSuccOf",Xxe="org.eclipse.elk.layered.crossingMinimization.positionChoiceConstraint",Vxe="org.eclipse.elk.layered.crossingMinimization.positionId",Wxe="org.eclipse.elk.layered.crossingMinimization.greedySwitch.activationThreshold",Rre="org.eclipse.elk.layered.crossingMinimization.greedySwitch.type",iG="org.eclipse.elk.layered.crossingMinimization.greedySwitchHierarchical.type",Xx="org.eclipse.elk.layered.nodePlacement.strategy",rG="org.eclipse.elk.layered.nodePlacement.favorStraightEdges",$re="org.eclipse.elk.layered.nodePlacement.bk.edgeStraightening",Bre="org.eclipse.elk.layered.nodePlacement.bk.fixedAlignment",zre="org.eclipse.elk.layered.nodePlacement.linearSegments.deflectionDampening",Fre="org.eclipse.elk.layered.nodePlacement.networkSimplex.nodeFlexibility",qre="org.eclipse.elk.layered.nodePlacement.networkSimplex.nodeFlexibility.default",Kxe="org.eclipse.elk.layered.edgeRouting.selfLoopDistribution",Yxe="org.eclipse.elk.layered.edgeRouting.selfLoopOrdering",sG="org.eclipse.elk.layered.edgeRouting.splines.mode",oG="org.eclipse.elk.layered.edgeRouting.splines.sloppy.layerSpacingFactor",Hre="org.eclipse.elk.layered.edgeRouting.polyline.slopedEdgeZoneWidth",Zxe="org.eclipse.elk.layered.spacing.baseValue",e3e="org.eclipse.elk.layered.spacing.edgeNodeBetweenLayers",t3e="org.eclipse.elk.layered.spacing.edgeEdgeBetweenLayers",n3e="org.eclipse.elk.layered.spacing.nodeNodeBetweenLayers",i3e="org.eclipse.elk.layered.priority.direction",r3e="org.eclipse.elk.layered.priority.shortness",s3e="org.eclipse.elk.layered.priority.straightness",Qre="org.eclipse.elk.layered.compaction.connectedComponents",o3e="org.eclipse.elk.layered.compaction.postCompaction.strategy",c3e="org.eclipse.elk.layered.compaction.postCompaction.constraints",cG="org.eclipse.elk.layered.highDegreeNodes.treatment",Gre="org.eclipse.elk.layered.highDegreeNodes.threshold",Ure="org.eclipse.elk.layered.highDegreeNodes.treeHeight",G1="org.eclipse.elk.layered.wrapping.strategy",lG="org.eclipse.elk.layered.wrapping.additionalEdgeSpacing",uG="org.eclipse.elk.layered.wrapping.correctionFactor",uE="org.eclipse.elk.layered.wrapping.cutting.strategy",Jre="org.eclipse.elk.layered.wrapping.cutting.cuts",Xre="org.eclipse.elk.layered.wrapping.cutting.msd.freedom",aG="org.eclipse.elk.layered.wrapping.validify.strategy",fG="org.eclipse.elk.layered.wrapping.validify.forbiddenIndices",hG="org.eclipse.elk.layered.wrapping.multiEdge.improveCuts",dG="org.eclipse.elk.layered.wrapping.multiEdge.distancePenalty",Vre="org.eclipse.elk.layered.wrapping.multiEdge.improveWrappedEdges",Wre="org.eclipse.elk.layered.layerUnzipping.strategy",Kre="org.eclipse.elk.layered.layerUnzipping.minimizeEdgeLength",Yre="org.eclipse.elk.layered.layerUnzipping.layerSplit",Zre="org.eclipse.elk.layered.layerUnzipping.resetOnLongEdges",l3e="org.eclipse.elk.layered.edgeLabels.sideSelection",u3e="org.eclipse.elk.layered.edgeLabels.centerLabelPlacementStrategy",gG="org.eclipse.elk.layered.considerModelOrder.strategy",a3e="org.eclipse.elk.layered.considerModelOrder.portModelOrder",CL="org.eclipse.elk.layered.considerModelOrder.noModelOrder",ese="org.eclipse.elk.layered.considerModelOrder.components",f3e="org.eclipse.elk.layered.considerModelOrder.longEdgeStrategy",tse="org.eclipse.elk.layered.considerModelOrder.crossingCounterNodeInfluence",nse="org.eclipse.elk.layered.considerModelOrder.crossingCounterPortInfluence",ise="org.eclipse.elk.layered.considerModelOrder.groupModelOrder.cycleBreakingId",rse="org.eclipse.elk.layered.considerModelOrder.groupModelOrder.crossingMinimizationId",sse="org.eclipse.elk.layered.considerModelOrder.groupModelOrder.componentGroupId",h3e="org.eclipse.elk.layered.considerModelOrder.groupModelOrder.cbGroupOrderStrategy",ose="org.eclipse.elk.layered.considerModelOrder.groupModelOrder.cbPreferredSourceId",cse="org.eclipse.elk.layered.considerModelOrder.groupModelOrder.cbPreferredTargetId",d3e="org.eclipse.elk.layered.considerModelOrder.groupModelOrder.cmGroupOrderStrategy",g3e="org.eclipse.elk.layered.considerModelOrder.groupModelOrder.cmEnforcedGroupOrders",lse="layering",oct="layering.minWidth",cct="layering.nodePromotion",o9="crossingMinimization",pG="org.eclipse.elk.hierarchyHandling",lct="crossingMinimization.greedySwitch",uct="nodePlacement",act="nodePlacement.bk",fct="edgeRouting",ML="org.eclipse.elk.edgeRouting",Lh="spacing",p3e="priority",b3e="compaction",hct="compaction.postCompaction",dct="Specifies whether and how post-process compaction is applied.",m3e="highDegreeNodes",w3e="wrapping",gct="wrapping.cutting",pct="wrapping.validify",v3e="wrapping.multiEdge",use="layerUnzipping",ase="edgeLabels",aE="considerModelOrder",c9="considerModelOrder.groupModelOrder",y3e="Group ID of the Node Type",x3e="org.eclipse.elk.spacing.commentComment",k3e="org.eclipse.elk.spacing.commentNode",O3e="org.eclipse.elk.spacing.componentComponent",S3e="org.eclipse.elk.spacing.edgeEdge",fse="org.eclipse.elk.spacing.edgeNode",j3e="org.eclipse.elk.spacing.labelLabel",T3e="org.eclipse.elk.spacing.labelPortHorizontal",E3e="org.eclipse.elk.spacing.labelPortVertical",C3e="org.eclipse.elk.spacing.labelNode",M3e="org.eclipse.elk.spacing.nodeSelfLoop",A3e="org.eclipse.elk.spacing.portPort",N3e="org.eclipse.elk.spacing.individual",_3e="org.eclipse.elk.port.borderOffset",D3e="org.eclipse.elk.noLayout",L3e="org.eclipse.elk.port.side",AL="org.eclipse.elk.debugMode",P3e="org.eclipse.elk.alignment",I3e="org.eclipse.elk.insideSelfLoops.activate",R3e="org.eclipse.elk.insideSelfLoops.yo",hse="org.eclipse.elk.direction",$3e="org.eclipse.elk.nodeLabels.padding",B3e="org.eclipse.elk.portLabels.nextToPortIfPossible",z3e="org.eclipse.elk.portLabels.treatAsGroup",F3e="org.eclipse.elk.portAlignment.default",q3e="org.eclipse.elk.portAlignment.north",H3e="org.eclipse.elk.portAlignment.south",Q3e="org.eclipse.elk.portAlignment.west",G3e="org.eclipse.elk.portAlignment.east",bG="org.eclipse.elk.contentAlignment",U3e="org.eclipse.elk.junctionPoints",J3e="org.eclipse.elk.edge.thickness",X3e="org.eclipse.elk.edgeLabels.placement",V3e="org.eclipse.elk.port.index",W3e="org.eclipse.elk.commentBox",K3e="org.eclipse.elk.hypernode",Y3e="org.eclipse.elk.port.anchor",dse="org.eclipse.elk.partitioning.activate",gse="org.eclipse.elk.partitioning.partition",mG="org.eclipse.elk.position",pse="org.eclipse.elk.margins",Z3e="org.eclipse.elk.spacing.portsSurrounding",wG="org.eclipse.elk.interactiveLayout",tc="org.eclipse.elk.core.util",e4e={3:1,4:1,5:1,597:1},bct="NETWORK_SIMPLEX",t4e="SIMPLE",bse="No implementation is available for the node placer ",Xr={86:1,43:1},bw="org.eclipse.elk.alg.layered.p1cycles",mct="Depth-first cycle removal",wct="Model order cycle breaking",U1="org.eclipse.elk.alg.layered.p2layers",n4e={411:1,223:1},vct={838:1,3:1,4:1},rl="org.eclipse.elk.alg.layered.p3order",Vx=17976931348623157e292,mse=5e-324,Xs="org.eclipse.elk.alg.layered.p4nodes",yct={3:1,4:1,5:1,846:1},pd=1e-5,X0="org.eclipse.elk.alg.layered.p4nodes.bk",wse="org.eclipse.elk.alg.layered.p5edges",nh="org.eclipse.elk.alg.layered.p5edges.orthogonal",vse="org.eclipse.elk.alg.layered.p5edges.orthogonal.direction",yse=1e-6,Ev="org.eclipse.elk.alg.layered.p5edges.splines",xse=.09999999999999998,vG=1e-8,xct=4.71238898038469,kct=1.5707963267948966,i4e=3.141592653589793,J1="org.eclipse.elk.alg.mrtree",Oct="Tree layout",Sct="P4_EDGE_ROUTING",kse=.10000000149011612,yG="SUPER_ROOT",fE="org.eclipse.elk.alg.mrtree.graph",r4e=-17976931348623157e292,_c="org.eclipse.elk.alg.mrtree.intermediate",jct="Processor compute fanout",xG={3:1,6:1,4:1,5:1,526:1,91:1,111:1},Tct="Set neighbors in level",NL="org.eclipse.elk.alg.mrtree.options",Ect="DESCENDANTS",s4e="org.eclipse.elk.mrtree.compaction",o4e="org.eclipse.elk.mrtree.edgeEndTextureLength",c4e="org.eclipse.elk.mrtree.treeLevel",l4e="org.eclipse.elk.mrtree.positionConstraint",u4e="org.eclipse.elk.mrtree.weighting",a4e="org.eclipse.elk.mrtree.edgeRoutingMode",f4e="org.eclipse.elk.mrtree.searchOrder",Cct="Position Constraint",sl="org.eclipse.elk.mrtree",h4e="org.eclipse.elk.tree",Mct="Processor arrange level",l9="org.eclipse.elk.alg.mrtree.p2order",Au="org.eclipse.elk.alg.mrtree.p4route",d4e="org.eclipse.elk.alg.radial",Act="The given graph is not a tree!",Sb=6.283185307179586,g4e="Before",kG="After",p4e="org.eclipse.elk.alg.radial.intermediate",Nct="COMPACTION",Ose="org.eclipse.elk.alg.radial.intermediate.compaction",_ct={3:1,4:1,5:1,91:1},b4e="org.eclipse.elk.alg.radial.intermediate.optimization",Sse="No implementation is available for the layout option ",hE="org.eclipse.elk.alg.radial.options",Dct="CompactionStrategy",m4e="org.eclipse.elk.radial.centerOnRoot",w4e="org.eclipse.elk.radial.orderId",v4e="org.eclipse.elk.radial.radius",OG="org.eclipse.elk.radial.rotate",jse="org.eclipse.elk.radial.compactor",Tse="org.eclipse.elk.radial.compactionStepSize",y4e="org.eclipse.elk.radial.sorter",x4e="org.eclipse.elk.radial.wedgeCriteria",k4e="org.eclipse.elk.radial.optimizationCriteria",Ese="org.eclipse.elk.radial.rotation.targetAngle",Cse="org.eclipse.elk.radial.rotation.computeAdditionalWedgeSpace",O4e="org.eclipse.elk.radial.rotation.outgoingEdgeAngles",Lct="Compaction",S4e="rotation",Oa="org.eclipse.elk.radial",Pct="org.eclipse.elk.alg.radial.p1position.wedge",j4e="org.eclipse.elk.alg.radial.sorting",Ict=5.497787143782138,Rct=3.9269908169872414,$ct=2.356194490192345,Bct="org.eclipse.elk.alg.rectpacking",dE="org.eclipse.elk.alg.rectpacking.intermediate",Mse="org.eclipse.elk.alg.rectpacking.options",T4e="org.eclipse.elk.rectpacking.trybox",E4e="org.eclipse.elk.rectpacking.currentPosition",C4e="org.eclipse.elk.rectpacking.desiredPosition",M4e="org.eclipse.elk.rectpacking.inNewRow",A4e="org.eclipse.elk.rectpacking.orderBySize",N4e="org.eclipse.elk.rectpacking.widthApproximation.strategy",_4e="org.eclipse.elk.rectpacking.widthApproximation.targetWidth",D4e="org.eclipse.elk.rectpacking.widthApproximation.optimizationGoal",L4e="org.eclipse.elk.rectpacking.widthApproximation.lastPlaceShift",P4e="org.eclipse.elk.rectpacking.packing.strategy",I4e="org.eclipse.elk.rectpacking.packing.compaction.rowHeightReevaluation",R4e="org.eclipse.elk.rectpacking.packing.compaction.iterations",$4e="org.eclipse.elk.rectpacking.whiteSpaceElimination.strategy",Ase="widthApproximation",zct="Compaction Strategy",Fct="packing.compaction",Gl="org.eclipse.elk.rectpacking",u9="org.eclipse.elk.alg.rectpacking.p1widthapproximation",SG="org.eclipse.elk.alg.rectpacking.p2packing",qct="No Compaction",B4e="org.eclipse.elk.alg.rectpacking.p3whitespaceelimination",_L="org.eclipse.elk.alg.rectpacking.util",jG="No implementation available for ",Cv="org.eclipse.elk.alg.spore",Mv="org.eclipse.elk.alg.spore.options",mw="org.eclipse.elk.sporeCompaction",Nse="org.eclipse.elk.underlyingLayoutAlgorithm",z4e="org.eclipse.elk.processingOrder.treeConstruction",F4e="org.eclipse.elk.processingOrder.spanningTreeCostFunction",_se="org.eclipse.elk.processingOrder.preferredRoot",Dse="org.eclipse.elk.processingOrder.rootSelection",Lse="org.eclipse.elk.structure.structureExtractionStrategy",q4e="org.eclipse.elk.compaction.compactionStrategy",H4e="org.eclipse.elk.compaction.orthogonal",Q4e="org.eclipse.elk.overlapRemoval.maxIterations",G4e="org.eclipse.elk.overlapRemoval.runScanline",Pse="processingOrder",Hct="overlapRemoval",a9="org.eclipse.elk.sporeOverlap",Qct="org.eclipse.elk.alg.spore.p1structure",Ise="org.eclipse.elk.alg.spore.p2processingorder",Rse="org.eclipse.elk.alg.spore.p3execution",U4e="org.eclipse.elk.alg.vertiflex",J4e="org.eclipse.elk.vertiflex.verticalConstraint",X4e="org.eclipse.elk.vertiflex.layoutStrategy",V4e="org.eclipse.elk.vertiflex.layerDistance",W4e="org.eclipse.elk.vertiflex.considerNodeModelOrder",K4e="org.eclipse.elk.alg.vertiflex.options",ww="org.eclipse.elk.vertiflex",Gct="org.eclipse.elk.alg.vertiflex.p1yplacement",$se="org.eclipse.elk.alg.vertiflex.p2relative",Uct="org.eclipse.elk.alg.vertiflex.p3absolute",Jct="BendEdgeRouter",Y4e="org.eclipse.elk.alg.vertiflex.p4edgerouting",Xct="StraightEdgeRouter",Vct="Topdown Layout",Wct="Invalid index: ",f9="org.eclipse.elk.core.alg",Wx={343:1},Av={297:1},Kct="Make sure its type is registered with the ",Z4e=" utility class.",h9="true",Bse="false",Yct="Couldn't clone property '",vw=.05,Xc="org.eclipse.elk.core.options",Zct=1.2999999523162842,yw="org.eclipse.elk.box",e5e="org.eclipse.elk.expandNodes",t5e="org.eclipse.elk.box.packingMode",elt="org.eclipse.elk.algorithm",tlt="org.eclipse.elk.resolvedAlgorithm",n5e="org.eclipse.elk.bendPoints",Ntn="org.eclipse.elk.labelManager",nlt="org.eclipse.elk.softwrappingFuzziness",ilt="org.eclipse.elk.scaleFactor",rlt="org.eclipse.elk.childAreaWidth",slt="org.eclipse.elk.childAreaHeight",olt="org.eclipse.elk.animate",clt="org.eclipse.elk.animTimeFactor",llt="org.eclipse.elk.layoutAncestors",ult="org.eclipse.elk.maxAnimTime",alt="org.eclipse.elk.minAnimTime",flt="org.eclipse.elk.progressBar",hlt="org.eclipse.elk.validateGraph",dlt="org.eclipse.elk.validateOptions",glt="org.eclipse.elk.zoomToFit",plt="org.eclipse.elk.json.shapeCoords",blt="org.eclipse.elk.json.edgeCoords",_tn="org.eclipse.elk.font.name",mlt="org.eclipse.elk.font.size",zse="org.eclipse.elk.topdown.sizeCategories",i5e="org.eclipse.elk.topdown.sizeCategoriesHierarchicalNodeWeight",Fse="org.eclipse.elk.topdown.sizeApproximator",r5e="org.eclipse.elk.topdown.scaleCap",wlt="org.eclipse.elk.edge.type",vlt="partitioning",ylt="nodeLabels",TG="portAlignment",qse="nodeSize",Hse="port",s5e="portLabels",d9="topdown",xlt="insideSelfLoops",o5e="INHERIT",g9="org.eclipse.elk.fixed",EG="org.eclipse.elk.random",CG={3:1,34:1,23:1,525:1,290:1},klt="port must have a parent node to calculate the port side",Olt="The edge needs to have exactly one edge section. Found: ",gE="org.eclipse.elk.core.util.adapters",Sa="org.eclipse.emf.ecore",Kx="org.eclipse.elk.graph",Slt="EMapPropertyHolder",jlt="ElkBendPoint",Tlt="ElkGraphElement",Elt="ElkConnectableShape",c5e="ElkEdge",Clt="ElkEdgeSection",Mlt="EModelElement",Alt="ENamedElement",l5e="ElkLabel",u5e="ElkNode",a5e="ElkPort",Nlt={95:1,94:1},uk="org.eclipse.emf.common.notify.impl",V0="The feature '",pE="' is not a valid changeable feature",_lt="Expecting null",Qse="' is not a valid feature",Dlt="The feature ID",Llt=" is not a valid feature ID",nc=32768,Plt={110:1,95:1,94:1,57:1,52:1,101:1},Xt="org.eclipse.emf.ecore.impl",jb="org.eclipse.elk.graph.impl",bE="Recursive containment not allowed for ",p9="The datatype '",xw="' is not a valid classifier",Gse="The value '",Yx={198:1,3:1,4:1},Use="The class '",b9="http://www.eclipse.org/elk/ElkGraph",f5e="property",mE="value",Jse="source",Ilt="properties",Rlt="identifier",Xse="height",Vse="width",Wse="parent",Kse="text",Yse="children",$lt="hierarchical",h5e="sources",Zse="targets",eoe="sections",MG="bendPoints",d5e="outgoingShape",g5e="incomingShape",p5e="outgoingSections",b5e="incomingSections",_s="org.eclipse.emf.common.util",m5e="Severe implementation error in the Json to ElkGraph importer.",bd="id",hs="org.eclipse.elk.graph.json",m9="Unhandled parameter types: ",Blt="startPoint",zlt="An edge must have at least one source and one target (edge id: '",w9="').",Flt="Referenced edge section does not exist: ",qlt=" (edge id: '",w5e="target",Hlt="sourcePoint",Qlt="targetPoint",AG="group",hi="name",Glt="connectableShape cannot be null",Ult="edge cannot be null",Jlt="Passed edge is not 'simple'.",NG="org.eclipse.elk.graph.util",DL="The 'no duplicates' constraint is violated",toe="targetIndex=",Tb=", size=",noe="sourceIndex=",md={3:1,4:1,22:1,32:1,56:1,18:1,16:1,59:1,71:1,67:1,61:1},ioe={3:1,4:1,22:1,32:1,56:1,18:1,51:1,16:1,59:1,71:1,67:1,61:1,592:1},_G="logging",Xlt="measureExecutionTime",Vlt="parser.parse.1",Wlt="parser.parse.2",DG="parser.next.1",roe="parser.next.2",Klt="parser.next.3",Ylt="parser.next.4",Eb="parser.factor.1",v5e="parser.factor.2",Zlt="parser.factor.3",eut="parser.factor.4",tut="parser.factor.5",nut="parser.factor.6",iut="parser.atom.1",rut="parser.atom.2",sut="parser.atom.3",y5e="parser.atom.4",soe="parser.atom.5",x5e="parser.cc.1",LG="parser.cc.2",out="parser.cc.3",cut="parser.cc.5",k5e="parser.cc.6",O5e="parser.cc.7",ooe="parser.cc.8",lut="parser.ope.1",uut="parser.ope.2",aut="parser.ope.3",Gg="parser.descape.1",fut="parser.descape.2",hut="parser.descape.3",dut="parser.descape.4",gut="parser.descape.5",ja="parser.process.1",put="parser.quantifier.1",but="parser.quantifier.2",mut="parser.quantifier.3",wut="parser.quantifier.4",S5e="parser.quantifier.5",vut="org.eclipse.emf.common.notify",j5e={420:1,683:1},yut={3:1,4:1,22:1,32:1,56:1,18:1,16:1,71:1,61:1},LL={374:1,152:1},wE="index=",coe={3:1,4:1,5:1,131:1},xut={3:1,4:1,22:1,32:1,56:1,18:1,16:1,59:1,71:1,61:1},T5e={3:1,6:1,4:1,5:1,200:1},kut={3:1,4:1,5:1,178:1,375:1},Out=";/?:@&=+$,",Sut="invalid authority: ",jut="EAnnotation",Tut="ETypedElement",Eut="EStructuralFeature",Cut="EAttribute",Mut="EClassifier",Aut="EEnumLiteral",Nut="EGenericType",_ut="EOperation",Dut="EParameter",Lut="EReference",Put="ETypeParameter",Gi="org.eclipse.emf.ecore.util",loe={78:1},E5e={3:1,22:1,18:1,16:1,61:1,593:1,78:1,72:1,98:1},Iut="org.eclipse.emf.ecore.util.FeatureMap$Entry",Pl=8192,vE="byte",PG="char",yE="double",xE="float",kE="int",OE="long",SE="short",Rut="java.lang.Object",Zx={3:1,4:1,5:1,258:1},C5e={3:1,4:1,5:1,685:1},$ut={3:1,4:1,22:1,32:1,56:1,18:1,16:1,59:1,71:1,67:1,61:1,72:1},To={3:1,4:1,22:1,32:1,56:1,18:1,16:1,59:1,71:1,67:1,61:1,78:1,72:1,98:1},PL="mixed",Kn="http:///org/eclipse/emf/ecore/util/ExtendedMetaData",Ua="kind",But={3:1,4:1,5:1,686:1},M5e={3:1,4:1,22:1,32:1,56:1,18:1,16:1,71:1,61:1,78:1,72:1,98:1},IG={22:1,32:1,56:1,18:1,16:1,61:1,72:1},RG={51:1,130:1,289:1},$G={76:1,345:1},BG="The value of type '",zG="' must be of type '",e3=1318,Ja="http://www.eclipse.org/emf/2002/Ecore",FG=-32768,kw="constraints",ys="baseType",zut="getEStructuralFeature",Fut="getFeatureID",jE="feature",qut="getOperationID",A5e="operation",Hut="defaultValue",Qut="eTypeParameters",Gut="isInstance",Uut="getEEnumLiteral",Jut="eContainingClass",ui={58:1},Xut={3:1,4:1,5:1,123:1},Vut="org.eclipse.emf.ecore.resource",Wut={95:1,94:1,595:1,2013:1},uoe="org.eclipse.emf.ecore.resource.impl",N5e="unspecified",IL="simple",qG="attribute",Kut="attributeWildcard",HG="element",aoe="elementWildcard",ih="collapse",foe="itemType",QG="namespace",RL="##targetNamespace",Xa="whiteSpace",_5e="wildcards",Cb="http://www.eclipse.org/emf/2003/XMLType",hoe="##any",v9="uninitialized",$L="The multiplicity constraint is violated",GG="org.eclipse.emf.ecore.xml.type",Yut="ProcessingInstruction",Zut="SimpleAnyType",eat="XMLTypeDocumentRoot",Dr="org.eclipse.emf.ecore.xml.type.impl",BL="INF",tat="processing",nat="ENTITIES_._base",D5e="minLength",L5e="ENTITY",UG="NCName",iat="IDREFS_._base",P5e="integer",doe="token",goe="pattern",rat="[a-zA-Z]{1,8}(-[a-zA-Z0-9]{1,8})*",I5e="\\i\\c*",sat="[\\i-[:]][\\c-[:]]*",oat="nonPositiveInteger",zL="maxInclusive",R5e="NMTOKEN",cat="NMTOKENS_._base",$5e="nonNegativeInteger",FL="minInclusive",lat="normalizedString",uat="unsignedByte",aat="unsignedInt",fat="18446744073709551615",hat="unsignedShort",dat="processingInstruction",Ug="org.eclipse.emf.ecore.xml.type.internal",y9=1114111,gat="Internal Error: shorthands: \\u",TE="xml:isDigit",poe="xml:isWord",boe="xml:isSpace",moe="xml:isNameChar",woe="xml:isInitialNameChar",pat="09٠٩۰۹०९০৯੦੯૦૯୦୯௧௯౦౯೦೯൦൯๐๙໐໙༠༩",bat="AZazÀÖØöøıĴľŁňŊžƀǃǍǰǴǵǺȗɐʨʻˁΆΆΈΊΌΌΎΡΣώϐϖϚϚϜϜϞϞϠϠϢϳЁЌЎяёќўҁҐӄӇӈӋӌӐӫӮӵӸӹԱՖՙՙաֆאתװײءغفيٱڷںھۀێېۓەەۥۦअहऽऽक़ॡঅঌএঐওনপরললশহড়ঢ়য়ৡৰৱਅਊਏਐਓਨਪਰਲਲ਼ਵਸ਼ਸਹਖ਼ੜਫ਼ਫ਼ੲੴઅઋઍઍએઑઓનપરલળવહઽઽૠૠଅଌଏଐଓନପରଲଳଶହଽଽଡ଼ଢ଼ୟୡஅஊஎஐஒகஙசஜஜஞடணதநபமவஷஹఅఌఎఐఒనపళవహౠౡಅಌಎಐಒನಪಳವಹೞೞೠೡഅഌഎഐഒനപഹൠൡกฮะะาำเๅກຂຄຄງຈຊຊຍຍດທນຟມຣລລວວສຫອຮະະາຳຽຽເໄཀཇཉཀྵႠჅაჶᄀᄀᄂᄃᄅᄇᄉᄉᄋᄌᄎᄒᄼᄼᄾᄾᅀᅀᅌᅌᅎᅎᅐᅐᅔᅕᅙᅙᅟᅡᅣᅣᅥᅥᅧᅧᅩᅩᅭᅮᅲᅳᅵᅵᆞᆞᆨᆨᆫᆫᆮᆯᆷᆸᆺᆺᆼᇂᇫᇫᇰᇰᇹᇹḀẛẠỹἀἕἘἝἠὅὈὍὐὗὙὙὛὛὝὝὟώᾀᾴᾶᾼιιῂῄῆῌῐΐῖΊῠῬῲῴῶῼΩΩKÅ℮℮ↀↂ〇〇〡〩ぁゔァヺㄅㄬ一龥가힣",mat="Private Use",voe="ASSIGNED",yoe="\0ÿĀſƀɏɐʯʰ˿̀ͯͰϿЀӿ԰֏֐׿؀ۿ܀ݏހ޿ऀॿঀ৿਀੿઀૿଀୿஀௿ఀ౿ಀ೿ഀൿ඀෿฀๿຀໿ༀ࿿က႟Ⴀჿᄀᇿሀ፿Ꭰ᏿᐀ᙿ ᚟ᚠ᛿ក៿᠀᢯Ḁỿἀ῿ ⁯⁰₟₠⃏⃐⃿℀⅏⅐↏←⇿∀⋿⌀⏿␀␿⑀⑟①⓿─╿▀▟■◿☀⛿✀➿⠀⣿⺀⻿⼀⿟⿰⿿　〿぀ゟ゠ヿ㄀ㄯ㄰㆏㆐㆟ㆠㆿ㈀㋿㌀㏿㐀䶵一鿿ꀀ꒏꒐꓏가힣豈﫿ﬀﭏﭐ﷿︠︯︰﹏﹐﹯ﹰ﻾\uFEFF\uFEFF＀￯",B5e="UNASSIGNED",x9={3:1,122:1},wat="org.eclipse.emf.ecore.xml.type.util",JG={3:1,4:1,5:1,377:1},z5e="org.eclipse.xtext.xbase.lib",vat="Cannot add elements to a Range",yat="Cannot set elements in a Range",xat="Cannot remove elements from a Range",kat="user.agent",f,XG,xoe;p.goog=p.goog||{},p.goog.global=p.goog.global||p,XG={},T(1,null,{},j),f.Fb=function(t){return v$e(this,t)},f.Gb=function(){return this.Pm},f.Hb=function(){return Lm(this)},f.Ib=function(){var t;return qp(ju(this))+"@"+(t=Ri(this)>>>0,t.toString(16))},f.equals=function(e){return this.Fb(e)},f.hashCode=function(){return this.Hb()},f.toString=function(){return this.Ib()};var Oat,Sat,jat;T(299,1,{299:1,2103:1},Dme),f.te=function(t){var n;return n=new Dme,n.i=4,t>1?n.c=WHe(this,t-1):n.c=this,n},f.ue=function(){return j1(this),this.b},f.ve=function(){return qp(this)},f.we=function(){return j1(this),this.k},f.xe=function(){return(this.i&4)!=0},f.ye=function(){return(this.i&1)!=0},f.Ib=function(){return Hbe(this)},f.i=0;var Br=C(Jo,"Object",1),F5e=C(Jo,"Class",299);T(2075,1,rL),C(sL,"Optional",2075),T(1172,2075,rL,A),f.Fb=function(t){return t===this},f.Hb=function(){return 2040732332},f.Ib=function(){return"Optional.absent()"},f.Jb=function(t){return Rn(t),Kj(),koe};var koe;C(sL,"Absent",1172),T(634,1,{},nY),C(sL,"Joiner",634);var Dtn=Ki(sL,"Predicate");T(584,1,{181:1,584:1,3:1,48:1},mK),f.Mb=function(t){return ZVe(this,t)},f.Lb=function(t){return ZVe(this,t)},f.Fb=function(t){var n;return oe(t,584)?(n=c(t,584),Mve(this.a,n.a)):!1},f.Hb=function(){return $me(this.a)+306654252},f.Ib=function(){return EQt(this.a)},C(sL,"Predicates/AndPredicate",584),T(416,2075,{416:1,3:1},Rj),f.Fb=function(t){var n;return oe(t,416)?(n=c(t,416),yi(this.a,n.a)):!1},f.Hb=function(){return 1502476572+Ri(this.a)},f.Ib=function(){return Bst+this.a+")"},f.Jb=function(t){return new Rj(pq(t.Kb(this.a),"the Function passed to Optional.transform() must not return null."))},C(sL,"Present",416),T(206,1,qS),f.Nb=function(t){gs(this,t)},f.Qb=function(){cPe()},C(xt,"UnmodifiableIterator",206),T(2055,206,HS),f.Qb=function(){cPe()},f.Rb=function(t){throw J(new $n)},f.Wb=function(t){throw J(new $n)},C(xt,"UnmodifiableListIterator",2055),T(394,2055,HS),f.Ob=function(){return this.b<this.c},f.Sb=function(){return this.b>0},f.Pb=function(){if(this.b>=this.c)throw J(new Co);return this.Xb(this.b++)},f.Tb=function(){return this.b},f.Ub=function(){if(this.b<=0)throw J(new Co);return this.Xb(--this.b)},f.Vb=function(){return this.b-1},f.b=0,f.c=0,C(xt,"AbstractIndexedListIterator",394),T(709,206,qS),f.Ob=function(){return cte(this)},f.Pb=function(){return Rbe(this)},f.e=1,C(xt,"AbstractIterator",709),T(2063,1,{231:1}),f.Zb=function(){var t;return t=this.f,t||(this.f=this.ac())},f.Fb=function(t){return Mte(this,t)},f.Hb=function(){return Ri(this.Zb())},f.dc=function(){return this.gc()==0},f.ec=function(){return b5(this)},f.Ib=function(){return jo(this.Zb())},C(xt,"AbstractMultimap",2063),T(737,2063,vb),f.$b=function(){sH(this)},f._b=function(t){return OPe(this,t)},f.ac=function(){return new S6(this,this.c)},f.ic=function(t){return this.hc()},f.bc=function(){return new wx(this,this.c)},f.jc=function(){return this.mc(this.hc())},f.kc=function(){return new ULe(this)},f.lc=function(){return Rne(this.c.vc().Lc(),new I,64,this.d)},f.cc=function(t){return Si(this,t)},f.fc=function(t){return xD(this,t)},f.gc=function(){return this.d},f.mc=function(t){return Ct(),new f6(t)},f.nc=function(){return new GLe(this)},f.oc=function(){return Rne(this.c.Bc().Lc(),new _,64,this.d)},f.pc=function(t,n){return new Fq(this,t,n,null)},f.d=0,C(xt,"AbstractMapBasedMultimap",737),T(1678,737,vb),f.hc=function(){return new Hc(this.a)},f.jc=function(){return Ct(),Ct(),Rs},f.cc=function(t){return c(Si(this,t),16)},f.fc=function(t){return c(xD(this,t),16)},f.Zb=function(){return k5(this)},f.Fb=function(t){return Mte(this,t)},f.qc=function(t){return c(Si(this,t),16)},f.rc=function(t){return c(xD(this,t),16)},f.mc=function(t){return bq(c(t,16))},f.pc=function(t,n){return oGe(this,t,c(n,16),null)},C(xt,"AbstractListMultimap",1678),T(743,1,ts),f.Nb=function(t){gs(this,t)},f.Ob=function(){return this.c.Ob()||this.e.Ob()},f.Pb=function(){var t;return this.e.Ob()||(t=c(this.c.Pb(),45),this.b=t.jd(),this.a=c(t.kd(),18),this.e=this.a.Jc()),this.sc(this.b,this.e.Pb())},f.Qb=function(){this.e.Qb(),c(za(this.a),18).dc()&&this.c.Qb(),--this.d.d},C(xt,"AbstractMapBasedMultimap/Itr",743),T(1110,743,ts,GLe),f.sc=function(t,n){return n},C(xt,"AbstractMapBasedMultimap/1",1110),T(1111,1,{},_),f.Kb=function(t){return c(t,18).Lc()},C(xt,"AbstractMapBasedMultimap/1methodref$spliterator$Type",1111),T(1112,743,ts,ULe),f.sc=function(t,n){return new Mm(t,n)},C(xt,"AbstractMapBasedMultimap/2",1112);var q5e=Ki(yn,"Map");T(2044,1,fw),f.wc=function(t){fD(this,t)},f.$b=function(){this.vc().$b()},f.tc=function(t){return vne(this,t)},f._b=function(t){return!!E2e(this,t,!1)},f.uc=function(t){var n,i,r;for(i=this.vc().Jc();i.Ob();)if(n=c(i.Pb(),45),r=n.kd(),ve(t)===ve(r)||t!=null&&yi(t,r))return!0;return!1},f.Fb=function(t){var n,i,r;if(t===this)return!0;if(!oe(t,93)||(r=c(t,93),this.gc()!=r.gc()))return!1;for(i=r.vc().Jc();i.Ob();)if(n=c(i.Pb(),45),!this.tc(n))return!1;return!0},f.xc=function(t){return Ao(E2e(this,t,!1))},f.Hb=function(){return Ame(this.vc())},f.dc=function(){return this.gc()==0},f.ec=function(){return new an(this)},f.yc=function(t,n){throw J(new vg("Put not supported on this map"))},f.zc=function(t){lT(this,t)},f.Ac=function(t){return Ao(E2e(this,t,!0))},f.gc=function(){return this.vc().gc()},f.Ib=function(){return OZe(this)},f.Bc=function(){return new x1(this)},C(yn,"AbstractMap",2044),T(2064,2044,fw),f.bc=function(){return new Az(this)},f.vc=function(){return GFe(this)},f.ec=function(){var t;return t=this.g,t||(this.g=this.bc())},f.Bc=function(){var t;return t=this.i,t||(this.i=new vIe(this))},C(xt,"Maps/ViewCachingAbstractMap",2064),T(398,2064,fw,S6),f.xc=function(t){return mPt(this,t)},f.Ac=function(t){return CRt(this,t)},f.$b=function(){this.d==this.e.c?this.e.$b():GF(new R0e(this))},f._b=function(t){return QWe(this.d,t)},f.Dc=function(){return new L4(this)},f.Cc=function(){return this.Dc()},f.Fb=function(t){return this===t||yi(this.d,t)},f.Hb=function(){return Ri(this.d)},f.ec=function(){return this.e.ec()},f.gc=function(){return this.d.gc()},f.Ib=function(){return jo(this.d)},C(xt,"AbstractMapBasedMultimap/AsMap",398);var Ta=Ki(Jo,"Iterable");T(32,1,Ov),f.Ic=function(t){ws(this,t)},f.Lc=function(){return new Tt(this,0)},f.Mc=function(){return new jt(null,this.Lc())},f.Ec=function(t){throw J(new vg("Add not supported on this collection"))},f.Fc=function(t){return Os(this,t)},f.$b=function(){kpe(this)},f.Gc=function(t){return uv(this,t,!1)},f.Hc=function(t){return mD(this,t)},f.dc=function(){return this.gc()==0},f.Kc=function(t){return uv(this,t,!0)},f.Nc=function(){return V0e(this)},f.Oc=function(t){return jT(this,t)},f.Ib=function(){return Mh(this)},C(yn,"AbstractCollection",32);var Va=Ki(yn,"Set");T(Nh,32,Ll),f.Lc=function(){return new Tt(this,1)},f.Fb=function(t){return $Ke(this,t)},f.Hb=function(){return Ame(this)},C(yn,"AbstractSet",Nh),T(2047,Nh,Ll),C(xt,"Sets/ImprovedAbstractSet",2047),T(q1,2047,Ll),f.$b=function(){this.Pc().$b()},f.Gc=function(t){return vKe(this,t)},f.dc=function(){return this.Pc().dc()},f.Kc=function(t){var n;return this.Gc(t)&&oe(t,45)?(n=c(t,45),this.Pc().ec().Kc(n.jd())):!1},f.gc=function(){return this.Pc().gc()},C(xt,"Maps/EntrySet",q1),T(1108,q1,Ll,L4),f.Gc=function(t){return swe(this.a.d.vc(),t)},f.Jc=function(){return new R0e(this.a)},f.Pc=function(){return this.a},f.Kc=function(t){var n;return swe(this.a.d.vc(),t)?(n=c(za(c(t,45)),45),sLt(this.a.e,n.jd()),!0):!1},f.Lc=function(){return M_(this.a.d.vc().Lc(),new VB(this.a))},C(xt,"AbstractMapBasedMultimap/AsMap/AsMapEntries",1108),T(1109,1,{},VB),f.Kb=function(t){return VGe(this.a,c(t,45))},C(xt,"AbstractMapBasedMultimap/AsMap/AsMapEntries/0methodref$wrapEntry$Type",1109),T(741,1,ts,R0e),f.Nb=function(t){gs(this,t)},f.Pb=function(){var t;return t=c(this.b.Pb(),45),this.a=c(t.kd(),18),VGe(this.c,t)},f.Ob=function(){return this.b.Ob()},f.Qb=function(){D6(!!this.a),this.b.Qb(),this.c.e.d-=this.a.gc(),this.a.$b(),this.a=null},C(xt,"AbstractMapBasedMultimap/AsMap/AsMapIterator",741),T(534,2047,Ll,Az),f.$b=function(){this.b.$b()},f.Gc=function(t){return this.b._b(t)},f.Ic=function(t){Rn(t),this.b.wc(new IN(t))},f.dc=function(){return this.b.dc()},f.Jc=function(){return new Yj(this.b.vc().Jc())},f.Kc=function(t){return this.b._b(t)?(this.b.Ac(t),!0):!1},f.gc=function(){return this.b.gc()},C(xt,"Maps/KeySet",534),T(333,534,Ll,wx),f.$b=function(){var t;GF((t=this.b.vc().Jc(),new u1e(this,t)))},f.Hc=function(t){return this.b.ec().Hc(t)},f.Fb=function(t){return this===t||yi(this.b.ec(),t)},f.Hb=function(){return Ri(this.b.ec())},f.Jc=function(){var t;return t=this.b.vc().Jc(),new u1e(this,t)},f.Kc=function(t){var n,i;return i=0,n=c(this.b.Ac(t),18),n&&(i=n.gc(),n.$b(),this.a.d-=i),i>0},f.Lc=function(){return this.b.ec().Lc()},C(xt,"AbstractMapBasedMultimap/KeySet",333),T(742,1,ts,u1e),f.Nb=function(t){gs(this,t)},f.Ob=function(){return this.c.Ob()},f.Pb=function(){return this.a=c(this.c.Pb(),45),this.a.jd()},f.Qb=function(){var t;D6(!!this.a),t=c(this.a.kd(),18),this.c.Qb(),this.b.a.d-=t.gc(),t.$b(),this.a=null},C(xt,"AbstractMapBasedMultimap/KeySet/1",742),T(492,398,{93:1,136:1},k_),f.bc=function(){return this.Qc()},f.ec=function(){return this.Sc()},f.Qc=function(){return new YN(this.c,this.Uc())},f.Rc=function(){return this.Uc().Rc()},f.Sc=function(){var t;return t=this.b,t||(this.b=this.Qc())},f.Tc=function(){return this.Uc().Tc()},f.Uc=function(){return c(this.d,136)},C(xt,"AbstractMapBasedMultimap/SortedAsMap",492),T(442,492,txe,_7),f.bc=function(){return new O6(this.a,c(c(this.d,136),141))},f.Qc=function(){return new O6(this.a,c(c(this.d,136),141))},f.ec=function(){var t;return t=this.b,c(t||(this.b=new O6(this.a,c(c(this.d,136),141))),279)},f.Sc=function(){var t;return t=this.b,c(t||(this.b=new O6(this.a,c(c(this.d,136),141))),279)},f.Uc=function(){return c(c(this.d,136),141)},f.Vc=function(t){return c(c(this.d,136),141).Vc(t)},f.Wc=function(t){return c(c(this.d,136),141).Wc(t)},f.Xc=function(t,n){return new _7(this.a,c(c(this.d,136),141).Xc(t,n))},f.Yc=function(t){return c(c(this.d,136),141).Yc(t)},f.Zc=function(t){return c(c(this.d,136),141).Zc(t)},f.$c=function(t,n){return new _7(this.a,c(c(this.d,136),141).$c(t,n))},C(xt,"AbstractMapBasedMultimap/NavigableAsMap",442),T(491,333,zst,YN),f.Lc=function(){return this.b.ec().Lc()},C(xt,"AbstractMapBasedMultimap/SortedKeySet",491),T(397,491,nxe,O6),C(xt,"AbstractMapBasedMultimap/NavigableKeySet",397),T(543,32,Ov,Fq),f.Ec=function(t){var n,i;return cu(this),i=this.d.dc(),n=this.d.Ec(t),n&&(++this.f.d,i&&j_(this)),n},f.Fc=function(t){var n,i,r;return t.dc()?!1:(r=(cu(this),this.d.gc()),n=this.d.Fc(t),n&&(i=this.d.gc(),this.f.d+=i-r,r==0&&j_(this)),n)},f.$b=function(){var t;t=(cu(this),this.d.gc()),t!=0&&(this.d.$b(),this.f.d-=t,YF(this))},f.Gc=function(t){return cu(this),this.d.Gc(t)},f.Hc=function(t){return cu(this),this.d.Hc(t)},f.Fb=function(t){return t===this?!0:(cu(this),yi(this.d,t))},f.Hb=function(){return cu(this),Ri(this.d)},f.Jc=function(){return cu(this),new S0e(this)},f.Kc=function(t){var n;return cu(this),n=this.d.Kc(t),n&&(--this.f.d,YF(this)),n},f.gc=function(){return o$e(this)},f.Lc=function(){return cu(this),this.d.Lc()},f.Ib=function(){return cu(this),jo(this.d)},C(xt,"AbstractMapBasedMultimap/WrappedCollection",543);var Ju=Ki(yn,"List");T(739,543,{22:1,32:1,18:1,16:1},W0e),f.gd=function(t){cb(this,t)},f.Lc=function(){return cu(this),this.d.Lc()},f._c=function(t,n){var i;cu(this),i=this.d.dc(),c(this.d,16)._c(t,n),++this.a.d,i&&j_(this)},f.ad=function(t,n){var i,r,o;return n.dc()?!1:(o=(cu(this),this.d.gc()),i=c(this.d,16).ad(t,n),i&&(r=this.d.gc(),this.a.d+=r-o,o==0&&j_(this)),i)},f.Xb=function(t){return cu(this),c(this.d,16).Xb(t)},f.bd=function(t){return cu(this),c(this.d,16).bd(t)},f.cd=function(){return cu(this),new R$e(this)},f.dd=function(t){return cu(this),new cHe(this,t)},f.ed=function(t){var n;return cu(this),n=c(this.d,16).ed(t),--this.a.d,YF(this),n},f.fd=function(t,n){return cu(this),c(this.d,16).fd(t,n)},f.hd=function(t,n){return cu(this),oGe(this.a,this.e,c(this.d,16).hd(t,n),this.b?this.b:this)},C(xt,"AbstractMapBasedMultimap/WrappedList",739),T(1107,739,{22:1,32:1,18:1,16:1,59:1},SBe),C(xt,"AbstractMapBasedMultimap/RandomAccessWrappedList",1107),T(626,1,ts,S0e),f.Nb=function(t){gs(this,t)},f.Ob=function(){return G6(this),this.b.Ob()},f.Pb=function(){return G6(this),this.b.Pb()},f.Qb=function(){lBe(this)},C(xt,"AbstractMapBasedMultimap/WrappedCollection/WrappedIterator",626),T(740,626,Ud,R$e,cHe),f.Qb=function(){lBe(this)},f.Rb=function(t){var n;n=o$e(this.a)==0,(G6(this),c(this.b,130)).Rb(t),++this.a.a.d,n&&j_(this.a)},f.Sb=function(){return(G6(this),c(this.b,130)).Sb()},f.Tb=function(){return(G6(this),c(this.b,130)).Tb()},f.Ub=function(){return(G6(this),c(this.b,130)).Ub()},f.Vb=function(){return(G6(this),c(this.b,130)).Vb()},f.Wb=function(t){(G6(this),c(this.b,130)).Wb(t)},C(xt,"AbstractMapBasedMultimap/WrappedList/WrappedListIterator",740),T(738,543,zst,zge),f.Lc=function(){return cu(this),this.d.Lc()},C(xt,"AbstractMapBasedMultimap/WrappedSortedSet",738),T(1106,738,nxe,M$e),C(xt,"AbstractMapBasedMultimap/WrappedNavigableSet",1106),T(1105,543,Ll,UBe),f.Lc=function(){return cu(this),this.d.Lc()},C(xt,"AbstractMapBasedMultimap/WrappedSet",1105),T(1114,1,{},I),f.Kb=function(t){return aLt(c(t,45))},C(xt,"AbstractMapBasedMultimap/lambda$1$Type",1114),T(1113,1,{},wK),f.Kb=function(t){return new Mm(this.a,t)},C(xt,"AbstractMapBasedMultimap/lambda$2$Type",1113);var Mb=Ki(yn,"Map/Entry");T(359,1,$ie),f.Fb=function(t){var n;return oe(t,45)?(n=c(t,45),T1(this.jd(),n.jd())&&T1(this.kd(),n.kd())):!1},f.Hb=function(){var t,n;return t=this.jd(),n=this.kd(),(t==null?0:Ri(t))^(n==null?0:Ri(n))},f.ld=function(t){throw J(new $n)},f.Ib=function(){return this.jd()+"="+this.kd()},C(xt,Fst,359),T(2065,32,Ov),f.$b=function(){this.md().$b()},f.Gc=function(t){var n;return oe(t,45)?(n=c(t,45),__t(this.md(),n.jd(),n.kd())):!1},f.Kc=function(t){var n;return oe(t,45)?(n=c(t,45),FQe(this.md(),n.jd(),n.kd())):!1},f.gc=function(){return this.md().d},C(xt,"Multimaps/Entries",2065),T(744,2065,Ov,WB),f.Jc=function(){return this.a.kc()},f.md=function(){return this.a},f.Lc=function(){return this.a.lc()},C(xt,"AbstractMultimap/Entries",744),T(745,744,Ll,Hde),f.Lc=function(){return this.a.lc()},f.Fb=function(t){return J2e(this,t)},f.Hb=function(){return YXe(this)},C(xt,"AbstractMultimap/EntrySet",745),T(746,32,Ov,KB),f.$b=function(){this.a.$b()},f.Gc=function(t){return SRt(this.a,t)},f.Jc=function(){return this.a.nc()},f.gc=function(){return this.a.d},f.Lc=function(){return this.a.oc()},C(xt,"AbstractMultimap/Values",746),T(2066,32,{841:1,22:1,32:1,18:1}),f.Ic=function(t){Rn(t),yx(this).Ic(new iz(t))},f.Lc=function(){var t;return t=yx(this).Lc(),Rne(t,new ce,64|t.wd()&1296,this.a.d)},f.Ec=function(t){return Vde(),!0},f.Fc=function(t){return Rn(this),Rn(t),oe(t,544)?P_t(c(t,841)):!t.dc()&&Yee(this,t.Jc())},f.Gc=function(t){var n;return n=c(lv(k5(this.a),t),18),(n?n.gc():0)>0},f.Fb=function(t){return jUt(this,t)},f.Hb=function(){return Ri(yx(this))},f.dc=function(){return yx(this).dc()},f.Kc=function(t){return Get(this,t,1)>0},f.Ib=function(){return jo(yx(this))},C(xt,"AbstractMultiset",2066),T(2068,2047,Ll),f.$b=function(){sH(this.a.a)},f.Gc=function(t){var n,i;return oe(t,493)?(i=c(t,421),c(i.a.kd(),18).gc()<=0?!1:(n=uQe(this.a,i.a.jd()),n==c(i.a.kd(),18).gc())):!1},f.Kc=function(t){var n,i,r,o;return oe(t,493)&&(i=c(t,421),n=i.a.jd(),r=c(i.a.kd(),18).gc(),r!=0)?(o=this.a,xGt(o,n,r)):!1},C(xt,"Multisets/EntrySet",2068),T(1120,2068,Ll,vK),f.Jc=function(){return new KLe(GFe(k5(this.a.a)).Jc())},f.gc=function(){return k5(this.a.a).gc()},C(xt,"AbstractMultiset/EntrySet",1120),T(625,737,vb),f.hc=function(){return this.nd()},f.jc=function(){return this.od()},f.cc=function(t){return this.pd(t)},f.fc=function(t){return this.qd(t)},f.Zb=function(){var t;return t=this.f,t||(this.f=this.ac())},f.od=function(){return Ct(),Ct(),eU},f.Fb=function(t){return Mte(this,t)},f.pd=function(t){return c(Si(this,t),24)},f.qd=function(t){return c(xD(this,t),24)},f.mc=function(t){return Ct(),new w6(c(t,24))},f.pc=function(t,n){return new UBe(this,t,c(n,24))},C(xt,"AbstractSetMultimap",625),T(1706,625,vb),f.hc=function(){return new kg(this.b)},f.nd=function(){return new kg(this.b)},f.jc=function(){return lpe(new kg(this.b))},f.od=function(){return lpe(new kg(this.b))},f.cc=function(t){return c(c(Si(this,t),24),85)},f.pd=function(t){return c(c(Si(this,t),24),85)},f.fc=function(t){return c(c(xD(this,t),24),85)},f.qd=function(t){return c(c(xD(this,t),24),85)},f.mc=function(t){return oe(t,279)?lpe(c(t,279)):(Ct(),new Cge(c(t,85)))},f.Zb=function(){var t;return t=this.f,t||(this.f=oe(this.c,141)?new _7(this,c(this.c,141)):oe(this.c,136)?new k_(this,c(this.c,136)):new S6(this,this.c))},f.pc=function(t,n){return oe(n,279)?new M$e(this,t,c(n,279)):new zge(this,t,c(n,85))},C(xt,"AbstractSortedSetMultimap",1706),T(1707,1706,vb),f.Zb=function(){var t;return t=this.f,c(c(t||(this.f=oe(this.c,141)?new _7(this,c(this.c,141)):oe(this.c,136)?new k_(this,c(this.c,136)):new S6(this,this.c)),136),141)},f.ec=function(){var t;return t=this.i,c(c(t||(this.i=oe(this.c,141)?new O6(this,c(this.c,141)):oe(this.c,136)?new YN(this,c(this.c,136)):new wx(this,this.c)),85),279)},f.bc=function(){return oe(this.c,141)?new O6(this,c(this.c,141)):oe(this.c,136)?new YN(this,c(this.c,136)):new wx(this,this.c)},C(xt,"AbstractSortedKeySortedSetMultimap",1707),T(2088,1,{2025:1}),f.Fb=function(t){return hqt(this,t)},f.Hb=function(){var t;return Ame((t=this.g,t||(this.g=new _N(this))))},f.Ib=function(){var t;return OZe((t=this.f,t||(this.f=new vge(this))))},C(xt,"AbstractTable",2088),T(676,Nh,Ll,_N),f.$b=function(){lPe()},f.Gc=function(t){var n,i;return oe(t,471)?(n=c(t,694),i=c(lv(wqe(this.a),k0(n.c.e,n.b)),93),!!i&&swe(i.vc(),new Mm(k0(n.c.c,n.a),C5(n.c,n.b,n.a)))):!1},f.Jc=function(){return IAt(this.a)},f.Kc=function(t){var n,i;return oe(t,471)?(n=c(t,694),i=c(lv(wqe(this.a),k0(n.c.e,n.b)),93),!!i&&c$t(i.vc(),new Mm(k0(n.c.c,n.a),C5(n.c,n.b,n.a)))):!1},f.gc=function(){return yFe(this.a)},f.Lc=function(){return B_t(this.a)},C(xt,"AbstractTable/CellSet",676),T(2004,32,Ov,yK),f.$b=function(){lPe()},f.Gc=function(t){return nHt(this.a,t)},f.Jc=function(){return RAt(this.a)},f.gc=function(){return yFe(this.a)},f.Lc=function(){return IQe(this.a)},C(xt,"AbstractTable/Values",2004),T(1679,1678,vb),C(xt,"ArrayListMultimapGwtSerializationDependencies",1679),T(510,1679,vb,tY,qpe),f.hc=function(){return new Hc(this.a)},f.a=0,C(xt,"ArrayListMultimap",510),T(675,2088,{675:1,2025:1,3:1},Qet),C(xt,"ArrayTable",675),T(2e3,394,HS,sBe),f.Xb=function(t){return new Eme(this.a,t)},C(xt,"ArrayTable/1",2e3),T(2001,1,{},xK),f.rd=function(t){return new Eme(this.a,t)},C(xt,"ArrayTable/1methodref$getCell$Type",2001),T(2089,1,{694:1}),f.Fb=function(t){var n;return t===this?!0:oe(t,471)?(n=c(t,694),T1(k0(this.c.e,this.b),k0(n.c.e,n.b))&&T1(k0(this.c.c,this.a),k0(n.c.c,n.a))&&T1(C5(this.c,this.b,this.a),C5(n.c,n.b,n.a))):!1},f.Hb=function(){return jH(W(V(Br,1),Lt,1,5,[k0(this.c.e,this.b),k0(this.c.c,this.a),C5(this.c,this.b,this.a)]))},f.Ib=function(){return"("+k0(this.c.e,this.b)+","+k0(this.c.c,this.a)+")="+C5(this.c,this.b,this.a)},C(xt,"Tables/AbstractCell",2089),T(471,2089,{471:1,694:1},Eme),f.a=0,f.b=0,f.d=0,C(xt,"ArrayTable/2",471),T(2003,1,{},YB),f.rd=function(t){return ZUe(this.a,t)},C(xt,"ArrayTable/2methodref$getValue$Type",2003),T(2002,394,HS,oBe),f.Xb=function(t){return ZUe(this.a,t)},C(xt,"ArrayTable/3",2002),T(2056,2044,fw),f.$b=function(){GF(this.kc())},f.vc=function(){return new zj(this)},f.lc=function(){return new Yqe(this.kc(),this.gc())},C(xt,"Maps/IteratorBasedAbstractMap",2056),T(834,2056,fw),f.$b=function(){throw J(new $n)},f._b=function(t){return SPe(this.c,t)},f.kc=function(){return new cBe(this,this.c.b.c.gc())},f.lc=function(){return MZ(this.c.b.c.gc(),16,new P4(this))},f.xc=function(t){var n;return n=c(D7(this.c,t),15),n?this.td(n.a):null},f.dc=function(){return this.c.b.c.dc()},f.ec=function(){return $Z(this.c)},f.yc=function(t,n){var i;if(i=c(D7(this.c,t),15),!i)throw J(new qt(this.sd()+" "+t+" not in "+$Z(this.c)));return this.ud(i.a,n)},f.Ac=function(t){throw J(new $n)},f.gc=function(){return this.c.b.c.gc()},C(xt,"ArrayTable/ArrayMap",834),T(1999,1,{},P4),f.rd=function(t){return vqe(this.a,t)},C(xt,"ArrayTable/ArrayMap/0methodref$getEntry$Type",1999),T(1997,359,$ie,tIe),f.jd=function(){return Yjt(this.a,this.b)},f.kd=function(){return this.a.td(this.b)},f.ld=function(t){return this.a.ud(this.b,t)},f.b=0,C(xt,"ArrayTable/ArrayMap/1",1997),T(1998,394,HS,cBe),f.Xb=function(t){return vqe(this.a,t)},C(xt,"ArrayTable/ArrayMap/2",1998),T(1996,834,fw,lqe),f.sd=function(){return"Column"},f.td=function(t){return C5(this.b,this.a,t)},f.ud=function(t,n){return RVe(this.b,this.a,t,n)},f.a=0,C(xt,"ArrayTable/Row",1996),T(835,834,fw,vge),f.td=function(t){return new lqe(this.a,t)},f.yc=function(t,n){return c(n,93),x9t()},f.ud=function(t,n){return c(n,93),k9t()},f.sd=function(){return"Row"},C(xt,"ArrayTable/RowMap",835),T(1138,1,Gu,nIe),f.yd=function(t){return(this.a.wd()&-262&t)!=0},f.wd=function(){return this.a.wd()&-262},f.xd=function(){return this.a.xd()},f.Nb=function(t){this.a.Nb(new rIe(t,this.b))},f.zd=function(t){return this.a.zd(new iIe(t,this.b))},C(xt,"CollectSpliterators/1",1138),T(1139,1,ln,iIe),f.Ad=function(t){this.a.Ad(this.b.Kb(t))},C(xt,"CollectSpliterators/1/lambda$0$Type",1139),T(1140,1,ln,rIe),f.Ad=function(t){this.a.Ad(this.b.Kb(t))},C(xt,"CollectSpliterators/1/lambda$1$Type",1140),T(1135,1,Gu,Cze),f.yd=function(t){return((16464|this.b)&t)!=0},f.wd=function(){return 16464|this.b},f.xd=function(){return this.a.xd()},f.Nb=function(t){this.a.Oe(new oIe(t,this.c))},f.zd=function(t){return this.a.Pe(new sIe(t,this.c))},f.b=0,C(xt,"CollectSpliterators/1WithCharacteristics",1135),T(1136,1,oL,sIe),f.Bd=function(t){this.a.Ad(this.b.rd(t))},C(xt,"CollectSpliterators/1WithCharacteristics/lambda$0$Type",1136),T(1137,1,oL,oIe),f.Bd=function(t){this.a.Ad(this.b.rd(t))},C(xt,"CollectSpliterators/1WithCharacteristics/lambda$1$Type",1137),T(1131,1,Gu),f.yd=function(t){return(this.a&t)!=0},f.wd=function(){return this.a},f.xd=function(){return this.e&&(this.b=uge(this.b,this.e.xd())),uge(this.b,0)},f.Nb=function(t){this.e&&(this.e.Nb(t),this.e=null),this.c.Nb(new cIe(this,t)),this.b=0},f.zd=function(t){for(;;){if(this.e&&this.e.zd(t))return O7(this.b,cL)&&(this.b=Ha(this.b,1)),!0;if(this.e=null,!this.c.zd(new PN(this)))return!1}},f.a=0,f.b=0,C(xt,"CollectSpliterators/FlatMapSpliterator",1131),T(1133,1,ln,PN),f.Ad=function(t){Q7t(this.a,t)},C(xt,"CollectSpliterators/FlatMapSpliterator/lambda$0$Type",1133),T(1134,1,ln,cIe),f.Ad=function(t){pAt(this.a,this.b,t)},C(xt,"CollectSpliterators/FlatMapSpliterator/lambda$1$Type",1134),T(1132,1131,Gu,cGe),C(xt,"CollectSpliterators/FlatMapSpliteratorOfObject",1132),T(257,1,Bie),f.Dd=function(t){return this.Cd(c(t,257))},f.Cd=function(t){var n;return t==(XK(),Soe)?1:t==(JK(),Ooe)?-1:(n=(qF(),aD(this.a,t.a)),n!=0?n:(Bt(),oe(this,517)==oe(t,517)?0:oe(this,517)?1:-1))},f.Gd=function(){return this.a},f.Fb=function(t){return Zwe(this,t)},C(xt,"Cut",257),T(1810,257,Bie,QLe),f.Cd=function(t){return t==this?0:1},f.Ed=function(t){throw J(new Tde)},f.Fd=function(t){t.a+="+∞)"},f.Gd=function(){throw J(new oo(Hst))},f.Hb=function(){return Og(),zwe(this)},f.Hd=function(t){return!1},f.Ib=function(){return"+∞"};var Ooe;C(xt,"Cut/AboveAll",1810),T(517,257,{257:1,517:1,3:1,34:1},fBe),f.Ed=function(t){Sc((t.a+="(",t),this.a)},f.Fd=function(t){Kp(Sc(t,this.a),93)},f.Hb=function(){return~Ri(this.a)},f.Hd=function(t){return qF(),aD(this.a,t)<0},f.Ib=function(){return"/"+this.a+"\\"},C(xt,"Cut/AboveValue",517),T(1809,257,Bie,HLe),f.Cd=function(t){return t==this?0:-1},f.Ed=function(t){t.a+="(-∞"},f.Fd=function(t){throw J(new Tde)},f.Gd=function(){throw J(new oo(Hst))},f.Hb=function(){return Og(),zwe(this)},f.Hd=function(t){return!0},f.Ib=function(){return"-∞"};var Soe;C(xt,"Cut/BelowAll",1809),T(1811,257,Bie,hBe),f.Ed=function(t){Sc((t.a+="[",t),this.a)},f.Fd=function(t){Kp(Sc(t,this.a),41)},f.Hb=function(){return Ri(this.a)},f.Hd=function(t){return qF(),aD(this.a,t)<=0},f.Ib=function(){return"\\"+this.a+"/"},C(xt,"Cut/BelowValue",1811),T(539,1,Jd),f.Ic=function(t){ws(this,t)},f.Ib=function(){return j$t(c(pq(this,"use Optional.orNull() instead of Optional.or(null)"),22).Jc())},C(xt,"FluentIterable",539),T(438,539,Jd,T7),f.Jc=function(){return new Ht(Vt(this.a.Jc(),new U))},C(xt,"FluentIterable/2",438),T(36,1,{},U),f.Kb=function(t){return c(t,22).Jc()},f.Fb=function(t){return this===t},C(xt,"FluentIterable/2/0methodref$iterator$Type",36),T(1051,539,Jd,m$e),f.Jc=function(){return Bd(this)},C(xt,"FluentIterable/3",1051),T(721,394,HS,Oge),f.Xb=function(t){return this.a[t].Jc()},C(xt,"FluentIterable/3/1",721),T(2049,1,{}),f.Ib=function(){return jo(this.Id().b)},C(xt,"ForwardingObject",2049),T(2050,2049,Qst),f.Id=function(){return this.Jd()},f.Ic=function(t){ws(this,t)},f.Lc=function(){return new Tt(this,0)},f.Mc=function(){return new jt(null,this.Lc())},f.Ec=function(t){return this.Jd(),MPe()},f.Fc=function(t){return this.Jd(),APe()},f.$b=function(){this.Jd(),NPe()},f.Gc=function(t){return this.Jd().Gc(t)},f.Hc=function(t){return this.Jd().Hc(t)},f.dc=function(){return this.Jd().b.dc()},f.Jc=function(){return this.Jd().Jc()},f.Kc=function(t){return this.Jd(),_Pe()},f.gc=function(){return this.Jd().b.gc()},f.Nc=function(){return this.Jd().Nc()},f.Oc=function(t){return this.Jd().Oc(t)},C(xt,"ForwardingCollection",2050),T(2057,32,ixe),f.Jc=function(){return this.Md()},f.Ec=function(t){throw J(new $n)},f.Fc=function(t){throw J(new $n)},f.Kd=function(){var t;return t=this.c,t||(this.c=this.Ld())},f.$b=function(){throw J(new $n)},f.Gc=function(t){return t!=null&&uv(this,t,!1)},f.Ld=function(){switch(this.gc()){case 0:return UF(),Eoe;case 1:return new dZ(Rn(this.Md().Pb()));default:return new O0e(this,this.Nc())}},f.Kc=function(t){throw J(new $n)},C(xt,"ImmutableCollection",2057),T(1271,2057,ixe,tz),f.Jc=function(){return M5(new nx(this.a.b.Jc()))},f.Gc=function(t){return t!=null&&i7(this.a,t)},f.Hc=function(t){return f1e(this.a,t)},f.dc=function(){return this.a.b.dc()},f.Md=function(){return M5(new nx(this.a.b.Jc()))},f.gc=function(){return this.a.b.gc()},f.Nc=function(){return this.a.b.Nc()},f.Oc=function(t){return h1e(this.a,t)},f.Ib=function(){return jo(this.a.b)},C(xt,"ForwardingImmutableCollection",1271),T(312,2057,QS),f.Jc=function(){return this.Md()},f.cd=function(){return this.Nd(0)},f.dd=function(t){return this.Nd(t)},f.gd=function(t){cb(this,t)},f.Lc=function(){return new Tt(this,16)},f.hd=function(t,n){return this.Od(t,n)},f._c=function(t,n){throw J(new $n)},f.ad=function(t,n){throw J(new $n)},f.Kd=function(){return this},f.Fb=function(t){return pUt(this,t)},f.Hb=function(){return DIt(this)},f.bd=function(t){return t==null?-1:Qzt(this,t)},f.Md=function(){return this.Nd(0)},f.Nd=function(t){return cZ(this,t)},f.ed=function(t){throw J(new $n)},f.fd=function(t,n){throw J(new $n)},f.Od=function(t,n){var i;return _H((i=new wIe(this),new nd(i,t,n)))},C(xt,"ImmutableList",312),T(2084,312,QS),f.Jc=function(){return M5(this.Pd().Jc())},f.hd=function(t,n){return _H(this.Pd().hd(t,n))},f.Gc=function(t){return t!=null&&this.Pd().Gc(t)},f.Hc=function(t){return this.Pd().Hc(t)},f.Fb=function(t){return yi(this.Pd(),t)},f.Xb=function(t){return k0(this,t)},f.Hb=function(){return Ri(this.Pd())},f.bd=function(t){return this.Pd().bd(t)},f.dc=function(){return this.Pd().dc()},f.Md=function(){return M5(this.Pd().Jc())},f.gc=function(){return this.Pd().gc()},f.Od=function(t,n){return _H(this.Pd().hd(t,n))},f.Nc=function(){return this.Pd().Oc(ye(Br,Lt,1,this.Pd().gc(),5,1))},f.Oc=function(t){return this.Pd().Oc(t)},f.Ib=function(){return jo(this.Pd())},C(xt,"ForwardingImmutableList",2084),T(724,1,GS),f.vc=function(){return Jp(this)},f.wc=function(t){fD(this,t)},f.ec=function(){return $Z(this)},f.Bc=function(){return this.Td()},f.$b=function(){throw J(new $n)},f._b=function(t){return this.xc(t)!=null},f.uc=function(t){return this.Td().Gc(t)},f.Rd=function(){return new I4(this)},f.Sd=function(){return new s6(this)},f.Fb=function(t){return jRt(this,t)},f.Hb=function(){return Jp(this).Hb()},f.dc=function(){return this.gc()==0},f.yc=function(t,n){return O9t()},f.Ac=function(t){throw J(new $n)},f.Ib=function(){return WHt(this)},f.Td=function(){return this.e?this.e:this.e=this.Sd()},f.c=null,f.d=null,f.e=null,C(xt,"ImmutableMap",724),T(725,724,GS),f._b=function(t){return SPe(this,t)},f.uc=function(t){return kIe(this.b,t)},f.Qd=function(){return xWe(new LN(this))},f.Rd=function(){return xWe(Fqe(this.b))},f.Sd=function(){return new tz(zqe(this.b))},f.Fb=function(t){return OIe(this.b,t)},f.xc=function(t){return D7(this,t)},f.Hb=function(){return Ri(this.b.c)},f.dc=function(){return this.b.c.dc()},f.gc=function(){return this.b.c.gc()},f.Ib=function(){return jo(this.b.c)},C(xt,"ForwardingImmutableMap",725),T(2051,2050,zie),f.Id=function(){return this.Ud()},f.Jd=function(){return this.Ud()},f.Lc=function(){return new Tt(this,1)},f.Fb=function(t){return t===this||this.Ud().Fb(t)},f.Hb=function(){return this.Ud().Hb()},C(xt,"ForwardingSet",2051),T(1066,2051,zie,LN),f.Id=function(){return q6(this.a.b)},f.Jd=function(){return q6(this.a.b)},f.Gc=function(t){if(oe(t,45)&&c(t,45).jd()==null)return!1;try{return xIe(q6(this.a.b),t)}catch(n){if(n=vr(n),oe(n,214))return!1;throw J(n)}},f.Ud=function(){return q6(this.a.b)},f.Oc=function(t){var n,i;return n=CHe(q6(this.a.b),t),q6(this.a.b).b.gc()<n.length&&(i=n,dr(i,q6(this.a.b).b.gc(),null)),n},C(xt,"ForwardingImmutableMap/1",1066),T(2058,2057,Y5),f.Jc=function(){return this.Md()},f.Lc=function(){return new Tt(this,1)},f.Fb=function(t){return J2e(this,t)},f.Hb=function(){return YXe(this)},C(xt,"ImmutableSet",2058),T(716,2058,Y5),f.Jc=function(){return M5(new nx(this.a.b.Jc()))},f.Gc=function(t){return t!=null&&i7(this.a,t)},f.Hc=function(t){return f1e(this.a,t)},f.Hb=function(){return Ri(this.a.b)},f.dc=function(){return this.a.b.dc()},f.Md=function(){return M5(new nx(this.a.b.Jc()))},f.gc=function(){return this.a.b.gc()},f.Nc=function(){return this.a.b.Nc()},f.Oc=function(t){return h1e(this.a,t)},f.Ib=function(){return jo(this.a.b)},C(xt,"ForwardingImmutableSet",716),T(2052,2051,Gst),f.Id=function(){return this.b},f.Jd=function(){return this.b},f.Ud=function(){return this.b},f.Lc=function(){return new Qz(this)},C(xt,"ForwardingSortedSet",2052),T(535,2056,GS,KH),f.zc=function(t){lT(this,t)},f.Bc=function(){var t;return t=this.d,new tZ(t||(this.d=new $j(this)))},f.$b=function(){G_(this)},f._b=function(t){return!!oT(this,t,Hn(Ss(Xd,zd(Hn(Ss(t==null?0:Ri(t),Vd)),15))))},f.uc=function(t){return oXe(this,t)},f.kc=function(){return new bBe(this,this)},f.wc=function(t){qHe(this,t)},f.xc=function(t){return Tx(this,t)},f.ec=function(){return new nZ(this)},f.yc=function(t,n){return MQ(this,t,n)},f.Ac=function(t){var n;return n=oT(this,t,Hn(Ss(Xd,zd(Hn(Ss(t==null?0:Ri(t),Vd)),15)))),n?(Bx(this,n),n.e=null,n.c=null,n.i):null},f.gc=function(){return this.i},f.vd=function(){var t;return t=this.d,new tZ(t||(this.d=new $j(this)))},f.f=0,f.g=0,f.i=0,C(xt,"HashBiMap",535),T(536,1,ts),f.Nb=function(t){gs(this,t)},f.Ob=function(){return uGe(this)},f.Pb=function(){var t;if(!uGe(this))throw J(new Co);return t=c(za(this.c),309),this.c=t.c,this.f=t,--this.d,this.Vd(t)},f.Qb=function(){if(this.e.g!=this.b)throw J(new ua);if(!this.f)throw J(new oo(exe));Bx(this.e,this.f),this.b=this.e.g,this.f=null},f.b=0,f.d=0,f.f=null,C(xt,"HashBiMap/Itr",536),T(1016,536,ts,bBe),f.Vd=function(t){return new lIe(this,t)},C(xt,"HashBiMap/1",1016),T(1017,359,$ie,lIe),f.jd=function(){return this.a.g},f.kd=function(){return this.a.i},f.ld=function(t){var n,i,r;return i=this.a.i,r=Hn(Ss(Xd,zd(Hn(Ss(t==null?0:Ri(t),Vd)),15))),r==this.a.f&&(ve(t)===ve(i)||t!=null&&yi(t,i))?t:($Ve(!cT(this.b.a,t,r),t),Bx(this.b.a,this.a),n=new aq(this.a.g,this.a.a,t,r),FD(this.b.a,n,this.a),this.a.e=null,this.a.c=null,this.b.b=this.b.a.g,this.b.f==this.a&&(this.b.f=n),this.a=n,i)},C(xt,"HashBiMap/1/MapEntry",1017),T(247,359,{359:1,247:1,3:1,45:1},Mm),f.jd=function(){return this.g},f.kd=function(){return this.i},f.ld=function(t){throw J(new $n)},C(xt,"ImmutableEntry",247),T(309,247,{359:1,309:1,247:1,3:1,45:1},aq),f.a=0,f.f=0;var joe=C(xt,"HashBiMap/BiEntry",309);T(616,2056,GS,$j),f.zc=function(t){lT(this,t)},f.Bc=function(){return new nZ(this.a)},f.$b=function(){G_(this.a)},f._b=function(t){return oXe(this.a,t)},f.kc=function(){return new mBe(this,this.a)},f.wc=function(t){Rn(t),qHe(this.a,new kK(t))},f.xc=function(t){return cH(this,t)},f.ec=function(){return new tZ(this)},f.yc=function(t,n){return kWt(this.a,t,n)},f.Ac=function(t){var n;return n=cT(this.a,t,Hn(Ss(Xd,zd(Hn(Ss(t==null?0:Ri(t),Vd)),15)))),n?(Bx(this.a,n),n.e=null,n.c=null,n.g):null},f.gc=function(){return this.a.i},f.vd=function(){return new nZ(this.a)},C(xt,"HashBiMap/Inverse",616),T(1013,536,ts,mBe),f.Vd=function(t){return new uIe(this,t)},C(xt,"HashBiMap/Inverse/1",1013),T(1014,359,$ie,uIe),f.jd=function(){return this.a.i},f.kd=function(){return this.a.g},f.ld=function(t){var n,i,r;return r=this.a.g,n=Hn(Ss(Xd,zd(Hn(Ss(t==null?0:Ri(t),Vd)),15))),n==this.a.a&&(ve(t)===ve(r)||t!=null&&yi(t,r))?t:($Ve(!oT(this.b.a.a,t,n),t),Bx(this.b.a.a,this.a),i=new aq(t,n,this.a.i,this.a.f),this.a=i,FD(this.b.a.a,i,null),this.b.b=this.b.a.a.g,r)},C(xt,"HashBiMap/Inverse/1/InverseEntry",1014),T(617,534,Ll,tZ),f.Jc=function(){return new JLe(this.a.a)},f.Kc=function(t){var n;return n=cT(this.a.a,t,Hn(Ss(Xd,zd(Hn(Ss(t==null?0:Ri(t),Vd)),15)))),n?(Bx(this.a.a,n),!0):!1},C(xt,"HashBiMap/Inverse/InverseKeySet",617),T(1012,536,ts,JLe),f.Vd=function(t){return t.i},C(xt,"HashBiMap/Inverse/InverseKeySet/1",1012),T(1015,1,{},kK),f.Wd=function(t,n){ZSt(this.a,t,n)},C(xt,"HashBiMap/Inverse/lambda$0$Type",1015),T(615,534,Ll,nZ),f.Jc=function(){return new XLe(this.a)},f.Kc=function(t){var n;return n=oT(this.a,t,Hn(Ss(Xd,zd(Hn(Ss(t==null?0:Ri(t),Vd)),15)))),n?(Bx(this.a,n),n.e=null,n.c=null,!0):!1},C(xt,"HashBiMap/KeySet",615),T(1011,536,ts,XLe),f.Vd=function(t){return t.g},C(xt,"HashBiMap/KeySet/1",1011),T(1104,625,vb),C(xt,"HashMultimapGwtSerializationDependencies",1104),T(274,1104,vb,Qm),f.hc=function(){return new Cz(ov(this.a))},f.nd=function(){return new Cz(ov(this.a))},f.a=2,C(xt,"HashMultimap",274),T(2076,312,QS),f.Gc=function(t){return this.Xd().Gc(t)},f.dc=function(){return this.Xd().dc()},f.gc=function(){return this.Xd().gc()},C(xt,"ImmutableAsList",2076),T(2009,725,GS),f.Td=function(){return new G4(this.a)},f.Bc=function(){return new G4(this.a)},f.vd=function(){return new G4(this.a)},C(xt,"ImmutableBiMap",2009),T(2054,1,{}),C(xt,"ImmutableCollection/Builder",2054),T(1027,716,Y5,VLe),C(xt,"ImmutableEnumSet",1027),T(971,394,HS,Eze),f.Xb=function(t){return this.a.Xb(t)},C(xt,"ImmutableList/1",971),T(970,2054,{},tze),C(xt,"ImmutableList/Builder",970),T(620,206,qS,DN),f.Ob=function(){return this.a.Ob()},f.Pb=function(){return c(this.a.Pb(),45).jd()},C(xt,"ImmutableMap/1",620),T(1046,1,{},B),f.Kb=function(t){return c(t,45).jd()},C(xt,"ImmutableMap/2methodref$getKey$Type",1046),T(1045,1,{},nze),C(xt,"ImmutableMap/Builder",1045),T(2077,2058,Y5),f.Kd=function(){var t;return t=this.b,t||(this.b=new R4(this))},f.Ld=function(){return new O0e(this,jT(this,ye(Br,Lt,1,this.gc(),5,1)))},C(xt,"ImmutableSet/CachingAsList",2077),T(2078,2077,Y5),f.Jc=function(){var t;return t=Jp(this.a).Md(),new DN(t)},f.Ld=function(){return new R4(this)},f.Ic=function(t){var n,i;for(Rn(t),i=this.gc(),n=0;n<i;n++)t.Ad(c(Jp(this.a).Kd().Xb(n),45).jd())},f.Md=function(){var t;return t=this.b,cZ(t||(this.b=new R4(this)),0)},f.Lc=function(){return MZ(this.gc(),1296,new ez(this))},C(xt,"IndexedImmutableSet",2078),T(1207,2078,Y5,I4),f.Jc=function(){var t;return t=Jp(this.a).Md(),new DN(t)},f.Gc=function(t){return this.a._b(t)},f.Ic=function(t){Rn(t),fD(this.a,new ZB(t))},f.Md=function(){var t;return t=Jp(this.a).Md(),new DN(t)},f.gc=function(){return this.a.gc()},f.Lc=function(){return M_(Jp(this.a).Lc(),new B)},C(xt,"ImmutableMapKeySet",1207),T(1208,1,{},ZB),f.Wd=function(t,n){this.a.Ad(t)},C(xt,"ImmutableMapKeySet/lambda$0$Type",1208),T(1204,2057,ixe,s6),f.Jc=function(){return new EZ(this)},f.Kd=function(){var t;return t=Jp(this.a).Kd(),new dIe(this,t)},f.Gc=function(t){return t!=null&&fqt(new EZ(this),t)},f.Md=function(){return new EZ(this)},f.gc=function(){return this.a.gc()},f.Lc=function(){return M_(Jp(this.a).Lc(),new F)},C(xt,"ImmutableMapValues",1204),T(1205,1,{},F),f.Kb=function(t){return c(t,45).kd()},C(xt,"ImmutableMapValues/0methodref$getValue$Type",1205),T(635,206,qS,EZ),f.Ob=function(){return this.a.Ob()},f.Pb=function(){return c(this.a.Pb(),45).kd()},C(xt,"ImmutableMapValues/1",635),T(1206,2076,QS,dIe),f.Xd=function(){return this.a},f.Xb=function(t){return c(this.b.Xb(t),45).kd()},C(xt,"ImmutableMapValues/2",1206),T(1209,1,{},ez),f.rd=function(t){return Sqe(this.a,t)},C(xt,"IndexedImmutableSet/0methodref$get$Type",1209),T(636,2076,QS,R4),f.Xd=function(){return this.a},f.Xb=function(t){return Sqe(this.a,t)},f.gc=function(){return this.a.a.gc()},C(xt,"IndexedImmutableSet/1",636),T(1047,539,Jd,rFe),f.Ic=function(t){Rn(t),this.b.Ic(new aIe(this.a,t))},f.Jc=function(){return oge(this)},C(xt,"Iterables/4",1047),T(1048,1,ln,aIe),f.Ad=function(t){j8t(this.b,this.a,t)},C(xt,"Iterables/4/lambda$0$Type",1048),T(1049,539,Jd,sFe),f.Ic=function(t){Rn(t),ws(this.a,new hIe(t,this.b))},f.Jc=function(){return Vt(new cn(this.a),this.b)},C(xt,"Iterables/5",1049),T(1050,1,ln,hIe),f.Ad=function(t){this.a.Ad(E$e(t))},C(xt,"Iterables/5/lambda$0$Type",1050),T(1068,206,qS,nz),f.Ob=function(){return this.a.Ob()},f.Pb=function(){return this.a.Pb()},C(xt,"Iterators/1",1068),T(1069,709,qS,fIe),f.Yb=function(){for(var t;this.b.Ob();)if(t=this.b.Pb(),this.a.Lb(t))return t;return this.e=2,null},C(xt,"Iterators/5",1069),T(486,1,ts),f.Nb=function(t){gs(this,t)},f.Ob=function(){return this.b.Ob()},f.Pb=function(){return this.Yd(this.b.Pb())},f.Qb=function(){this.b.Qb()},C(xt,"TransformedIterator",486),T(1070,486,ts,gBe),f.Yd=function(t){return this.a.Kb(t)},C(xt,"Iterators/6",1070),T(1067,394,HS,oFe),f.Xb=function(t){return this.a[t]};var Tat;C(xt,"Iterators/ArrayItr",1067),T(35,1,{35:1,51:1},Ht),f.Nb=function(t){gs(this,t)},f.Ob=function(){return hn(this)},f.Pb=function(){return sn(this)},f.Qb=function(){if(!this.c)throw J(new oo(exe));this.c.Qb(),this.c=null},C(xt,"Iterators/ConcatenatedIterator",35),T(23,1,{3:1,34:1,23:1}),f.Dd=function(t){return tPe(this,c(t,23))},f.Fb=function(t){return this===t},f.Hb=function(){return Lm(this)},f.Ib=function(){return lZ(this)},f.g=0;var On=C(Jo,"Enum",23);T(541,23,{541:1,3:1,34:1,23:1,51:1},K$e),f.Nb=function(t){gs(this,t)},f.Ob=function(){return!1},f.Pb=function(){throw J(new Co)},f.Qb=function(){D6(!1)};var Toe,Eat=mn(xt,"Iterators/EmptyModifiableIterator",541,On,LMt,e7t),Cat;T(727,206,qS,l6),f.Ob=function(){return!this.a},f.Pb=function(){if(this.a)throw J(new Co);return this.a=!0,this.b},f.a=!1,C(xt,"Iterators/SingletonIterator",727),T(1894,625,vb),C(xt,"LinkedHashMultimapGwtSerializationDependencies",1894),T(1895,1894,vb,OWe),f.hc=function(){return new oZ(ov(this.b))},f.$b=function(){sH(this),QN(this.a,this.a)},f.nd=function(){return new oZ(ov(this.b))},f.ic=function(t){return new fWe(this,t,this.b)},f.kc=function(){return new ape(this)},f.lc=function(){var t;return new Tt((t=this.g,c(t||(this.g=new Hde(this)),24)),17)},f.ec=function(){var t;return t=this.i,t||(this.i=new wx(this,this.c))},f.nc=function(){return new Gde(new ape(this))},f.oc=function(){var t;return M_(new Tt((t=this.g,c(t||(this.g=new Hde(this)),24)),17),new K)},f.b=2,C(xt,"LinkedHashMultimap",1895),T(1898,1,{},K),f.Kb=function(t){return c(t,45).kd()},C(xt,"LinkedHashMultimap/0methodref$getValue$Type",1898),T(826,1,ts,ape),f.Nb=function(t){gs(this,t)},f.Pb=function(){return AIt(this)},f.Ob=function(){return this.a!=this.b.a},f.Qb=function(){D6(!!this.c),FQe(this.b,this.c.g,this.c.i),this.c=null},C(xt,"LinkedHashMultimap/1",826),T(229,247,{359:1,247:1,229:1,600:1,3:1,45:1},ype),f.Zd=function(){return c(za(this.f),600)},f.$d=function(t){this.c=t},f._d=function(t){this.f=t},f.d=0;var Mat=C(xt,"LinkedHashMultimap/ValueEntry",229);T(1896,2047,{600:1,22:1,32:1,18:1,24:1},fWe),f.Ec=function(t){var n,i,r,o,a;for(a=Hn(Ss(Xd,zd(Hn(Ss(t==null?0:Ri(t),Vd)),15))),n=a&this.b.length-1,o=this.b[n],i=o;i;i=i.a)if(i.d==a&&T1(i.i,t))return!1;return r=new ype(this.c,t,a,o),dPe(this.d,r),r.f=this,this.d=r,QN(c(za(this.g.a.b),229),r),QN(r,this.g.a),this.b[n]=r,++this.f,++this.e,lqt(this),!0},f.$b=function(){var t,n;for(n_(this.b,null),this.f=0,t=this.a;t!=this;t=t.Zd())n=c(t,229),QN(c(za(n.b),229),c(za(n.e),229));this.a=this,this.d=this,++this.e},f.Gc=function(t){var n,i;for(i=Hn(Ss(Xd,zd(Hn(Ss(t==null?0:Ri(t),Vd)),15))),n=this.b[i&this.b.length-1];n;n=n.a)if(n.d==i&&T1(n.i,t))return!0;return!1},f.Ic=function(t){var n;for(Rn(t),n=this.a;n!=this;n=n.Zd())t.Ad(c(n,229).i)},f.Zd=function(){return this.a},f.Jc=function(){return new Lqe(this)},f.Kc=function(t){return pnt(this,t)},f.$d=function(t){this.d=t},f._d=function(t){this.a=t},f.gc=function(){return this.f},f.e=0,f.f=0,C(xt,"LinkedHashMultimap/ValueSet",1896),T(1897,1,ts,Lqe),f.Nb=function(t){gs(this,t)},f.Ob=function(){return B0e(this),this.b!=this.c},f.Pb=function(){var t,n;if(B0e(this),this.b==this.c)throw J(new Co);return t=c(this.b,229),n=t.i,this.d=t,this.b=c(za(t.f),600),n},f.Qb=function(){B0e(this),D6(!!this.d),pnt(this.c,this.d.i),this.a=this.c.e,this.d=null},f.a=0,C(xt,"LinkedHashMultimap/ValueSet/1",1897),T(774,2063,vb,g$e),f.Zb=function(){var t;return t=this.f,t||(this.f=new O1e(this))},f.Fb=function(t){return Mte(this,t)},f.cc=function(t){return new cY(this,t)},f.fc=function(t){return Sbe(this,t)},f.$b=function(){aqe(this)},f._b=function(t){return yIe(this,t)},f.ac=function(){return new O1e(this)},f.bc=function(){return new Bj(this)},f.qc=function(t){return new cY(this,t)},f.dc=function(){return!this.a},f.rc=function(t){return Sbe(this,t)},f.gc=function(){return this.d},f.c=0,f.d=0,C(xt,"LinkedListMultimap",774),T(56,32,US),f.gd=function(t){cb(this,t)},f.Lc=function(){return new Tt(this,16)},f._c=function(t,n){throw J(new vg("Add not supported on this list"))},f.Ec=function(t){return this._c(this.gc(),t),!0},f.ad=function(t,n){var i,r,o;for(zt(n),i=!1,o=n.Jc();o.Ob();)r=o.Pb(),this._c(t++,r),i=!0;return i},f.$b=function(){this.ae(0,this.gc())},f.Fb=function(t){return Mve(this,t)},f.Hb=function(){return $me(this)},f.bd=function(t){return AXe(this,t)},f.Jc=function(){return new Gj(this)},f.cd=function(){return this.dd(0)},f.dd=function(t){return new os(this,t)},f.ed=function(t){throw J(new vg("Remove not supported on this list"))},f.ae=function(t,n){var i,r;for(r=this.dd(t),i=t;i<n;++i)r.Pb(),r.Qb()},f.fd=function(t,n){throw J(new vg("Set not supported on this list"))},f.hd=function(t,n){return new nd(this,t,n)},f.j=0,C(yn,"AbstractList",56),T(2041,56,US),f._c=function(t,n){M6(this,t,n)},f.ad=function(t,n){return gWe(this,t,n)},f.Xb=function(t){return pc(this,t)},f.Jc=function(){return this.dd(0)},f.ed=function(t){return Ene(this,t)},f.fd=function(t,n){var i,r;i=this.dd(t);try{return r=i.Pb(),i.Wb(n),r}catch(o){throw o=vr(o),oe(o,113)?J(new zc("Can't set element "+t)):J(o)}},C(yn,"AbstractSequentialList",2041),T(643,2041,US,cY),f.dd=function(t){return dBe(this,t)},f.gc=function(){var t;return t=c(Ut(this.a.b,this.b),263),t?t.a:0},C(xt,"LinkedListMultimap/1",643),T(1292,2047,Ll,Bj),f.Gc=function(t){return yIe(this.a,t)},f.Jc=function(){return new nVe(this.a)},f.Kc=function(t){return!Sbe(this.a,t).a.dc()},f.gc=function(){return r7(this.a.b)},C(xt,"LinkedListMultimap/1KeySetImpl",1292),T(1291,1,ts,nVe),f.Nb=function(t){gs(this,t)},f.Ob=function(){return z0e(this),!!this.c},f.Pb=function(){if(z0e(this),!this.c)throw J(new Co);this.a=this.c,Sr(this.d,this.a.a);do this.c=this.c.b;while(this.c&&!Sr(this.d,this.c.a));return this.a.a},f.Qb=function(){z0e(this),D6(!!this.a),GF(new Xee(this.e,this.a.a)),this.a=null,this.b=this.e.c},f.b=0,C(xt,"LinkedListMultimap/DistinctKeyIterator",1291),T(263,1,{263:1},Mpe),f.a=0,C(xt,"LinkedListMultimap/KeyList",263),T(501,359,{359:1,501:1,45:1},gIe),f.jd=function(){return this.a},f.kd=function(){return this.f},f.ld=function(t){var n;return n=this.f,this.f=t,n},C(xt,"LinkedListMultimap/Node",501),T(562,1,Ud,Xee,wet),f.Nb=function(t){gs(this,t)},f.Rb=function(t){this.e=hye(this.f,this.b,t,this.c),++this.d,this.a=null},f.Ob=function(){return!!this.c},f.Sb=function(){return!!this.e},f.Pb=function(){return qbe(this)},f.Tb=function(){return this.d},f.Ub=function(){return RJe(this)},f.Vb=function(){return this.d-1},f.Qb=function(){D6(!!this.a),this.a!=this.c?(this.e=this.a.e,--this.d):this.c=this.a.c,dJt(this.f,this.a),this.a=null},f.Wb=function(t){xge(!!this.a),this.a.f=t},f.d=0,C(xt,"LinkedListMultimap/ValueForKeyIterator",562),T(1023,56,US),f._c=function(t,n){this.a._c(t,n)},f.ad=function(t,n){return this.a.ad(t,n)},f.Gc=function(t){return this.a.Gc(t)},f.Xb=function(t){return this.a.Xb(t)},f.ed=function(t){return this.a.ed(t)},f.fd=function(t,n){return this.a.fd(t,n)},f.gc=function(){return this.a.gc()},C(xt,"Lists/AbstractListWrapper",1023),T(Ga,1023,Jst),C(xt,"Lists/RandomAccessListWrapper",Ga),T(1026,Ga,Jst,wIe),f.dd=function(t){return this.a.dd(t)},C(xt,"Lists/1",1026),T(437,56,{437:1,22:1,32:1,56:1,18:1,16:1},a1e),f._c=function(t,n){this.a._c($6(this,t),n)},f.$b=function(){this.a.$b()},f.Xb=function(t){return this.a.Xb(upe(this,t))},f.Jc=function(){return mQe(this,0)},f.dd=function(t){return mQe(this,t)},f.ed=function(t){return this.a.ed(upe(this,t))},f.ae=function(t,n){(XQe(t,n,this.a.gc()),Eu(this.a.hd($6(this,n),$6(this,t)))).$b()},f.fd=function(t,n){return this.a.fd(upe(this,t),n)},f.gc=function(){return this.a.gc()},f.hd=function(t,n){return XQe(t,n,this.a.gc()),Eu(this.a.hd($6(this,n),$6(this,t)))},C(xt,"Lists/ReverseList",437),T(1022,437,{437:1,22:1,32:1,56:1,18:1,16:1,59:1},WLe),C(xt,"Lists/RandomAccessReverseList",1022),T(1025,1,Ud,pIe),f.Nb=function(t){gs(this,t)},f.Rb=function(t){this.c.Rb(t),this.c.Ub(),this.a=!1},f.Ob=function(){return this.c.Sb()},f.Sb=function(){return this.c.Ob()},f.Pb=function(){if(!this.c.Sb())throw J(new Co);return this.a=!0,this.c.Ub()},f.Tb=function(){return $6(this.b,this.c.Tb())},f.Ub=function(){if(!this.c.Ob())throw J(new Co);return this.a=!0,this.c.Pb()},f.Vb=function(){return $6(this.b,this.c.Tb())-1},f.Qb=function(){D6(this.a),this.c.Qb(),this.a=!1},f.Wb=function(t){xge(this.a),this.c.Wb(t)},f.a=!1,C(xt,"Lists/ReverseList/1",1025),T(436,486,ts,Yj),f.Yd=function(t){return Hz(t)},C(xt,"Maps/1",436),T(708,486,ts,Gde),f.Yd=function(t){return c(t,45).kd()},C(xt,"Maps/2",708),T(967,486,ts,pBe),f.Yd=function(t){return new Mm(t,jPe(this.a,t))},C(xt,"Maps/3",967),T(964,q1,Ll,zj),f.Ic=function(t){s9t(this.a,t)},f.Jc=function(){return this.a.kc()},f.Pc=function(){return this.a},f.Lc=function(){return this.a.lc()},C(xt,"Maps/IteratorBasedAbstractMap/1",964),T(965,1,{},IN),f.Wd=function(t,n){this.a.Ad(t)},C(xt,"Maps/KeySet/lambda$0$Type",965),T(963,32,Ov,vIe),f.$b=function(){this.a.$b()},f.Gc=function(t){return this.a.uc(t)},f.Ic=function(t){Rn(t),this.a.wc(new SK(t))},f.dc=function(){return this.a.dc()},f.Jc=function(){return new Gde(this.a.vc().Jc())},f.Kc=function(t){var n,i;try{return uv(this,t,!0)}catch(r){if(r=vr(r),oe(r,46)){for(i=this.a.vc().Jc();i.Ob();)if(n=c(i.Pb(),45),T1(t,n.kd()))return this.a.Ac(n.jd()),!0;return!1}else throw J(r)}},f.gc=function(){return this.a.gc()},C(xt,"Maps/Values",963),T(966,1,{},SK),f.Wd=function(t,n){this.a.Ad(n)},C(xt,"Maps/Values/lambda$0$Type",966),T(747,2064,fw,O1e),f.xc=function(t){return this.a._b(t)?this.a.cc(t):null},f.Ac=function(t){return this.a._b(t)?this.a.fc(t):null},f.$b=function(){this.a.$b()},f._b=function(t){return this.a._b(t)},f.Dc=function(){return new jK(this)},f.Cc=function(){return this.Dc()},f.dc=function(){return this.a.dc()},f.ec=function(){return this.a.ec()},f.gc=function(){return this.a.ec().gc()},C(xt,"Multimaps/AsMap",747),T(1115,q1,Ll,jK),f.Jc=function(){return Sjt(this.a.a.ec(),new OK(this))},f.Pc=function(){return this.a},f.Kc=function(t){var n;return vKe(this,t)?(n=c(za(c(t,45)),45),p9t(this.a,n.jd()),!0):!1},C(xt,"Multimaps/AsMap/EntrySet",1115),T(1119,1,{},OK),f.Kb=function(t){return jPe(this,t)},f.Fb=function(t){return this===t},C(xt,"Multimaps/AsMap/EntrySet/lambda$0$Type",1119),T(544,2066,{544:1,841:1,22:1,32:1,18:1},o6),f.$b=function(){sH(this.a)},f.Gc=function(t){return OPe(this.a,t)},f.Ic=function(t){Rn(t),ws(q7(this.a),new Fj(t))},f.Jc=function(){return new Yj(q7(this.a).a.kc())},f.gc=function(){return this.a.d},f.Lc=function(){return M_(q7(this.a).Lc(),new Y)},C(xt,"Multimaps/Keys",544),T(1117,1,{},Y),f.Kb=function(t){return c(t,45).jd()},C(xt,"Multimaps/Keys/0methodref$getKey$Type",1117),T(1116,486,ts,KLe),f.Yd=function(t){return new TK(c(t,45))},C(xt,"Multimaps/Keys/1",1116),T(2067,1,{421:1}),f.Fb=function(t){var n;return oe(t,493)?(n=c(t,421),c(this.a.kd(),18).gc()==c(n.a.kd(),18).gc()&&T1(this.a.jd(),n.a.jd())):!1},f.Hb=function(){var t;return t=this.a.jd(),(t==null?0:Ri(t))^c(this.a.kd(),18).gc()},f.Ib=function(){var t,n;return n=A7(this.a.jd()),t=c(this.a.kd(),18).gc(),t==1?n:n+" x "+t},C(xt,"Multisets/AbstractEntry",2067),T(493,2067,{493:1,421:1},TK),C(xt,"Multimaps/Keys/1/1",493),T(1118,1,ln,Fj),f.Ad=function(t){this.a.Ad(c(t,45).jd())},C(xt,"Multimaps/Keys/lambda$1$Type",1118),T(1121,1,ln,Z),f.Ad=function(t){HCt(c(t,421))},C(xt,"Multiset/lambda$0$Type",1121),T(748,1,ln,iz),f.Ad=function(t){OPt(this.a,c(t,421))},C(xt,"Multiset/lambda$1$Type",748),T(1122,1,{},ee),C(xt,"Multisets/0methodref$add$Type",1122),T(749,1,{},ce),f.Kb=function(t){return G_t(c(t,421))},C(xt,"Multisets/lambda$1$Type",749),T(2085,1,rL),C(xt,"RangeGwtSerializationDependencies",2085),T(511,2085,{181:1,511:1,3:1,48:1},Gwe),f.Lb=function(t){return VFe(this,c(t,34))},f.Mb=function(t){return VFe(this,c(t,34))},f.Fb=function(t){var n;return oe(t,511)?(n=c(t,511),Zwe(this.a,n.a)&&Zwe(this.b,n.b)):!1},f.Hb=function(){return this.a.Hb()*31+this.b.Hb()},f.Ib=function(){return mGe(this.a,this.b)},C(xt,"Range",511),T(649,2076,QS,O0e),f.dd=function(t){return cZ(this.b,t)},f.Xd=function(){return this.a},f.Xb=function(t){return k0(this.b,t)},f.Nd=function(t){return cZ(this.b,t)},C(xt,"RegularImmutableAsList",649),T(652,2084,QS,kee),f.Pd=function(){return this.a};var Eoe;C(xt,"RegularImmutableList",652),T(540,725,GS,v1e,y1e);var Aat;C(xt,"RegularImmutableMap",540),T(726,716,Y5,x1e);var H5e;C(xt,"RegularImmutableSet",726),T(2053,Nh,Ll),f.Jc=function(){return new Ope(this.a,this.b)},f.Ec=function(t){throw J(new $n)},f.Fc=function(t){throw J(new $n)},f.$b=function(){throw J(new $n)},f.Kc=function(t){throw J(new $n)},C(xt,"Sets/SetView",2053),T(968,2053,Ll,mIe),f.Jc=function(){return new Ope(this.a,this.b)},f.Gc=function(t){return _Z(this.a,t)&&this.b.Gc(t)},f.Hc=function(t){return mD(this.a,t)&&this.b.Hc(t)},f.dc=function(){return iYe(this.b,this.a)},f.gc=function(){return hD(this)},f.Mc=function(){return pi(new jt(null,new Tt(this.a,1)),new rz(this.b))},C(xt,"Sets/2",968),T(969,1,Jn,rz),f.Mb=function(t){return this.a.Gc(t)},C(xt,"Sets/2/0methodref$contains$Type",969),T(710,709,qS,Ope),f.Yb=function(){for(var t;lge(this.a);)if(t=Y7(this.a),this.c.Gc(t))return t;return this.e=2,null},C(xt,"Sets/2/1",710),T(613,2052,{613:1,3:1,22:1,18:1,279:1,24:1,85:1},IHe),f.Id=function(){return this.b},f.Jd=function(){return this.b},f.Ud=function(){return this.b},f.Ic=function(t){this.a.Ic(t)},f.Mc=function(){return this.a.Mc()},C(xt,"Sets/UnmodifiableNavigableSet",613),T(2010,2009,GS,qqe),f.Td=function(){return new G4(this.a)},f.Bc=function(){return new G4(this.a)},f.vd=function(){return new G4(this.a)},C(xt,"SingletonImmutableBiMap",2010),T(653,2084,QS,dZ),f.Pd=function(){return this.a},C(xt,"SingletonImmutableList",653),T(360,2058,Y5,G4),f.Jc=function(){return new l6(this.a)},f.Gc=function(t){return yi(this.a,t)},f.Md=function(){return new l6(this.a)},f.gc=function(){return 1},C(xt,"SingletonImmutableSet",360),T(1129,1,{},D),f.Kb=function(t){return c(t,163)},C(xt,"Streams/lambda$0$Type",1129),T(1130,1,HQ,sz),f.be=function(){yqt(this.a)},C(xt,"Streams/lambda$1$Type",1130),T(1708,1707,vb,wHe),f.Zb=function(){var t;return t=this.f,c(c(t||(this.f=oe(this.c,141)?new _7(this,c(this.c,141)):oe(this.c,136)?new k_(this,c(this.c,136)):new S6(this,this.c)),136),141)},f.hc=function(){return new kg(this.b)},f.nd=function(){return new kg(this.b)},f.ec=function(){var t;return t=this.i,c(c(t||(this.i=oe(this.c,141)?new O6(this,c(this.c,141)):oe(this.c,136)?new YN(this,c(this.c,136)):new wx(this,this.c)),85),279)},f.ac=function(){return oe(this.c,141)?new _7(this,c(this.c,141)):oe(this.c,136)?new k_(this,c(this.c,136)):new S6(this,this.c)},f.ic=function(t){return t==null&&this.a.Le(t,t),new kg(this.b)},C(xt,"TreeMultimap",1708),T(81,1,{3:1,81:1}),f.ce=function(t){return new Error(t)},f.de=function(){return this.e},f.ee=function(){var t,n,i;for(i=(this.k==null&&(this.k=ye(Coe,Be,81,0,0,1)),this.k),n=ye(Br,Lt,1,i.length,5,1),t=0;t<i.length;t++)n[t]=i[t].e;return n},f.fe=function(){return this.f},f.ge=function(){return this.g},f.he=function(){a9t(this,L_t(this.ce(wq(this,this.g)))),eLe(this)},f.Ib=function(){return wq(this,this.ge())},f.e=Xst,f.i=!1,f.n=!0;var Coe=C(Jo,"Throwable",81);T(102,81,{3:1,102:1,81:1}),C(Jo,"Exception",102),T(63,102,H1,zp,Mo),C(Jo,"RuntimeException",63),T(603,63,H1),C(Jo,"JsException",603),T(865,603,H1),C(uL,"JavaScriptExceptionBase",865),T(477,865,{477:1,3:1,102:1,63:1,81:1},kWe),f.ge=function(){return Dqt(this),this.c},f.ie=function(){return ve(this.b)===ve(Q5e)?null:this.b};var Q5e;C(sxe,"JavaScriptException",477);var Nat=C(sxe,"JavaScriptObject$",0),Moe;T(2026,1,{}),C(sxe,"Scheduler",2026);var VG=0,_at=0,WG=-1;T(892,2026,{},fe);var G5e;C(uL,"SchedulerImpl",892);var Aoe;T(2037,1,{}),C(uL,"StackTraceCreator/Collector",2037),T(866,2037,{},be),f.je=function(t){var n={},i=[];t[Hie]=i;for(var r=arguments.callee.caller;r;){var o=(U6(),r.name||(r.name=LPt(r.toString())));i.push(o);var a=":"+o,d=n[a];if(d){var b,v;for(b=0,v=d.length;b<v;b++)if(d[b]===r)return}(d||(n[a]=[])).push(r),r=r.caller}},f.ke=function(t){var n,i,r,o;for(r=(U6(),t&&t[Hie]?t[Hie]:[]),i=r.length,o=ye(ske,Be,325,i,0,1),n=0;n<i;n++)o[n]=new ree(r[n],null,-1);return o},C(uL,"StackTraceCreator/CollectorLegacy",866),T(2038,2037,{}),f.je=function(t){},f.le=function(t,n,i,r){return new ree(n,t+"@"+r,i<0?-1:i)},f.ke=function(t){var n,i,r,o,a,d;if(o=sFt(t),a=ye(ske,Be,325,0,0,1),n=0,r=o.length,r==0)return a;for(d=Krt(this,o[0]),Ot(d.d,qie)||(a[n++]=d),i=1;i<r;i++)a[n++]=Krt(this,o[i]);return a},C(uL,"StackTraceCreator/CollectorModern",2038),T(867,2038,{},me),f.le=function(t,n,i,r){return new ree(n,t,-1)},C(uL,"StackTraceCreator/CollectorModernNoSourceMap",867),T(1055,1,{}),C(cxe,Kst,1055),T(622,1055,{622:1},yqe);var U5e;C(lre,Kst,622),T(2080,1,{}),C(cxe,Yst,2080),T(2081,2080,{}),C(lre,Yst,2081),T(1101,1,{},Re);var EE;C(lre,"LocaleInfo",1101),T(2006,1,{},Te),f.a=0,C(lre,"TimeZone",2006),T(1268,2081,{},ze),C("com.google.gwt.i18n.client.impl.cldr","DateTimeFormatInfoImpl",1268),T(439,1,{439:1},Kze),f.a=!1,f.b=0,C(cxe,"DateTimeFormat/PatternPart",439),T(208,1,Zst,_z,_me,Vge),f.Dd=function(t){return A_t(this,c(t,208))},f.Fb=function(t){return oe(t,208)&&k7(Zo(this.q.getTime()),Zo(c(t,208).q.getTime()))},f.Hb=function(){var t;return t=Zo(this.q.getTime()),Hn(Oee(t,Vp(t,32)))},f.Ib=function(){var t,n,i;return i=-this.q.getTimezoneOffset(),t=(i>=0?"+":"")+(i/60|0),n=wF(p.Math.abs(i)%60),(IZe(),Gat)[this.q.getDay()]+" "+Uat[this.q.getMonth()]+" "+wF(this.q.getDate())+" "+wF(this.q.getHours())+":"+wF(this.q.getMinutes())+":"+wF(this.q.getSeconds())+" GMT"+t+n+" "+this.q.getFullYear()};var KG=C(yn,"Date",208);T(1994,208,Zst,nZe),f.a=!1,f.b=0,f.c=0,f.d=0,f.e=0,f.f=0,f.g=!1,f.i=0,f.j=0,f.k=0,f.n=0,f.o=0,f.p=0,C("com.google.gwt.i18n.shared.impl","DateRecord",1994),T(2043,1,{}),f.ne=function(){return null},f.oe=function(){return null},f.pe=function(){return null},f.qe=function(){return null},f.re=function(){return null},C(ek,"JSONValue",2043),T(142,2043,{142:1},mg,RN),f.Fb=function(t){return oe(t,142)?Gpe(this.a,c(t,142).a):!1},f.me=function(){return HSt},f.Hb=function(){return Ape(this.a)},f.ne=function(){return this},f.Ib=function(){var t,n,i;for(i=new Lu("["),n=0,t=this.a.length;n<t;n++)n>0&&(i.a+=","),Sc(i,tv(this,n));return i.a+="]",i.a},C(ek,"JSONArray",142),T(482,2043,{482:1},qj),f.me=function(){return QSt},f.oe=function(){return this},f.Ib=function(){return Bt(),""+this.a},f.a=!1;var Dat,Lat;C(ek,"JSONBoolean",482),T(990,63,H1,YLe),C(ek,"JSONException",990),T(1028,2043,{},Ke),f.me=function(){return XSt},f.Ib=function(){return pl};var Pat;C(ek,"JSONNull",1028),T(266,2043,{266:1},c6),f.Fb=function(t){return oe(t,266)?this.a==c(t,266).a:!1},f.me=function(){return GSt},f.Hb=function(){return o5(this.a)},f.pe=function(){return this},f.Ib=function(){return this.a+""},f.a=0,C(ek,"JSONNumber",266),T(150,2043,{150:1},W4,B4),f.Fb=function(t){return oe(t,150)?Gpe(this.a,c(t,150).a):!1},f.me=function(){return USt},f.Hb=function(){return Ape(this.a)},f.qe=function(){return this},f.Ib=function(){var t,n,i,r,o,a,d;for(d=new Lu("{"),t=!0,a=ate(this,ye(nt,Be,2,0,6,1)),i=a,r=0,o=i.length;r<o;++r)n=i[r],t?t=!1:d.a+=Jc,Zn(d,stt(n)),d.a+=":",Sc(d,C1(this,n));return d.a+="}",d.a},C(ek,"JSONObject",150),T(601,Nh,Ll,lY),f.Gc=function(t){return Kr(t)&&A9t(this.a,zn(t))},f.Jc=function(){return new Gj(new Ho(this.b))},f.gc=function(){return this.b.length},C(ek,"JSONObject/1",601);var Noe;T(213,2043,{213:1},J2),f.Fb=function(t){return oe(t,213)?Ot(this.a,c(t,213).a):!1},f.me=function(){return JSt},f.Hb=function(){return Dg(this.a)},f.re=function(){return this},f.Ib=function(){return stt(this.a)},C(ek,"JSONString",213);var W0,J5e,Iat,X5e,V5e;T(2039,1,{524:1}),C(lxe,"OutputStream",2039),T(2040,2039,{524:1}),C(lxe,"FilterOutputStream",2040),T(868,2040,{524:1},ge),C(lxe,"PrintStream",868),T(423,1,{475:1}),f.Ib=function(){return this.a},C(Jo,"AbstractStringBuilder",423),T(530,63,H1,Sz),C(Jo,"ArithmeticException",530),T(99,63,GQ,Ede,zc),C(Jo,"IndexOutOfBoundsException",99),T(650,99,GQ,sLe,Kde),C(Jo,"ArrayIndexOutOfBoundsException",650),T(529,63,H1,BK,sPe),C(Jo,"ArrayStoreException",529),T(298,81,eot,YK),C(Jo,"Error",298),T(202,298,eot,Tde,ube),C(Jo,"AssertionError",202),Oat={3:1,476:1,34:1};var K0,k9,ir=C(Jo,"Boolean",476);T(245,1,{3:1,245:1});var W5e;C(Jo,"Number",245),T(224,245,{3:1,224:1,34:1,245:1},rr),f.Dd=function(t){return E9t(this,c(t,224))},f.se=function(){return this.a},f.Fb=function(t){return oe(t,224)&&c(t,224).a==this.a},f.Hb=function(){return this.a},f.Ib=function(){return""+this.a},f.a=0;var ak=C(Jo,"Byte",224),K5e;T(183,1,{3:1,183:1,34:1},Fo),f.Dd=function(t){return C9t(this,c(t,183))},f.Fb=function(t){return oe(t,183)&&c(t,183).a==this.a},f.Hb=function(){return this.a},f.Ib=function(){return String.fromCharCode(this.a)},f.a=0;var Y5e,CE=C(Jo,"Character",183),Z5e;T(214,63,{3:1,214:1,102:1,63:1,81:1},tLe,m6),C(Jo,"ClassCastException",214),Sat={3:1,34:1,347:1,245:1};var kr=C(Jo,"Double",347);T(165,245,{3:1,34:1,165:1,245:1},Fs,Mde),f.Dd=function(t){return $8t(this,c(t,165))},f.se=function(){return this.a},f.Fb=function(t){return oe(t,165)&&kze(this.a,c(t,165).a)},f.Hb=function(){return xs(this.a)},f.Ib=function(){return""+this.a},f.a=0;var O9=C(Jo,"Float",165);T(33,63,{3:1,102:1,33:1,63:1,81:1},GN,qt,vWe),C(Jo,"IllegalArgumentException",33),T(73,63,H1,Tl,oo),C(Jo,"IllegalStateException",73),T(15,245,{3:1,34:1,15:1,245:1},qo),f.Dd=function(t){return nge(this,c(t,15))},f.se=function(){return this.a},f.Fb=function(t){return oe(t,15)&&c(t,15).a==this.a},f.Hb=function(){return this.a},f.Ib=function(){return""+this.a},f.a=0;var Lr=C(Jo,"Integer",15),eke,Rat;T(192,245,{3:1,34:1,192:1,245:1},xm),f.Dd=function(t){return B8t(this,c(t,192))},f.se=function(){return ib(this.a)},f.Fb=function(t){return oe(t,192)&&k7(c(t,192).a,this.a)},f.Hb=function(){return P7t(this.a)},f.Ib=function(){return""+R7(this.a)},f.a=0;var Ow=C(Jo,"Long",192),tke;T(2119,1,{}),T(1891,63,H1,oPe),C(Jo,"NegativeArraySizeException",1891),T(174,603,{3:1,102:1,174:1,63:1,81:1},U4,K4),f.ce=function(t){return new TypeError(t)},C(Jo,"NullPointerException",174);var nke,_oe,$at,ike;T(133,33,{3:1,102:1,33:1,133:1,63:1,81:1},Yh),C(Jo,"NumberFormatException",133),T(193,245,{3:1,34:1,245:1,193:1},$t),f.Dd=function(t){return M9t(this,c(t,193))},f.se=function(){return this.a},f.Fb=function(t){return oe(t,193)&&c(t,193).a==this.a},f.Hb=function(){return this.a},f.Ib=function(){return""+this.a},f.a=0;var Sw=C(Jo,"Short",193),rke;T(325,1,{3:1,325:1},ree),f.Fb=function(t){var n;return oe(t,325)?(n=c(t,325),this.c==n.c&&this.d==n.d&&this.a==n.a&&this.b==n.b):!1},f.Hb=function(){return jH(W(V(Br,1),Lt,1,5,[Pe(this.c),this.a,this.d,this.b]))},f.Ib=function(){return this.a+"."+this.d+"("+(this.b!=null?this.b:"Unknown Source")+(this.c>=0?":"+this.c:"")+")"},f.c=0;var ske=C(Jo,"StackTraceElement",325);jat={3:1,475:1,34:1,2:1};var nt=C(Jo,rxe,2);T(112,423,{475:1},yg,t7,Ba),C(Jo,"StringBuffer",112),T(106,423,{475:1},b0,Z4,Lu),C(Jo,"StringBuilder",106),T(698,99,GQ,Wde),C(Jo,"StringIndexOutOfBoundsException",698),T(2124,1,{});var Bat;T(46,63,{3:1,102:1,63:1,81:1,46:1},$n,vg),C(Jo,"UnsupportedOperationException",46),T(249,245,{3:1,34:1,245:1,249:1},TD,o1e),f.Dd=function(t){return Hit(this,c(t,249))},f.se=function(){return gv(wrt(this))},f.Fb=function(t){var n;return this===t?!0:oe(t,249)?(n=c(t,249),this.e==n.e&&Hit(this,n)==0):!1},f.Hb=function(){var t;return this.b!=0?this.b:this.a<54?(t=Zo(this.f),this.b=Hn(Yr(t,-1)),this.b=33*this.b+Hn(Yr(Im(t,32),-1)),this.b=17*this.b+xs(this.e),this.b):(this.b=17*NWe(this.c)+xs(this.e),this.b)},f.Ib=function(){return wrt(this)},f.a=0,f.b=0,f.d=0,f.e=0,f.f=0;var zat,Ab,oke,cke,lke,uke,ake,fke,Doe=C("java.math","BigDecimal",249);T(92,245,{3:1,34:1,245:1,92:1},A1,GQe,Wp,qKe,O0),f.Dd=function(t){return LKe(this,c(t,92))},f.se=function(){return gv(Pie(this,0))},f.Fb=function(t){return Swe(this,t)},f.Hb=function(){return NWe(this)},f.Ib=function(){return Pie(this,0)},f.b=-2,f.c=0,f.d=0,f.e=0;var Fat,YG,qat,Loe,ZG,ME,t3=C("java.math","BigInteger",92),Hat,Qat,fk,AE;T(487,2044,fw),f.$b=function(){sc(this)},f._b=function(t){return jc(this,t)},f.uc=function(t){return pWe(this,t,this.i)||pWe(this,t,this.f)},f.vc=function(){return new Bp(this)},f.xc=function(t){return Ut(this,t)},f.yc=function(t,n){return oi(this,t,n)},f.Ac=function(t){return E5(this,t)},f.gc=function(){return r7(this)},f.g=0,C(yn,"AbstractHashMap",487),T(307,Nh,Ll,Bp),f.$b=function(){this.a.$b()},f.Gc=function(t){return VQe(this,t)},f.Jc=function(){return new sv(this.a)},f.Kc=function(t){var n;return VQe(this,t)?(n=c(t,45).jd(),this.a.Ac(n),!0):!1},f.gc=function(){return this.a.gc()},C(yn,"AbstractHashMap/EntrySet",307),T(308,1,ts,sv),f.Nb=function(t){gs(this,t)},f.Pb=function(){return Ex(this)},f.Ob=function(){return this.b},f.Qb=function(){jJe(this)},f.b=!1,f.d=0,C(yn,"AbstractHashMap/EntrySetIterator",308),T(422,1,ts,Gj),f.Nb=function(t){gs(this,t)},f.Ob=function(){return gY(this)},f.Pb=function(){return Tpe(this)},f.Qb=function(){iu(this)},f.b=0,f.c=-1,C(yn,"AbstractList/IteratorImpl",422),T(97,422,Ud,os),f.Qb=function(){iu(this)},f.Rb=function(t){z2(this,t)},f.Sb=function(){return this.b>0},f.Tb=function(){return this.b},f.Ub=function(){return dn(this.b>0),this.a.Xb(this.c=--this.b)},f.Vb=function(){return this.b-1},f.Wb=function(t){I2(this.c!=-1),this.a.fd(this.c,t)},C(yn,"AbstractList/ListIteratorImpl",97),T(217,56,US,nd),f._c=function(t,n){K2(t,this.b),this.c._c(this.a+t,n),++this.b},f.Xb=function(t){return ht(t,this.b),this.c.Xb(this.a+t)},f.ed=function(t){var n;return ht(t,this.b),n=this.c.ed(this.a+t),--this.b,n},f.fd=function(t,n){return ht(t,this.b),this.c.fd(this.a+t,n)},f.gc=function(){return this.b},f.a=0,f.b=0,C(yn,"AbstractList/SubList",217),T(234,Nh,Ll,an),f.$b=function(){this.a.$b()},f.Gc=function(t){return this.a._b(t)},f.Jc=function(){var t;return t=this.a.vc().Jc(),new mr(t)},f.Kc=function(t){return this.a._b(t)?(this.a.Ac(t),!0):!1},f.gc=function(){return this.a.gc()},C(yn,"AbstractMap/1",234),T(533,1,ts,mr),f.Nb=function(t){gs(this,t)},f.Ob=function(){return this.a.Ob()},f.Pb=function(){var t;return t=c(this.a.Pb(),45),t.jd()},f.Qb=function(){this.a.Qb()},C(yn,"AbstractMap/1/1",533),T(232,32,Ov,x1),f.$b=function(){this.a.$b()},f.Gc=function(t){return this.a.uc(t)},f.Jc=function(){var t;return t=this.a.vc().Jc(),new C2(t)},f.gc=function(){return this.a.gc()},C(yn,"AbstractMap/2",232),T(305,1,ts,C2),f.Nb=function(t){gs(this,t)},f.Ob=function(){return this.a.Ob()},f.Pb=function(){var t;return t=c(this.a.Pb(),45),t.kd()},f.Qb=function(){this.a.Qb()},C(yn,"AbstractMap/2/1",305),T(483,1,{483:1,45:1}),f.Fb=function(t){var n;return oe(t,45)?(n=c(t,45),dc(this.d,n.jd())&&dc(this.e,n.kd())):!1},f.jd=function(){return this.d},f.kd=function(){return this.e},f.Hb=function(){return gx(this.d)^gx(this.e)},f.ld=function(t){return Yge(this,t)},f.Ib=function(){return this.d+"="+this.e},C(yn,"AbstractMap/AbstractEntry",483),T(392,483,{483:1,392:1,45:1},qz),C(yn,"AbstractMap/SimpleEntry",392),T(2061,1,are),f.Fb=function(t){var n;return oe(t,45)?(n=c(t,45),dc(this.jd(),n.jd())&&dc(this.kd(),n.kd())):!1},f.Hb=function(){return gx(this.jd())^gx(this.kd())},f.Ib=function(){return this.jd()+"="+this.kd()},C(yn,Fst,2061),T(2069,2044,txe),f.Vc=function(t){return sY(this.Ce(t))},f.tc=function(t){return XGe(this,t)},f._b=function(t){return Kge(this,t)},f.vc=function(){return new LK(this)},f.Rc=function(){return uqe(this.Ee())},f.Wc=function(t){return sY(this.Fe(t))},f.xc=function(t){var n;return n=t,Ao(this.De(n))},f.Yc=function(t){return sY(this.Ge(t))},f.ec=function(){return new PAe(this)},f.Tc=function(){return uqe(this.He())},f.Zc=function(t){return sY(this.Ie(t))},C(yn,"AbstractNavigableMap",2069),T(627,Nh,Ll,LK),f.Gc=function(t){return oe(t,45)&&XGe(this.b,c(t,45))},f.Jc=function(){return this.b.Be()},f.Kc=function(t){var n;return oe(t,45)?(n=c(t,45),this.b.Je(n)):!1},f.gc=function(){return this.b.gc()},C(yn,"AbstractNavigableMap/EntrySet",627),T(1127,Nh,nxe,PAe),f.Lc=function(){return new Qz(this)},f.$b=function(){this.a.$b()},f.Gc=function(t){return Kge(this.a,t)},f.Jc=function(){var t;return t=this.a.vc().b.Be(),new IAe(t)},f.Kc=function(t){return Kge(this.a,t)?(this.a.Ac(t),!0):!1},f.gc=function(){return this.a.gc()},C(yn,"AbstractNavigableMap/NavigableKeySet",1127),T(1128,1,ts,IAe),f.Nb=function(t){gs(this,t)},f.Ob=function(){return gY(this.a.a)},f.Pb=function(){var t;return t=EBe(this.a),t.jd()},f.Qb=function(){_ze(this.a)},C(yn,"AbstractNavigableMap/NavigableKeySet/1",1128),T(2082,32,Ov),f.Ec=function(t){return p5(CS(this,t),XS),!0},f.Fc=function(t){return zt(t),N_(t!=this,"Can't add a queue to itself"),Os(this,t)},f.$b=function(){for(;Zee(this)!=null;);},C(yn,"AbstractQueue",2082),T(315,32,{4:1,22:1,32:1,18:1},bx,ZQe),f.Ec=function(t){return Zpe(this,t),!0},f.$b=function(){sbe(this)},f.Gc=function(t){return _Ve(new G7(this),t)},f.dc=function(){return e7(this)},f.Jc=function(){return new G7(this)},f.Kc=function(t){return ONt(new G7(this),t)},f.gc=function(){return this.c-this.b&this.a.length-1},f.Lc=function(){return new Tt(this,272)},f.Oc=function(t){var n;return n=this.c-this.b&this.a.length-1,t.length<n&&(t=Tz(new Array(n),t)),JXe(this,t,n),t.length>n&&dr(t,n,null),t},f.b=0,f.c=0,C(yn,"ArrayDeque",315),T(451,1,ts,G7),f.Nb=function(t){gs(this,t)},f.Ob=function(){return this.a!=this.b},f.Pb=function(){return EH(this)},f.Qb=function(){NXe(this)},f.a=0,f.b=0,f.c=-1,C(yn,"ArrayDeque/IteratorImpl",451),T(13,56,iot,Fe,Hc,Fl),f._c=function(t,n){Up(this,t,n)},f.Ec=function(t){return qe(this,t)},f.ad=function(t,n){return Vme(this,t,n)},f.Fc=function(t){return yr(this,t)},f.$b=function(){M2(this.c,0)},f.Gc=function(t){return Do(this,t,0)!=-1},f.Ic=function(t){Qc(this,t)},f.Xb=function(t){return Xe(this,t)},f.bd=function(t){return Do(this,t,0)},f.dc=function(){return this.c.length==0},f.Jc=function(){return new G(this)},f.ed=function(t){return Mg(this,t)},f.Kc=function(t){return fl(this,t)},f.ae=function(t,n){pQe(this,t,n)},f.fd=function(t,n){return Su(this,t,n)},f.gc=function(){return this.c.length},f.gd=function(t){Rr(this,t)},f.Nc=function(){return zF(this.c)},f.Oc=function(t){return jh(this,t)};var Ltn=C(yn,"ArrayList",13);T(7,1,ts,G),f.Nb=function(t){gs(this,t)},f.Ob=function(){return No(this)},f.Pb=function(){return Q(this)},f.Qb=function(){z7(this)},f.a=0,f.b=-1,C(yn,"ArrayList/1",7),T(2091,p.Function,{},He),f.Ke=function(t,n){return ji(t,n)},T(124,56,rot,Ho),f.Gc=function(t){return AXe(this,t)!=-1},f.Ic=function(t){var n,i,r,o;for(zt(t),i=this.a,r=0,o=i.length;r<o;++r)n=i[r],t.Ad(n)},f.Xb=function(t){return TFe(this,t)},f.fd=function(t,n){var i;return i=(ht(t,this.a.length),this.a[t]),dr(this.a,t,n),i},f.gc=function(){return this.a.length},f.gd=function(t){NZ(this.a,this.a.length,t)},f.Nc=function(){return VKe(this,ye(Br,Lt,1,this.a.length,5,1))},f.Oc=function(t){return VKe(this,t)},C(yn,"Arrays/ArrayList",124);var Rs,Yd,eU;T(945,56,rot,Le),f.Gc=function(t){return!1},f.Xb=function(t){return tge(t)},f.Jc=function(){return Ct(),j6(),S9},f.cd=function(){return Ct(),j6(),S9},f.gc=function(){return 0},C(yn,"Collections/EmptyList",945),T(946,1,Ud,Oe),f.Nb=function(t){gs(this,t)},f.Rb=function(t){throw J(new $n)},f.Ob=function(){return!1},f.Sb=function(){return!1},f.Pb=function(){throw J(new Co)},f.Tb=function(){return 0},f.Ub=function(){throw J(new Co)},f.Vb=function(){return-1},f.Qb=function(){throw J(new Tl)},f.Wb=function(t){throw J(new Tl)};var S9;C(yn,"Collections/EmptyListIterator",946),T(948,2044,GS,Qe),f._b=function(t){return!1},f.uc=function(t){return!1},f.vc=function(){return Ct(),eU},f.xc=function(t){return null},f.ec=function(){return Ct(),eU},f.gc=function(){return 0},f.Bc=function(){return Ct(),Rs},C(yn,"Collections/EmptyMap",948),T(947,Nh,Y5,ae),f.Gc=function(t){return!1},f.Jc=function(){return Ct(),j6(),S9},f.gc=function(){return 0},C(yn,"Collections/EmptySet",947),T(604,56,{3:1,22:1,32:1,56:1,18:1,16:1},DK),f.Gc=function(t){return dc(this.a,t)},f.Xb=function(t){return ht(t,1),this.a},f.gc=function(){return 1},C(yn,"Collections/SingletonList",604),T(379,1,Qst,f6),f.Ic=function(t){ws(this,t)},f.Lc=function(){return new Tt(this,0)},f.Mc=function(){return new jt(null,this.Lc())},f.Ec=function(t){return MPe()},f.Fc=function(t){return APe()},f.$b=function(){NPe()},f.Gc=function(t){return i7(this,t)},f.Hc=function(t){return f1e(this,t)},f.dc=function(){return this.b.dc()},f.Jc=function(){return new nx(this.b.Jc())},f.Kc=function(t){return _Pe()},f.gc=function(){return this.b.gc()},f.Nc=function(){return this.b.Nc()},f.Oc=function(t){return h1e(this,t)},f.Ib=function(){return jo(this.b)},C(yn,"Collections/UnmodifiableCollection",379),T(326,1,ts,nx),f.Nb=function(t){gs(this,t)},f.Ob=function(){return this.b.Ob()},f.Pb=function(){return this.b.Pb()},f.Qb=function(){DPe()},C(yn,"Collections/UnmodifiableCollectionIterator",326),T(532,379,sot,TF),f.Lc=function(){return new Tt(this,16)},f._c=function(t,n){throw J(new $n)},f.ad=function(t,n){throw J(new $n)},f.Fb=function(t){return yi(this.a,t)},f.Xb=function(t){return this.a.Xb(t)},f.Hb=function(){return Ri(this.a)},f.bd=function(t){return this.a.bd(t)},f.dc=function(){return this.a.dc()},f.cd=function(){return new Ege(this.a.dd(0))},f.dd=function(t){return new Ege(this.a.dd(t))},f.ed=function(t){throw J(new $n)},f.fd=function(t,n){throw J(new $n)},f.gd=function(t){throw J(new $n)},f.hd=function(t,n){return new TF(this.a.hd(t,n))},C(yn,"Collections/UnmodifiableList",532),T(701,326,Ud,Ege),f.Qb=function(){DPe()},f.Rb=function(t){throw J(new $n)},f.Sb=function(){return this.a.Sb()},f.Tb=function(){return this.a.Tb()},f.Ub=function(){return this.a.Ub()},f.Vb=function(){return this.a.Vb()},f.Wb=function(t){throw J(new $n)},C(yn,"Collections/UnmodifiableListIterator",701),T(605,1,fw,PK),f.wc=function(t){fD(this,t)},f.$b=function(){throw J(new $n)},f._b=function(t){return this.c._b(t)},f.uc=function(t){return kIe(this,t)},f.vc=function(){return q6(this)},f.Fb=function(t){return OIe(this,t)},f.xc=function(t){return this.c.xc(t)},f.Hb=function(){return Ri(this.c)},f.dc=function(){return this.c.dc()},f.ec=function(){return Fqe(this)},f.yc=function(t,n){throw J(new $n)},f.Ac=function(t){throw J(new $n)},f.gc=function(){return this.c.gc()},f.Ib=function(){return jo(this.c)},f.Bc=function(){return zqe(this)},C(yn,"Collections/UnmodifiableMap",605),T(391,379,zie,w6),f.Lc=function(){return new Tt(this,1)},f.Fb=function(t){return yi(this.b,t)},f.Hb=function(){return Ri(this.b)},C(yn,"Collections/UnmodifiableSet",391),T(949,391,zie,uPe),f.Gc=function(t){return xIe(this,t)},f.Hc=function(t){return this.b.Hc(t)},f.Jc=function(){var t;return t=this.b.Jc(),new RAe(t)},f.Nc=function(){var t;return t=this.b.Nc(),xGe(t,t.length),t},f.Oc=function(t){return CHe(this,t)},C(yn,"Collections/UnmodifiableMap/UnmodifiableEntrySet",949),T(950,1,ts,RAe),f.Nb=function(t){gs(this,t)},f.Pb=function(){return new lde(c(this.a.Pb(),45))},f.Ob=function(){return this.a.Ob()},f.Qb=function(){throw J(new $n)},C(yn,"Collections/UnmodifiableMap/UnmodifiableEntrySet/1",950),T(699,1,are,lde),f.Fb=function(t){return this.a.Fb(t)},f.jd=function(){return this.a.jd()},f.kd=function(){return this.a.kd()},f.Hb=function(){return this.a.Hb()},f.ld=function(t){throw J(new $n)},f.Ib=function(){return jo(this.a)},C(yn,"Collections/UnmodifiableMap/UnmodifiableEntrySet/UnmodifiableEntry",699),T(606,532,{22:1,18:1,16:1,59:1},iY),C(yn,"Collections/UnmodifiableRandomAccessList",606),T(700,391,Gst,Cge),f.Lc=function(){return new Qz(this)},f.Fb=function(t){return yi(this.a,t)},f.Hb=function(){return Ri(this.a)},C(yn,"Collections/UnmodifiableSortedSet",700),T(850,1,fre,kt),f.Le=function(t,n){var i;return i=kGe(c(t,12),c(n,12)),i!=0?i:Dit(c(t,12),c(n,12))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(yn,"Comparator/lambda$0$Type",850);var hke,Poe,dke;T(763,1,fre,Ae),f.Le=function(t,n){return WCt(c(t,34),c(n,34))},f.Fb=function(t){return this===t},f.Me=function(){return Fm(),dke},C(yn,"Comparators/NaturalOrderComparator",763),T(1203,1,fre,Ye),f.Le=function(t,n){return KCt(c(t,34),c(n,34))},f.Fb=function(t){return this===t},f.Me=function(){return Fm(),Poe},C(yn,"Comparators/ReverseNaturalOrderComparator",1203),T(55,1,fre,Xn),f.Fb=function(t){return this===t},f.Le=function(t,n){return this.a.Le(n,t)},f.Me=function(){return this.a},C(yn,"Comparators/ReversedComparator",55),T(179,63,H1,ua),C(yn,"ConcurrentModificationException",179);var Gat,Uat;T(1364,1,dL,mt),f.Ne=function(t){SKe(this,t)},f.Ib=function(){return"DoubleSummaryStatistics[count = "+R7(this.a)+", avg = "+(hY(this.a,0)?wbe(this)/ib(this.a):0)+", min = "+this.c+", max = "+this.b+", sum = "+wbe(this)+"]"},f.a=0,f.b=Qr,f.c=nr,f.d=0,f.e=0,f.f=0,C(yn,"DoubleSummaryStatistics",1364),T(1864,63,H1,nLe),C(yn,"EmptyStackException",1864),T(453,2044,fw,yT),f.yc=function(t,n){return Wge(this,t,n)},f.$b=function(){_qe(this)},f._b=function(t){return BIe(this,t)},f.uc=function(t){var n,i;for(i=new t5(this.a);i.a<i.c.a.length;)if(n=Y7(i),dc(t,this.b[n.g]))return!0;return!1},f.vc=function(){return new BAe(this)},f.xc=function(t){return Zs(this,t)},f.Ac=function(t){return Hpe(this,t)},f.gc=function(){return this.a.c},C(yn,"EnumMap",453),T(1304,Nh,Ll,BAe),f.$b=function(){_qe(this.a)},f.Gc=function(t){return WQe(this,t)},f.Jc=function(){return new jFe(this.a)},f.Kc=function(t){var n;return WQe(this,t)?(n=c(t,45).jd(),Hpe(this.a,n),!0):!1},f.gc=function(){return this.a.a.c},C(yn,"EnumMap/EntrySet",1304),T(1305,1,ts,jFe),f.Nb=function(t){gs(this,t)},f.Pb=function(){return this.b=Y7(this.a),new FIe(this.c,this.b)},f.Ob=function(){return lge(this.a)},f.Qb=function(){I2(!!this.b),Hpe(this.c,this.b),this.b=null},C(yn,"EnumMap/EntrySetIterator",1305),T(1306,2061,are,FIe),f.jd=function(){return this.a},f.kd=function(){return this.b.b[this.a.g]},f.ld=function(t){return $0e(this.b.b,this.a.g,t)},C(yn,"EnumMap/MapEntry",1306),T(185,Nh,{22:1,32:1,18:1,185:1,24:1});var Jat=C(yn,"EnumSet",185);T(167,185,{22:1,32:1,18:1,185:1,167:1,24:1},ha),f.Ec=function(t){return yf(this,c(t,23))},f.Gc=function(t){return _Z(this,t)},f.Jc=function(){return new t5(this)},f.Kc=function(t){return RFe(this,t)},f.gc=function(){return this.c},f.c=0,C(yn,"EnumSet/EnumSetImpl",167),T(357,1,ts,t5),f.Nb=function(t){gs(this,t)},f.Pb=function(){return Y7(this)},f.Ob=function(){return lge(this)},f.Qb=function(){I2(this.b!=-1),dr(this.c.b,this.b,null),--this.c.c,this.b=-1},f.a=-1,f.b=-1,C(yn,"EnumSet/EnumSetImpl/IteratorImpl",357),T(44,487,Gx,wn,e5,k$e),f.ze=function(t,n){return ve(t)===ve(n)||t!=null&&yi(t,n)},f.Ae=function(t){var n;return t==null?0:(n=Ri(t),n|0)},C(yn,"HashMap",44),T(47,Nh,uxe,Or,Cz,q2),f.Ec=function(t){return Sr(this,t)},f.$b=function(){this.a.$b()},f.Gc=function(t){return $a(this,t)},f.dc=function(){return this.a.gc()==0},f.Jc=function(){return this.a.ec().Jc()},f.Kc=function(t){return bge(this,t)},f.gc=function(){return this.a.gc()};var Ptn=C(yn,"HashSet",47);T(1884,1,oL,Ue),f.Bd=function(t){yVe(this,t)},f.Ib=function(){return"IntSummaryStatistics[count = "+R7(this.a)+", avg = "+(hY(this.a,0)?ib(this.d)/ib(this.a):0)+", min = "+this.c+", max = "+this.b+", sum = "+R7(this.d)+"]"},f.a=0,f.b=ls,f.c=di,f.d=0,C(yn,"IntSummaryStatistics",1884),T(1054,1,Jd,O$e),f.Ic=function(t){ws(this,t)},f.Jc=function(){return new Cbe(this)},f.c=0,C(yn,"InternalHashCodeMap",1054),T(723,1,ts,Cbe),f.Nb=function(t){gs(this,t)},f.Pb=function(){return this.d=this.a[this.c++],this.d},f.Ob=function(){var t;return this.c<this.a.length?!0:(t=this.b.next(),t.done?!1:(this.a=t.value[1],this.c=0,!0))},f.Qb=function(){kve(this.e,this.d.jd()),this.c!=0&&--this.c},f.c=0,f.d=null,C(yn,"InternalHashCodeMap/1",723);var Xat;T(1052,1,Jd,S$e),f.Ic=function(t){ws(this,t)},f.Jc=function(){return new lbe(this)},f.c=0,f.d=0,C(yn,"InternalStringMap",1052),T(722,1,ts,lbe),f.Nb=function(t){gs(this,t)},f.Pb=function(){return this.c=this.a,this.a=this.b.next(),new Pze(this.d,this.c,this.d.d)},f.Ob=function(){return!this.a.done},f.Qb=function(){OVe(this.d,this.c.value[0])},C(yn,"InternalStringMap/1",722),T(1053,2061,are,Pze),f.jd=function(){return this.b.value[0]},f.kd=function(){return this.a.d!=this.c?f7(this.a,this.b.value[0]):this.b.value[1]},f.ld=function(t){return Zm(this.a,this.b.value[0],t)},f.c=0,C(yn,"InternalStringMap/2",1053),T(226,44,Gx,M0,Ebe),f.$b=function(){rze(this)},f._b=function(t){return zIe(this,t)},f.uc=function(t){var n;for(n=this.d.a;n!=this.d;){if(dc(n.e,t))return!0;n=n.a}return!1},f.vc=function(){return new ade(this)},f.xc=function(t){return Oh(this,t)},f.yc=function(t,n){return gb(this,t,n)},f.Ac=function(t){return SJe(this,t)},f.gc=function(){return r7(this.e)},f.c=!1,C(yn,"LinkedHashMap",226),T(395,392,{483:1,392:1,395:1,45:1},MBe,j0e),C(yn,"LinkedHashMap/ChainEntry",395),T(711,Nh,Ll,ade),f.$b=function(){rze(this.a)},f.Gc=function(t){return KQe(this,t)},f.Jc=function(){return new fpe(this)},f.Kc=function(t){var n;return KQe(this,t)?(n=c(t,45).jd(),SJe(this.a,n),!0):!1},f.gc=function(){return r7(this.a.e)},C(yn,"LinkedHashMap/EntrySet",711),T(712,1,ts,fpe),f.Nb=function(t){gs(this,t)},f.Pb=function(){return CJe(this)},f.Ob=function(){return this.c!=this.d.a.d},f.Qb=function(){I2(!!this.a),yZ(this.d.a.e.g,this.b),L0e(this.a),E5(this.d.a.e,this.a.d),this.b=this.d.a.e.g,this.a=null},f.b=0,C(yn,"LinkedHashMap/EntrySet/EntryIterator",712),T(184,47,uxe,Ld,oZ,q0e);var Itn=C(yn,"LinkedHashSet",184);T(66,2041,{3:1,4:1,22:1,32:1,56:1,18:1,66:1,16:1},Ai,wZ),f.Ec=function(t){return ei(this,t)},f.$b=function(){Ou(this)},f.dd=function(t){return _n(this,t)},f.gc=function(){return this.b},f.b=0;var Rtn=C(yn,"LinkedList",66);T(972,1,Ud,Rze),f.Nb=function(t){gs(this,t)},f.Rb=function(t){oq(this,t)},f.Ob=function(){return XN(this)},f.Sb=function(){return this.b.b!=this.d.a},f.Pb=function(){return An(this)},f.Tb=function(){return this.a},f.Ub=function(){return $Qe(this)},f.Vb=function(){return this.a-1},f.Qb=function(){tte(this)},f.Wb=function(t){I2(!!this.c),this.c.c=t},f.a=0,f.c=null,C(yn,"LinkedList/ListIteratorImpl",972),T(614,1,{},Pt),C(yn,"LinkedList/Node",614),T(2036,1,{});var gke,Vat;C(yn,"Locale",2036),T(863,2036,{},rn),f.Ib=function(){return""},C(yn,"Locale/1",863),T(864,2036,{},Cn),f.Ib=function(){return"unknown"},C(yn,"Locale/4",864),T(113,63,{3:1,102:1,63:1,81:1,113:1},Co,Qqe),C(yn,"NoSuchElementException",113),T(461,1,{461:1},VK),f.Fb=function(t){var n;return t===this?!0:oe(t,461)?(n=c(t,461),dc(this.a,n.a)):!1},f.Hb=function(){return gx(this.a)},f.Ib=function(){return this.a!=null?Bst+A7(this.a)+")":"Optional.empty()"};var pke;C(yn,"Optional",461),T(405,1,{405:1},p$e,uZ),f.Fb=function(t){var n;return t===this?!0:oe(t,405)?(n=c(t,405),this.a==n.a&&ji(this.b,n.b)==0):!1},f.Hb=function(){return this.a?xs(this.b):0},f.Ib=function(){return this.a?"OptionalDouble.of("+(""+this.b)+")":"OptionalDouble.empty()"},f.a=!1,f.b=0;var Ioe;C(yn,"OptionalDouble",405),T(514,1,{514:1},b$e,_Be),f.Fb=function(t){var n;return t===this?!0:oe(t,514)?(n=c(t,514),this.a==n.a&&fc(this.b,n.b)==0):!1},f.Hb=function(){return this.a?this.b:0},f.Ib=function(){return this.a?"OptionalInt.of("+(""+this.b)+")":"OptionalInt.empty()"},f.a=!1,f.b=0;var Wat;C(yn,"OptionalInt",514),T(500,2082,Ov,nq),f.Fc=function(t){return r2e(this,t)},f.$b=function(){M2(this.b.c,0)},f.Gc=function(t){return(t==null?-1:Do(this.b,t,0))!=-1},f.Jc=function(){return new $Ae(this)},f.Kc=function(t){return UXe(this,t)},f.gc=function(){return this.b.c.length},f.Lc=function(){return new Tt(this,256)},f.Nc=function(){return zF(this.b.c)},f.Oc=function(t){return jh(this.b,t)},C(yn,"PriorityQueue",500),T(1272,1,ts,$Ae),f.Nb=function(t){gs(this,t)},f.Ob=function(){return this.a<this.c.b.c.length},f.Pb=function(){return dn(this.a<this.c.b.c.length),this.b=this.a++,Xe(this.c.b,this.b)},f.Qb=function(){I2(this.b!=-1),lte(this.c,this.a=this.b),this.b=-1},f.a=0,f.b=-1,C(yn,"PriorityQueue/1",1272),T(237,1,{237:1},Ute,Lq),f.a=0,f.b=0;var bke,mke,$tn=0;C(yn,"Random",237),T(27,1,Gu,Tt,U2,Yqe),f.yd=function(t){return(this.a&t)!=0},f.wd=function(){return this.a},f.xd=function(){return K0e(this),this.c},f.Nb=function(t){K0e(this),this.d.Nb(t)},f.zd=function(t){return XJe(this,t)},f.a=0,f.c=0,C(yn,"Spliterators/IteratorSpliterator",27),T(484,27,Gu,Qz),C(yn,"SortedSet/1",484),T(607,1,dL,fde),f.Ne=function(t){this.a.Ad(t)},C(yn,"Spliterator/OfDouble/0methodref$accept$Type",607),T(608,1,dL,hde),f.Ne=function(t){this.a.Ad(t)},C(yn,"Spliterator/OfDouble/1methodref$accept$Type",608),T(609,1,oL,dde),f.Bd=function(t){this.a.Ad(Pe(t))},C(yn,"Spliterator/OfInt/2methodref$accept$Type",609),T(610,1,oL,gde),f.Bd=function(t){this.a.Ad(Pe(t))},C(yn,"Spliterator/OfInt/3methodref$accept$Type",610),T(623,1,Gu),f.Nb=function(t){i1e(this,t)},f.yd=function(t){return(this.d&t)!=0},f.wd=function(){return this.d},f.xd=function(){return this.e},f.d=0,f.e=0,C(yn,"Spliterators/BaseSpliterator",623),T(731,623,Gu),f.Oe=function(t){sx(this,t)},f.Nb=function(t){oe(t,191)?sx(this,c(t,191)):sx(this,new hde(t))},f.zd=function(t){return oe(t,191)?this.Pe(c(t,191)):this.Pe(new fde(t))},C(yn,"Spliterators/AbstractDoubleSpliterator",731),T(730,623,Gu),f.Oe=function(t){sx(this,t)},f.Nb=function(t){oe(t,204)?sx(this,c(t,204)):sx(this,new gde(t))},f.zd=function(t){return oe(t,204)?this.Pe(c(t,204)):this.Pe(new dde(t))},C(yn,"Spliterators/AbstractIntSpliterator",730),T(489,623,Gu),C(yn,"Spliterators/AbstractSpliterator",489),T(702,1,Gu),f.Nb=function(t){i1e(this,t)},f.yd=function(t){return(this.b&t)!=0},f.wd=function(){return this.b},f.xd=function(){return this.d-this.c},f.b=0,f.c=0,f.d=0,C(yn,"Spliterators/BaseArraySpliterator",702),T(952,702,Gu,hFe),f.Qe=function(t,n){j9t(this,c(t,42),n)},f.Nb=function(t){eee(this,t)},f.zd=function(t){return zq(this,t)},C(yn,"Spliterators/ArraySpliterator",952),T(703,702,Gu,jze),f.Qe=function(t,n){T9t(this,c(t,191),n)},f.Oe=function(t){eee(this,t)},f.Nb=function(t){oe(t,191)?eee(this,c(t,191)):eee(this,new hde(t))},f.Pe=function(t){return zq(this,t)},f.zd=function(t){return oe(t,191)?zq(this,c(t,191)):zq(this,new fde(t))},C(yn,"Spliterators/DoubleArraySpliterator",703),T(2045,1,Gu),f.Nb=function(t){i1e(this,t)},f.yd=function(t){return(16448&t)!=0},f.wd=function(){return 16448},f.xd=function(){return 0};var Kat;C(yn,"Spliterators/EmptySpliterator",2045),T(951,2045,Gu,Pn),f.Oe=function(t){$p(t)},f.Nb=function(t){oe(t,204)?$p(c(t,204)):$p(new gde(t))},f.Pe=function(t){return k1e(t)},f.zd=function(t){return oe(t,204)?k1e(c(t,204)):k1e(new dde(t))},C(yn,"Spliterators/EmptySpliterator/OfInt",951),T(581,56,oot,vz),f._c=function(t,n){R6(t,this.a.c.length+1),Up(this.a,t,n)},f.Ec=function(t){return qe(this.a,t)},f.ad=function(t,n){return R6(t,this.a.c.length+1),Vme(this.a,t,n)},f.Fc=function(t){return yr(this.a,t)},f.$b=function(){M2(this.a.c,0)},f.Gc=function(t){return Do(this.a,t,0)!=-1},f.Hc=function(t){return mD(this.a,t)},f.Ic=function(t){Qc(this.a,t)},f.Xb=function(t){return R6(t,this.a.c.length),Xe(this.a,t)},f.bd=function(t){return Do(this.a,t,0)},f.dc=function(){return this.a.c.length==0},f.Jc=function(){return new G(this.a)},f.ed=function(t){return R6(t,this.a.c.length),Mg(this.a,t)},f.ae=function(t,n){pQe(this.a,t,n)},f.fd=function(t,n){return R6(t,this.a.c.length),Su(this.a,t,n)},f.gc=function(){return this.a.c.length},f.gd=function(t){Rr(this.a,t)},f.hd=function(t,n){return new nd(this.a,t,n)},f.Nc=function(){return zF(this.a.c)},f.Oc=function(t){return jh(this.a,t)},f.Ib=function(){return Mh(this.a)},C(yn,"Vector",581),T(582,581,oot,yz),C(yn,"Stack",582),T(215,1,{215:1},ub),f.Ib=function(){return RQe(this)},C(yn,"StringJoiner",215),T(545,2069,{3:1,93:1,141:1,136:1},jIe,zZ),f.$b=function(){ZLe(this)},f.Be=function(){return new QQe(this)},f.vc=function(){return new OBe(this)},f.Ce=function(t){return xS(this,t,!0)},f.De=function(t){return aWe(this,t)},f.Ee=function(){return Ibe(this)},f.Fe=function(t){return MD(this,t,!0)},f.Ge=function(t){return xS(this,t,!1)},f.He=function(){return eJe(this)},f.Ie=function(t){return MD(this,t,!1)},f.Xc=function(t,n){return gQe(this,t,n)},f.yc=function(t,n){return WVe(this,t,n)},f.Ac=function(t){return PHe(this,t)},f.Je=function(t){return jbe(this,t)},f.gc=function(){return this.c},f.$c=function(t,n){return dQe(this,t,n)},f.c=0,C(yn,"TreeMap",545),T(546,1,ts,QQe,hte),f.Nb=function(t){gs(this,t)},f.Pb=function(){return EBe(this)},f.Ob=function(){return gY(this.a)},f.Qb=function(){_ze(this)},C(yn,"TreeMap/EntryIterator",546),T(1123,627,Ll,OBe),f.$b=function(){ZLe(this.a)},C(yn,"TreeMap/EntrySet",1123),T(443,392,{483:1,392:1,45:1,443:1},qee),f.b=!1;var Btn=C(yn,"TreeMap/Node",443);T(628,1,{},mi),f.Ib=function(){return"State: mv="+this.c+" value="+this.d+" done="+this.a+" found="+this.b},f.a=!1,f.b=!1,f.c=!1,C(yn,"TreeMap/State",628),T(629,2069,txe,qne),f.Be=function(){return new hte(this.c,this.f,this.b,this.a,this.e,this.d)},f.vc=function(){return new LK(this)},f.Ce=function(t){return RF(this,xS(this.c,t,!0))},f.De=function(t){return RF(this,aWe(this.c,t))},f.Ee=function(){var t;return this.f.Re()?this.a?t=xS(this.c,this.b,!0):t=xS(this.c,this.b,!1):t=Ibe(this.c),t&&uq(this,t.d)?t:null},f.Fe=function(t){return RF(this,MD(this.c,t,!0))},f.Ge=function(t){return RF(this,xS(this.c,t,!1))},f.He=function(){var t;return this.f.Se()?this.d?t=MD(this.c,this.e,!0):t=MD(this.c,this.e,!1):t=eJe(this.c),t&&uq(this,t.d)?t:null},f.Ie=function(t){return RF(this,MD(this.c,t,!1))},f.Xc=function(t,n){if(this.f.Se()&&this.c.a.Le(t,this.e)>0)throw J(new qt(hxe+t+" greater than "+this.e));return this.f.Re()?LHe(this.c,this.b,this.a,t,n):gQe(this.c,t,n)},f.yc=function(t,n){if(!Tne(this.c,this.f,t,this.b,this.a,this.e,this.d))throw J(new qt(t+" outside the range "+this.b+" to "+this.e));return WVe(this.c,t,n)},f.Ac=function(t){var n;return n=t,Tne(this.c,this.f,n,this.b,this.a,this.e,this.d)?PHe(this.c,n):null},f.Je=function(t){return uq(this,t.jd())&&jbe(this.c,t)},f.gc=function(){var t,n,i;if(this.f.Re()?this.a?n=xS(this.c,this.b,!0):n=xS(this.c,this.b,!1):n=Ibe(this.c),!(n&&uq(this,n.d)&&n))return 0;for(t=0,i=new hte(this.c,this.f,this.b,this.a,this.e,this.d);gY(i.a);i.b=c(Tpe(i.a),45))++t;return t},f.$c=function(t,n){if(this.f.Re()&&this.c.a.Le(t,this.b)<0)throw J(new qt(hxe+t+cot+this.b));return this.f.Se()?LHe(this.c,t,n,this.e,this.d):dQe(this.c,t,n)},f.a=!1,f.d=!1,C(yn,"TreeMap/SubMap",629),T(310,23,gre,Gz),f.Re=function(){return!1},f.Se=function(){return!1};var Roe,$oe,Boe,zoe,tU=mn(yn,"TreeMap/SubMapType",310,On,V_t,uTt);T(1124,310,gre,A$e),f.Se=function(){return!0},mn(yn,"TreeMap/SubMapType/1",1124,tU,null,null),T(1125,310,gre,q$e),f.Re=function(){return!0},f.Se=function(){return!0},mn(yn,"TreeMap/SubMapType/2",1125,tU,null,null),T(1126,310,gre,N$e),f.Re=function(){return!0},mn(yn,"TreeMap/SubMapType/3",1126,tU,null,null);var Yat;T(143,Nh,{3:1,22:1,32:1,18:1,279:1,24:1,85:1,143:1},FK,Mge,kg,h6),f.Lc=function(){return new Qz(this)},f.Ec=function(t){return L_(this,t)},f.$b=function(){this.a.$b()},f.Gc=function(t){return this.a._b(t)},f.Jc=function(){return this.a.ec().Jc()},f.Kc=function(t){return rZ(this,t)},f.gc=function(){return this.a.gc()};var ztn=C(yn,"TreeSet",143);T(1063,1,{},zAe),f.Te=function(t,n){return C7t(this.a,t,n)},C(pre,"BinaryOperator/lambda$0$Type",1063),T(1064,1,{},FAe),f.Te=function(t,n){return M7t(this.a,t,n)},C(pre,"BinaryOperator/lambda$1$Type",1064),T(944,1,{},Mr),f.Kb=function(t){return t},C(pre,"Function/lambda$0$Type",944),T(390,1,Jn,d6),f.Mb=function(t){return!this.a.Mb(t)},C(pre,"Predicate/lambda$2$Type",390),T(574,1,{574:1});var Zat=C(eE,"Handler",574);T(2086,1,rL),f.ve=function(){return"DUMMY"},f.Ib=function(){return this.ve()};var wke;C(eE,"Level",2086),T(1689,2086,rL,hr),f.ve=function(){return"INFO"},C(eE,"Level/LevelInfo",1689),T(1841,1,{},oLe);var Foe;C(eE,"LogManager",1841),T(1883,1,rL,$ze),f.b=null,C(eE,"LogRecord",1883),T(515,1,{515:1},_ee),f.e=!1;var eft=!1,tft=!1,Ph=!1,nft=!1,ift=!1;C(eE,"Logger",515),T(827,574,{574:1},Gn),C(eE,"SimpleConsoleLogHandler",827),T(132,23,{3:1,34:1,23:1,132:1},pY);var vke,bl,yke,ml=mn(Js,"Collector/Characteristics",132,On,DNt,aTt),rft;T(753,1,{},rpe),C(Js,"CollectorImpl",753),T(1061,1,{},er),f.Te=function(t,n){return s$t(c(t,215),c(n,215))},C(Js,"Collectors/10methodref$merge$Type",1061),T(1062,1,{},Zl),f.Kb=function(t){return RQe(c(t,215))},C(Js,"Collectors/11methodref$toString$Type",1062),T(153,1,{},rs),f.Wd=function(t,n){c(t,18).Ec(n)},C(Js,"Collectors/20methodref$add$Type",153),T(155,1,{},Ls),f.Ve=function(){return new Fe},C(Js,"Collectors/21methodref$ctor$Type",155),T(1060,1,{},f1),f.Wd=function(t,n){N1(c(t,215),c(n,475))},C(Js,"Collectors/9methodref$add$Type",1060),T(1059,1,{},Yze),f.Ve=function(){return new ub(this.a,this.b,this.c)},C(Js,"Collectors/lambda$15$Type",1059),T(154,1,{},mo),f.Te=function(t,n){return o8t(c(t,18),c(n,18))},C(Js,"Collectors/lambda$45$Type",154),T(542,1,{}),f.Ye=function(){Q7(this)},f.d=!1,C(Js,"TerminatableStream",542),T(775,542,dxe,qge),f.Ye=function(){Q7(this)},C(Js,"DoubleStreamImpl",775),T(1309,731,Gu,Zze),f.Pe=function(t){return Izt(this,c(t,191))},f.a=null,C(Js,"DoubleStreamImpl/2",1309),T(1310,1,dL,qAe),f.Ne=function(t){ejt(this.a,t)},C(Js,"DoubleStreamImpl/2/lambda$0$Type",1310),T(1307,1,dL,HAe),f.Ne=function(t){Z8t(this.a,t)},C(Js,"DoubleStreamImpl/lambda$0$Type",1307),T(1308,1,dL,QAe),f.Ne=function(t){SKe(this.a,t)},C(Js,"DoubleStreamImpl/lambda$2$Type",1308),T(1363,730,Gu,WGe),f.Pe=function(t){return z_t(this,c(t,204))},f.a=0,f.b=0,f.c=0,C(Js,"IntStream/5",1363),T(800,542,dxe,Hge),f.Ye=function(){Q7(this)},f.Ze=function(){return T0(this),this.a},C(Js,"IntStreamImpl",800),T(801,542,dxe,d1e),f.Ye=function(){Q7(this)},f.Ze=function(){return T0(this),pge(),Kat},C(Js,"IntStreamImpl/Empty",801),T(1668,1,oL,GAe),f.Bd=function(t){yVe(this.a,t)},C(Js,"IntStreamImpl/lambda$4$Type",1668);var Ftn=Ki(Js,"Stream");T(28,542,{524:1,684:1,840:1},jt),f.Ye=function(){Q7(this)};var hk;C(Js,"StreamImpl",28),T(1083,489,Gu,Tze),f.zd=function(t){for(;RLt(this);){if(this.a.zd(t))return!0;Q7(this.b),this.b=null,this.a=null}return!1},C(Js,"StreamImpl/1",1083),T(1084,1,ln,UAe),f.Ad=function(t){vCt(this.a,c(t,840))},C(Js,"StreamImpl/1/lambda$0$Type",1084),T(1085,1,Jn,JAe),f.Mb=function(t){return Sr(this.a,t)},C(Js,"StreamImpl/1methodref$add$Type",1085),T(1086,489,Gu,uHe),f.zd=function(t){var n;return this.a||(n=new Fe,this.b.a.Nb(new XAe(n)),Ct(),Rr(n,this.c),this.a=new Tt(n,16)),XJe(this.a,t)},f.a=null,C(Js,"StreamImpl/5",1086),T(1087,1,ln,XAe),f.Ad=function(t){qe(this.a,t)},C(Js,"StreamImpl/5/2methodref$add$Type",1087),T(732,489,Gu,Dbe),f.zd=function(t){for(this.b=!1;!this.b&&this.c.zd(new qIe(this,t)););return this.b},f.b=!1,C(Js,"StreamImpl/FilterSpliterator",732),T(1077,1,ln,qIe),f.Ad=function(t){dMt(this.a,this.b,t)},C(Js,"StreamImpl/FilterSpliterator/lambda$0$Type",1077),T(1072,731,Gu,sUe),f.Pe=function(t){return U7t(this,c(t,191))},C(Js,"StreamImpl/MapToDoubleSpliterator",1072),T(1076,1,ln,HIe),f.Ad=function(t){k8t(this.a,this.b,t)},C(Js,"StreamImpl/MapToDoubleSpliterator/lambda$0$Type",1076),T(1071,730,Gu,oUe),f.Pe=function(t){return J7t(this,c(t,204))},C(Js,"StreamImpl/MapToIntSpliterator",1071),T(1075,1,ln,QIe),f.Ad=function(t){O8t(this.a,this.b,t)},C(Js,"StreamImpl/MapToIntSpliterator/lambda$0$Type",1075),T(729,489,Gu,ybe),f.zd=function(t){return Sze(this,t)},C(Js,"StreamImpl/MapToObjSpliterator",729),T(1074,1,ln,GIe),f.Ad=function(t){S8t(this.a,this.b,t)},C(Js,"StreamImpl/MapToObjSpliterator/lambda$0$Type",1074),T(1073,489,Gu,PXe),f.zd=function(t){for(;hY(this.b,0);){if(!this.a.zd(new is))return!1;this.b=Ha(this.b,1)}return this.a.zd(t)},f.b=0,C(Js,"StreamImpl/SkipSpliterator",1073),T(1078,1,ln,is),f.Ad=function(t){},C(Js,"StreamImpl/SkipSpliterator/lambda$0$Type",1078),T(624,1,ln,bs),f.Ad=function(t){EK(this,t)},C(Js,"StreamImpl/ValueConsumer",624),T(1079,1,ln,bo),f.Ad=function(t){Hp()},C(Js,"StreamImpl/lambda$0$Type",1079),T(1080,1,ln,Bl),f.Ad=function(t){Hp()},C(Js,"StreamImpl/lambda$1$Type",1080),T(1081,1,{},VAe),f.Te=function(t,n){return pTt(this.a,t,n)},C(Js,"StreamImpl/lambda$4$Type",1081),T(1082,1,ln,UIe),f.Ad=function(t){z7t(this.b,this.a,t)},C(Js,"StreamImpl/lambda$5$Type",1082),T(1088,1,ln,WAe),f.Ad=function(t){RIt(this.a,c(t,376))},C(Js,"TerminatableStream/lambda$0$Type",1088),T(2121,1,{}),T(1993,1,{},Ir),C("javaemul.internal","ConsoleLogger",1993);var qtn=0;T(2113,1,{}),T(1817,1,ln,eu),f.Ad=function(t){c(t,322)},C(VS,"BowyerWatsonTriangulation/lambda$0$Type",1817),T(1818,1,ln,KAe),f.Ad=function(t){Os(this.a,c(t,322).e)},C(VS,"BowyerWatsonTriangulation/lambda$1$Type",1818),T(1819,1,ln,Un),f.Ad=function(t){c(t,180)},C(VS,"BowyerWatsonTriangulation/lambda$2$Type",1819),T(1814,1,Yn,YAe),f.Le=function(t,n){return MDt(this.a,c(t,180),c(n,180))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(VS,"NaiveMinST/lambda$0$Type",1814),T(401,1,{},g6),C(VS,"NodeMicroLayout",401),T(180,1,{180:1},n5),f.Fb=function(t){var n;return oe(t,180)?(n=c(t,180),dc(this.a,n.a)&&dc(this.b,n.b)||dc(this.a,n.b)&&dc(this.b,n.a)):!1},f.Hb=function(){return gx(this.a)+gx(this.b)};var Htn=C(VS,"TEdge",180);T(322,1,{322:1},Eye),f.Fb=function(t){var n;return oe(t,322)?(n=c(t,322),Jq(this,n.a)&&Jq(this,n.b)&&Jq(this,n.c)):!1},f.Hb=function(){return gx(this.a)+gx(this.b)+gx(this.c)},C(VS,"TTriangle",322),T(227,1,{227:1},yF),C(VS,"Tree",227),T(1195,1,{},sQe),C(aot,"Scanline",1195);var sft=Ki(aot,fot);T(1745,1,{},VJe),C(Wd,"CGraph",1745),T(321,1,{321:1},GHe),f.b=0,f.c=0,f.d=0,f.g=0,f.i=0,f.k=Qr,C(Wd,"CGroup",321),T(821,1,{},Nde),C(Wd,"CGroup/CGroupBuilder",821),T(60,1,{60:1},cze),f.Ib=function(){var t;return this.j?zn(this.j.Kb(this)):(j1(nU),nU.o+"@"+(t=Lm(this)>>>0,t.toString(16)))},f.f=0,f.i=Qr;var nU=C(Wd,"CNode",60);T(820,1,{},_de),C(Wd,"CNode/CNodeBuilder",820);var oft;T(1568,1,{},Rc),f.df=function(t,n){return 0},f.ef=function(t,n){return 0},C(Wd,dot,1568),T(1847,1,{},io),f.af=function(t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H;for(x=nr,r=new G(t.a.b);r.a<r.c.c.length;)n=c(Q(r),60),x=p.Math.min(x,n.a.j.d.c+n.b.a);for(P=new Ai,d=new G(t.a.a);d.a<d.c.c.length;)a=c(Q(d),321),a.k=x,a.g==0&&tr(P,a,P.c.b,P.c);for(;P.b!=0;){for(a=c(P.b==0?null:(dn(P.b!=0),ba(P,P.a.a)),321),o=a.j.d.c,L=a.a.a.ec().Jc();L.Ob();)S=c(L.Pb(),60),H=a.k+S.b.a,!qRt(t,a,t.d)||S.d.c<H?S.i=H:S.i=S.d.c;for(o-=a.j.i,a.b+=o,t.d==(Nr(),yo)||t.d==Fh?a.c+=o:a.c-=o,M=a.a.a.ec().Jc();M.Ob();)for(S=c(M.Pb(),60),v=S.c.Jc();v.Ob();)b=c(v.Pb(),60),O1(t.d)?z=t.g.df(S,b):z=t.g.ef(S,b),b.a.k=p.Math.max(b.a.k,S.i+S.d.b+z-b.b.a),vHe(t,b,t.d)&&(b.a.k=p.Math.max(b.a.k,b.d.c-b.b.a)),--b.a.g,b.a.g==0&&ei(P,b.a)}for(i=new G(t.a.b);i.a<i.c.c.length;)n=c(Q(i),60),n.d.c=n.i},C(Wd,"LongestPathCompaction",1847),T(1743,1,{},ett),f.e=!1;var cft,lft,uft,qoe=C(Wd,bot,1743);T(1744,1,ln,ZAe),f.Ad=function(t){VIt(this.a,c(t,49))},C(Wd,mot,1744),T(1848,1,{},zf),f.bf=function(t){var n,i,r,o,a,d,b;for(i=new G(t.a.b);i.a<i.c.c.length;)n=c(Q(i),60),n.c.$b();for(o=new G(t.a.b);o.a<o.c.c.length;)for(r=c(Q(o),60),d=new G(t.a.b);d.a<d.c.c.length;)a=c(Q(d),60),r!=a&&(r.a&&r.a==a.a||(O1(t.d)?b=t.g.ef(r,a):b=t.g.df(r,a),(a.d.c>r.d.c||r.d.c==a.d.c&&r.d.b<a.d.b)&&xBt(a.d.d+a.d.a+b,r.d.d)&&Pwe(a.d.d,r.d.d+r.d.a+b)&&r.c.Ec(a)))},C(Wd,"QuadraticConstraintCalculation",1848),T(520,1,{520:1},$K),f.a=!1,f.b=!1,f.c=!1,f.d=!1,C(Wd,wot,520),T(811,1,{},H0e),f.bf=function(t){this.c=t,zD(this,new uO)},C(Wd,vot,811),T(1771,1,{690:1},kHe),f._e=function(t){DQt(this,c(t,466))},C(Wd,yot,1771),T(1772,1,Yn,tu),f.Le=function(t,n){return bAt(c(t,60),c(n,60))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Wd,xot,1772),T(466,1,{466:1},T1e),f.a=!1,C(Wd,kot,466),T(1773,1,Yn,Kw),f.Le=function(t,n){return VFt(c(t,466),c(n,466))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Wd,Oot,1773),T(1774,1,hd,uO),f.Lb=function(t){return c(t,60),!0},f.Fb=function(t){return this===t},f.Mb=function(t){return c(t,60),!0},C(Wd,"ScanlineConstraintCalculator/lambda$1$Type",1774),T(220,1,{220:1},aO),f.Ib=function(){return"NEdge[id="+this.b+" w="+this.g+" d="+this.a+"]"},f.a=1,f.b=0,f.c=0,f.f=!1,f.g=0;var aft=C(tE,"NEdge",220);T(186,1,{},Ra),C(tE,"NEdge/NEdgeBuilder",186),T(658,1,{},zK),C(tE,"NGraph",658),T(126,1,{126:1},aUe),f.c=-1,f.d=0,f.e=0,f.i=-1,f.j=!1;var xke=C(tE,"NNode",126);T(802,1,sot,Ade),f.Ic=function(t){ws(this,t)},f.gd=function(t){cb(this,t)},f.Lc=function(){return new Tt(this,16)},f.Mc=function(){return new jt(null,new Tt(this,16))},f._c=function(t,n){++this.b,Up(this.a,t,n)},f.Ec=function(t){return jF(this,t)},f.ad=function(t,n){return++this.b,Vme(this.a,t,n)},f.Fc=function(t){return++this.b,yr(this.a,t)},f.$b=function(){++this.b,M2(this.a.c,0)},f.Gc=function(t){return Do(this.a,t,0)!=-1},f.Hc=function(t){return mD(this.a,t)},f.Xb=function(t){return Xe(this.a,t)},f.bd=function(t){return Do(this.a,t,0)},f.dc=function(){return this.a.c.length==0},f.Jc=function(){return M5(new G(this.a))},f.cd=function(){throw J(new $n)},f.dd=function(t){throw J(new $n)},f.ed=function(t){return++this.b,Mg(this.a,t)},f.Kc=function(t){return Tge(this,t)},f.fd=function(t,n){return++this.b,Su(this.a,t,n)},f.gc=function(){return this.a.c.length},f.hd=function(t,n){return new nd(this.a,t,n)},f.Nc=function(){return zF(this.a.c)},f.Oc=function(t){return jh(this.a,t)},f.b=0,C(tE,"NNode/ChangeAwareArrayList",802),T(276,1,{},Fp),C(tE,"NNode/NNodeBuilder",276),T(1677,1,{},dO),f.a=!1,f.f=di,f.j=0,C(tE,"NetworkSimplex",1677),T(1290,1,ln,eNe),f.Ad=function(t){Hye(this.a,c(t,692),!0,!1)},C(Sot,"NodeLabelAndSizeCalculator/lambda$0$Type",1290),T(561,1,{},fz),f.b=!0,f.c=!0,f.d=!0,f.e=!0,C(Sot,"NodeMarginCalculator",561),T(219,1,{219:1}),f.j=!1,f.k=!1;var fft=C(xb,"Cell",219);T(129,219,{129:1,219:1},oze),f.ff=function(){return FF(this)},f.gf=function(){var t;return t=this.n,this.a.a+t.b+t.c},C(xb,"AtomicCell",129),T(240,23,{3:1,34:1,23:1,240:1},bY);var Vo,Vc,Wo,Nv=mn(xb,"ContainerArea",240,On,LNt,fTt),hft;T(338,219,jot),C(xb,"ContainerCell",338),T(1516,338,jot,kKe),f.ff=function(){var t;return t=0,this.e?this.b?t=this.b.b:this.a[1][1]&&(t=this.a[1][1].ff()):t=kwe(this,NYe(this,!0)),t>0?t+this.n.d+this.n.a:0},f.gf=function(){var t,n,i,r,o;if(o=0,this.e)this.b?o=this.b.a:this.a[1][1]&&(o=this.a[1][1].gf());else if(this.g)o=kwe(this,Cne(this,null,!0));else for(n=(Yf(),W(V(Nv,1),_e,240,0,[Vo,Vc,Wo])),i=0,r=n.length;i<r;++i)t=n[i],o=p.Math.max(o,kwe(this,Cne(this,t,!0)));return o>0?o+this.n.b+this.n.c:0},f.hf=function(){var t,n,i,r,o;if(this.g)for(t=Cne(this,null,!1),i=(Yf(),W(V(Nv,1),_e,240,0,[Vo,Vc,Wo])),r=0,o=i.length;r<o;++r)n=i[r],jnt(this,n,t);else for(i=(Yf(),W(V(Nv,1),_e,240,0,[Vo,Vc,Wo])),r=0,o=i.length;r<o;++r)n=i[r],t=Cne(this,n,!1),jnt(this,n,t)},f.jf=function(){var t,n,i,r;n=this.i,t=this.n,r=NYe(this,!1),bbe(this,(Yf(),Vo),n.d+t.d,r),bbe(this,Wo,n.d+n.a-t.a-r[2],r),i=n.a-t.d-t.a,r[0]>0&&(r[0]+=this.d,i-=r[0]),r[2]>0&&(r[2]+=this.d,i-=r[2]),this.c.a=p.Math.max(0,i),this.c.d=n.d+t.d+(this.c.a-i)/2,r[1]=p.Math.max(r[1],i),bbe(this,Vc,n.d+t.d+r[0]-(r[1]-i)/2,r)},f.b=null,f.d=0,f.e=!1,f.f=!1,f.g=!1;var Hoe=0,iU=0;C(xb,"GridContainerCell",1516),T(464,23,{3:1,34:1,23:1,464:1},mY);var Y0,wd,Tf,dft=mn(xb,"HorizontalLabelAlignment",464,On,PNt,hTt),gft;T(319,219,{219:1,319:1},$He,WJe,MHe),f.ff=function(){return lFe(this)},f.gf=function(){return P0e(this)},f.a=0,f.c=!1;var Qtn=C(xb,"LabelCell",319);T(256,338,{219:1,338:1,256:1},OT),f.ff=function(){return _T(this)},f.gf=function(){return DT(this)},f.hf=function(){pie(this)},f.jf=function(){bie(this)},f.b=0,f.c=0,f.d=!1,C(xb,"StripContainerCell",256),T(1672,1,Jn,Ff),f.Mb=function(t){return w9t(c(t,219))},C(xb,"StripContainerCell/lambda$0$Type",1672),T(1673,1,{},lg),f.We=function(t){return c(t,219).gf()},C(xb,"StripContainerCell/lambda$1$Type",1673),T(1674,1,Jn,qf),f.Mb=function(t){return v9t(c(t,219))},C(xb,"StripContainerCell/lambda$2$Type",1674),T(1675,1,{},Cp),f.We=function(t){return c(t,219).ff()},C(xb,"StripContainerCell/lambda$3$Type",1675),T(465,23,{3:1,34:1,23:1,465:1},wY);var Ef,Z0,rh,pft=mn(xb,"VerticalLabelAlignment",465,On,INt,dTt),bft;T(794,1,{},Gye),f.c=0,f.d=0,f.k=0,f.s=0,f.t=0,f.v=!1,f.w=0,f.D=!1,f.F=!1,C(XQ,"NodeContext",794),T(1514,1,Yn,fO),f.Le=function(t,n){return x$e(c(t,64),c(n,64))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(XQ,"NodeContext/0methodref$comparePortSides$Type",1514),T(1515,1,Yn,hO),f.Le=function(t,n){return vHt(c(t,116),c(n,116))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(XQ,"NodeContext/1methodref$comparePortContexts$Type",1515),T(169,23,{3:1,34:1,23:1,169:1},wa);var mft,wft,vft,yft,xft,kft,Oft,Sft,jft,Tft,Eft,Cft,Mft,Aft,Nft,_ft,Dft,Lft,Pft,Ift,Rft,Qoe,$ft=mn(XQ,"NodeLabelLocation",169,On,sne,gTt),Bft;T(116,1,{116:1},ctt),f.a=!1,C(XQ,"PortContext",116),T(1519,1,ln,Yw),f.Ad=function(t){qPe(c(t,319))},C(pL,Tot,1519),T(1520,1,Jn,Zw),f.Mb=function(t){return!!c(t,116).c},C(pL,Eot,1520),T(1521,1,ln,e2),f.Ad=function(t){qPe(c(t,116).c)},C(pL,"LabelPlacer/lambda$2$Type",1521);var kke;T(1518,1,ln,f0),f.Ad=function(t){B2(),KSt(c(t,116))},C(pL,"NodeLabelAndSizeUtilities/lambda$0$Type",1518),T(795,1,ln,g0e),f.Ad=function(t){f8t(this.b,this.c,this.a,c(t,190))},f.a=!1,f.c=!1,C(pL,"NodeLabelCellCreator/lambda$0$Type",795),T(1517,1,ln,tNe),f.Ad=function(t){t9t(this.a,c(t,190))},C(pL,"PortContextCreator/lambda$0$Type",1517);var rU;T(1889,1,{},t2),C(KS,"GreedyRectangleStripOverlapRemover",1889),T(1890,1,Yn,im),f.Le=function(t,n){return Qjt(c(t,228),c(n,228))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(KS,"GreedyRectangleStripOverlapRemover/0methodref$compareByYCoordinate$Type",1890),T(1843,1,{},fLe),f.a=5,f.e=0,C(KS,"RectangleStripOverlapRemover",1843),T(1844,1,Yn,gO),f.Le=function(t,n){return Gjt(c(t,228),c(n,228))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(KS,"RectangleStripOverlapRemover/0methodref$compareLeftRectangleBorders$Type",1844),T(1846,1,Yn,_y),f.Le=function(t,n){return CMt(c(t,228),c(n,228))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(KS,"RectangleStripOverlapRemover/1methodref$compareRightRectangleBorders$Type",1846),T(414,23,{3:1,34:1,23:1,414:1},Uz);var qL,Goe,Uoe,HL,zft=mn(KS,"RectangleStripOverlapRemover/OverlapRemovalDirection",414,On,X_t,mTt),Fft;T(228,1,{228:1},PZ),C(KS,"RectangleStripOverlapRemover/RectangleNode",228),T(1845,1,ln,nNe),f.Ad=function(t){Jzt(this.a,c(t,228))},C(KS,"RectangleStripOverlapRemover/lambda$1$Type",1845);var qft=!1,NE,Oke;T(1815,1,ln,Ti),f.Ad=function(t){vrt(c(t,227))},C(rk,"DepthFirstCompaction/0methodref$compactTree$Type",1815),T(817,1,ln,pde),f.Ad=function(t){nAt(this.a,c(t,227))},C(rk,"DepthFirstCompaction/lambda$1$Type",817),T(1816,1,ln,Ize),f.Ad=function(t){PBt(this.a,this.b,this.c,c(t,227))},C(rk,"DepthFirstCompaction/lambda$2$Type",1816);var _E,Ske;T(68,1,{68:1},cQe),C(rk,"Node",68),T(1191,1,{},z$e),C(rk,"ScanlineOverlapCheck",1191),T(1192,1,{690:1},SHe),f._e=function(t){L7t(this,c(t,445))},C(rk,"ScanlineOverlapCheck/OverlapsScanlineHandler",1192),T(1193,1,Yn,gu),f.Le=function(t,n){return v$t(c(t,68),c(n,68))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(rk,"ScanlineOverlapCheck/OverlapsScanlineHandler/lambda$0$Type",1193),T(445,1,{445:1},E1e),f.a=!1,C(rk,"ScanlineOverlapCheck/Timestamp",445),T(1194,1,Yn,gh),f.Le=function(t,n){return WFt(c(t,445),c(n,445))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(rk,"ScanlineOverlapCheck/lambda$0$Type",1194),T(549,1,{},h0),C("org.eclipse.elk.alg.common.utils","SVGImage",549),T(755,1,{},pO),C(yre,yxe,755),T(1176,1,Yn,M8),f.Le=function(t,n){return jGt(c(t,238),c(n,238))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(yre,Aot,1176),T(1177,1,ln,JIe),f.Ad=function(t){$Nt(this.b,this.a,c(t,254))},C(yre,xxe,1177),T(207,1,kb),C(Ux,"AbstractLayoutProvider",207),T(733,207,kb,Dde),f.kf=function(t,n){Ktt(this,t,n)},C(yre,"ForceLayoutProvider",733);var Gtn=Ki(bL,Not);T(151,1,{3:1,105:1,151:1},Dy),f.of=function(t,n){return wD(this,t,n)},f.lf=function(){return CFe(this)},f.mf=function(t){return R(this,t)},f.nf=function(t){return xi(this,t)},C(bL,"MapPropertyHolder",151),T(314,151,{3:1,314:1,105:1,151:1}),C(mL,"FParticle",314),T(254,314,{3:1,254:1,314:1,105:1,151:1},pqe),f.Ib=function(){var t;return this.a?(t=Do(this.a.a,this,0),t>=0?"b"+t+"["+Cee(this.a)+"]":"b["+Cee(this.a)+"]"):"b_"+Lm(this)},C(mL,"FBendpoint",254),T(292,151,{3:1,292:1,105:1,151:1},lze),f.Ib=function(){return Cee(this)},C(mL,"FEdge",292),T(238,151,{3:1,238:1,105:1,151:1},Rq);var Utn=C(mL,"FGraph",238);T(448,314,{3:1,448:1,314:1,105:1,151:1},vGe),f.Ib=function(){return this.b==null||this.b.length==0?"l["+Cee(this.a)+"]":"l_"+this.b},C(mL,"FLabel",448),T(156,314,{3:1,156:1,314:1,105:1,151:1},F$e),f.Ib=function(){return Qpe(this)},f.a=0,C(mL,"FNode",156),T(2079,1,{}),f.qf=function(t){xye(this,t)},f.rf=function(){MYe(this)},f.d=0,C(kxe,"AbstractForceModel",2079),T(638,2079,{638:1},vVe),f.pf=function(t,n){var i,r,o,a,d;return Ort(this.f,t,n),o=Hr(Ms(n.d),t.d),d=p.Math.sqrt(o.a*o.a+o.b*o.b),r=p.Math.max(0,d-H7(t.e)/2-H7(n.e)/2),i=Ket(this.e,t,n),i>0?a=-xMt(r,this.c)*i:a=s7t(r,this.b)*c(R(t,(Sf(),dk)),15).a,S1(o,a/d),o},f.qf=function(t){xye(this,t),this.a=c(R(t,(Sf(),oU)),15).a,this.c=ue(he(R(t,cU))),this.b=ue(he(R(t,Xoe)))},f.sf=function(t){return t<this.a},f.a=0,f.b=0,f.c=0,C(kxe,"EadesModel",638),T(639,2079,{639:1},mFe),f.pf=function(t,n){var i,r,o,a,d;return Ort(this.f,t,n),o=Hr(Ms(n.d),t.d),d=p.Math.sqrt(o.a*o.a+o.b*o.b),r=p.Math.max(0,d-H7(t.e)/2-H7(n.e)/2),a=r7t(r,this.a)*c(R(t,(Sf(),dk)),15).a,i=Ket(this.e,t,n),i>0&&(a-=g9t(r,this.a)*i),S1(o,a*this.b/d),o},f.qf=function(t){var n,i,r,o,a,d,b;for(xye(this,t),this.b=ue(he(R(t,(Sf(),Voe)))),this.c=this.b/c(R(t,oU),15).a,r=t.e.c.length,a=0,o=0,b=new G(t.e);b.a<b.c.c.length;)d=c(Q(b),156),a+=d.e.a,o+=d.e.b;n=a*o,i=ue(he(R(t,cU)))*_h,this.a=p.Math.sqrt(n/(2*r))*i},f.rf=function(){MYe(this),this.b-=this.c},f.sf=function(t){return this.b>0},f.a=0,f.b=0,f.c=0,C(kxe,"FruchtermanReingoldModel",639);var n3=Ki(Io,"ILayoutMetaDataProvider");T(852,1,jf,iK),f.tf=function(t){ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,VQ),""),"Force Model"),"Determines the model for force calculation."),jke),(q0(),Ui)),Tke),gt((Th(),Nt))))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Oxe),""),"Iterations"),"The number of iterations on the force model."),Pe(300)),js),Lr),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Sxe),""),"Repulsive Power"),"Determines how many bend points are added to the edge; such bend points are regarded as repelling particles in the force model"),Pe(0)),js),Lr),gt(ch)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,xre),""),"FR Temperature"),"The temperature is used as a scaling factor for particle displacements."),dd),us),kr),gt(Nt)))),Yi(t,xre,VQ,Vft),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,kre),""),"Eades Repulsion"),"Factor for repulsive forces in Eades' model."),5),us),kr),gt(Nt)))),Yi(t,kre,VQ,Uft),dst((new rK,t))};var Hft,Qft,jke,Gft,Uft,Jft,Xft,Vft;C(iE,"ForceMetaDataProvider",852),T(429,23,{3:1,34:1,23:1,429:1},j1e);var Joe,sU,Tke=mn(iE,"ForceModelStrategy",429,On,lNt,vTt),Wft;T(993,1,jf,rK),f.tf=function(t){dst(t)};var Kft,Yft,Eke,oU,Cke,Zft,eht,tht,nht,Mke,iht,Ake,Nke,rht,dk,sht,Xoe,_ke,oht,cht,cU,Voe,lht,uht,aht,Dke,fht;C(iE,"ForceOptions",993),T(994,1,{},bO),f.uf=function(){var t;return t=new Dde,t},f.vf=function(t){},C(iE,"ForceOptions/ForceFactory",994);var QL,DE,gk,lU;T(853,1,jf,LB),f.tf=function(t){ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Txe),""),"Fixed Position"),"Prevent that the node is moved by the layout algorithm."),(Bt(),!1)),(q0(),Pr)),ir),gt((Th(),fr))))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Exe),""),"Desired Edge Length"),"Either specified for parent nodes or for individual edges, where the latter takes higher precedence."),100),us),kr),_i(Nt,W(V($h,1),_e,161,0,[ch]))))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Cxe),""),"Layout Dimension"),"Dimensions that are permitted to be altered during layout."),Lke),Ui),Fke),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Mxe),""),"Stress Epsilon"),"Termination criterion for the iterative process."),dd),us),kr),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Axe),""),"Iteration Limit"),"Maximum number of performed iterations. Takes higher precedence than 'epsilon'."),Pe(di)),js),Lr),gt(Nt)))),zrt((new so,t))};var hht,dht,Lke,ght,pht,bht;C(iE,"StressMetaDataProvider",853),T(997,1,jf,so),f.tf=function(t){zrt(t)};var uU,Pke,Ike,Rke,$ke,Bke,mht,wht,vht,yht,zke,xht;C(iE,"StressOptions",997),T(998,1,{},A8),f.uf=function(){var t;return t=new uze,t},f.vf=function(t){},C(iE,"StressOptions/StressFactory",998),T(1091,207,kb,uze),f.kf=function(t,n){var i,r,o,a,d;for(n.Tg(Iot,1),et(Ze(ke(t,(DD(),$ke))))?et(Ze(ke(t,zke)))||J7((i=new g6((v0(),new wg(t))),i)):Ktt(new Dde,t,n.dh(1)),o=GVe(t),r=Xit(this.a,o),d=r.Jc();d.Ob();)a=c(d.Pb(),238),!(a.e.c.length<=1)&&(ZKt(this.b,a),xUt(this.b),Qc(a.d,new Mp));o=ast(r),vst(o),n.Ug()},C(YQ,"StressLayoutProvider",1091),T(1092,1,ln,Mp),f.Ad=function(t){Aye(c(t,448))},C(YQ,"StressLayoutProvider/lambda$0$Type",1092),T(995,1,{},rLe),f.c=0,f.e=0,f.g=0,C(YQ,"StressMajorization",995),T(385,23,{3:1,34:1,23:1,385:1},vY);var Woe,Koe,Yoe,Fke=mn(YQ,"StressMajorization/Dimension",385,On,BNt,yTt),kht;T(996,1,Yn,iNe),f.Le=function(t,n){return W7t(this.a,c(t,156),c(n,156))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(YQ,"StressMajorization/lambda$0$Type",996),T(1173,1,{},xQe),C(ck,"ElkLayered",1173),T(1174,1,ln,rNe),f.Ad=function(t){lGt(this.a,c(t,37))},C(ck,"ElkLayered/lambda$0$Type",1174),T(1175,1,ln,sNe),f.Ad=function(t){V7t(this.a,c(t,37))},C(ck,"ElkLayered/lambda$1$Type",1175),T(1258,1,{},H$e);var Oht,Sht,jht;C(ck,"GraphConfigurator",1258),T(764,1,ln,bde),f.Ad=function(t){XZe(this.a,c(t,9))},C(ck,"GraphConfigurator/lambda$0$Type",764),T(765,1,{},mO),f.Kb=function(t){return d2e(),new jt(null,new Tt(c(t,26).a,16))},C(ck,"GraphConfigurator/lambda$1$Type",765),T(766,1,ln,mde),f.Ad=function(t){XZe(this.a,c(t,9))},C(ck,"GraphConfigurator/lambda$2$Type",766),T(1090,207,kb,cLe),f.kf=function(t,n){var i;i=NKt(new dLe,t),ve(ke(t,(Ge(),Fv)))===ve((R1(),Zg))?T$t(this.a,i,n):mUt(this.a,i,n),n.Zg()||ist(new n6,i)},C(ck,"LayeredLayoutProvider",1090),T(364,23,{3:1,34:1,23:1,364:1},i_);var Cf,Zd,vc,yc,Vs,qke=mn(ck,"LayeredPhases",364,On,GDt,xTt),Tht;T(1700,1,{},LXe),f.i=0;var Eht;C(SL,"ComponentsToCGraphTransformer",1700);var Cht;T(1701,1,{},Pa),f.wf=function(t,n){return p.Math.min(t.a!=null?ue(t.a):t.c.i,n.a!=null?ue(n.a):n.c.i)},f.xf=function(t,n){return p.Math.min(t.a!=null?ue(t.a):t.c.i,n.a!=null?ue(n.a):n.c.i)},C(SL,"ComponentsToCGraphTransformer/1",1701),T(84,1,{84:1}),f.i=0,f.k=!0,f.o=Qr;var Zoe=C(sE,"CNode",84);T(463,84,{463:1,84:1},Age,qwe),f.Ib=function(){return""},C(SL,"ComponentsToCGraphTransformer/CRectNode",463),T(1669,1,{},ph);var ece,tce;C(SL,"OneDimensionalComponentsCompaction",1669),T(1670,1,{},rm),f.Kb=function(t){return CNt(c(t,49))},f.Fb=function(t){return this===t},C(SL,"OneDimensionalComponentsCompaction/lambda$0$Type",1670),T(1671,1,{},e4),f.Kb=function(t){return N$t(c(t,49))},f.Fb=function(t){return this===t},C(SL,"OneDimensionalComponentsCompaction/lambda$1$Type",1671),T(1703,1,{},xqe),C(sE,"CGraph",1703),T(197,1,{197:1},nne),f.b=0,f.c=0,f.e=0,f.g=!0,f.i=Qr,C(sE,"CGroup",197),T(1702,1,{},i2),f.wf=function(t,n){return p.Math.max(t.a!=null?ue(t.a):t.c.i,n.a!=null?ue(n.a):n.c.i)},f.xf=function(t,n){return p.Math.max(t.a!=null?ue(t.a):t.c.i,n.a!=null?ue(n.a):n.c.i)},C(sE,dot,1702),T(1704,1,{},Zet),f.d=!1;var Mht,nce=C(sE,bot,1704);T(1705,1,{},r2),f.Kb=function(t){return g1e(),Bt(),c(c(t,49).a,84).d.e!=0},f.Fb=function(t){return this===t},C(sE,mot,1705),T(825,1,{},F0e),f.a=!1,f.b=!1,f.c=!1,f.d=!1,C(sE,wot,825),T(1885,1,{},BFe),C(ZQ,vot,1885);var GL=Ki(Ob,fot);T(1886,1,{378:1},OHe),f._e=function(t){TXt(this,c(t,468))},C(ZQ,yot,1886),T(1887,1,Yn,ra),f.Le=function(t,n){return mAt(c(t,84),c(n,84))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(ZQ,xot,1887),T(468,1,{468:1},C1e),f.a=!1,C(ZQ,kot,468),T(1888,1,Yn,D8),f.Le=function(t,n){return KFt(c(t,468),c(n,468))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(ZQ,Oot,1888),T(148,1,{148:1},E6,N0e),f.Fb=function(t){var n;return t==null||Jtn!=ju(t)?!1:(n=c(t,148),dc(this.c,n.c)&&dc(this.d,n.d))},f.Hb=function(){return jH(W(V(Br,1),Lt,1,5,[this.c,this.d]))},f.Ib=function(){return"("+this.c+Jc+this.d+(this.a?"cx":"")+this.b+")"},f.a=!0,f.c=0,f.d=0;var Jtn=C(Ob,"Point",148);T(413,23,{3:1,34:1,23:1,413:1},Jz);var jw,_v,i3,Dv,Aht=mn(Ob,"Point/Quadrant",413,On,J_t,wTt),Nht;T(1691,1,{},lLe),f.b=null,f.c=null,f.d=null,f.e=null,f.f=null;var _ht,Dht,Lht,Pht,Iht;C(Ob,"RectilinearConvexHull",1691),T(576,1,{378:1},UH),f._e=function(t){qLt(this,c(t,148))},f.b=0;var Hke;C(Ob,"RectilinearConvexHull/MaximalElementsEventHandler",576),T(1693,1,Yn,MM),f.Le=function(t,n){return wAt(he(t),he(n))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Ob,"RectilinearConvexHull/MaximalElementsEventHandler/lambda$0$Type",1693),T(1692,1,{378:1},qJe),f._e=function(t){qJt(this,c(t,148))},f.a=0,f.b=null,f.c=null,f.d=null,f.e=null,C(Ob,"RectilinearConvexHull/RectangleEventHandler",1692),T(1694,1,Yn,_8),f.Le=function(t,n){return y_t(c(t,148),c(n,148))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Ob,"RectilinearConvexHull/lambda$0$Type",1694),T(1695,1,Yn,N8),f.Le=function(t,n){return x_t(c(t,148),c(n,148))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Ob,"RectilinearConvexHull/lambda$1$Type",1695),T(1696,1,Yn,Ly),f.Le=function(t,n){return O_t(c(t,148),c(n,148))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Ob,"RectilinearConvexHull/lambda$2$Type",1696),T(1697,1,Yn,wO),f.Le=function(t,n){return k_t(c(t,148),c(n,148))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Ob,"RectilinearConvexHull/lambda$3$Type",1697),T(1698,1,Yn,n2),f.Le=function(t,n){return LHt(c(t,148),c(n,148))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Ob,"RectilinearConvexHull/lambda$4$Type",1698),T(1699,1,{},oQe),C(Ob,"Scanline",1699),T(2083,1,{}),C(Dh,"AbstractGraphPlacer",2083),T(337,1,{337:1},DBe),f.Df=function(t){return this.Ef(t)?(St(this.b,c(R(t,(De(),X1)),24),t),!0):!1},f.Ef=function(t){var n,i,r,o;for(n=c(R(t,(De(),X1)),24),o=c(Si(Ni,n),24),r=o.Jc();r.Ob();)if(i=c(r.Pb(),24),!c(Si(this.b,i),16).dc())return!1;return!0};var Ni;C(Dh,"ComponentGroup",337),T(773,2083,{},Lde),f.Ff=function(t){var n,i;for(i=new G(this.a);i.a<i.c.c.length;)if(n=c(Q(i),337),n.Df(t))return;qe(this.a,new DBe(t))},f.Cf=function(t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z;if(this.a.c.length=0,n.a.c.length=0,t.dc()){n.f.a=0,n.f.b=0;return}for(d=c(t.Xb(0),37),ec(n,d),o=t.Jc();o.Ob();)r=c(o.Pb(),37),this.Ff(r);for(z=new as,a=ue(he(R(d,(Ge(),uP)))),x=new G(this.a);x.a<x.c.c.length;)b=c(Q(x),337),S=yst(b,a),Ag(lq(b.b),z.a,z.b),z.a+=S.a,z.b+=S.b;if(n.f.a=z.a-a,n.f.b=z.b-a,et(Ze(R(d,VU)))&&ve(R(d,W1))===ve(($1(),i8))){for(P=t.Jc();P.Ob();)M=c(P.Pb(),37),IS(M,M.c.a,M.c.b);for(i=new Ap,Vye(i,t,a),L=t.Jc();L.Ob();)M=c(L.Pb(),37),ki(Xf(M.c),i.e);ki(Xf(n.f),i.a)}for(v=new G(this.a);v.a<v.c.c.length;)b=c(Q(v),337),_be(n,lq(b.b))},C(Dh,"ComponentGroupGraphPlacer",773),T(1288,773,{},SLe),f.Ff=function(t){BWe(this,t)},f.Cf=function(t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de;if(this.a.c.length=0,n.a.c.length=0,t.dc()){n.f.a=0,n.f.b=0;return}for(d=c(t.Xb(0),37),ec(n,d),o=t.Jc();o.Ob();)r=c(o.Pb(),37),BWe(this,r);for(de=new as,se=new as,H=new as,z=new as,a=ue(he(R(d,(Ge(),uP)))),x=new G(this.a);x.a<x.c.c.length;){if(b=c(Q(x),337),O1(c(R(n,(Dn(),Fb)),87))){for(H.a=de.a,ie=new Yj(q7(WZ(b.b).a).a.kc());ie.b.Ob();)if(X=c(Hz(ie.b.Pb()),24),X.Gc((Je(),Kt))){H.a=se.a;break}}else if(hx(c(R(n,Fb),87))){for(H.b=de.b,ie=new Yj(q7(WZ(b.b).a).a.kc());ie.b.Ob();)if(X=c(Hz(ie.b.Pb()),24),X.Gc((Je(),Yt))){H.b=se.b;break}}if(S=yst(c(b,572),a),Ag(lq(b.b),H.a,H.b),O1(c(R(n,Fb),87))){for(se.a=H.a+S.a,z.a=p.Math.max(z.a,se.a),ie=new Yj(q7(WZ(b.b).a).a.kc());ie.b.Ob();)if(X=c(Hz(ie.b.Pb()),24),X.Gc((Je(),bn))){de.a=H.a+S.a;break}se.b=H.b+S.b,H.b=se.b,z.b=p.Math.max(z.b,H.b)}else if(hx(c(R(n,Fb),87))){for(se.b=H.b+S.b,z.b=p.Math.max(z.b,se.b),ie=new Yj(q7(WZ(b.b).a).a.kc());ie.b.Ob();)if(X=c(Hz(ie.b.Pb()),24),X.Gc((Je(),nn))){de.b=H.b+S.b;break}se.a=H.a+S.a,H.a=se.a,z.a=p.Math.max(z.a,H.a)}}if(n.f.a=z.a-a,n.f.b=z.b-a,et(Ze(R(d,VU)))&&ve(R(d,W1))===ve(($1(),i8))){for(P=t.Jc();P.Ob();)M=c(P.Pb(),37),IS(M,M.c.a,M.c.b);for(i=new Ap,Vye(i,t,a),L=t.Jc();L.Ob();)M=c(L.Pb(),37),ki(Xf(M.c),i.e);ki(Xf(n.f),i.a)}for(v=new G(this.a);v.a<v.c.c.length;)b=c(Q(v),337),_be(n,lq(b.b))},C(Dh,"ComponentGroupModelOrderGraphPlacer",1288),T(384,23,{3:1,34:1,23:1,384:1},Xz);var ice,Qke,rce,LE,Gke=mn(Dh,"ComponentOrderingStrategy",384,On,W_t,kTt),Rht;T(655,1,{},Ap),C(Dh,"ComponentsCompactor",655),T(1511,13,iot,YGe),f.Ec=function(t){return CT(this,c(t,148))},C(Dh,"ComponentsCompactor/Hullpoints",1511),T(1508,1,{847:1},lYe),f.a=!1,C(Dh,"ComponentsCompactor/InternalComponent",1508),T(1507,1,Jd,aLe),f.Ic=function(t){ws(this,t)},f.Jc=function(){return new G(this.a)},C(Dh,"ComponentsCompactor/InternalConnectedComponents",1507),T(1510,1,{598:1},itt),f.zf=function(){return null},f.Af=function(){return this.a},f.yf=function(){return one(this.d)},f.Bf=function(){return this.b},C(Dh,"ComponentsCompactor/InternalExternalExtension",1510),T(1509,1,{598:1},hLe),f.Af=function(){return this.a},f.yf=function(){return one(this.d)},f.zf=function(){return this.c},f.Bf=function(){return this.b},C(Dh,"ComponentsCompactor/InternalUnionExternalExtension",1509),T(1513,1,{},Tnt),C(Dh,"ComponentsCompactor/OuterSegments",1513),T(1512,1,{},uLe),C(Dh,"ComponentsCompactor/Segments",1512),T(1259,1,{},fUe),C(Dh,yxe,1259),T(1260,1,Yn,L8),f.Le=function(t,n){return j_t(c(t,37),c(n,37))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Dh,"ComponentsProcessor/lambda$0$Type",1260),T(572,337,{337:1,572:1},KGe),f.Df=function(t){return Hme(this,t)},f.Ef=function(t){return cnt(this,t)};var ri;C(Dh,"ModelOrderComponentGroup",572),T(1286,2083,{},sm),f.Cf=function(t,n){var i,r,o,a,d,b,v,x,S,M,L;if(t.gc()==1){M=c(t.Xb(0),37),M!=n&&(n.a.c.length=0,dit(n,M,0,0),ec(n,M),jpe(n.d,M.d),n.f.a=M.f.a,n.f.b=M.f.b);return}else if(t.dc()){n.a.c.length=0,n.f.a=0,n.f.b=0;return}for(this.Hf(t,n),o=c(t.Xb(0),37),n.a.c.length=0,ec(n,o),x=0,L=0,d=t.Jc();d.Ob();)a=c(d.Pb(),37),S=a.f,x=p.Math.max(x,S.a),L+=S.a*S.b;if(x=p.Math.max(x,p.Math.sqrt(L)*ue(he(R(n,(Ge(),XU))))),r=ue(he(R(n,uP))),this.Gf(t,n,x,r),et(Ze(R(o,VU)))){for(i=new Ap,Vye(i,t,r),v=t.Jc();v.Ob();)b=c(v.Pb(),37),ki(Xf(b.c),i.e);ki(Xf(n.f),i.a)}_be(n,t)},f.Gf=function(t,n,i,r){var o,a,d,b,v,x,S,M;for(S=0,M=0,b=0,o=r,d=t.Jc();d.Ob();)a=c(d.Pb(),37),x=a.f,S+x.a>i&&(S=0,M+=b+r,b=0),v=a.c,IS(a,S+v.a,M+v.b),Xf(v),o=p.Math.max(o,S+x.a),b=p.Math.max(b,x.b),S+=x.a+r;n.f.a=o,n.f.b=M+b},f.Hf=function(t,n){var i,r,o,a,d;if(ve(R(n,(Ge(),XE)))===ve(($5(),LE))){for(r=t.Jc();r.Ob();){for(i=c(r.Pb(),37),d=0,a=new G(i.a);a.a<a.c.c.length;)o=c(Q(a),9),d+=c(R(o,g0t),15).a;i.p=d}Ct(),t.gd(new AM)}},C(Dh,"SimpleRowGraphPlacer",1286),T(1289,1286,{},s2),f.Gf=function(t,n,i,r){var o,a,d,b,v,x,S,M,L,P;for(L=0,P=0,b=0,o=r,v=null,M=0,d=t.Jc();d.Ob();)a=c(d.Pb(),37),S=a.f,(L+S.a>i&&!c(R(a,(De(),X1)),24).Gc((Je(),Kt))||v&&c(R(v,(De(),X1)),24).Gc((Je(),nn))||c(R(a,(De(),X1)),24).Gc((Je(),Yt)))&&(L=M,P+=b+r,b=0),x=a.c,c(R(a,(De(),X1)),24).Gc((Je(),Kt))&&(L=o+r),IS(a,L+x.a,P+x.b),o=p.Math.max(o,L+S.a),c(R(a,X1),24).Gc(bn)&&(M=p.Math.max(M,L+S.a+r)),Xf(x),b=p.Math.max(b,S.b),L+=S.a+r,v=a;n.f.a=o,n.f.b=P+b},f.Hf=function(t,n){},C(Dh,"ModelOrderRowGraphPlacer",1289),T(1287,1,Yn,AM),f.Le=function(t,n){return PIt(c(t,37),c(n,37))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Dh,"SimpleRowGraphPlacer/1",1287);var $ht;T(1257,1,hd,vO),f.Lb=function(t){var n;return n=c(R(c(t,253).b,(Ge(),ho)),79),!!n&&n.b!=0},f.Fb=function(t){return this===t},f.Mb=function(t){var n;return n=c(R(c(t,253).b,(Ge(),ho)),79),!!n&&n.b!=0},C(eG,"CompoundGraphPostprocessor/1",1257),T(1256,1,Di,gLe),f.If=function(t,n){fYe(this,c(t,37),n)},C(eG,"CompoundGraphPreprocessor",1256),T(447,1,{447:1},eKe),f.c=!1,C(eG,"CompoundGraphPreprocessor/ExternalPort",447),T(253,1,{253:1},PF),f.Ib=function(){return lZ(this.c)+":"+Jet(this.b)},C(eG,"CrossHierarchyEdge",253),T(771,1,Yn,wde),f.Le=function(t,n){return kFt(this,c(t,253),c(n,253))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(eG,"CrossHierarchyEdgeComparator",771),T(248,151,{3:1,248:1,105:1,151:1}),f.p=0,C(wc,"LGraphElement",248),T(17,248,{3:1,17:1,248:1,105:1,151:1},qm),f.Ib=function(){return Jet(this)};var j9=C(wc,"LEdge",17);T(37,248,{3:1,22:1,37:1,248:1,105:1,151:1},tme),f.Ic=function(t){ws(this,t)},f.Jc=function(){return new G(this.b)},f.Ib=function(){return this.b.c.length==0?"G-unlayered"+Mh(this.a):this.a.c.length==0?"G-layered"+Mh(this.b):"G[layerless"+Mh(this.a)+", layers"+Mh(this.b)+"]"};var Bht=C(wc,"LGraph",37),zht;T(662,1,{}),f.Jf=function(){return this.e.n},f.mf=function(t){return R(this.e,t)},f.Kf=function(){return this.e.o},f.Lf=function(){return this.e.p},f.nf=function(t){return xi(this.e,t)},f.Mf=function(t){this.e.n.a=t.a,this.e.n.b=t.b},f.Nf=function(t){this.e.o.a=t.a,this.e.o.b=t.b},f.Of=function(t){this.e.p=t},C(wc,"LGraphAdapters/AbstractLShapeAdapter",662),T(467,1,{845:1},Uj),f.Pf=function(){var t,n;if(!this.b)for(this.b=Pd(this.a.b.c.length),n=new G(this.a.b);n.a<n.c.c.length;)t=c(Q(n),70),qe(this.b,new hz(t));return this.b},f.b=null,C(wc,"LGraphAdapters/LEdgeAdapter",467),T(661,1,{},iee),f.Qf=function(){var t,n,i,r,o,a;if(!this.b){for(this.b=new Fe,r=new G(this.a.b);r.a<r.c.c.length;)for(i=c(Q(r),26),a=new G(i.a);a.a<a.c.c.length;)if(o=c(Q(a),9),this.c.Mb(o)&&(qe(this.b,new LF(this,o,this.e)),this.d)){if(xi(o,(De(),Sk)))for(n=c(R(o,Sk),16).Jc();n.Ob();)t=c(n.Pb(),9),qe(this.b,new LF(this,t,!1));if(xi(o,mk))for(n=c(R(o,mk),16).Jc();n.Ob();)t=c(n.Pb(),9),qe(this.b,new LF(this,t,!1))}}return this.b},f.Jf=function(){throw J(new vg(Bot))},f.mf=function(t){return R(this.a,t)},f.Kf=function(){return this.a.f},f.Lf=function(){return this.a.p},f.nf=function(t){return xi(this.a,t)},f.Mf=function(t){throw J(new vg(Bot))},f.Nf=function(t){this.a.f.a=t.a,this.a.f.b=t.b},f.Of=function(t){this.a.p=t},f.b=null,f.d=!1,f.e=!1,C(wc,"LGraphAdapters/LGraphAdapter",661),T(578,662,{190:1},hz),C(wc,"LGraphAdapters/LLabelAdapter",578),T(577,662,{692:1},LF),f.Rf=function(){return this.b},f.Sf=function(){return Ct(),Ct(),Rs},f.Pf=function(){var t,n;if(!this.a)for(this.a=Pd(c(this.e,9).b.c.length),n=new G(c(this.e,9).b);n.a<n.c.c.length;)t=c(Q(n),70),qe(this.a,new hz(t));return this.a},f.Tf=function(){var t;return t=c(this.e,9).d,new Zge(t.d,t.c,t.a,t.b)},f.Uf=function(){return Ct(),Ct(),Rs},f.Vf=function(){var t,n;if(!this.c)for(this.c=Pd(c(this.e,9).j.c.length),n=new G(c(this.e,9).j);n.a<n.c.c.length;)t=c(Q(n),12),qe(this.c,new XIe(t,this.d));return this.c},f.Wf=function(){return et(Ze(R(c(this.e,9),(De(),g6e))))},f.Xf=function(t){c(this.e,9).d.b=t.b,c(this.e,9).d.d=t.d,c(this.e,9).d.c=t.c,c(this.e,9).d.a=t.a},f.Yf=function(t){c(this.e,9).f.b=t.b,c(this.e,9).f.d=t.d,c(this.e,9).f.c=t.c,c(this.e,9).f.a=t.a},f.Zf=function(){vPt(this,(s7(),zht))},f.a=null,f.b=null,f.c=null,f.d=!1,C(wc,"LGraphAdapters/LNodeAdapter",577),T(1775,662,{844:1},XIe),f.Sf=function(){var t,n,i,r,o,a,d,b;if(this.d&&c(this.e,12).i.k==(Jt(),Dc))return Ct(),Ct(),Rs;if(!this.a){for(this.a=new Fe,i=new G(c(this.e,12).e);i.a<i.c.c.length;)t=c(Q(i),17),qe(this.a,new Uj(t));if(this.d&&(r=c(R(c(this.e,12),(De(),Ul)),9),r))for(n=new Ht(Vt(pr(r).a.Jc(),new U));hn(n);)t=c(sn(n),17),qe(this.a,new Uj(t));if(xi(c(this.e,12).i,(De(),Nw))&&(d=c(R(c(this.e,12).i,Nw),339),b=c(Oh(d.e,this.e),114),b))for(a=new G(b.b);a.a<a.c.c.length;)o=c(Q(a),342),qe(this.a,new Uj(o.a))}return this.a},f.Pf=function(){var t,n;if(!this.b)for(this.b=Pd(c(this.e,12).f.c.length),n=new G(c(this.e,12).f);n.a<n.c.c.length;)t=c(Q(n),70),qe(this.b,new hz(t));return this.b},f.Uf=function(){var t,n,i,r,o,a,d,b;if(this.d&&c(this.e,12).i.k==(Jt(),Dc))return Ct(),Ct(),Rs;if(!this.c){for(this.c=new Fe,i=new G(c(this.e,12).g);i.a<i.c.c.length;)t=c(Q(i),17),qe(this.c,new Uj(t));if(this.d&&(r=c(R(c(this.e,12),(De(),Ul)),9),r))for(n=new Ht(Vt($i(r).a.Jc(),new U));hn(n);)t=c(sn(n),17),qe(this.c,new Uj(t));if(xi(c(this.e,12).i,(De(),Nw))&&(d=c(R(c(this.e,12).i,Nw),339),b=c(Oh(d.e,this.e),114),b))for(a=new G(b.e);a.a<a.c.c.length;)o=c(Q(a),342),qe(this.c,new Uj(o.a))}return this.c},f.$f=function(){return c(this.e,12).j},f._f=function(){return et(Ze(R(c(this.e,12),(De(),nP))))},f.a=null,f.b=null,f.c=null,f.d=!1,C(wc,"LGraphAdapters/LPortAdapter",1775),T(1776,1,Yn,P8),f.Le=function(t,n){return tVt(c(t,12),c(n,12))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(wc,"LGraphAdapters/PortComparator",1776),T(812,1,Jn,I8),f.Mb=function(t){return c(t,9),s7(),!0},C(wc,"LGraphAdapters/lambda$0$Type",812),T(400,248,{3:1,248:1,400:1,105:1,151:1}),C(wc,"LShape",400),T(70,400,{3:1,248:1,70:1,400:1,105:1,151:1},pPe,age),f.Ib=function(){var t;return t=qCt(this),t==null?"label":"l_"+t},C(wc,"LLabel",70),T(216,1,{3:1,4:1,216:1,419:1}),f.Fb=function(t){var n;return oe(t,216)?(n=c(t,216),this.d==n.d&&this.a==n.a&&this.b==n.b&&this.c==n.c):!1},f.Hb=function(){var t,n;return t=o5(this.b)<<16,t|=o5(this.a)&_r,n=o5(this.c)<<16,n|=o5(this.d)&_r,t^n},f.ag=function(t){var n,i,r,o,a,d,b,v,x,S,M;for(a=0;a<t.length&&TWe((en(a,t.length),t.charCodeAt(a)),Fot);)++a;for(n=t.length;n>0&&TWe((en(n-1,t.length),t.charCodeAt(n-1)),qot);)--n;if(a<n){S=xv((fs(a,n,t.length),t.substr(a,n-a)),",|;");try{for(b=S,v=0,x=b.length;v<x;++v){if(d=b[v],o=xv(d,"="),o.length!=2)throw J(new qt("Expecting a list of key-value pairs."));r=pv(o[0]),M=gv(pv(o[1])),Ot(r,"top")?this.d=M:Ot(r,"left")?this.b=M:Ot(r,"bottom")?this.a=M:Ot(r,"right")&&(this.c=M)}}catch(L){throw L=vr(L),oe(L,133)?(i=L,J(new qt(Hot+i))):J(L)}}},f.Ib=function(){return"[top="+this.d+",left="+this.b+",bottom="+this.a+",right="+this.c+"]"},f.a=0,f.b=0,f.c=0,f.d=0,C(jL,"Spacing",216),T(125,216,Qot,Vj,C$e,Zge,kZ);var Uke=C(jL,"ElkMargin",125);T(656,125,Qot,qK),C(wc,"LMargin",656),T(9,400,{3:1,248:1,9:1,400:1,105:1,151:1},Eh),f.Ib=function(){return rYe(this)},f.i=!1;var e1=C(wc,"LNode",9);T(252,23,{3:1,34:1,23:1,252:1},i5);var Ih,Cr,lc,jr,PE,or,Dc,UL,sce=mn(wc,"LNode/NodeType",252,On,uPt,bTt),Fht;T(769,1,Jn,Py),f.Mb=function(t){return et(Ze(R(c(t,70),(Ge(),b3))))},C(wc,"LNode/lambda$0$Type",769),T(100,216,Got,X4,Qp,b0e);var Jke=C(jL,"ElkPadding",100);T(772,100,Got,Ide),C(wc,"LPadding",772),T(12,400,{3:1,248:1,12:1,400:1,105:1,151:1},bc),f.Ib=function(){var t,n,i;return t=new b0,Zn((t.a+="p_",t),tQ(this)),this.i&&Zn(Sc((t.a+="[",t),this.i),"]"),this.e.c.length==1&&this.g.c.length==0&&c(Xe(this.e,0),17).c!=this&&(n=c(Xe(this.e,0),17).c,Zn((t.a+=" << ",t),tQ(n)),Zn(Sc((t.a+="[",t),n.i),"]")),this.e.c.length==0&&this.g.c.length==1&&c(Xe(this.g,0),17).d!=this&&(i=c(Xe(this.g,0),17).d,Zn((t.a+=" >> ",t),tQ(i)),Zn(Sc((t.a+="[",t),i.i),"]")),t.a},f.c=!0,f.d=!1;var Xke,Vke,Wke,Kke,Yke,Zke,qht=C(wc,"LPort",12);T(404,1,Jd,p6),f.Ic=function(t){ws(this,t)},f.Jc=function(){var t;return t=new G(this.a.e),new oNe(t)},C(wc,"LPort/1",404),T(1285,1,ts,oNe),f.Nb=function(t){gs(this,t)},f.Pb=function(){return c(Q(this.a),17).c},f.Ob=function(){return No(this.a)},f.Qb=function(){z7(this.a)},C(wc,"LPort/1/1",1285),T(366,1,Jd,Q4),f.Ic=function(t){ws(this,t)},f.Jc=function(){var t;return t=new G(this.a.g),new vde(t)},C(wc,"LPort/2",366),T(770,1,ts,vde),f.Nb=function(t){gs(this,t)},f.Pb=function(){return c(Q(this.a),17).d},f.Ob=function(){return No(this.a)},f.Qb=function(){z7(this.a)},C(wc,"LPort/2/1",770),T(1278,1,Jd,VIe),f.Ic=function(t){ws(this,t)},f.Jc=function(){return new kh(this)},C(wc,"LPort/CombineIter",1278),T(210,1,ts,kh),f.Nb=function(t){gs(this,t)},f.Qb=function(){TPe()},f.Ob=function(){return N7(this)},f.Pb=function(){return No(this.a)?Q(this.a):Q(this.b)},C(wc,"LPort/CombineIter/1",210),T(1279,1,hd,t4),f.Lb=function(t){return eqe(t)},f.Fb=function(t){return this===t},f.Mb=function(t){return _l(),c(t,12).g.c.length!=0},C(wc,"LPort/lambda$0$Type",1279),T(1280,1,hd,d0),f.Lb=function(t){return tqe(t)},f.Fb=function(t){return this===t},f.Mb=function(t){return _l(),c(t,12).e.c.length!=0},C(wc,"LPort/lambda$1$Type",1280),T(1281,1,hd,Ed),f.Lb=function(t){return _l(),c(t,12).j==(Je(),Kt)},f.Fb=function(t){return this===t},f.Mb=function(t){return _l(),c(t,12).j==(Je(),Kt)},C(wc,"LPort/lambda$2$Type",1281),T(1282,1,hd,R8),f.Lb=function(t){return _l(),c(t,12).j==(Je(),nn)},f.Fb=function(t){return this===t},f.Mb=function(t){return _l(),c(t,12).j==(Je(),nn)},C(wc,"LPort/lambda$3$Type",1282),T(1283,1,hd,NM),f.Lb=function(t){return _l(),c(t,12).j==(Je(),bn)},f.Fb=function(t){return this===t},f.Mb=function(t){return _l(),c(t,12).j==(Je(),bn)},C(wc,"LPort/lambda$4$Type",1283),T(1284,1,hd,o2),f.Lb=function(t){return _l(),c(t,12).j==(Je(),Yt)},f.Fb=function(t){return this===t},f.Mb=function(t){return _l(),c(t,12).j==(Je(),Yt)},C(wc,"LPort/lambda$5$Type",1284),T(26,248,{3:1,22:1,248:1,26:1,105:1,151:1},hc),f.Ic=function(t){ws(this,t)},f.Jc=function(){return new G(this.a)},f.Ib=function(){return"L_"+Do(this.b.b,this,0)+Mh(this.a)},C(wc,"Layer",26),T(1676,1,{},UUe),f.b=0,C(wc,"Tarjan",1676),T(1294,1,{},dLe),C(Qg,Uot,1294),T(1298,1,{},$8),f.Kb=function(t){return to(c(t,83))},C(Qg,"ElkGraphImporter/0methodref$connectableShapeToNode$Type",1298),T(1301,1,{},Iy),f.Kb=function(t){return to(c(t,83))},C(Qg,"ElkGraphImporter/1methodref$connectableShapeToNode$Type",1301),T(1295,1,ln,cNe),f.Ad=function(t){att(this.a,c(t,127))},C(Qg,xxe,1295),T(1296,1,ln,lNe),f.Ad=function(t){att(this.a,c(t,127))},C(Qg,Jot,1296),T(1297,1,{},_M),f.Kb=function(t){return new jt(null,new Tt(H6(c(t,74)),16))},C(Qg,Xot,1297),T(1299,1,Jn,uNe),f.Mb=function(t){return K8t(this.a,c(t,19))},C(Qg,Vot,1299),T(1300,1,{},Cd),f.Kb=function(t){return new jt(null,new Tt(oAt(c(t,74)),16))},C(Qg,"ElkGraphImporter/lambda$5$Type",1300),T(1302,1,Jn,aNe),f.Mb=function(t){return Y8t(this.a,c(t,19))},C(Qg,"ElkGraphImporter/lambda$7$Type",1302),T(1303,1,Jn,Ry),f.Mb=function(t){return CAt(c(t,74))},C(Qg,"ElkGraphImporter/lambda$8$Type",1303),T(1273,1,{},n6);var Hht;C(Qg,"ElkGraphLayoutTransferrer",1273),T(1274,1,Jn,fNe),f.Mb=function(t){return Z7t(this.a,c(t,17))},C(Qg,"ElkGraphLayoutTransferrer/lambda$0$Type",1274),T(1275,1,ln,hNe),f.Ad=function(t){t_(),qe(this.a,c(t,17))},C(Qg,"ElkGraphLayoutTransferrer/lambda$1$Type",1275),T(1276,1,Jn,dNe),f.Mb=function(t){return D7t(this.a,c(t,17))},C(Qg,"ElkGraphLayoutTransferrer/lambda$2$Type",1276),T(1277,1,ln,gNe),f.Ad=function(t){t_(),qe(this.a,c(t,17))},C(Qg,"ElkGraphLayoutTransferrer/lambda$3$Type",1277),T(813,1,{},n0e),C(tn,"BiLinkedHashMultiMap",813),T(1528,1,Di,B8),f.If=function(t,n){nIt(c(t,37),n)},C(tn,"CommentNodeMarginCalculator",1528),T(1529,1,{},yO),f.Kb=function(t){return new jt(null,new Tt(c(t,26).a,16))},C(tn,"CommentNodeMarginCalculator/lambda$0$Type",1529),T(1530,1,ln,om),f.Ad=function(t){CKt(c(t,9))},C(tn,"CommentNodeMarginCalculator/lambda$1$Type",1530),T(1531,1,Di,QI),f.If=function(t,n){DXt(c(t,37),n)},C(tn,"CommentPostprocessor",1531),T(1532,1,Di,GI),f.If=function(t,n){nen(c(t,37),n)},C(tn,"CommentPreprocessor",1532),T(1533,1,Di,n4),f.If=function(t,n){UJt(c(t,37),n)},C(tn,"ConstraintsPostprocessor",1533),T(1534,1,Di,BV),f.If=function(t,n){$It(c(t,37),n)},C(tn,"EdgeAndLayerConstraintEdgeReverser",1534),T(1535,1,Di,UI),f.If=function(t,n){nBt(c(t,37),n)},C(tn,"EndLabelPostprocessor",1535),T(1536,1,{},JI),f.Kb=function(t){return new jt(null,new Tt(c(t,26).a,16))},C(tn,"EndLabelPostprocessor/lambda$0$Type",1536),T(1537,1,Jn,DM),f.Mb=function(t){return zDt(c(t,9))},C(tn,"EndLabelPostprocessor/lambda$1$Type",1537),T(1538,1,ln,zV),f.Ad=function(t){YFt(c(t,9))},C(tn,"EndLabelPostprocessor/lambda$2$Type",1538),T(1539,1,Di,FV),f.If=function(t,n){PQt(c(t,37),n)},C(tn,"EndLabelPreprocessor",1539),T(1540,1,{},z8),f.Kb=function(t){return new jt(null,new Tt(c(t,26).a,16))},C(tn,"EndLabelPreprocessor/lambda$0$Type",1540),T(1541,1,ln,Bze),f.Ad=function(t){h8t(this.a,this.b,this.c,c(t,9))},f.a=0,f.b=0,f.c=!1,C(tn,"EndLabelPreprocessor/lambda$1$Type",1541),T(1542,1,Jn,cm),f.Mb=function(t){return ve(R(c(t,70),(Ge(),yd)))===ve((Sh(),n8))},C(tn,"EndLabelPreprocessor/lambda$2$Type",1542),T(1543,1,ln,pNe),f.Ad=function(t){ei(this.a,c(t,70))},C(tn,"EndLabelPreprocessor/lambda$3$Type",1543),T(1544,1,Jn,LM),f.Mb=function(t){return ve(R(c(t,70),(Ge(),yd)))===ve((Sh(),oy))},C(tn,"EndLabelPreprocessor/lambda$4$Type",1544),T(1545,1,ln,bNe),f.Ad=function(t){ei(this.a,c(t,70))},C(tn,"EndLabelPreprocessor/lambda$5$Type",1545),T(1593,1,Di,Dj),f.If=function(t,n){f$t(c(t,37),n)};var Qht;C(tn,"EndLabelSorter",1593),T(1594,1,Yn,PM),f.Le=function(t,n){return HBt(c(t,458),c(n,458))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(tn,"EndLabelSorter/1",1594),T(458,1,{458:1},gHe),C(tn,"EndLabelSorter/LabelGroup",458),T(1595,1,{},i4),f.Kb=function(t){return e_(),new jt(null,new Tt(c(t,26).a,16))},C(tn,"EndLabelSorter/lambda$0$Type",1595),T(1596,1,Jn,r4),f.Mb=function(t){return e_(),c(t,9).k==(Jt(),or)},C(tn,"EndLabelSorter/lambda$1$Type",1596),T(1597,1,ln,XI),f.Ad=function(t){XHt(c(t,9))},C(tn,"EndLabelSorter/lambda$2$Type",1597),T(1598,1,Jn,IM),f.Mb=function(t){return e_(),ve(R(c(t,70),(Ge(),yd)))===ve((Sh(),oy))},C(tn,"EndLabelSorter/lambda$3$Type",1598),T(1599,1,Jn,VI),f.Mb=function(t){return e_(),ve(R(c(t,70),(Ge(),yd)))===ve((Sh(),n8))},C(tn,"EndLabelSorter/lambda$4$Type",1599),T(1546,1,Di,xO),f.If=function(t,n){GKt(this,c(t,37))},f.b=0,f.c=0,C(tn,"FinalSplineBendpointsCalculator",1546),T(1547,1,{},lm),f.Kb=function(t){return new jt(null,new Tt(c(t,26).a,16))},C(tn,"FinalSplineBendpointsCalculator/lambda$0$Type",1547),T(1548,1,{},RM),f.Kb=function(t){return new jt(null,new U2(new Ht(Vt($i(c(t,9)).a.Jc(),new U))))},C(tn,"FinalSplineBendpointsCalculator/lambda$1$Type",1548),T(1549,1,Jn,kO),f.Mb=function(t){return!vs(c(t,17))},C(tn,"FinalSplineBendpointsCalculator/lambda$2$Type",1549),T(1550,1,Jn,c2),f.Mb=function(t){return xi(c(t,17),(De(),_b))},C(tn,"FinalSplineBendpointsCalculator/lambda$3$Type",1550),T(1551,1,ln,mNe),f.Ad=function(t){KVt(this.a,c(t,134))},C(tn,"FinalSplineBendpointsCalculator/lambda$4$Type",1551),T(1552,1,ln,$M),f.Ad=function(t){NT(c(t,17).a)},C(tn,"FinalSplineBendpointsCalculator/lambda$5$Type",1552),T(797,1,Di,yde),f.If=function(t,n){$Yt(this,c(t,37),n)},C(tn,"GraphTransformer",797),T(506,23,{3:1,34:1,23:1,506:1},M1e);var oce,JL,Ght=mn(tn,"GraphTransformer/Mode",506,On,uNt,OTt),Uht;T(1553,1,Di,F8),f.If=function(t,n){sJt(c(t,37),n)},C(tn,"HierarchicalNodeResizingProcessor",1553),T(1554,1,Di,WI),f.If=function(t,n){qPt(c(t,37),n)},C(tn,"HierarchicalPortConstraintProcessor",1554),T(1555,1,Yn,q8),f.Le=function(t,n){return szt(c(t,9),c(n,9))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(tn,"HierarchicalPortConstraintProcessor/NodeComparator",1555),T(1556,1,Di,H8),f.If=function(t,n){QWt(c(t,37),n)},C(tn,"HierarchicalPortDummySizeProcessor",1556),T(1557,1,Di,KI),f.If=function(t,n){iVt(this,c(t,37),n)},f.a=0,C(tn,"HierarchicalPortOrthogonalEdgeRouter",1557),T(1558,1,Yn,Md),f.Le=function(t,n){return Hjt(c(t,9),c(n,9))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(tn,"HierarchicalPortOrthogonalEdgeRouter/1",1558),T(1559,1,Yn,$y),f.Le=function(t,n){return ILt(c(t,9),c(n,9))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(tn,"HierarchicalPortOrthogonalEdgeRouter/2",1559),T(1560,1,Di,Q8),f.If=function(t,n){NHt(c(t,37),n)},C(tn,"HierarchicalPortPositionProcessor",1560),T(1561,1,Di,vN),f.If=function(t,n){Ben(this,c(t,37))},f.a=0,f.c=0;var aU,fU;C(tn,"HighDegreeNodeLayeringProcessor",1561),T(573,1,{573:1},OO),f.b=-1,f.d=-1,C(tn,"HighDegreeNodeLayeringProcessor/HighDegreeNodeInformation",573),T(1562,1,{},qV),f.Kb=function(t){return C_(),pr(c(t,9))},f.Fb=function(t){return this===t},C(tn,"HighDegreeNodeLayeringProcessor/lambda$0$Type",1562),T(1563,1,{},BM),f.Kb=function(t){return C_(),$i(c(t,9))},f.Fb=function(t){return this===t},C(tn,"HighDegreeNodeLayeringProcessor/lambda$1$Type",1563),T(1569,1,Di,zM),f.If=function(t,n){PWt(this,c(t,37),n)},C(tn,"HyperedgeDummyMerger",1569),T(798,1,{},v0e),f.a=!1,f.b=!1,f.c=!1,C(tn,"HyperedgeDummyMerger/MergeState",798),T(1570,1,{},SO),f.Kb=function(t){return new jt(null,new Tt(c(t,26).a,16))},C(tn,"HyperedgeDummyMerger/lambda$0$Type",1570),T(1571,1,{},G8),f.Kb=function(t){return new jt(null,new Tt(c(t,9).j,16))},C(tn,"HyperedgeDummyMerger/lambda$1$Type",1571),T(1572,1,ln,YI),f.Ad=function(t){c(t,12).p=-1},C(tn,"HyperedgeDummyMerger/lambda$2$Type",1572),T(1573,1,Di,HV),f.If=function(t,n){LWt(c(t,37),n)},C(tn,"HypernodesProcessor",1573),T(1574,1,Di,QV),f.If=function(t,n){HWt(c(t,37),n)},C(tn,"InLayerConstraintProcessor",1574),T(1575,1,Di,GV),f.If=function(t,n){dIt(c(t,37),n)},C(tn,"InnermostNodeMarginCalculator",1575),T(1576,1,Di,FM),f.If=function(t,n){YZt(this,c(t,37))},f.a=Qr,f.b=Qr,f.c=nr,f.d=nr;var Xtn=C(tn,"InteractiveExternalPortPositioner",1576);T(1577,1,{},UV),f.Kb=function(t){return c(t,17).d.i},f.Fb=function(t){return this===t},C(tn,"InteractiveExternalPortPositioner/lambda$0$Type",1577),T(1578,1,{},wNe),f.Kb=function(t){return Ujt(this.a,he(t))},f.Fb=function(t){return this===t},C(tn,"InteractiveExternalPortPositioner/lambda$1$Type",1578),T(1579,1,{},JV),f.Kb=function(t){return c(t,17).c.i},f.Fb=function(t){return this===t},C(tn,"InteractiveExternalPortPositioner/lambda$2$Type",1579),T(1580,1,{},vNe),f.Kb=function(t){return Jjt(this.a,he(t))},f.Fb=function(t){return this===t},C(tn,"InteractiveExternalPortPositioner/lambda$3$Type",1580),T(1581,1,{},yNe),f.Kb=function(t){return q7t(this.a,he(t))},f.Fb=function(t){return this===t},C(tn,"InteractiveExternalPortPositioner/lambda$4$Type",1581),T(1582,1,{},xNe),f.Kb=function(t){return H7t(this.a,he(t))},f.Fb=function(t){return this===t},C(tn,"InteractiveExternalPortPositioner/lambda$5$Type",1582),T(80,23,{3:1,34:1,23:1,80:1,177:1},Er),f.bg=function(){switch(this.g){case 15:return new h2;case 22:return new fm;case 48:return new lA;case 29:case 36:return new nW;case 33:return new B8;case 43:return new QI;case 1:return new GI;case 42:return new n4;case 57:return new yde((iS(),JL));case 0:return new yde((iS(),oce));case 2:return new BV;case 55:return new UI;case 34:return new FV;case 52:return new xO;case 56:return new F8;case 13:return new WI;case 39:return new H8;case 45:return new KI;case 41:return new Q8;case 9:return new vN;case 50:return new kBe;case 38:return new zM;case 44:return new HV;case 28:return new QV;case 31:return new GV;case 3:return new FM;case 18:return new XV;case 30:return new VV;case 5:return new yN;case 51:return new YV;case 35:return new PB;case 37:return new iW;case 53:return new Dj;case 11:return new eR;case 7:return new xN;case 40:return new rW;case 46:return new sW;case 16:return new oW;case 10:return new uRe;case 49:return new aW;case 21:return new fW;case 23:return new Oz((hb(),lC));case 8:return new HM;case 12:return new dW;case 4:return new tR;case 19:return new i6;case 17:return new cR;case 54:return new TO;case 6:return new yW;case 25:return new mLe;case 26:return new Qy;case 47:return new GM;case 32:return new dze;case 14:return new pR;case 27:return new CW;case 20:return new MO;case 24:return new Oz((hb(),mJ));default:throw J(new qt(Tre+(this.f!=null?this.f:""+this.g)))}};var eOe,tOe,nOe,iOe,rOe,sOe,oOe,cOe,lOe,uOe,aOe,r3,hU,dU,fOe,hOe,dOe,gOe,pOe,bOe,mOe,IE,wOe,vOe,yOe,xOe,kOe,cce,gU,pU,OOe,bU,mU,wU,T9,Lv,Pv,SOe,vU,yU,jOe,xU,kU,TOe,EOe,COe,MOe,OU,lce,pk,SU,jU,TU,EU,AOe,NOe,_Oe,DOe,Vtn=mn(tn,Ere,80,On,ant,STt),Jht;T(1583,1,Di,XV),f.If=function(t,n){VZt(c(t,37),n)},C(tn,"InvertedPortProcessor",1583),T(1584,1,Di,VV),f.If=function(t,n){GVt(c(t,37),n)},C(tn,"LabelAndNodeSizeProcessor",1584),T(1585,1,Jn,WV),f.Mb=function(t){return c(t,9).k==(Jt(),or)},C(tn,"LabelAndNodeSizeProcessor/lambda$0$Type",1585),T(1586,1,Jn,ZI),f.Mb=function(t){return c(t,9).k==(Jt(),Cr)},C(tn,"LabelAndNodeSizeProcessor/lambda$1$Type",1586),T(1587,1,ln,Gze),f.Ad=function(t){d8t(this.b,this.a,this.c,c(t,9))},f.a=!1,f.c=!1,C(tn,"LabelAndNodeSizeProcessor/lambda$2$Type",1587),T(1588,1,Di,yN),f.If=function(t,n){EZt(c(t,37),n)};var Xht;C(tn,"LabelDummyInserter",1588),T(1589,1,hd,KV),f.Lb=function(t){return ve(R(c(t,70),(Ge(),yd)))===ve((Sh(),t8))},f.Fb=function(t){return this===t},f.Mb=function(t){return ve(R(c(t,70),(Ge(),yd)))===ve((Sh(),t8))},C(tn,"LabelDummyInserter/1",1589),T(1590,1,Di,YV),f.If=function(t,n){dZt(c(t,37),n)},C(tn,"LabelDummyRemover",1590),T(1591,1,Jn,ZV),f.Mb=function(t){return et(Ze(R(c(t,70),(Ge(),b3))))},C(tn,"LabelDummyRemover/lambda$0$Type",1591),T(1344,1,Di,PB),f.If=function(t,n){cZt(this,c(t,37),n)},f.a=null;var uce;C(tn,"LabelDummySwitcher",1344),T(295,1,{295:1},oit),f.c=0,f.d=null,f.f=0,C(tn,"LabelDummySwitcher/LabelDummyInfo",295),T(1345,1,{},eW),f.Kb=function(t){return _5(),new jt(null,new Tt(c(t,26).a,16))},C(tn,"LabelDummySwitcher/lambda$0$Type",1345),T(1346,1,Jn,qM),f.Mb=function(t){return _5(),c(t,9).k==(Jt(),lc)},C(tn,"LabelDummySwitcher/lambda$1$Type",1346),T(1347,1,{},kNe),f.Kb=function(t){return _7t(this.a,c(t,9))},C(tn,"LabelDummySwitcher/lambda$2$Type",1347),T(1348,1,ln,ONe),f.Ad=function(t){BMt(this.a,c(t,295))},C(tn,"LabelDummySwitcher/lambda$3$Type",1348),T(1349,1,Yn,tW),f.Le=function(t,n){return pMt(c(t,295),c(n,295))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(tn,"LabelDummySwitcher/lambda$4$Type",1349),T(796,1,Di,nW),f.If=function(t,n){gLt(c(t,37),n)},C(tn,"LabelManagementProcessor",796),T(1592,1,Di,iW),f.If=function(t,n){kXt(c(t,37),n)},C(tn,"LabelSideSelector",1592),T(1600,1,Di,eR),f.If=function(t,n){uKt(c(t,37),n)},C(tn,"LayerConstraintPostprocessor",1600),T(1601,1,Di,xN),f.If=function(t,n){nUt(c(t,37),n)};var LOe;C(tn,"LayerConstraintPreprocessor",1601),T(368,23,{3:1,34:1,23:1,368:1},Vz);var XL,CU,MU,ace,Vht=mn(tn,"LayerConstraintPreprocessor/HiddenNodeConnections",368,On,K_t,jTt),Wht;T(1602,1,Di,rW),f.If=function(t,n){TYt(c(t,37),n)},C(tn,"LayerSizeAndGraphHeightCalculator",1602),T(1603,1,Di,sW),f.If=function(t,n){oJt(c(t,37),n)},C(tn,"LongEdgeJoiner",1603),T(1604,1,Di,oW),f.If=function(t,n){iYt(c(t,37),n)},C(tn,"LongEdgeSplitter",1604),T(1605,1,Di,uRe),f.If=function(t,n){FZt(this,c(t,37),n)},f.e=0,f.f=0,f.j=0,f.k=0,f.n=0,f.o=0;var Kht,Yht;C(tn,"NodePromotion",1605),T(1606,1,Yn,cW),f.Le=function(t,n){return xRt(c(t,9),c(n,9))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(tn,"NodePromotion/1",1606),T(1607,1,Yn,lW),f.Le=function(t,n){return yRt(c(t,9),c(n,9))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(tn,"NodePromotion/2",1607),T(1608,1,{},uW),f.Kb=function(t){return c(t,49),IF(),Bt(),!0},f.Fb=function(t){return this===t},C(tn,"NodePromotion/lambda$0$Type",1608),T(1609,1,{},SNe),f.Kb=function(t){return xNt(this.a,c(t,49))},f.Fb=function(t){return this===t},f.a=0,C(tn,"NodePromotion/lambda$1$Type",1609),T(1610,1,{},jNe),f.Kb=function(t){return kNt(this.a,c(t,49))},f.Fb=function(t){return this===t},f.a=0,C(tn,"NodePromotion/lambda$2$Type",1610),T(1611,1,Di,aW),f.If=function(t,n){Aen(c(t,37),n)},C(tn,"NorthSouthPortPostprocessor",1611),T(1612,1,Di,fW),f.If=function(t,n){Ien(c(t,37),n)},C(tn,"NorthSouthPortPreprocessor",1612),T(1613,1,Yn,hW),f.Le=function(t,n){return BIt(c(t,12),c(n,12))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(tn,"NorthSouthPortPreprocessor/lambda$0$Type",1613),T(1614,1,Di,HM),f.If=function(t,n){SWt(c(t,37),n)},C(tn,"PartitionMidprocessor",1614),T(1615,1,Jn,jO),f.Mb=function(t){return xi(c(t,9),(Ge(),Hv))},C(tn,"PartitionMidprocessor/lambda$0$Type",1615),T(1616,1,ln,TNe),f.Ad=function(t){EAt(this.a,c(t,9))},C(tn,"PartitionMidprocessor/lambda$1$Type",1616),T(1617,1,Di,dW),f.If=function(t,n){EJt(c(t,37),n)},C(tn,"PartitionPostprocessor",1617),T(1618,1,Di,tR),f.If=function(t,n){AVt(c(t,37),n)},C(tn,"PartitionPreprocessor",1618),T(1619,1,Jn,nR),f.Mb=function(t){return xi(c(t,9),(Ge(),Hv))},C(tn,"PartitionPreprocessor/lambda$0$Type",1619),T(1620,1,Jn,iR),f.Mb=function(t){return xi(c(t,9),(Ge(),Hv))},C(tn,"PartitionPreprocessor/lambda$1$Type",1620),T(1621,1,{},rR),f.Kb=function(t){return new jt(null,new U2(new Ht(Vt($i(c(t,9)).a.Jc(),new U))))},C(tn,"PartitionPreprocessor/lambda$2$Type",1621),T(1622,1,Jn,ENe),f.Mb=function(t){return Y9t(this.a,c(t,17))},C(tn,"PartitionPreprocessor/lambda$3$Type",1622),T(1623,1,ln,sR),f.Ad=function(t){KIt(c(t,17))},C(tn,"PartitionPreprocessor/lambda$4$Type",1623),T(1624,1,Jn,CNe),f.Mb=function(t){return $Mt(this.a,c(t,9))},f.a=0,C(tn,"PartitionPreprocessor/lambda$5$Type",1624),T(1625,1,Di,i6),f.If=function(t,n){rWt(c(t,37),n)};var POe,Zht,edt,tdt,IOe,ROe;C(tn,"PortListSorter",1625),T(1626,1,{},s4),f.Kb=function(t){return aS(),c(t,12).e},C(tn,"PortListSorter/lambda$0$Type",1626),T(1627,1,{},gW),f.Kb=function(t){return aS(),c(t,12).g},C(tn,"PortListSorter/lambda$1$Type",1627),T(1628,1,Yn,pW),f.Le=function(t,n){return kGe(c(t,12),c(n,12))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(tn,"PortListSorter/lambda$2$Type",1628),T(1629,1,Yn,bW),f.Le=function(t,n){return gFt(c(t,12),c(n,12))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(tn,"PortListSorter/lambda$3$Type",1629),T(1630,1,Yn,oR),f.Le=function(t,n){return Dit(c(t,12),c(n,12))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(tn,"PortListSorter/lambda$4$Type",1630),T(1631,1,Di,cR),f.If=function(t,n){aUt(c(t,37),n)},C(tn,"PortSideProcessor",1631),T(1632,1,Di,TO),f.If=function(t,n){bVt(c(t,37),n)},C(tn,"ReversedEdgeRestorer",1632),T(1637,1,Di,mLe),f.If=function(t,n){Wzt(this,c(t,37),n)},C(tn,"SelfLoopPortRestorer",1637),T(1638,1,{},EO),f.Kb=function(t){return new jt(null,new Tt(c(t,26).a,16))},C(tn,"SelfLoopPortRestorer/lambda$0$Type",1638),T(1639,1,Jn,mW),f.Mb=function(t){return c(t,9).k==(Jt(),or)},C(tn,"SelfLoopPortRestorer/lambda$1$Type",1639),T(1640,1,Jn,U8),f.Mb=function(t){return xi(c(t,9),(De(),Nw))},C(tn,"SelfLoopPortRestorer/lambda$2$Type",1640),T(1641,1,{},lR),f.Kb=function(t){return c(R(c(t,9),(De(),Nw)),339)},C(tn,"SelfLoopPortRestorer/lambda$3$Type",1641),T(1642,1,ln,MNe),f.Ad=function(t){lQt(this.a,c(t,339))},C(tn,"SelfLoopPortRestorer/lambda$4$Type",1642),T(799,1,ln,QM),f.Ad=function(t){yQt(c(t,108))},C(tn,"SelfLoopPortRestorer/lambda$5$Type",799),T(1644,1,Di,GM),f.If=function(t,n){lzt(c(t,37),n)},C(tn,"SelfLoopPostProcessor",1644),T(1645,1,{},UM),f.Kb=function(t){return new jt(null,new Tt(c(t,26).a,16))},C(tn,"SelfLoopPostProcessor/lambda$0$Type",1645),T(1646,1,Jn,uR),f.Mb=function(t){return c(t,9).k==(Jt(),or)},C(tn,"SelfLoopPostProcessor/lambda$1$Type",1646),T(1647,1,Jn,aR),f.Mb=function(t){return xi(c(t,9),(De(),Nw))},C(tn,"SelfLoopPostProcessor/lambda$2$Type",1647),T(1648,1,ln,fR),f.Ad=function(t){pqt(c(t,9))},C(tn,"SelfLoopPostProcessor/lambda$3$Type",1648),T(1649,1,{},wW),f.Kb=function(t){return new jt(null,new Tt(c(t,108).f,1))},C(tn,"SelfLoopPostProcessor/lambda$4$Type",1649),T(1650,1,ln,ANe),f.Ad=function(t){U_t(this.a,c(t,342))},C(tn,"SelfLoopPostProcessor/lambda$5$Type",1650),T(1651,1,Jn,vW),f.Mb=function(t){return!!c(t,108).i},C(tn,"SelfLoopPostProcessor/lambda$6$Type",1651),T(1652,1,ln,NNe),f.Ad=function(t){d9t(this.a,c(t,108))},C(tn,"SelfLoopPostProcessor/lambda$7$Type",1652),T(1633,1,Di,yW),f.If=function(t,n){QUt(c(t,37),n)},C(tn,"SelfLoopPreProcessor",1633),T(1634,1,{},xW),f.Kb=function(t){return new jt(null,new Tt(c(t,108).f,1))},C(tn,"SelfLoopPreProcessor/lambda$0$Type",1634),T(1635,1,{},kW),f.Kb=function(t){return c(t,342).a},C(tn,"SelfLoopPreProcessor/lambda$1$Type",1635),T(1636,1,ln,h1),f.Ad=function(t){jjt(c(t,17))},C(tn,"SelfLoopPreProcessor/lambda$2$Type",1636),T(1653,1,Di,dze),f.If=function(t,n){GHt(this,c(t,37),n)},C(tn,"SelfLoopRouter",1653),T(1654,1,{},CO),f.Kb=function(t){return new jt(null,new Tt(c(t,26).a,16))},C(tn,"SelfLoopRouter/lambda$0$Type",1654),T(1655,1,Jn,hR),f.Mb=function(t){return c(t,9).k==(Jt(),or)},C(tn,"SelfLoopRouter/lambda$1$Type",1655),T(1656,1,Jn,dR),f.Mb=function(t){return xi(c(t,9),(De(),Nw))},C(tn,"SelfLoopRouter/lambda$2$Type",1656),T(1657,1,{},gR),f.Kb=function(t){return c(R(c(t,9),(De(),Nw)),339)},C(tn,"SelfLoopRouter/lambda$3$Type",1657),T(1658,1,ln,WIe),f.Ad=function(t){xAt(this.a,this.b,c(t,339))},C(tn,"SelfLoopRouter/lambda$4$Type",1658),T(1659,1,Di,pR),f.If=function(t,n){uXt(c(t,37),n)},C(tn,"SemiInteractiveCrossMinProcessor",1659),T(1660,1,Jn,JM),f.Mb=function(t){return c(t,9).k==(Jt(),or)},C(tn,"SemiInteractiveCrossMinProcessor/lambda$0$Type",1660),T(1661,1,Jn,OW),f.Mb=function(t){return CFe(c(t,9))._b((Ge(),Uv))},C(tn,"SemiInteractiveCrossMinProcessor/lambda$1$Type",1661),T(1662,1,Yn,o4),f.Le=function(t,n){return eIt(c(t,9),c(n,9))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(tn,"SemiInteractiveCrossMinProcessor/lambda$2$Type",1662),T(1663,1,{},XM),f.Te=function(t,n){return TAt(c(t,9),c(n,9))},C(tn,"SemiInteractiveCrossMinProcessor/lambda$3$Type",1663),T(1665,1,Di,MO),f.If=function(t,n){QYt(c(t,37),n)},C(tn,"SortByInputModelProcessor",1665),T(1666,1,Jn,VM),f.Mb=function(t){return c(t,12).g.c.length!=0},C(tn,"SortByInputModelProcessor/lambda$0$Type",1666),T(1667,1,ln,_Ne),f.Ad=function(t){jQt(this.a,c(t,12))},C(tn,"SortByInputModelProcessor/lambda$1$Type",1667),T(1746,811,{},VXe),f.bf=function(t){var n,i,r,o;switch(this.c=t,this.a.g){case 2:n=new Fe,lr(pi(new jt(null,new Tt(this.c.a.b,16)),new kR),new tRe(this,n)),zD(this,new By),Qc(n,new c4),n.c.length=0,lr(pi(new jt(null,new Tt(this.c.a.b,16)),new WM),new LNe(n)),zD(this,new mR),Qc(n,new zy),n.c.length=0,i=$$e(pte(X2(new jt(null,new Tt(this.c.a.b,16)),new PNe(this))),new wR),lr(new jt(null,new Tt(this.c.a.a,16)),new YIe(i,n)),zD(this,new yR),Qc(n,new SW),n.c.length=0;break;case 3:r=new Fe,zD(this,new bR),o=$$e(pte(X2(new jt(null,new Tt(this.c.a.b,16)),new DNe(this))),new vR),lr(pi(new jt(null,new Tt(this.c.a.b,16)),new jW),new eRe(o,r)),zD(this,new TW),Qc(r,new xR),r.c.length=0;break;default:throw J(new iLe)}},f.b=0,C(xr,"EdgeAwareScanlineConstraintCalculation",1746),T(1747,1,hd,bR),f.Lb=function(t){return oe(c(t,60).g,157)},f.Fb=function(t){return this===t},f.Mb=function(t){return oe(c(t,60).g,157)},C(xr,"EdgeAwareScanlineConstraintCalculation/lambda$0$Type",1747),T(1748,1,{},DNe),f.We=function(t){return YQt(this.a,c(t,60))},C(xr,"EdgeAwareScanlineConstraintCalculation/lambda$1$Type",1748),T(1756,1,HQ,KIe),f.be=function(){ET(this.a,this.b,-1)},f.b=0,C(xr,"EdgeAwareScanlineConstraintCalculation/lambda$10$Type",1756),T(1758,1,hd,By),f.Lb=function(t){return oe(c(t,60).g,157)},f.Fb=function(t){return this===t},f.Mb=function(t){return oe(c(t,60).g,157)},C(xr,"EdgeAwareScanlineConstraintCalculation/lambda$11$Type",1758),T(1759,1,ln,c4),f.Ad=function(t){c(t,376).be()},C(xr,"EdgeAwareScanlineConstraintCalculation/lambda$12$Type",1759),T(1760,1,Jn,WM),f.Mb=function(t){return oe(c(t,60).g,9)},C(xr,"EdgeAwareScanlineConstraintCalculation/lambda$13$Type",1760),T(1762,1,ln,LNe),f.Ad=function(t){I$t(this.a,c(t,60))},C(xr,"EdgeAwareScanlineConstraintCalculation/lambda$14$Type",1762),T(1761,1,HQ,rRe),f.be=function(){ET(this.b,this.a,-1)},f.a=0,C(xr,"EdgeAwareScanlineConstraintCalculation/lambda$15$Type",1761),T(1763,1,hd,mR),f.Lb=function(t){return oe(c(t,60).g,9)},f.Fb=function(t){return this===t},f.Mb=function(t){return oe(c(t,60).g,9)},C(xr,"EdgeAwareScanlineConstraintCalculation/lambda$16$Type",1763),T(1764,1,ln,zy),f.Ad=function(t){c(t,376).be()},C(xr,"EdgeAwareScanlineConstraintCalculation/lambda$17$Type",1764),T(1765,1,{},PNe),f.We=function(t){return ZQt(this.a,c(t,60))},C(xr,"EdgeAwareScanlineConstraintCalculation/lambda$18$Type",1765),T(1766,1,{},wR),f.Ue=function(){return 0},C(xr,"EdgeAwareScanlineConstraintCalculation/lambda$19$Type",1766),T(1749,1,{},vR),f.Ue=function(){return 0},C(xr,"EdgeAwareScanlineConstraintCalculation/lambda$2$Type",1749),T(1768,1,ln,YIe),f.Ad=function(t){sMt(this.a,this.b,c(t,321))},f.a=0,C(xr,"EdgeAwareScanlineConstraintCalculation/lambda$20$Type",1768),T(1767,1,HQ,ZIe),f.be=function(){_tt(this.a,this.b,-1)},f.b=0,C(xr,"EdgeAwareScanlineConstraintCalculation/lambda$21$Type",1767),T(1769,1,hd,yR),f.Lb=function(t){return c(t,60),!0},f.Fb=function(t){return this===t},f.Mb=function(t){return c(t,60),!0},C(xr,"EdgeAwareScanlineConstraintCalculation/lambda$22$Type",1769),T(1770,1,ln,SW),f.Ad=function(t){c(t,376).be()},C(xr,"EdgeAwareScanlineConstraintCalculation/lambda$23$Type",1770),T(1750,1,Jn,jW),f.Mb=function(t){return oe(c(t,60).g,9)},C(xr,"EdgeAwareScanlineConstraintCalculation/lambda$3$Type",1750),T(1752,1,ln,eRe),f.Ad=function(t){oMt(this.a,this.b,c(t,60))},f.a=0,C(xr,"EdgeAwareScanlineConstraintCalculation/lambda$4$Type",1752),T(1751,1,HQ,sRe),f.be=function(){ET(this.b,this.a,-1)},f.a=0,C(xr,"EdgeAwareScanlineConstraintCalculation/lambda$5$Type",1751),T(1753,1,hd,TW),f.Lb=function(t){return c(t,60),!0},f.Fb=function(t){return this===t},f.Mb=function(t){return c(t,60),!0},C(xr,"EdgeAwareScanlineConstraintCalculation/lambda$6$Type",1753),T(1754,1,ln,xR),f.Ad=function(t){c(t,376).be()},C(xr,"EdgeAwareScanlineConstraintCalculation/lambda$7$Type",1754),T(1755,1,Jn,kR),f.Mb=function(t){return oe(c(t,60).g,157)},C(xr,"EdgeAwareScanlineConstraintCalculation/lambda$8$Type",1755),T(1757,1,ln,tRe),f.Ad=function(t){xPt(this.a,this.b,c(t,60))},C(xr,"EdgeAwareScanlineConstraintCalculation/lambda$9$Type",1757),T(1564,1,Di,kBe),f.If=function(t,n){oYt(this,c(t,37),n)};var ndt;C(xr,"HorizontalGraphCompactor",1564),T(1565,1,{},INe),f.df=function(t,n){var i,r,o;return $be(t,n)||(i=kx(t),r=kx(n),i&&i.k==(Jt(),Cr)||r&&r.k==(Jt(),Cr))?0:(o=c(R(this.a.a,(De(),d3)),317),Wjt(o,i?i.k:(Jt(),jr),r?r.k:(Jt(),jr)))},f.ef=function(t,n){var i,r,o;return $be(t,n)?1:(i=kx(t),r=kx(n),o=c(R(this.a.a,(De(),d3)),317),Nge(o,i?i.k:(Jt(),jr),r?r.k:(Jt(),jr)))},C(xr,"HorizontalGraphCompactor/1",1565),T(1566,1,{},KM),f.cf=function(t,n){return o7(),t.a.i==0},C(xr,"HorizontalGraphCompactor/lambda$0$Type",1566),T(1567,1,{},RNe),f.cf=function(t,n){return MAt(this.a,t,n)},C(xr,"HorizontalGraphCompactor/lambda$1$Type",1567),T(1713,1,{},EJe);var idt,rdt;C(xr,"LGraphToCGraphTransformer",1713),T(1721,1,Jn,g0),f.Mb=function(t){return t!=null},C(xr,"LGraphToCGraphTransformer/0methodref$nonNull$Type",1721),T(1714,1,{},J8),f.Kb=function(t){return Pu(),jo(R(c(c(t,60).g,9),(De(),Oi)))},C(xr,"LGraphToCGraphTransformer/lambda$0$Type",1714),T(1715,1,{},ug),f.Kb=function(t){return Pu(),qWe(c(c(t,60).g,157))},C(xr,"LGraphToCGraphTransformer/lambda$1$Type",1715),T(1724,1,Jn,l4),f.Mb=function(t){return Pu(),oe(c(t,60).g,9)},C(xr,"LGraphToCGraphTransformer/lambda$10$Type",1724),T(1725,1,ln,YM),f.Ad=function(t){SAt(c(t,60))},C(xr,"LGraphToCGraphTransformer/lambda$11$Type",1725),T(1726,1,Jn,X8),f.Mb=function(t){return Pu(),oe(c(t,60).g,157)},C(xr,"LGraphToCGraphTransformer/lambda$12$Type",1726),T(1730,1,ln,V8),f.Ad=function(t){e$t(c(t,60))},C(xr,"LGraphToCGraphTransformer/lambda$13$Type",1730),T(1727,1,ln,$Ne),f.Ad=function(t){U8t(this.a,c(t,8))},f.a=0,C(xr,"LGraphToCGraphTransformer/lambda$14$Type",1727),T(1728,1,ln,BNe),f.Ad=function(t){X8t(this.a,c(t,120))},f.a=0,C(xr,"LGraphToCGraphTransformer/lambda$15$Type",1728),T(1729,1,ln,zNe),f.Ad=function(t){J8t(this.a,c(t,8))},f.a=0,C(xr,"LGraphToCGraphTransformer/lambda$16$Type",1729),T(1731,1,{},ZM),f.Kb=function(t){return Pu(),new jt(null,new U2(new Ht(Vt($i(c(t,9)).a.Jc(),new U))))},C(xr,"LGraphToCGraphTransformer/lambda$17$Type",1731),T(1732,1,Jn,Fy),f.Mb=function(t){return Pu(),vs(c(t,17))},C(xr,"LGraphToCGraphTransformer/lambda$18$Type",1732),T(1733,1,ln,FNe),f.Ad=function(t){KLt(this.a,c(t,17))},C(xr,"LGraphToCGraphTransformer/lambda$19$Type",1733),T(1717,1,ln,qNe),f.Ad=function(t){T_t(this.a,c(t,157))},C(xr,"LGraphToCGraphTransformer/lambda$2$Type",1717),T(1734,1,{},OR),f.Kb=function(t){return Pu(),new jt(null,new Tt(c(t,26).a,16))},C(xr,"LGraphToCGraphTransformer/lambda$20$Type",1734),T(1735,1,{},W8),f.Kb=function(t){return Pu(),new jt(null,new U2(new Ht(Vt($i(c(t,9)).a.Jc(),new U))))},C(xr,"LGraphToCGraphTransformer/lambda$21$Type",1735),T(1736,1,{},u4),f.Kb=function(t){return Pu(),c(R(c(t,17),(De(),_b)),16)},C(xr,"LGraphToCGraphTransformer/lambda$22$Type",1736),T(1737,1,Jn,EW),f.Mb=function(t){return Kjt(c(t,16))},C(xr,"LGraphToCGraphTransformer/lambda$23$Type",1737),T(1738,1,ln,HNe),f.Ad=function(t){eGt(this.a,c(t,16))},C(xr,"LGraphToCGraphTransformer/lambda$24$Type",1738),T(1739,1,{},d1),f.Kb=function(t){return Pu(),new jt(null,new U2(new Ht(Vt($i(c(t,9)).a.Jc(),new U))))},C(xr,"LGraphToCGraphTransformer/lambda$25$Type",1739),T(1740,1,Jn,eA),f.Mb=function(t){return Pu(),vs(c(t,17))},C(xr,"LGraphToCGraphTransformer/lambda$26$Type",1740),T(1742,1,ln,QNe),f.Ad=function(t){QPt(this.a,c(t,17))},C(xr,"LGraphToCGraphTransformer/lambda$27$Type",1742),T(1741,1,ln,GNe),f.Ad=function(t){$9t(this.a,c(t,70))},f.a=0,C(xr,"LGraphToCGraphTransformer/lambda$28$Type",1741),T(1716,1,ln,nRe),f.Ad=function(t){jDt(this.a,this.b,c(t,157))},C(xr,"LGraphToCGraphTransformer/lambda$3$Type",1716),T(1718,1,{},um),f.Kb=function(t){return Pu(),new jt(null,new Tt(c(t,26).a,16))},C(xr,"LGraphToCGraphTransformer/lambda$4$Type",1718),T(1719,1,{},SR),f.Kb=function(t){return Pu(),new jt(null,new U2(new Ht(Vt($i(c(t,9)).a.Jc(),new U))))},C(xr,"LGraphToCGraphTransformer/lambda$5$Type",1719),T(1720,1,{},K8),f.Kb=function(t){return Pu(),c(R(c(t,17),(De(),_b)),16)},C(xr,"LGraphToCGraphTransformer/lambda$6$Type",1720),T(1722,1,ln,UNe),f.Ad=function(t){fGt(this.a,c(t,16))},C(xr,"LGraphToCGraphTransformer/lambda$8$Type",1722),T(1723,1,ln,iRe),f.Ad=function(t){wjt(this.a,this.b,c(t,157))},C(xr,"LGraphToCGraphTransformer/lambda$9$Type",1723),T(1712,1,{},qy),f.af=function(t){var n,i,r,o,a;for(this.a=t,this.d=new zK,this.c=ye(xke,Lt,126,this.a.a.a.c.length,0,1),this.b=0,i=new G(this.a.a.a);i.a<i.c.c.length;)n=c(Q(i),321),n.d=this.b,a=Dm(ZN(new Fp,n),this.d),this.c[this.b]=a,++this.b;for(OZt(this),yen(this),jJt(this),fie(xZ(this.d),new V4),o=new G(this.a.a.b);o.a<o.c.c.length;)r=c(Q(o),60),r.d.c=this.c[r.a.d].e+r.b.a},f.b=0,C(xr,"NetworkSimplexCompaction",1712),T(157,1,{34:1,157:1},QT),f.Dd=function(t){return rPt(this,c(t,157))},f.Ib=function(){return qWe(this)},C(xr,"VerticalSegment",157),T(833,1,{},A2e),f.c=0,f.e=0,f.i=0,C(oE,"BetweenLayerEdgeTwoNodeCrossingsCounter",833),T(674,1,{674:1},uVe),f.Ib=function(){return"AdjacencyList [node="+this.d+", adjacencies= "+this.a+"]"},f.b=0,f.c=0,f.f=0,C(oE,"BetweenLayerEdgeTwoNodeCrossingsCounter/AdjacencyList",674),T(296,1,{34:1,296:1},NBe),f.Dd=function(t){return _Ct(this,c(t,296))},f.Ib=function(){return"Adjacency [position="+this.c+", cardinality="+this.a+", currentCardinality="+this.b+"]"},f.a=0,f.b=0,f.c=0,C(oE,"BetweenLayerEdgeTwoNodeCrossingsCounter/AdjacencyList/Adjacency",296),T(2005,1,{},set),f.b=0,f.e=!1,C(oE,"CrossingMatrixFiller",2005);var sdt=Ki(Kd,"IInitializable");T(1863,1,cE,oRe),f.eg=function(t,n,i,r,o,a){},f.gg=function(t,n,i){},f.cg=function(){return this.c!=(hb(),lC)},f.dg=function(){this.e=ye(Fn,ci,30,this.d,15,1)},f.fg=function(t,n){n[t][0].c.p=t},f.hg=function(t,n,i,r){++this.d},f.ig=function(){return!0},f.jg=function(t,n,i,r){return _We(this,t,n,i),qDt(this,n)},f.kg=function(t,n){var i;return i=Q9t(n,t.length),_We(this,t,i,n),QVe(this,i)},f.d=0,C(oE,"GreedySwitchHeuristic",1863),T(2008,1,{},LFe),f.b=0,f.d=0,C(oE,"NorthSouthEdgeNeighbouringNodeCrossingsCounter",2008),T(1995,1,{},Qnt),f.a=!1,C(oE,"SwitchDecider",1995),T(108,1,{108:1},met),f.a=null,f.c=null,f.i=null,C(lk,"SelfHyperLoop",108),T(1992,1,{},GKe),f.c=0,f.e=0,C(lk,"SelfHyperLoopLabels",1992),T(418,23,{3:1,34:1,23:1,418:1},Wz);var Iv,E9,C9,fce,odt=mn(lk,"SelfHyperLoopLabels/Alignment",418,On,Y_t,TTt),cdt;T(342,1,{342:1},uUe),C(lk,"SelfLoopEdge",342),T(339,1,{339:1},UKe),f.a=!1,C(lk,"SelfLoopHolder",339),T(1777,1,Jn,tA),f.Mb=function(t){return vs(c(t,17))},C(lk,"SelfLoopHolder/lambda$0$Type",1777),T(114,1,{114:1},YKe),f.a=!1,f.c=!1,C(lk,"SelfLoopPort",114),T(1849,1,Jn,jR),f.Mb=function(t){return vs(c(t,17))},C(lk,"SelfLoopPort/lambda$0$Type",1849),T(372,23,{3:1,34:1,23:1,372:1},r_);var AU,VL,NU,_U,DU,ldt=mn(lk,"SelfLoopType",372,On,JDt,ETt),udt;T(1785,1,{},Lj);var adt,fdt,hdt,ddt;C(Uu,"PortRestorer",1785),T(369,23,{3:1,34:1,23:1,369:1},yY);var Tw,ep,Ew,hce=mn(Uu,"PortRestorer/PortSideArea",369,On,t_t,ATt),gdt;T(1786,1,{},nA),f.Kb=function(t){return z0(),c(t,16).Mc()},C(Uu,"PortRestorer/lambda$0$Type",1786),T(1787,1,ln,TR),f.Ad=function(t){z0(),c(t,114).c=!1},C(Uu,"PortRestorer/lambda$1$Type",1787),T(1796,1,Jn,ag),f.Mb=function(t){return z0(),c(t,12).j==(Je(),Yt)},C(Uu,"PortRestorer/lambda$10$Type",1796),T(1797,1,{},a4),f.Kb=function(t){return z0(),c(t,114).d},C(Uu,"PortRestorer/lambda$11$Type",1797),T(1798,1,ln,JNe),f.Ad=function(t){B9t(this.a,c(t,12))},C(Uu,"PortRestorer/lambda$12$Type",1798),T(1788,1,ln,XNe),f.Ad=function(t){h7t(this.a,c(t,108))},C(Uu,"PortRestorer/lambda$2$Type",1788),T(1789,1,Yn,f4),f.Le=function(t,n){return APt(c(t,114),c(n,114))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Uu,"PortRestorer/lambda$3$Type",1789),T(1790,1,Jn,Y8),f.Mb=function(t){return z0(),c(t,114).c},C(Uu,"PortRestorer/lambda$4$Type",1790),T(1791,1,Jn,AO),f.Mb=function(t){return SIt(c(t,12))},C(Uu,"PortRestorer/lambda$5$Type",1791),T(1792,1,Jn,fg),f.Mb=function(t){return z0(),c(t,12).j==(Je(),Kt)},C(Uu,"PortRestorer/lambda$6$Type",1792),T(1793,1,Jn,hg),f.Mb=function(t){return z0(),c(t,12).j==(Je(),nn)},C(Uu,"PortRestorer/lambda$7$Type",1793),T(1794,1,Jn,l2),f.Mb=function(t){return pDt(c(t,12))},C(Uu,"PortRestorer/lambda$8$Type",1794),T(1795,1,Jn,Np),f.Mb=function(t){return z0(),c(t,12).j==(Je(),bn)},C(Uu,"PortRestorer/lambda$9$Type",1795),T(277,23,{3:1,34:1,23:1,277:1},x5);var dce,gce,pce,bce,mce,wce,vce,yce,$Oe=mn(Uu,"PortSideAssigner/Target",277,On,aPt,NTt),pdt;T(1778,1,{},_p),f.Kb=function(t){return pi(new jt(null,new Tt(c(t,108).j,16)),new cf)},C(Uu,"PortSideAssigner/lambda$1$Type",1778),T(1779,1,{},am),f.Kb=function(t){return c(t,114).d},C(Uu,"PortSideAssigner/lambda$2$Type",1779),T(1780,1,ln,ER),f.Ad=function(t){$r(c(t,12),(Je(),Kt))},C(Uu,"PortSideAssigner/lambda$3$Type",1780),T(1781,1,{},iA),f.Kb=function(t){return c(t,114).d},C(Uu,"PortSideAssigner/lambda$4$Type",1781),T(1782,1,ln,VNe),f.Ad=function(t){YSt(this.a,c(t,12))},C(Uu,"PortSideAssigner/lambda$5$Type",1782),T(1783,1,Yn,rA),f.Le=function(t,n){return JMt(c(t,108),c(n,108))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Uu,"PortSideAssigner/lambda$6$Type",1783),T(1784,1,Yn,CR),f.Le=function(t,n){return TCt(c(t,114),c(n,114))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Uu,"PortSideAssigner/lambda$7$Type",1784),T(814,1,Jn,cf),f.Mb=function(t){return c(t,114).c},C(Uu,"PortSideAssigner/lambda$8$Type",814),T(2087,1,{}),C(J0,"AbstractSelfLoopRouter",2087),T(1803,1,Yn,Sl),f.Le=function(t,n){return K7t(c(t,108),c(n,108))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(J0,Tot,1803),T(1804,1,Yn,ko),f.Le=function(t,n){return Y7t(c(t,108),c(n,108))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(J0,Eot,1804),T(1850,2087,{},u2),f.lg=function(t,n,i){return i},C(J0,"OrthogonalSelfLoopRouter",1850),T(1852,1,ln,cRe),f.Ad=function(t){Fwe(this.b,this.a,c(t,8))},C(J0,"OrthogonalSelfLoopRouter/lambda$0$Type",1852),T(1851,1850,{},dg),f.lg=function(t,n,i){var r,o;return r=t.c.d,M6(i,0,ki(Ms(r.n),r.a)),o=t.d.d,ei(i,ki(Ms(o.n),o.a)),vWt(i)},C(J0,"PolylineSelfLoopRouter",1851),T(1799,1,{},cK),f.a=null;var s3;C(J0,"RoutingDirector",1799),T(1800,1,Yn,sA),f.Le=function(t,n){return OCt(c(t,114),c(n,114))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(J0,"RoutingDirector/lambda$0$Type",1800),T(1801,1,{},a2),f.Kb=function(t){return Pz(),c(t,108).j},C(J0,"RoutingDirector/lambda$1$Type",1801),T(1802,1,ln,MR),f.Ad=function(t){Pz(),c(t,16).gd(s3)},C(J0,"RoutingDirector/lambda$2$Type",1802),T(1805,1,{},AR),C(J0,"RoutingSlotAssigner",1805),T(1806,1,Jn,WNe),f.Mb=function(t){return C8t(this.a,c(t,108))},C(J0,"RoutingSlotAssigner/lambda$0$Type",1806),T(1807,1,Yn,KNe),f.Le=function(t,n){return GCt(this.a,c(t,108),c(n,108))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(J0,"RoutingSlotAssigner/lambda$1$Type",1807),T(1853,1850,{},h4),f.lg=function(t,n,i){var r,o,a,d;return r=ue(he(GH(t.b.g.b,(Ge(),m3)))),d=new LBe(W(V(Vr,1),Be,8,0,[(a=t.c.d,ki(new Cs(a.n),a.a))])),VUt(t,n,i,d,r),ei(d,(o=t.d.d,ki(new Cs(o.n),o.a))),vYe(new Cye(d))},C(J0,"SplineSelfLoopRouter",1853),T(516,1,Yn,Ome,Kqe),f.Le=function(t,n){return nL(this,c(t,9),c(n,9))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},f.a=!1,C(tG,"ModelOrderNodeComparator",516),T(1808,1,Jn,Hy),f.Mb=function(t){return c(t,12).e.c.length!=0},C(tG,"ModelOrderNodeComparator/lambda$0$Type",1808),T(579,1,Jn,d4),f.Mb=function(t){return c(t,12).e.c.length!=0},C(tG,"ModelOrderNodeComparator/lambda$1$Type",579),T(580,1,Jn,f2),f.Mb=function(t){return c(t,12).g.c.length!=0},C(tG,"ModelOrderNodeComparator/lambda$2$Type",580),T(663,1,Yn,rKe,Lbe),f.Le=function(t,n){return ZFe(this,t,n)},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},f.c=!1,C(tG,"ModelOrderPortComparator",663),T(1643,1,Di,Qy),f.If=function(t,n){rtn(c(t,37))},C("org.eclipse.elk.alg.layered.intermediate.unzipping","AlternatingLayerUnzipper",1643),T(809,1,{},Dp),f.mg=function(t,n){var i,r,o,a;for(o=eet(n),i=new Fe,a=n.f/o,r=1;r<o;++r)qe(i,Pe(Hn(Zo(p.Math.round(r*a)))));return i},f.ng=function(){return!1},C(gd,"ARDCutIndexHeuristic",809),T(1522,1,Di,h2),f.If=function(t,n){RVt(c(t,37),n)},C(gd,"BreakingPointInserter",1522),T(318,1,{318:1},ibe),f.Ib=function(){var t;return t=new b0,t.a+="BPInfo[",t.a+=`
	start=`,Sc(t,this.i),t.a+=`
	end=`,Sc(t,this.a),t.a+=`
	nodeStartEdge=`,Sc(t,this.e),t.a+=`
	startEndEdge=`,Sc(t,this.j),t.a+=`
	originalEdge=`,Sc(t,this.f),t.a+=`
	startInLayerDummy=`,Sc(t,this.k),t.a+=`
	startInLayerEdge=`,Sc(t,this.n),t.a+=`
	endInLayerDummy=`,Sc(t,this.b),t.a+=`
	endInLayerEdge=`,Sc(t,this.c),t.a},C(gd,"BreakingPointInserter/BPInfo",318),T(657,1,{657:1},c_e),f.a=!1,f.b=0,f.c=0,C(gd,"BreakingPointInserter/Cut",657),T(1523,1,Di,fm),f.If=function(t,n){eJt(c(t,37),n)},C(gd,"BreakingPointProcessor",1523),T(1524,1,Jn,oA),f.Mb=function(t){return GJe(c(t,9))},C(gd,"BreakingPointProcessor/0methodref$isEnd$Type",1524),T(1525,1,Jn,cA),f.Mb=function(t){return UJe(c(t,9))},C(gd,"BreakingPointProcessor/1methodref$isStart$Type",1525),T(1526,1,Di,lA),f.If=function(t,n){OJt(this,c(t,37),n)},C(gd,"BreakingPointRemover",1526),T(1527,1,ln,g4),f.Ad=function(t){c(t,134).k=!0},C(gd,"BreakingPointRemover/lambda$0$Type",1527),T(805,1,{},Tve),f.b=0,f.e=0,f.f=0,f.j=0,C(gd,"GraphStats",805),T(806,1,{},NO),f.Te=function(t,n){return p.Math.max(ue(he(t)),ue(he(n)))},C(gd,"GraphStats/0methodref$max$Type",806),T(807,1,{},d2),f.Te=function(t,n){return p.Math.max(ue(he(t)),ue(he(n)))},C(gd,"GraphStats/2methodref$max$Type",807),T(1709,1,{},Hf),f.Te=function(t,n){return hEt(he(t),he(n))},C(gd,"GraphStats/lambda$1$Type",1709),T(1710,1,{},YNe),f.Kb=function(t){return KKe(this.a,c(t,26))},C(gd,"GraphStats/lambda$2$Type",1710),T(1711,1,{},ZNe),f.Kb=function(t){return int(this.a,c(t,26))},C(gd,"GraphStats/lambda$6$Type",1711),T(808,1,{},_O),f.mg=function(t,n){var i;return i=c(R(t,(Ge(),GSe)),16),i||(Ct(),Ct(),Rs)},f.ng=function(){return!1},C(gd,"ICutIndexCalculator/ManualCutIndexCalculator",808),T(810,1,{},uA),f.mg=function(t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se;for(Se=(n.n==null&&SYe(n),n.n),v=(n.d==null&&SYe(n),n.d),de=ye(ns,no,30,Se.length,15,1),de[0]=Se[0],ie=Se[0],x=1;x<Se.length;x++)de[x]=de[x-1]+Se[x],ie+=Se[x];for(o=eet(n)-1,d=c(R(t,(Ge(),USe)),15).a,r=Qr,i=new Fe,L=p.Math.max(0,o-d);L<=p.Math.min(n.f-1,o+d);L++){if(H=ie/(L+1),X=0,S=1,a=new Fe,se=Qr,M=0,b=0,z=v[0],L==0)se=ie,b=(n.g==null&&(n.g=iVe(n,new d2)),ue(n.g));else{for(;S<n.f;)de[S-1]-X>=H&&(qe(a,Pe(S)),se=p.Math.max(se,de[S-1]-M),b+=z,X+=de[S-1]-X,M=de[S-1],z=v[S]),z=p.Math.max(z,v[S]),++S;b+=z}P=p.Math.min(1/se,1/n.b/b),P>r&&(r=P,i=a)}return i},f.ng=function(){return!1},C(gd,"MSDCutIndexHeuristic",810),T(1664,1,Di,CW),f.If=function(t,n){aKt(c(t,37),n)},C(gd,"SingleEdgeGraphWrapper",1664),T(233,23,{3:1,34:1,23:1,233:1},d7);var o3,M9,A9,Rv,RE,c3,N9=mn(Xo,"CenterEdgeLabelPlacementStrategy",233,On,TLt,MTt),bdt;T(427,23,{3:1,34:1,23:1,427:1},A1e);var BOe,xce,zOe=mn(Xo,"ConstraintCalculationStrategy",427,On,UAt,CTt),mdt;T(302,23,{3:1,34:1,23:1,302:1,173:1,177:1},Kz),f.bg=function(){return qtt(this)},f.og=function(){return qtt(this)};var WL,$E,FOe,qOe,HOe=mn(Xo,"CrossingMinimizationStrategy",302,On,nDt,_Tt),wdt;T(351,23,{3:1,34:1,23:1,351:1},xY);var QOe,kce,LU,GOe=mn(Xo,"CuttingStrategy",351,On,HNt,DTt),vdt;T(268,23,{3:1,34:1,23:1,268:1,173:1,177:1},ox),f.bg=function(){return Jnt(this)},f.og=function(){return Jnt(this)};var Oce,UOe,Sce,jce,Tce,Ece,Cce,Mce,KL,JOe=mn(Xo,"CycleBreakingStrategy",268,On,RPt,LTt),ydt;T(424,23,{3:1,34:1,23:1,424:1},N1e);var PU,XOe,VOe=mn(Xo,"DirectionCongruency",424,On,JAt,PTt),xdt;T(452,23,{3:1,34:1,23:1,452:1},kY);var _9,Ace,l3,kdt=mn(Xo,"EdgeConstraint",452,On,QNt,ITt),Odt;T(286,23,{3:1,34:1,23:1,286:1},g7);var Nce,_ce,Dce,Lce,IU,Pce,WOe=mn(Xo,"EdgeLabelSideSelection",286,On,OLt,RTt),Sdt;T(479,23,{3:1,34:1,23:1,479:1},_1e);var RU,KOe,YOe=mn(Xo,"EdgeStraighteningStrategy",479,On,XAt,$Tt),jdt;T(284,23,{3:1,34:1,23:1,284:1},p7);var Ice,ZOe,e6e,$U,t6e,n6e,i6e=mn(Xo,"FixedAlignment",284,On,SLt,BTt),Tdt;T(285,23,{3:1,34:1,23:1,285:1},b7);var r6e,s6e,o6e,c6e,BE,l6e,u6e=mn(Xo,"GraphCompactionStrategy",285,On,jLt,zTt),Edt;T(262,23,{3:1,34:1,23:1,262:1},_2);var D9,BU,L9,Ea,zE,zU,P9,u3,FU,FE,Rce=mn(Xo,"GraphProperties",262,On,rIt,FTt),Cdt;T(303,23,{3:1,34:1,23:1,303:1},OY);var YL,$ce,Bce,zce=mn(Xo,"GreedySwitchType",303,On,qNt,qTt),Mdt;T(330,23,{3:1,34:1,23:1,330:1},SY);var $v,a6e,ZL,Fce=mn(Xo,"GroupOrderStrategy",330,On,zNt,HTt),Adt;T(316,23,{3:1,34:1,23:1,316:1},jY);var bk,eP,a3,Ndt=mn(Xo,"InLayerConstraint",316,On,FNt,QTt),_dt;T(425,23,{3:1,34:1,23:1,425:1},D1e);var qce,f6e,h6e=mn(Xo,"InteractiveReferencePoint",425,On,HAt,GTt),Ddt,d6e,mk,Cw,tP,qU,g6e,p6e,HU,b6e,wk,QU,qE,vk,X1,Hce,GU,Ko,m6e,tp,Lc,Qce,Gce,nP,Nb,Mw,yk,w6e,Ldt,xk,iP,Bv,sh,Wa,Uce,f3,np,Pi,Oi,v6e,y6e,x6e,k6e,O6e,Jce,UU,Ul,Aw,Xce,kk,HE,Jg,h3,Nw,d3,g3,I9,_b,S6e,Vce,Wce,QE,Ok,JU,Sk,p3;T(166,23,{3:1,34:1,23:1,166:1},s_);var GE,V1,UE,Db,rP,j6e=mn(Xo,"LayerConstraint",166,On,KDt,UTt),Pdt;T(428,23,{3:1,34:1,23:1,428:1},L1e);var Kce,Yce,T6e=mn(Xo,"LayerUnzippingStrategy",428,On,QAt,JTt),Idt;T(851,1,jf,RB),f.tf=function(t){ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Dxe),""),"Direction Congruency"),"Specifies how drawings of the same graph with different layout directions compare to each other: either a natural reading direction is preserved or the drawings are rotated versions of each other."),B6e),(q0(),Ui)),VOe),gt((Th(),Nt))))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Lxe),""),"Feedback Edges"),"Whether feedback edges should be highlighted by routing around the nodes."),(Bt(),!1)),Pr),ir),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,nG),""),"Interactive Reference Point"),"Determines which point of a node is considered by interactive layout phases."),G6e),Ui),h6e),gt(Nt)))),Yi(t,nG,TL,z1t),Yi(t,nG,lE,B1t),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Pxe),""),"Merge Edges"),"Edges that have no ports are merged so they touch the connected nodes at the same points. When this option is disabled, one port is created for each edge directly connected to a node. When it is enabled, all such incoming edges share an input port, and all outgoing edges share an output port."),!1),Pr),ir),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Ixe),""),"Merge Hierarchy-Crossing Edges"),"If hierarchical layout is active, hierarchy-crossing edges use as few hierarchical ports as possible. They are broken by the algorithm, with hierarchical ports inserted as required. Usually, one such port is created for each edge at each hierarchy crossing point. With this option set to true, we try to create as few hierarchical ports as possible in the process. In particular, all edges that form a hyperedge can share a port."),!0),Pr),ir),gt(Nt)))),ft(t,new it(z9t(ut(lt(at(vt(rt(ct(st(ot(new tt,Rxe),""),"Allow Non-Flow Ports To Switch Sides"),"Specifies whether non-flow ports may switch sides if their node's port constraints are either FIXED_SIDE or FIXED_ORDER. A non-flow port is a port on a side that is not part of the currently configured layout flow. For instance, given a left-to-right layout direction, north and south ports would be considered non-flow ports. Further note that the underlying criterium whether to switch sides or not solely relies on the minimization of edge crossings. Hence, edge length and other aesthetics criteria are not addressed."),!1),Pr),ir),gt(Yg)),W(V(nt,1),Be,2,6,["org.eclipse.elk.layered.northOrSouthPort"])))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,$xe),""),"Port Sorting Strategy"),"Only relevant for nodes with FIXED_SIDE port constraints. Determines the way a node's ports are distributed on the sides of a node if their order is not prescribed. The option is set on parent nodes."),nSe),Ui),d9e),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Bxe),""),"Thoroughness"),"How much effort should be spent to produce a nice layout."),Pe(7)),js),Lr),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,zxe),""),"Add Unnecessary Bendpoints"),"Adds bend points even if an edge does not change direction. If true, each long edge dummy will contribute a bend point to its edges and hierarchy-crossing edges will always get a bend point where they cross hierarchy boundaries. By default, bend points are only added where an edge changes direction."),!1),Pr),ir),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Fxe),""),"Generate Position and Layer IDs"),"If enabled position id and layer id are generated, which are usually only used internally when setting the interactiveLayout option. This option should be specified on the root node."),!1),Pr),ir),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,TL),"cycleBreaking"),"Cycle Breaking Strategy"),"Strategy for cycle breaking. Cycle breaking looks for cycles in the graph and determines which edges to reverse to break the cycles. Reversed edges will end up pointing to the opposite direction of regular edges (that is, reversed edges will point left if edges usually point right)."),$6e),Ui),JOe),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,EL),lse),"Node Layering Strategy"),"Strategy for node layering."),X6e),Ui),t9e),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,qxe),lse),"Layer Constraint"),"Determines a constraint on the placement of the node regarding the layering."),U6e),Ui),j6e),gt(fr)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Hxe),lse),"Layer Choice Constraint"),"Allows to set a constraint regarding the layer placement of a node. Let i be the value of teh constraint. Assumed the drawing has n layers and i < n. If set to i, it expresses that the node should be placed in i-th layer. Should i>=n be true then the node is placed in the last layer of the drawing. Note that this option is not part of any of ELK Layered's default configurations but is only evaluated as part of the `InteractiveLayeredGraphVisitor`, which must be applied manually or used via the `DiagramLayoutEngine."),null),js),Lr),gt(fr)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Qxe),lse),"Layer ID"),"Layer identifier that was calculated by ELK Layered for a node. This is only generated if interactiveLayot or generatePositionAndLayerIds is set."),Pe(-1)),js),Lr),gt(fr)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Are),oct),"Upper Bound On Width [MinWidth Layerer]"),"Defines a loose upper bound on the width of the MinWidth layerer. If set to '-1' multiple values are tested and the best result is selected."),Pe(4)),js),Lr),gt(Nt)))),Yi(t,Are,EL,J1t),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Nre),oct),"Upper Layer Estimation Scaling Factor [MinWidth Layerer]"),"Multiplied with Upper Bound On Width for defining an upper bound on the width of layers which haven't been determined yet, but whose maximum width had been (roughly) estimated by the MinWidth algorithm. Compensates for too high estimations. If set to '-1' multiple values are tested and the best result is selected."),Pe(2)),js),Lr),gt(Nt)))),Yi(t,Nre,EL,V1t),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,_re),cct),"Node Promotion Strategy"),"Reduces number of dummy nodes after layering phase (if possible)."),J6e),Ui),a9e),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Dre),cct),"Max Node Promotion Iterations"),"Limits the number of iterations for node promotion."),Pe(0)),js),Lr),gt(Nt)))),Yi(t,Dre,_re,null),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Lre),"layering.coffmanGraham"),"Layer Bound"),"The maximum number of nodes allowed per layer."),Pe(di)),js),Lr),gt(Nt)))),Yi(t,Lre,EL,q1t),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,lE),o9),"Crossing Minimization Strategy"),"Strategy for crossing minimization."),R6e),Ui),HOe),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Gxe),o9),"Force Node Model Order"),"The node order given by the model does not change to produce a better layout. E.g. if node A is before node B in the model this is not changed during crossing minimization. This assumes that the node model order is already respected before crossing minimization. This can be achieved by setting considerModelOrder.strategy to NODES_AND_EDGES."),!1),Pr),ir),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Pre),o9),"Hierarchical Sweepiness"),"How likely it is to use cross-hierarchy (1) vs bottom-up (-1)."),.1),us),kr),gt(Nt)))),Yi(t,Pre,pG,h1t),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Ire),o9),"Semi-Interactive Crossing Minimization"),"Preserves the order of nodes within a layer but still minimizes crossings between edges connecting long edge dummies. Derives the desired order from positions specified by the 'org.eclipse.elk.position' layout option. Requires a crossing minimization strategy that is able to process 'in-layer' constraints."),!1),Pr),ir),gt(Nt)))),Yi(t,Ire,lE,w1t),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Uxe),o9),"In Layer Predecessor of"),"Allows to set a constraint which specifies of which node the current node is the predecessor. If set to 's' then the node is the predecessor of 's' and is in the same layer"),null),Nk),nt),gt(fr)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Jxe),o9),"In Layer Successor of"),"Allows to set a constraint which specifies of which node the current node is the successor. If set to 's' then the node is the successor of 's' and is in the same layer"),null),Nk),nt),gt(fr)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Xxe),o9),"Position Choice Constraint"),"Allows to set a constraint regarding the position placement of a node in a layer. Assumed the layer in which the node placed includes n other nodes and i < n. If set to i, it expresses that the node should be placed at the i-th position. Should i>=n be true then the node is placed at the last position in the layer. Note that this option is not part of any of ELK Layered's default configurations but is only evaluated as part of the `InteractiveLayeredGraphVisitor`, which must be applied manually or used via the `DiagramLayoutEngine."),null),js),Lr),gt(fr)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Vxe),o9),"Position ID"),"Position within a layer that was determined by ELK Layered for a node. This is only generated if interactiveLayot or generatePositionAndLayerIds is set."),Pe(-1)),js),Lr),gt(fr)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Wxe),lct),"Greedy Switch Activation Threshold"),"By default it is decided automatically if the greedy switch is activated or not. The decision is based on whether the size of the input graph (without dummy nodes) is smaller than the value of this option. A '0' enforces the activation."),Pe(40)),js),Lr),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Rre),lct),"Greedy Switch Crossing Minimization"),"Greedy Switch strategy for crossing minimization. The greedy switch heuristic is executed after the regular crossing minimization as a post-processor. Note that if 'hierarchyHandling' is set to 'INCLUDE_CHILDREN', the 'greedySwitchHierarchical.type' option must be used."),I6e),Ui),zce),gt(Nt)))),Yi(t,Rre,lE,a1t),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,iG),"crossingMinimization.greedySwitchHierarchical"),"Greedy Switch Crossing Minimization (hierarchical)"),"Activates the greedy switch heuristic in case hierarchical layout is used. The differences to the non-hierarchical case (see 'greedySwitch.type') are: 1) greedy switch is inactive by default, 3) only the option value set on the node at which hierarchical layout starts is relevant, and 2) if it's activated by the user, it properly addresses hierarchy-crossing edges."),P6e),Ui),zce),gt(Nt)))),Yi(t,iG,lE,c1t),Yi(t,iG,pG,l1t),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Xx),uct),"Node Placement Strategy"),"Strategy for node placement."),tSe),Ui),s9e),gt(Nt)))),ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,rG),uct),"Favor Straight Edges Over Balancing"),"Favor straight edges over a balanced node placement. The default behavior is determined automatically based on the used 'edgeRouting'. For an orthogonal style it is set to true, for all other styles to false."),Pr),ir),gt(Nt)))),Yi(t,rG,Xx,hgt),Yi(t,rG,Xx,dgt),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,$re),act),"BK Edge Straightening"),"Specifies whether the Brandes Koepf node placer tries to increase the number of straight edges at the expense of diagram size. There is a subtle difference to the 'favorStraightEdges' option, which decides whether a balanced placement of the nodes is desired, or not. In bk terms this means combining the four alignments into a single balanced one, or not. This option on the other hand tries to straighten additional edges during the creation of each of the four alignments."),Y6e),Ui),YOe),gt(Nt)))),Yi(t,$re,Xx,lgt),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Bre),act),"BK Fixed Alignment"),"Tells the BK node placer to use a certain alignment (out of its four) instead of the one producing the smallest height, or the combination of all four."),Z6e),Ui),i6e),gt(Nt)))),Yi(t,Bre,Xx,agt),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,zre),"nodePlacement.linearSegments"),"Linear Segments Deflection Dampening"),"Dampens the movement of nodes to keep the diagram from getting too large."),.3),us),kr),gt(Nt)))),Yi(t,zre,Xx,pgt),ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,Fre),"nodePlacement.networkSimplex"),"Node Flexibility"),"Aims at shorter and straighter edges. Two configurations are possible: (a) allow ports to move freely on the side they are assigned to (the order is always defined beforehand), (b) additionally allow to enlarge a node wherever it helps. If this option is not configured for a node, the 'nodeFlexibility.default' value is used, which is specified for the node's parent."),Ui),jle),gt(fr)))),Yi(t,Fre,Xx,vgt),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,qre),"nodePlacement.networkSimplex.nodeFlexibility"),"Node Flexibility Default"),"Default value of the 'nodeFlexibility' option for the children of a hierarchical node."),eSe),Ui),jle),gt(Nt)))),Yi(t,qre,Xx,wgt),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Kxe),fct),"Self-Loop Distribution"),"Alter the distribution of the loops around the node. It only takes effect for PortConstraints.FREE."),q6e),Ui),b9e),gt(fr)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Yxe),fct),"Self-Loop Ordering"),"Alter the ordering of the loops they can either be stacked or sequenced. It only takes effect for PortConstraints.FREE."),H6e),Ui),m9e),gt(fr)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,sG),"edgeRouting.splines"),"Spline Routing Mode"),"Specifies the way control points are assembled for each individual edge. CONSERVATIVE ensures that edges are properly routed around the nodes but feels rather orthogonal at times. SLOPPY uses fewer control points to obtain curvier edge routes but may result in edges overlapping nodes."),Q6e),Ui),v9e),gt(Nt)))),Yi(t,sG,ML,M1t),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,oG),"edgeRouting.splines.sloppy"),"Sloppy Spline Layer Spacing Factor"),"Spacing factor for routing area between layers when using sloppy spline routing."),.2),us),kr),gt(Nt)))),Yi(t,oG,ML,N1t),Yi(t,oG,sG,_1t),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Hre),"edgeRouting.polyline"),"Sloped Edge Zone Width"),"Width of the strip to the left and to the right of each layer where the polyline edge router is allowed to refrain from ensuring that edges are routed horizontally. This prevents awkward bend points for nodes that extent almost to the edge of their layer."),2),us),kr),gt(Nt)))),Yi(t,Hre,ML,j1t),ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,Zxe),Lh),"Spacing Base Value"),"An optional base value for all other layout options of the 'spacing' group. It can be used to conveniently alter the overall 'spaciousness' of the drawing. Whenever an explicit value is set for the other layout options, this base value will have no effect. The base value is not inherited, i.e. it must be set for each hierarchical node."),us),kr),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,e3e),Lh),"Edge Node Between Layers Spacing"),"The spacing to be preserved between nodes and edges that are routed next to the node's layer. For the spacing between nodes and edges that cross the node's layer 'spacing.edgeNode' is used."),10),us),kr),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,t3e),Lh),"Edge Edge Between Layer Spacing"),"Spacing to be preserved between pairs of edges that are routed between the same pair of layers. Note that 'spacing.edgeEdge' is used for the spacing between pairs of edges crossing the same layer."),10),us),kr),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,n3e),Lh),"Node Node Between Layers Spacing"),"The spacing to be preserved between any pair of nodes of two adjacent layers. Note that 'spacing.nodeNode' is used for the spacing between nodes within the layer itself."),20),us),kr),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,i3e),p3e),"Direction Priority"),"Defines how important it is to have a certain edge point into the direction of the overall layout. This option is evaluated during the cycle breaking phase."),Pe(0)),js),Lr),gt(ch)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,r3e),p3e),"Shortness Priority"),"Defines how important it is to keep an edge as short as possible. This option is evaluated during the layering phase."),Pe(0)),js),Lr),gt(ch)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,s3e),p3e),"Straightness Priority"),"Defines how important it is to keep an edge straight, i.e. aligned with one of the two axes. This option is evaluated during node placement."),Pe(0)),js),Lr),gt(ch)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Qre),b3e),"Connected Components Compaction"),"Tries to further compact components (disconnected sub-graphs)."),!1),Pr),ir),gt(Nt)))),Yi(t,Qre,rE,!0),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,o3e),hct),"Post Compaction Strategy"),dct),C6e),Ui),u6e),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,c3e),hct),"Post Compaction Constraint Calculation"),dct),E6e),Ui),zOe),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,cG),m3e),"High Degree Node Treatment"),"Makes room around high degree nodes to place leafs and trees."),!1),Pr),ir),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Gre),m3e),"High Degree Node Threshold"),"Whether a node is considered to have a high degree."),Pe(16)),js),Lr),gt(Nt)))),Yi(t,Gre,cG,!0),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Ure),m3e),"High Degree Node Maximum Tree Height"),"Maximum height of a subtree connected to a high degree node to be moved to separate layers."),Pe(5)),js),Lr),gt(Nt)))),Yi(t,Ure,cG,!0),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,G1),w3e),"Graph Wrapping Strategy"),"For certain graphs and certain prescribed drawing areas it may be desirable to split the laid out graph into chunks that are placed side by side. The edges that connect different chunks are 'wrapped' around from the end of one chunk to the start of the other chunk. The points between the chunks are referred to as 'cuts'."),sSe),Ui),O9e),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,lG),w3e),"Additional Wrapped Edges Spacing"),"To visually separate edges that are wrapped from regularly routed edges an additional spacing value can be specified in form of this layout option. The spacing is added to the regular edgeNode spacing."),10),us),kr),gt(Nt)))),Yi(t,lG,G1,_gt),Yi(t,lG,G1,Dgt),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,uG),w3e),"Correction Factor for Wrapping"),"At times and for certain types of graphs the executed wrapping may produce results that are consistently biased in the same fashion: either wrapping to often or to rarely. This factor can be used to correct the bias. Internally, it is simply multiplied with the 'aspect ratio' layout option."),1),us),kr),gt(Nt)))),Yi(t,uG,G1,Pgt),Yi(t,uG,G1,Igt),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,uE),gct),"Cutting Strategy"),"The strategy by which the layer indexes are determined at which the layering crumbles into chunks."),rSe),Ui),GOe),gt(Nt)))),Yi(t,uE,G1,qgt),Yi(t,uE,G1,Hgt),ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,Jre),gct),"Manually Specified Cuts"),"Allows the user to specify her own cuts for a certain graph."),Bh),Ju),gt(Nt)))),Yi(t,Jre,uE,$gt),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Xre),"wrapping.cutting.msd"),"MSD Freedom"),"The MSD cutting strategy starts with an initial guess on the number of chunks the graph should be split into. The freedom specifies how much the strategy may deviate from this guess. E.g. if an initial number of 3 is computed, a freedom of 1 allows 2, 3, and 4 cuts."),iSe),js),Lr),gt(Nt)))),Yi(t,Xre,uE,zgt),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,aG),pct),"Validification Strategy"),"When wrapping graphs, one can specify indices that are not allowed as split points. The validification strategy makes sure every computed split point is allowed."),oSe),Ui),k9e),gt(Nt)))),Yi(t,aG,G1,t0t),Yi(t,aG,G1,n0t),ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,fG),pct),"Valid Indices for Wrapping"),null),Bh),Ju),gt(Nt)))),Yi(t,fG,G1,Ygt),Yi(t,fG,G1,Zgt),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,hG),v3e),"Improve Cuts"),"For general graphs it is important that not too many edges wrap backwards. Thus a compromise between evenly-distributed cuts and the total number of cut edges is sought."),!0),Pr),ir),gt(Nt)))),Yi(t,hG,G1,Jgt),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,dG),v3e),"Distance Penalty When Improving Cuts"),null),2),us),kr),gt(Nt)))),Yi(t,dG,G1,Ggt),Yi(t,dG,hG,!0),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Vre),v3e),"Improve Wrapped Edges"),"The initial wrapping is performed in a very simple way. As a consequence, edges that wrap from one chunk to another may be unnecessarily long. Activating this option tries to shorten such edges."),!0),Pr),ir),gt(Nt)))),Yi(t,Vre,G1,Vgt),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Wre),use),"Layer Unzipping Strategy"),"The strategy to use for unzipping a layer into multiple sublayers while maintaining the existing ordering of nodes and edges after crossing minimization. The default value is 'NONE'."),K6e),Ui),T6e),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Kre),use),"Minimize Edge Length Heuristic"),"Use a heuristic to decide whether or not to actually perform the layer split with the goal of minimizing the total edge length. This option only works when layerSplit is set to 2. The property can be set to the nodes in a layer, which then applies the property for the layer. If any node sets the value to true, then the value is set to true for the entire layer."),!1),Pr),ir),gt(fr)))),Yi(t,Kre,Yre,tgt),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Yre),use),"Unzipping Layer Split"),"Defines the number of sublayers to split a layer into. The property can be set to the nodes in a layer, which then applies the property for the layer. If multiple nodes set the value to different values, then the lowest value is chosen."),V6e),js),Lr),gt(fr)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Zre),use),"Reset Alternation on Long Edges"),"If set to true, nodes will always be placed in the first sublayer after a long edge when using the ALTERNATING strategy. Otherwise long edge dummies are treated the same as regular nodes. The default value is true. The property can be set to the nodes in a layer, which then applies the property for the layer. If any node sets the value to false, then the value is set to false for the entire layer."),W6e),Pr),ir),gt(fr)))),Yi(t,Zre,Wre,igt),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,l3e),ase),"Edge Label Side Selection"),"Method to decide on edge label sides."),F6e),Ui),WOe),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,u3e),ase),"Edge Center Label Placement Strategy"),"Determines in which layer center labels of long edges should be placed."),z6e),Ui),N9),_i(Nt,W(V($h,1),_e,161,0,[K1]))))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,gG),aE),"Consider Model Order"),"Preserves the order of nodes and edges in the model file if this does not lead to additional edge crossings. Depending on the strategy this is not always possible since the node and edge order might be conflicting."),L6e),Ui),h9e),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,a3e),aE),"Consider Port Order"),"If disabled the port order of output ports is derived from the edge order and input ports are ordered by their incoming connections. If enabled all ports are ordered by the port model order."),!1),Pr),ir),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,CL),aE),"No Model Order"),"Set on a node to not set a model order for this node even though it is a real node."),!1),Pr),ir),gt(fr)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,ese),aE),"Consider Model Order for Components"),"If set to NONE the usual ordering strategy (by cumulative node priority and size of nodes) is used. INSIDE_PORT_SIDES orders the components with external ports only inside the groups with the same port side. FORCE_MODEL_ORDER enforces the mode order on components. This option might produce bad alignments and sub optimal drawings in terms of used area since the ordering should be respected."),M6e),Ui),Gke),gt(Nt)))),Yi(t,ese,rE,null),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,f3e),aE),"Long Edge Ordering Strategy"),"Indicates whether long edges are sorted under, over, or equal to nodes that have no connection to a previous layer in a left-to-right or right-to-left layout. Under and over changes to right and left in a vertical layout."),D6e),Ui),i9e),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,tse),aE),"Crossing Counter Node Order Influence"),"Indicates with what percentage (1 for 100%) violations of the node model order are weighted against the crossings e.g. a value of 0.5 means two model order violations are as important as on edge crossing. This allows some edge crossings in favor of preserving the model order. It is advised to set this value to a very small positive value (e.g. 0.001) to have minimal crossing and a optimal node order. Defaults to no influence (0)."),0),us),kr),gt(Nt)))),Yi(t,tse,gG,null),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,nse),aE),"Crossing Counter Port Order Influence"),"Indicates with what percentage (1 for 100%) violations of the port model order are weighted against the crossings e.g. a value of 0.5 means two model order violations are as important as on edge crossing. This allows some edge crossings in favor of preserving the model order. It is advised to set this value to a very small positive value (e.g. 0.001) to have minimal crossing and a optimal port order. Defaults to no influence (0)."),0),us),kr),gt(Nt)))),Yi(t,nse,gG,null),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,ise),c9),y3e),"Used to define partial ordering groups during cycle breaking. A lower group id means that the group is sorted before other groups. A group model order of 0 is the default group."),Pe(0)),js),Lr),gt(fr)))),Yi(t,ise,CL,!1),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,rse),c9),y3e),"Used to define partial ordering groups during crossing minimization. A lower group id means that the group is sorted before other groups. A group model order of 0 is the default group."),Pe(0)),js),Lr),_i(fr,W(V($h,1),_e,161,0,[ch,Yg]))))),Yi(t,rse,CL,!1),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,sse),c9),y3e),"Used to define partial ordering groups during component packing. A lower group id means that the group is sorted before other groups. A group model order of 0 is the default group."),Pe(0)),js),Lr),_i(fr,W(V($h,1),_e,161,0,[ch,Yg]))))),Yi(t,sse,CL,!1),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,h3e),c9),"Cycle Breaking Group Ordering Strategy"),"Determines how to count ordering violations during cycle breaking. NONE: They do not count. ENFORCED: A group with a higher model order is before a node with a smaller. MODEL_ORDER: The model order counts instead of the model order group id ordering."),A6e),Ui),Fce),gt(Nt)))),ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,ose),c9),"Cycle Breaking Preferred Source Id"),"The model order group id for which should be preferred as a source if possible."),js),Lr),gt(Nt)))),Yi(t,ose,TL,Udt),ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,cse),c9),"Cycle Breaking Preferred Target Id"),"The model order group id for which should be preferred as a target if possible."),js),Lr),gt(Nt)))),Yi(t,cse,TL,Xdt),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,d3e),c9),"Crossing Minimization Group Ordering Strategy"),"Determines how to count ordering violations during crossing minimization. NONE: They do not count. ENFORCED: A group with a lower id is before a group with a higher id. MODEL_ORDER: The model order counts instead of the model order group id ordering."),_6e),Ui),Fce),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,g3e),c9),"Crossing Minimization Enforced Group Orders"),"Holds all group ids which are enforcing their order during crossing minimization strategies. E.g. if only groups 2 and -1 (default) enforce their ordering. Other groups e.g. the group of timer nodes can be ordered arbitrarily if it helps and the mentioned groups may not change their order."),N6e),Bh),Ju),gt(Nt)))),Pst((new ON,t))};var Rdt,$dt,Bdt,E6e,zdt,C6e,Fdt,M6e,qdt,Hdt,Qdt,A6e,Gdt,Udt,Jdt,Xdt,Vdt,N6e,Wdt,_6e,Kdt,Ydt,Zdt,e1t,D6e,t1t,n1t,i1t,L6e,r1t,s1t,o1t,P6e,c1t,l1t,u1t,I6e,a1t,f1t,h1t,d1t,g1t,p1t,b1t,m1t,w1t,v1t,R6e,y1t,$6e,x1t,B6e,k1t,z6e,O1t,F6e,S1t,j1t,T1t,q6e,E1t,H6e,C1t,Q6e,M1t,A1t,N1t,_1t,D1t,L1t,P1t,I1t,R1t,$1t,G6e,B1t,z1t,F1t,q1t,H1t,Q1t,U6e,G1t,U1t,J1t,X1t,V1t,W1t,K1t,J6e,Y1t,X6e,Z1t,V6e,egt,tgt,ngt,W6e,igt,rgt,K6e,sgt,ogt,cgt,Y6e,lgt,ugt,Z6e,agt,fgt,hgt,dgt,ggt,pgt,bgt,mgt,eSe,wgt,vgt,ygt,tSe,xgt,nSe,kgt,Ogt,Sgt,jgt,Tgt,Egt,Cgt,Mgt,Agt,Ngt,_gt,Dgt,Lgt,Pgt,Igt,Rgt,$gt,Bgt,iSe,zgt,Fgt,rSe,qgt,Hgt,Qgt,Ggt,Ugt,Jgt,Xgt,Vgt,Wgt,sSe,Kgt,Ygt,Zgt,e0t,oSe,t0t,n0t;C(Xo,"LayeredMetaDataProvider",851),T(991,1,jf,ON),f.tf=function(t){Pst(t)};var vd,Zce,XU,JE,VU,cSe,WU,XE,sP,ele,jk,lSe,uSe,aSe,VE,i0t,WE,zv,tle,KU,nle,t1,ile,R9,fSe,oP,rle,hSe,r0t,s0t,o0t,YU,sle,KE,Tk,c0t,Xu,dSe,gSe,ZU,b3,yd,eJ,W1,pSe,bSe,mSe,ole,cle,wSe,Xg,lle,vSe,Fv,ySe,xSe,kSe,tJ,qv,Lb,OSe,SSe,ho,jSe,l0t,Ro,YE,TSe,ESe,CSe,cP,nJ,iJ,ule,ale,MSe,rJ,ASe,NSe,sJ,_w,_Se,fle,ZE,DSe,Dw,eC,oJ,Pb,hle,$9,cJ,Ib,LSe,PSe,ISe,Hv,RSe,u0t,a0t,f0t,h0t,Lw,Qv,cr,Vg,d0t,Gv,$Se,B9,BSe,Uv,g0t,z9,zSe,Ek,p0t,b0t,lP,dle,FSe,uP,Mf,Jv,m3,Rb,ip,lJ,Xv,gle,F9,q9,$b,Vv,ple,aP,tC,nC,m0t,w0t,v0t,qSe,y0t,ble,HSe,QSe,GSe,USe,mle,JSe,XSe,VSe,WSe,wle,uJ;C(Xo,"LayeredOptions",991),T(992,1,{},MW),f.uf=function(){var t;return t=new cLe,t},f.vf=function(t){},C(Xo,"LayeredOptions/LayeredFactory",992),T(1357,1,{}),f.a=0;var x0t;C(tc,"ElkSpacings/AbstractSpacingsBuilder",1357),T(785,1357,{},ywe);var aJ,k0t;C(Xo,"LayeredSpacings/LayeredSpacingsBuilder",785),T(269,23,{3:1,34:1,23:1,269:1,173:1,177:1},cx),f.bg=function(){return Hnt(this)},f.og=function(){return Hnt(this)};var vle,yle,xle,KSe,YSe,ZSe,fJ,kle,e9e,t9e=mn(Xo,"LayeringStrategy",269,On,$Pt,YTt),O0t;T(353,23,{3:1,34:1,23:1,353:1},TY);var Ole,n9e,hJ,i9e=mn(Xo,"LongEdgeOrderingStrategy",353,On,VNt,VTt),S0t;T(205,23,{3:1,34:1,23:1,205:1},Yz);var w3,v3,dJ,Sle,jle=mn(Xo,"NodeFlexibility",205,On,eDt,XTt),j0t;T(329,23,{3:1,34:1,23:1,329:1,173:1,177:1},o_),f.bg=function(){return ZZe(this)},f.og=function(){return ZZe(this)};var iC,Tle,Ele,rC,r9e,s9e=mn(Xo,"NodePlacementStrategy",329,On,WDt,WTt),T0t;T(246,23,{3:1,34:1,23:1,246:1},D2);var o9e,H9,sC,fP,c9e,l9e,hP,u9e,gJ,pJ,a9e=mn(Xo,"NodePromotionStrategy",246,On,iIt,KTt),E0t;T(270,23,{3:1,34:1,23:1,270:1},Zz);var f9e,rp,Cle,Mle,h9e=mn(Xo,"OrderingStrategy",270,On,tDt,ZTt),C0t;T(426,23,{3:1,34:1,23:1,426:1},P1e);var Ale,Nle,d9e=mn(Xo,"PortSortingStrategy",426,On,GAt,eEt),M0t;T(455,23,{3:1,34:1,23:1,455:1},EY);var Jl,Wc,oC,A0t=mn(Xo,"PortType",455,On,GNt,tEt),N0t;T(382,23,{3:1,34:1,23:1,382:1},CY);var g9e,_le,p9e,b9e=mn(Xo,"SelfLoopDistributionStrategy",382,On,UNt,nEt),_0t;T(349,23,{3:1,34:1,23:1,349:1},MY);var Dle,dP,Lle,m9e=mn(Xo,"SelfLoopOrderingStrategy",349,On,JNt,iEt),D0t;T(317,1,{317:1},Art),C(Xo,"Spacings",317),T(350,23,{3:1,34:1,23:1,350:1},AY);var Ple,w9e,cC,v9e=mn(Xo,"SplineRoutingMode",350,On,XNt,rEt),L0t;T(352,23,{3:1,34:1,23:1,352:1},NY);var Ile,y9e,x9e,k9e=mn(Xo,"ValidifyStrategy",352,On,WNt,sEt),P0t;T(383,23,{3:1,34:1,23:1,383:1},_Y);var Wv,Rle,Q9,O9e=mn(Xo,"WrappingStrategy",383,On,KNt,oEt),I0t;T(1373,1,Xr,lK),f.pg=function(t){return c(t,37),R0t},f.If=function(t,n){XYt(this,c(t,37),n)};var R0t;C(bw,"BFSNodeOrderCycleBreaker",1373),T(1371,1,Xr,Uf),f.pg=function(t){return c(t,37),$0t},f.If=function(t,n){HKt(this,c(t,37),n)};var $0t;C(bw,"DFSNodeOrderCycleBreaker",1371),T(1372,1,ln,zze),f.Ad=function(t){HVt(this.a,this.c,this.b,c(t,17))},f.b=!1,C(bw,"DFSNodeOrderCycleBreaker/lambda$0$Type",1372),T(1365,1,Xr,BB),f.pg=function(t){return c(t,37),B0t},f.If=function(t,n){qKt(this,c(t,37),n)};var B0t;C(bw,"DepthFirstCycleBreaker",1365),T(786,1,Xr,Q0e),f.pg=function(t){return c(t,37),z0t},f.If=function(t,n){atn(this,c(t,37),n)},f.qg=function(t){return c(Xe(t,VH(this.e,t.c.length)),9)};var z0t;C(bw,"GreedyCycleBreaker",786),T(1368,786,Xr,LRe),f.qg=function(t){var n,i,r,o,a,d,b,v,x;for(x=null,r=di,v=p.Math.max(this.b.a.c.length,c(R(this.b,(De(),np)),15).a),n=v*c(R(this.b,tP),15).a,o=new DO,i=ve(R(this.b,(Ge(),jk)))===ve((D0(),$v)),b=new G(t);b.a<b.c.c.length;)d=c(Q(b),9),xi(d,Pi)&&(a=i?J5(o,d,n,v):Q5(o,d,v),r>a&&(r=a,x=d));return x||c(Xe(t,VH(this.e,t.c.length)),9)},C(bw,"GreedyModelOrderCycleBreaker",1368),T(509,1,{},DO),f.a=0,f.b=0,C(bw,"GroupModelOrderCalculator",509),T(1366,1,Xr,Bc),f.pg=function(t){return c(t,37),F0t},f.If=function(t,n){pYt(this,c(t,37),n)};var F0t;C(bw,"InteractiveCycleBreaker",1366),T(1367,1,Xr,$B),f.pg=function(t){return c(t,37),q0t},f.If=function(t,n){mYt(c(t,37),n)};var q0t;C(bw,"ModelOrderCycleBreaker",1367),T(787,1,Xr),f.pg=function(t){return c(t,37),H0t},f.If=function(t,n){iKt(this,c(t,37),n)},f.rg=function(t,n){var i,r,o,a,d,b,v,x,S,M;for(d=0;d<this.d.b;d++){for(b=null,i=new DO,v=ls,M=c(pc(this.d,d),24).Jc();M.Ob();)S=c(M.Pb(),9),a=ve(R(this.a,(Ge(),jk)))===ve((D0(),$v)),b?(x=a?J5(i,S,n,t):Q5(i,S,t),v<x&&(b=S,v=x)):(b=S,v=a?J5(i,S,n,t):Q5(i,S,t));for(o=new Ht(Vt($i(b).a.Jc(),new U));hn(o);)r=c(sn(o),17),c(pc(this.d,d),24).Gc(r.d.i)&&qe(this.c,r)}};var H0t;C(bw,"SCCModelOrderCycleBreaker",787),T(1370,787,Xr,PRe),f.rg=function(t,n){var i,r,o,a,d,b,v,x,S,M,L,P;for(d=0;d<this.d.b;d++)if(!(c(pc(this.d,d),24).gc()<=1)){for(v=null,b=null,M=di,S=ls,a=ve(R(this.a,(Ge(),jk)))===ve((D0(),$v)),i=new DO,P=c(pc(this.d,d),24).Jc();P.Ob();)L=c(P.Pb(),9),!v||!b?(v=L,M=a?J5(i,L,n,t):Q5(i,L,t),b=L,S=M):(x=a?J5(i,L,n,t):Q5(i,L,t),M>x&&(v=L,M=x),S<x&&(b=L,S=x));if(ve(R(v,zv))===ve(R(this.a,lSe)))for(o=new Ht(Vt(pr(v).a.Jc(),new U));hn(o);)r=c(sn(o),17),c(pc(this.d,d),24).Gc(r.c.i)&&qe(this.c,r);else if(ve(R(b,zv))===ve(R(this.a,uSe)))for(o=new Ht(Vt($i(b).a.Jc(),new U));hn(o);)r=c(sn(o),17),c(pc(this.d,d),24).Gc(r.c.i)&&qe(this.c,r);else if(Vf(new Ht(Vt(pr(v).a.Jc(),new U)))>Vf(new Ht(Vt($i(b).a.Jc(),new U))))for(o=new Ht(Vt(pr(v).a.Jc(),new U));hn(o);)r=c(sn(o),17),c(pc(this.d,d),24).Gc(r.c.i)&&qe(this.c,r);else for(o=new Ht(Vt($i(b).a.Jc(),new U));hn(o);)r=c(sn(o),17),c(pc(this.d,d),24).Gc(r.d.i)&&qe(this.c,r)}},C(bw,"SCCNodeTypeCycleBreaker",1370),T(1369,787,Xr,IRe),f.rg=function(t,n){var i,r,o,a,d,b,v,x,S,M,L,P;for(d=0;d<this.d.b;d++)if(!(c(pc(this.d,d),24).gc()<=1)){for(v=null,b=null,M=di,S=ls,a=ve(R(this.a,(Ge(),jk)))===ve((D0(),$v)),i=new DO,P=c(pc(this.d,d),24).Jc();P.Ob();)L=c(P.Pb(),9),!v||!b?(v=L,M=a?J5(i,L,n,t):Q5(i,L,t),b=L,S=M):(x=a?J5(i,L,n,t):Q5(i,L,t),M>x&&(v=L,M=x),S<x&&(b=L,S=x));if(Vf(new Ht(Vt(pr(v).a.Jc(),new U)))>Vf(new Ht(Vt($i(b).a.Jc(),new U))))for(o=new Ht(Vt(pr(v).a.Jc(),new U));hn(o);)r=c(sn(o),17),c(pc(this.d,d),24).Gc(r.c.i)&&qe(this.c,r);else for(o=new Ht(Vt($i(b).a.Jc(),new U));hn(o);)r=c(sn(o),17),c(pc(this.d,d),24).Gc(r.d.i)&&qe(this.c,r)}},C(bw,"SCConnectivity",1369),T(1385,1,Xr,kN),f.pg=function(t){return c(t,37),Q0t},f.If=function(t,n){gen(this,c(t,37),n)};var Q0t;C(U1,"BreadthFirstModelOrderLayerer",1385),T(1386,1,Yn,sa),f.Le=function(t,n){return JQt(c(t,9),c(n,9))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(U1,"BreadthFirstModelOrderLayerer/lambda$0$Type",1386),T(1376,1,Xr,DIe),f.pg=function(t){return c(t,37),G0t},f.If=function(t,n){ptn(this,c(t,37),n)};var G0t;C(U1,"CoffmanGrahamLayerer",1376),T(1377,1,Yn,e_e),f.Le=function(t,n){return iXt(this.a,c(t,9),c(n,9))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(U1,"CoffmanGrahamLayerer/0methodref$compareNodesInTopo$Type",1377),T(1378,1,Yn,t_e),f.Le=function(t,n){return rMt(this.a,c(t,9),c(n,9))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(U1,"CoffmanGrahamLayerer/lambda$1$Type",1378),T(1387,1,Xr,sK),f.pg=function(t){return c(t,37),U0t},f.If=function(t,n){ttn(this,c(t,37),n)},f.c=0,f.e=0;var U0t;C(U1,"DepthFirstModelOrderLayerer",1387),T(1388,1,Yn,aA),f.Le=function(t,n){return XQt(c(t,9),c(n,9))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(U1,"DepthFirstModelOrderLayerer/lambda$0$Type",1388),T(1379,1,Xr,LO),f.pg=function(t){return c(t,37),Wn(Wn(Wn(new wr,(es(),Cf),(cs(),cce)),Zd,Pv),vc,Lv)},f.If=function(t,n){jen(c(t,37),n)},C(U1,"InteractiveLayerer",1379),T(571,1,{571:1},pLe),f.a=0,f.c=0,C(U1,"InteractiveLayerer/LayerSpan",571),T(1375,1,Xr,IB),f.pg=function(t){return c(t,37),J0t},f.If=function(t,n){KJt(this,c(t,37),n)};var J0t;C(U1,"LongestPathLayerer",1375),T(1384,1,Xr,oK),f.pg=function(t){return c(t,37),X0t},f.If=function(t,n){wXt(this,c(t,37),n)};var X0t;C(U1,"LongestPathSourceLayerer",1384),T(1382,1,Xr,Pj),f.pg=function(t){return c(t,37),Wn(Wn(Wn(new wr,(es(),Cf),(cs(),r3)),Zd,Pv),vc,Lv)},f.If=function(t,n){Pen(this,c(t,37),n)},f.a=0,f.b=0,f.d=0;var S9e,j9e;C(U1,"MinWidthLayerer",1382),T(1383,1,Yn,n_e),f.Le=function(t,n){return MIt(this,c(t,9),c(n,9))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(U1,"MinWidthLayerer/MinOutgoingEdgesComparator",1383),T(1374,1,Xr,SN),f.pg=function(t){return c(t,37),V0t},f.If=function(t,n){KYt(this,c(t,37),n)};var V0t;C(U1,"NetworkSimplexLayerer",1374),T(1380,1,Xr,aze),f.pg=function(t){return c(t,37),Wn(Wn(Wn(new wr,(es(),Cf),(cs(),r3)),Zd,Pv),vc,Lv)},f.If=function(t,n){RZt(this,c(t,37),n)},f.d=0,f.f=0,f.g=0,f.i=0,f.s=0,f.t=0,f.u=0,C(U1,"StretchWidthLayerer",1380),T(1381,1,Yn,NR),f.Le=function(t,n){return fLt(c(t,9),c(n,9))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(U1,"StretchWidthLayerer/1",1381),T(411,1,n4e),f.eg=function(t,n,i,r,o,a){},f.tg=function(t,n,i){return yit(this,t,n,i)},f.dg=function(){this.g=ye(py,vct,30,this.d,15,1),this.f=ye(py,vct,30,this.d,15,1)},f.fg=function(t,n){this.e[t]=ye(Fn,ci,30,n[t].length,15,1)},f.gg=function(t,n,i){var r;r=i[t][n],r.p=n,this.e[t][n]=n},f.hg=function(t,n,i,r){c(Xe(r[t][n].j,i),12).p=this.d++},f.b=0,f.c=0,f.d=0,C(rl,"AbstractBarycenterPortDistributor",411),T(1680,1,Yn,i_e),f.Le=function(t,n){return QBt(this.a,c(t,12),c(n,12))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(rl,"AbstractBarycenterPortDistributor/lambda$0$Type",1680),T(823,1,cE,Kpe),f.eg=function(t,n,i,r,o,a){},f.gg=function(t,n,i){},f.hg=function(t,n,i,r){},f.cg=function(){return!1},f.dg=function(){this.c=this.e.a,this.g=this.f.g},f.fg=function(t,n){n[t][0].c.p=t},f.ig=function(){return!1},f.ug=function(t,n,i,r){i?iZe(this,t):(uZe(this,t,r),Frt(this,t,n)),t.c.length>1&&(et(Ze(R(Jr((ht(0,t.c.length),c(t.c[0],9))),(Ge(),R9))))?Ftt(t,this.d,c(this,667)):(Ct(),Rr(t,this.d)),SVe(this.e,t))},f.jg=function(t,n,i,r){var o,a,d,b,v,x,S;for(n!=AFe(i,t.length)&&(a=t[n-(i?1:-1)],Obe(this.f,a,i?(Qs(),Wc):(Qs(),Jl))),o=t[n][0],S=!r||o.k==(Jt(),Cr),x=mf(t[n]),this.ug(x,S,!1,i),d=0,v=new G(x);v.a<v.c.c.length;)b=c(Q(v),9),t[n][d++]=b;return!1},f.kg=function(t,n){var i,r,o,a,d;for(d=AFe(n,t.length),a=mf(t[d]),this.ug(a,!1,!0,n),i=0,o=new G(a);o.a<o.c.c.length;)r=c(Q(o),9),t[d][i++]=r;return!1},C(rl,"BarycenterHeuristic",823),T(665,1,{665:1},o_e),f.Ib=function(){return"BarycenterState [node="+this.c+", summedWeight="+this.d+", degree="+this.b+", barycenter="+this.a+", visited="+this.e+"]"},f.b=0,f.d=0,f.e=!1;var W0t=C(rl,"BarycenterHeuristic/BarycenterState",665);T(1859,1,Yn,r_e),f.Le=function(t,n){return $qt(this.a,c(t,9),c(n,9))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(rl,"BarycenterHeuristic/lambda$0$Type",1859),T(822,1,cE,N2e),f.dg=function(){},f.eg=function(t,n,i,r,o,a){},f.hg=function(t,n,i,r){},f.fg=function(t,n){this.a[t]=ye(W0t,{3:1,4:1,5:1,2096:1},665,n[t].length,0,1),this.b[t]=ye(K0t,{3:1,4:1,5:1,2097:1},242,n[t].length,0,1)},f.gg=function(t,n,i){zKe(this,i[t][n],!0)},f.c=!1,C(rl,"ForsterConstraintResolver",822),T(242,1,{242:1},aHe,Mrt),f.Ib=function(){var t,n;for(n=new b0,n.a+="[",t=0;t<this.d.length;t++)Zn(n,rYe(this.d[t])),wh(this.g,this.d[0]).a!=null&&Zn(Zn((n.a+="<",n),L8t(wh(this.g,this.d[0]).a)),">"),t<this.d.length-1&&(n.a+=Jc);return(n.a+="]",n).a},f.a=0,f.c=0,f.f=0;var K0t=C(rl,"ForsterConstraintResolver/ConstraintGroup",242);T(1854,1,ln,s_e),f.Ad=function(t){zKe(this.a,c(t,9),!1)},C(rl,"ForsterConstraintResolver/lambda$0$Type",1854),T(221,1,{221:1,223:1},$rt),f.eg=function(t,n,i,r,o,a){},f.fg=function(t,n){},f.dg=function(){this.r=ye(Fn,ci,30,this.n,15,1)},f.gg=function(t,n,i){var r,o;o=i[t][n],r=o.e,r&&qe(this.b,r)},f.hg=function(t,n,i,r){++this.n},f.Ib=function(){return Hrt(this.e,new Or)},f.g=!1,f.i=!1,f.n=0,f.s=!1,C(rl,"GraphInfoHolder",221),T(1892,1,cE,tj),f.eg=function(t,n,i,r,o,a){},f.fg=function(t,n){},f.hg=function(t,n,i,r){},f.tg=function(t,n,i){return i&&n>0?pee(this.a,t[n-1],t[n]):!i&&n<t.length-1?pee(this.a,t[n],t[n+1]):ute(this.a,t[n],i?(Je(),Yt):(Je(),nn)),nJt(this,t,n,i)},f.dg=function(){this.d=ye(Fn,ci,30,this.c,15,1),this.a=new E_(this.d)},f.gg=function(t,n,i){var r;r=i[t][n],this.c+=r.j.c.length},f.c=0,C(rl,"GreedyPortDistributor",1892),T(1393,1,Xr,zB),f.pg=function(t){return GRt(c(t,37))},f.If=function(t,n){bZt(c(t,37),n)};var Y0t;C(rl,"InteractiveCrossingMinimizer",1393),T(1394,1,Yn,l_e),f.Le=function(t,n){return mqt(this,c(t,9),c(n,9))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(rl,"InteractiveCrossingMinimizer/1",1394),T(456,1,{456:1,86:1,43:1},Oz),f.pg=function(t){var n;return c(t,37),n=vF(Z0t),Wn(n,(es(),vc),(cs(),OU)),n},f.If=function(t,n){yWt(this,c(t,37),n)},f.e=0;var Z0t;C(rl,"LayerSweepCrossingMinimizer",456),T(1390,1,ln,u_e),f.Ad=function(t){fKt(this.a,c(t,221))},C(rl,"LayerSweepCrossingMinimizer/0methodref$compareDifferentRandomizedLayouts$Type",1390),T(1391,1,ln,a_e),f.Ad=function(t){BRt(this.a,c(t,221))},C(rl,"LayerSweepCrossingMinimizer/1methodref$minimizeCrossingsNoCounter$Type",1391),T(1392,1,ln,f_e),f.Ad=function(t){ort(this.a,c(t,221))},C(rl,"LayerSweepCrossingMinimizer/2methodref$minimizeCrossingsWithCounter$Type",1392),T(409,23,{3:1,34:1,23:1,409:1},eF);var gP,bJ,lC,mJ,ept=mn(rl,"LayerSweepCrossingMinimizer/CrossMinType",409,On,Z_t,cEt),tpt;T(1389,1,Jn,fA),f.Mb=function(t){return xme(),c(t,26).a.c.length==0},C(rl,"LayerSweepCrossingMinimizer/lambda$0$Type",1389),T(1856,1,cE,QHe),f.dg=function(){},f.eg=function(t,n,i,r,o,a){},f.hg=function(t,n,i,r){},f.fg=function(t,n){n[t][0].c.p=t,this.b[t]=ye(npt,{3:1,4:1,5:1,2022:1},666,n[t].length,0,1)},f.gg=function(t,n,i){var r;r=i[t][n],r.p=n,dr(this.b[t],n,new PO)},C(rl,"LayerSweepTypeDecider",1856),T(666,1,{666:1},PO),f.Ib=function(){return"NodeInfo [connectedEdges="+this.a+", hierarchicalInfluence="+this.b+", randomInfluence="+this.c+"]"},f.a=0,f.b=0,f.c=0;var npt=C(rl,"LayerSweepTypeDecider/NodeInfo",666);T(1857,1,hd,p4),f.Lb=function(t){return N7(new kh(c(t,12).b))},f.Fb=function(t){return this===t},f.Mb=function(t){return N7(new kh(c(t,12).b))},C(rl,"LayerSweepTypeDecider/lambda$0$Type",1857),T(1858,1,hd,b4),f.Lb=function(t){return N7(new kh(c(t,12).b))},f.Fb=function(t){return this===t},f.Mb=function(t){return N7(new kh(c(t,12).b))},C(rl,"LayerSweepTypeDecider/lambda$1$Type",1858),T(1893,411,n4e,gPe),f.sg=function(t,n,i){var r,o,a,d,b,v,x,S,M;switch(x=this.g,i.g){case 1:{for(r=0,o=0,v=new G(t.j);v.a<v.c.c.length;)d=c(Q(v),12),d.e.c.length!=0&&(++r,d.j==(Je(),Kt)&&++o);for(a=n+o,M=n+r,b=tw(t,(Qs(),Jl)).Jc();b.Ob();)d=c(b.Pb(),12),d.j==(Je(),Kt)?(x[d.p]=a,--a):(x[d.p]=M,--M);return r}case 2:{for(S=0,b=tw(t,(Qs(),Wc)).Jc();b.Ob();)d=c(b.Pb(),12),++S,x[d.p]=n+S;return S}default:throw J(new GN)}},C(rl,"LayerTotalPortDistributor",1893),T(1861,1,cE,pHe),f.dg=function(){},f.eg=function(t,n,i,r,o,a){},f.fg=function(t,n){},f.gg=function(t,n,i){},f.hg=function(t,n,i,r){},f.cg=function(){return!1},f.ig=function(){return!0},f.jg=function(t,n,i,r){var o,a,d,b;for(o=mf(t[n]),tZt(this,o,i?n-1:n+1),Ct(),Rr(o,this.b),a=0,b=new G(o);b.a<b.c.c.length;)d=c(Q(b),9),t[n][a++]=d;return!1},f.kg=function(t,n){var i,r,o,a,d,b;for(i=n?0:p.Math.max(0,t.length-1),r=mf(t[i]),b=new G(r);b.a<b.c.c.length;)a=c(Q(b),9),Ee(a,(De(),p3),RZ(this.a));for(Ct(),Rr(r,this.b),o=0,d=new G(r);d.a<d.c.c.length;)a=c(Q(d),9),t[i][o++]=a,Ee(a,(De(),p3),o);return!1},C(rl,"MedianHeuristic",1861),T(1862,1,Yn,AW),f.Le=function(t,n){return GGt(c(t,9),c(n,9))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(rl,"MedianHeuristic/lambda$0$Type",1862),T(667,823,{667:1,223:1},XXe),f.ug=function(t,n,i,r){i?iZe(this,t):(uZe(this,t,r),Frt(this,t,n)),t.c.length>1&&(et(Ze(R(Jr((ht(0,t.c.length),c(t.c[0],9))),(Ge(),R9))))?Ftt(t,this.d,this):(Ct(),Rr(t,this.d)),et(Ze(R(Jr((ht(0,t.c.length),c(t.c[0],9))),R9)))||SVe(this.e,t))},C(rl,"ModelOrderBarycenterHeuristic",667),T(1860,1,Yn,h_e),f.Le=function(t,n){return _Kt(this.a,c(t,9),c(n,9))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(rl,"ModelOrderBarycenterHeuristic/lambda$0$Type",1860),T(1395,1,Xr,TN),f.pg=function(t){var n;return c(t,37),n=vF(ipt),Wn(n,(es(),vc),(cs(),OU)),n},f.If=function(t,n){vAt((c(t,37),n))};var ipt;C(rl,"NoCrossingMinimizer",1395),T(803,411,n4e,n1e),f.sg=function(t,n,i){var r,o,a,d,b,v,x,S,M,L,P;switch(M=this.g,i.g){case 1:{for(o=0,a=0,S=new G(t.j);S.a<S.c.c.length;)v=c(Q(S),12),v.e.c.length!=0&&(++o,v.j==(Je(),Kt)&&++a);for(r=1/(o+1),d=n+a*r,P=n+1-r,x=tw(t,(Qs(),Jl)).Jc();x.Ob();)v=c(x.Pb(),12),v.j==(Je(),Kt)?(M[v.p]=d,d-=r):(M[v.p]=P,P-=r);break}case 2:{for(b=0,S=new G(t.j);S.a<S.c.c.length;)v=c(Q(S),12),v.g.c.length==0||++b;for(r=1/(b+1),L=n+r,x=tw(t,(Qs(),Wc)).Jc();x.Ob();)v=c(x.Pb(),12),M[v.p]=L,L+=r;break}default:throw J(new qt("Port type is undefined"))}return 1},C(rl,"NodeRelativePortDistributor",803),T(815,1,{},KFe,qZe),C(rl,"SweepCopy",815),T(1855,1,cE,OKe),f.fg=function(t,n){},f.dg=function(){var t;t=ye(Fn,ci,30,this.f,15,1),this.d=new y_e(t),this.a=new E_(t)},f.eg=function(t,n,i,r,o,a){var d;d=c(Xe(a[t][n].j,i),12),o.c==d&&o.c.i.c==o.d.i.c&&++this.e[t]},f.gg=function(t,n,i){var r;r=i[t][n],this.c[t]=this.c[t]|r.k==(Jt(),Dc)},f.hg=function(t,n,i,r){var o;o=c(Xe(r[t][n].j,i),12),o.p=this.f++,o.g.c.length+o.e.c.length>1&&(o.j==(Je(),nn)?this.b[t]=!0:o.j==Yt&&t>0&&(this.b[t-1]=!0))},f.f=0,C(Kd,"AllCrossingsCounter",1855),T(590,1,{},pH),f.b=0,f.d=0,C(Kd,"BinaryIndexedTree",590),T(523,1,{},E_);var T9e,wJ;C(Kd,"CrossingsCounter",523),T(1929,1,Yn,d_e),f.Le=function(t,n){return UCt(this.a,c(t,12),c(n,12))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Kd,"CrossingsCounter/lambda$0$Type",1929),T(1930,1,Yn,g_e),f.Le=function(t,n){return JCt(this.a,c(t,12),c(n,12))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Kd,"CrossingsCounter/lambda$1$Type",1930),T(1931,1,Yn,p_e),f.Le=function(t,n){return XCt(this.a,c(t,12),c(n,12))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Kd,"CrossingsCounter/lambda$2$Type",1931),T(1932,1,Yn,b_e),f.Le=function(t,n){return VCt(this.a,c(t,12),c(n,12))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Kd,"CrossingsCounter/lambda$3$Type",1932),T(1933,1,ln,m_e),f.Ad=function(t){XLt(this.a,c(t,12))},C(Kd,"CrossingsCounter/lambda$4$Type",1933),T(1934,1,Jn,w_e),f.Mb=function(t){return M8t(this.a,c(t,12))},C(Kd,"CrossingsCounter/lambda$5$Type",1934),T(1935,1,ln,v_e),f.Ad=function(t){RRe(this,t)},C(Kd,"CrossingsCounter/lambda$6$Type",1935),T(1936,1,ln,dRe),f.Ad=function(t){var n;L6(),C0(this.b,(n=this.a,c(t,12),n))},C(Kd,"CrossingsCounter/lambda$7$Type",1936),T(831,1,hd,gA),f.Lb=function(t){return L6(),xi(c(t,12),(De(),Ul))},f.Fb=function(t){return this===t},f.Mb=function(t){return L6(),xi(c(t,12),(De(),Ul))},C(Kd,"CrossingsCounter/lambda$8$Type",831),T(1928,1,{},y_e),C(Kd,"HyperedgeCrossingsCounter",1928),T(470,1,{34:1,470:1},hze),f.Dd=function(t){return CBt(this,c(t,470))},f.b=0,f.c=0,f.e=0,f.f=0;var Wtn=C(Kd,"HyperedgeCrossingsCounter/Hyperedge",470);T(371,1,{34:1,371:1},hq),f.Dd=function(t){return EUt(this,c(t,371))},f.b=0,f.c=0;var rpt=C(Kd,"HyperedgeCrossingsCounter/HyperedgeCorner",371);T(522,23,{3:1,34:1,23:1,522:1},$1e);var uC,aC,spt=mn(Kd,"HyperedgeCrossingsCounter/HyperedgeCorner/Type",522,On,YAt,lEt),opt;T(1397,1,Xr,fK),f.pg=function(t){return c(R(c(t,37),(De(),Lc)),24).Gc((Gs(),Ea))?cpt:null},f.If=function(t,n){tqt(this,c(t,37),n)};var cpt;C(Xs,"InteractiveNodePlacer",1397),T(1398,1,Xr,HB),f.pg=function(t){return c(R(c(t,37),(De(),Lc)),24).Gc((Gs(),Ea))?lpt:null},f.If=function(t,n){$zt(this,c(t,37),n)};var lpt,vJ,yJ;C(Xs,"LinearSegmentsNodePlacer",1398),T(264,1,{34:1,264:1},Pde),f.Dd=function(t){return q9t(this,c(t,264))},f.Fb=function(t){var n;return oe(t,264)?(n=c(t,264),this.b==n.b):!1},f.Hb=function(){return this.b},f.Ib=function(){return"ls"+Mh(this.e)},f.a=0,f.b=0,f.c=-1,f.d=-1,f.g=0;var upt=C(Xs,"LinearSegmentsNodePlacer/LinearSegment",264);T(1400,1,Xr,XFe),f.pg=function(t){return c(R(c(t,37),(De(),Lc)),24).Gc((Gs(),Ea))?apt:null},f.If=function(t,n){ntn(this,c(t,37),n)},f.b=0,f.g=0;var apt;C(Xs,"NetworkSimplexPlacer",1400),T(1419,1,Yn,_R),f.Le=function(t,n){return fc(c(t,15).a,c(n,15).a)},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Xs,"NetworkSimplexPlacer/0methodref$compare$Type",1419),T(1421,1,Yn,Gy),f.Le=function(t,n){return fc(c(t,15).a,c(n,15).a)},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Xs,"NetworkSimplexPlacer/1methodref$compare$Type",1421),T(651,1,{651:1},aRe);var Ktn=C(Xs,"NetworkSimplexPlacer/EdgeRep",651);T(410,1,{410:1},Spe),f.b=!1;var Ytn=C(Xs,"NetworkSimplexPlacer/NodeRep",410);T(504,13,{3:1,4:1,22:1,32:1,56:1,13:1,18:1,16:1,59:1,504:1},OLe),C(Xs,"NetworkSimplexPlacer/Path",504),T(1401,1,{},hA),f.Kb=function(t){return c(t,17).d.i.k},C(Xs,"NetworkSimplexPlacer/Path/lambda$0$Type",1401),T(1402,1,Jn,NW),f.Mb=function(t){return c(t,252)==(Jt(),jr)},C(Xs,"NetworkSimplexPlacer/Path/lambda$1$Type",1402),T(1403,1,{},Z8),f.Kb=function(t){return c(t,17).d.i},C(Xs,"NetworkSimplexPlacer/Path/lambda$2$Type",1403),T(1404,1,Jn,x_e),f.Mb=function(t){return VBe(yKe(c(t,9)))},C(Xs,"NetworkSimplexPlacer/Path/lambda$3$Type",1404),T(1405,1,Jn,DR),f.Mb=function(t){return DCt(c(t,12))},C(Xs,"NetworkSimplexPlacer/lambda$0$Type",1405),T(1406,1,ln,fRe),f.Ad=function(t){vjt(this.a,this.b,c(t,12))},C(Xs,"NetworkSimplexPlacer/lambda$1$Type",1406),T(1415,1,ln,k_e),f.Ad=function(t){dGt(this.a,c(t,17))},C(Xs,"NetworkSimplexPlacer/lambda$10$Type",1415),T(1416,1,{},m4),f.Kb=function(t){return Ru(),new jt(null,new Tt(c(t,26).a,16))},C(Xs,"NetworkSimplexPlacer/lambda$11$Type",1416),T(1417,1,ln,O_e),f.Ad=function(t){WXt(this.a,c(t,9))},C(Xs,"NetworkSimplexPlacer/lambda$12$Type",1417),T(1418,1,{},dA),f.Kb=function(t){return Ru(),Pe(c(t,126).e)},C(Xs,"NetworkSimplexPlacer/lambda$13$Type",1418),T(1420,1,{},ej),f.Kb=function(t){return Ru(),Pe(c(t,126).e)},C(Xs,"NetworkSimplexPlacer/lambda$15$Type",1420),T(1422,1,Jn,LR),f.Mb=function(t){return Ru(),c(t,410).c.k==(Jt(),or)},C(Xs,"NetworkSimplexPlacer/lambda$17$Type",1422),T(1423,1,Jn,Uy),f.Mb=function(t){return Ru(),c(t,410).c.j.c.length>1},C(Xs,"NetworkSimplexPlacer/lambda$18$Type",1423),T(1424,1,ln,Vqe),f.Ad=function(t){K$t(this.c,this.b,this.d,this.a,c(t,410))},f.c=0,f.d=0,C(Xs,"NetworkSimplexPlacer/lambda$19$Type",1424),T(1407,1,{},Jy),f.Kb=function(t){return Ru(),new jt(null,new Tt(c(t,26).a,16))},C(Xs,"NetworkSimplexPlacer/lambda$2$Type",1407),T(1425,1,ln,S_e),f.Ad=function(t){Ojt(this.a,c(t,12))},f.a=0,C(Xs,"NetworkSimplexPlacer/lambda$20$Type",1425),T(1426,1,{},PR),f.Kb=function(t){return Ru(),new jt(null,new Tt(c(t,26).a,16))},C(Xs,"NetworkSimplexPlacer/lambda$21$Type",1426),T(1427,1,ln,j_e),f.Ad=function(t){Ajt(this.a,c(t,9))},C(Xs,"NetworkSimplexPlacer/lambda$22$Type",1427),T(1428,1,Jn,IR),f.Mb=function(t){return VBe(t)},C(Xs,"NetworkSimplexPlacer/lambda$23$Type",1428),T(1429,1,{},w4),f.Kb=function(t){return Ru(),new jt(null,new Tt(c(t,26).a,16))},C(Xs,"NetworkSimplexPlacer/lambda$24$Type",1429),T(1430,1,Jn,T_e),f.Mb=function(t){return R8t(this.a,c(t,9))},C(Xs,"NetworkSimplexPlacer/lambda$25$Type",1430),T(1431,1,ln,hRe),f.Ad=function(t){pQt(this.a,this.b,c(t,9))},C(Xs,"NetworkSimplexPlacer/lambda$26$Type",1431),T(1432,1,Jn,IO),f.Mb=function(t){return Ru(),!vs(c(t,17))},C(Xs,"NetworkSimplexPlacer/lambda$27$Type",1432),T(1433,1,Jn,nj),f.Mb=function(t){return Ru(),!vs(c(t,17))},C(Xs,"NetworkSimplexPlacer/lambda$28$Type",1433),T(1434,1,{},E_e),f.Te=function(t,n){return kjt(this.a,c(t,26),c(n,26))},C(Xs,"NetworkSimplexPlacer/lambda$29$Type",1434),T(1408,1,{},RO),f.Kb=function(t){return Ru(),new jt(null,new U2(new Ht(Vt($i(c(t,9)).a.Jc(),new U))))},C(Xs,"NetworkSimplexPlacer/lambda$3$Type",1408),T(1409,1,Jn,ij),f.Mb=function(t){return Ru(),R_t(c(t,17))},C(Xs,"NetworkSimplexPlacer/lambda$4$Type",1409),T(1410,1,ln,C_e),f.Ad=function(t){oKt(this.a,c(t,17))},C(Xs,"NetworkSimplexPlacer/lambda$5$Type",1410),T(1411,1,{},RR),f.Kb=function(t){return Ru(),new jt(null,new Tt(c(t,26).a,16))},C(Xs,"NetworkSimplexPlacer/lambda$6$Type",1411),T(1412,1,Jn,Xy),f.Mb=function(t){return Ru(),c(t,9).k==(Jt(),or)},C(Xs,"NetworkSimplexPlacer/lambda$7$Type",1412),T(1413,1,{},$R),f.Kb=function(t){return Ru(),new jt(null,new U2(new Ht(Vt(sd(c(t,9)).a.Jc(),new U))))},C(Xs,"NetworkSimplexPlacer/lambda$8$Type",1413),T(1414,1,Jn,g2),f.Mb=function(t){return Ru(),NCt(c(t,17))},C(Xs,"NetworkSimplexPlacer/lambda$9$Type",1414),T(1396,1,Xr,uK),f.pg=function(t){return c(R(c(t,37),(De(),Lc)),24).Gc((Gs(),Ea))?fpt:null},f.If=function(t,n){BKt(c(t,37),n)};var fpt;C(Xs,"SimpleNodePlacer",1396),T(188,1,{188:1},zx),f.Ib=function(){var t;return t="",this.c==(td(),Pw)?t+=ik:this.c==Wg&&(t+=nk),this.o==(vh(),Bb)?t+=vre:this.o==Rh?t+="UP":t+="BALANCED",t},C(X0,"BKAlignedLayout",188),T(513,23,{3:1,34:1,23:1,513:1},I1e);var Wg,Pw,hpt=mn(X0,"BKAlignedLayout/HDirection",513,On,WAt,uEt),dpt;T(512,23,{3:1,34:1,23:1,512:1},R1e);var Bb,Rh,gpt=mn(X0,"BKAlignedLayout/VDirection",512,On,VAt,aEt),ppt;T(1681,1,{},gRe),C(X0,"BKAligner",1681),T(1684,1,{},UYe),C(X0,"BKCompactor",1684),T(659,1,{659:1},pA),f.a=0,C(X0,"BKCompactor/ClassEdge",659),T(459,1,{459:1},bLe),f.a=null,f.b=0,C(X0,"BKCompactor/ClassNode",459),T(1399,1,Xr,DRe),f.pg=function(t){return c(R(c(t,37),(De(),Lc)),24).Gc((Gs(),Ea))?bpt:null},f.If=function(t,n){vtn(this,c(t,37),n)},f.d=!1;var bpt;C(X0,"BKNodePlacer",1399),T(1682,1,{},bA),f.d=0,C(X0,"NeighborhoodInformation",1682),T(1683,1,Yn,M_e),f.Le=function(t,n){return lPt(this,c(t,49),c(n,49))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(X0,"NeighborhoodInformation/NeighborComparator",1683),T(816,1,{}),C(X0,"ThresholdStrategy",816),T(1812,816,{},wLe),f.vg=function(t,n,i){return this.a.o==(vh(),Rh)?nr:Qr},f.wg=function(){},C(X0,"ThresholdStrategy/NullThresholdStrategy",1812),T(583,1,{583:1},wRe),f.c=!1,f.d=!1,C(X0,"ThresholdStrategy/Postprocessable",583),T(1813,816,{},vLe),f.vg=function(t,n,i){var r,o,a;return o=n==i,r=this.a.a[i.p]==n,o||r?(a=t,this.a.c==(td(),Pw)?(o&&(a=xie(this,n,!0)),!isNaN(a)&&!isFinite(a)&&r&&(a=xie(this,i,!1))):(o&&(a=xie(this,n,!0)),!isNaN(a)&&!isFinite(a)&&r&&(a=xie(this,i,!1))),a):t},f.wg=function(){for(var t,n,i,r,o;this.d.b!=0;)o=c(DHe(this.d),583),r=Iit(this,o),r.a&&(t=r.a,i=et(this.a.f[this.a.g[o.b.p].p]),!(!i&&!vs(t)&&t.c.i.c==t.d.i.c)&&(n=Ptt(this,o),n||j$e(this.e,o)));for(;this.e.a.c.length!=0;)Ptt(this,c(Jme(this.e),583))},C(X0,"ThresholdStrategy/SimpleThresholdStrategy",1813),T(642,1,{642:1,173:1,177:1},p2),f.bg=function(){return xVe(this)},f.og=function(){return xVe(this)};var $le;C(wse,"EdgeRouterFactory",642),T(1462,1,Xr,hK),f.pg=function(t){return EXt(c(t,37))},f.If=function(t,n){XKt(c(t,37),n)};var mpt,wpt,vpt,ypt,xpt,E9e,kpt,Opt;C(wse,"OrthogonalEdgeRouter",1462),T(1455,1,Xr,_Re),f.pg=function(t){return aqt(c(t,37))},f.If=function(t,n){wen(this,c(t,37),n)};var Spt,jpt,Tpt,Ept,pP,Cpt;C(wse,"PolylineEdgeRouter",1455),T(1456,1,hd,$O),f.Lb=function(t){return Sme(c(t,9))},f.Fb=function(t){return this===t},f.Mb=function(t){return Sme(c(t,9))},C(wse,"PolylineEdgeRouter/1",1456),T(1868,1,Jn,mA),f.Mb=function(t){return c(t,135).c==(Wf(),sp)},C(nh,"HyperEdgeCycleDetector/lambda$0$Type",1868),T(1869,1,{},wA),f.Xe=function(t){return c(t,135).d},C(nh,"HyperEdgeCycleDetector/lambda$1$Type",1869),T(1870,1,Jn,BO),f.Mb=function(t){return c(t,135).c==(Wf(),sp)},C(nh,"HyperEdgeCycleDetector/lambda$2$Type",1870),T(1871,1,{},zO),f.Xe=function(t){return c(t,135).d},C(nh,"HyperEdgeCycleDetector/lambda$3$Type",1871),T(1872,1,{},BR),f.Xe=function(t){return c(t,135).d},C(nh,"HyperEdgeCycleDetector/lambda$4$Type",1872),T(1873,1,{},b2),f.Xe=function(t){return c(t,135).d},C(nh,"HyperEdgeCycleDetector/lambda$5$Type",1873),T(117,1,{34:1,117:1},gD),f.Dd=function(t){return F9t(this,c(t,117))},f.Fb=function(t){var n;return oe(t,117)?(n=c(t,117),this.g==n.g):!1},f.Hb=function(){return this.g},f.Ib=function(){var t,n,i,r;for(t=new Lu("{"),r=new G(this.n);r.a<r.c.c.length;)i=c(Q(r),12),n=_D(i.i),n==null&&(n="n"+Nze(i.i)),t.a+=""+n,r.a<r.c.c.length&&(t.a+=",");return t.a+="}",t.a},f.a=0,f.b=0,f.c=NaN,f.d=0,f.g=0,f.i=0,f.o=0,f.s=NaN,C(nh,"HyperEdgeSegment",117),T(135,1,{135:1},eb),f.Ib=function(){return this.a+"->"+this.b+" ("+o7t(this.c)+")"},f.d=0,C(nh,"HyperEdgeSegmentDependency",135),T(519,23,{3:1,34:1,23:1,519:1},B1e);var sp,Kv,Mpt=mn(nh,"HyperEdgeSegmentDependency/DependencyType",519,On,KAt,fEt),Apt;T(1874,1,{},A_e),C(nh,"HyperEdgeSegmentSplitter",1874),T(1875,1,{},bPe),f.a=0,f.b=0,C(nh,"HyperEdgeSegmentSplitter/AreaRating",1875),T(341,1,{341:1},OZ),f.a=0,f.b=0,f.c=0,C(nh,"HyperEdgeSegmentSplitter/FreeArea",341),T(1876,1,Yn,zR),f.Le=function(t,n){return iTt(c(t,117),c(n,117))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(nh,"HyperEdgeSegmentSplitter/lambda$0$Type",1876),T(1877,1,ln,Wqe),f.Ad=function(t){TDt(this.a,this.d,this.c,this.b,c(t,117))},f.b=0,C(nh,"HyperEdgeSegmentSplitter/lambda$1$Type",1877),T(1878,1,{},v4),f.Kb=function(t){return new jt(null,new Tt(c(t,117).e,16))},C(nh,"HyperEdgeSegmentSplitter/lambda$2$Type",1878),T(1879,1,{},rj),f.Kb=function(t){return new jt(null,new Tt(c(t,117).j,16))},C(nh,"HyperEdgeSegmentSplitter/lambda$3$Type",1879),T(1880,1,{},FR),f.We=function(t){return ue(he(t))},C(nh,"HyperEdgeSegmentSplitter/lambda$4$Type",1880),T(660,1,{},XZ),f.a=0,f.b=0,f.c=0,C(nh,"OrthogonalRoutingGenerator",660),T(1685,1,{},vA),f.Kb=function(t){return new jt(null,new Tt(c(t,117).e,16))},C(nh,"OrthogonalRoutingGenerator/lambda$0$Type",1685),T(1686,1,{},yA),f.Kb=function(t){return new jt(null,new Tt(c(t,117).j,16))},C(nh,"OrthogonalRoutingGenerator/lambda$1$Type",1686),T(668,1,{}),C(vse,"BaseRoutingDirectionStrategy",668),T(1866,668,{},yLe),f.xg=function(t,n,i){var r,o,a,d,b,v,x,S,M,L,P,z,H;if(!(t.r&&!t.q))for(S=n+t.o*i,x=new G(t.n);x.a<x.c.c.length;)for(v=c(Q(x),12),M=Lo(W(V(Vr,1),Be,8,0,[v.i.n,v.n,v.a])).a,b=new G(v.g);b.a<b.c.c.length;)d=c(Q(b),17),vs(d)||(z=d.d,H=Lo(W(V(Vr,1),Be,8,0,[z.i.n,z.n,z.a])).a,p.Math.abs(M-H)>dd&&(a=S,o=t,r=new $e(M,a),ei(d.a,r),lw(this,d,o,r,!1),L=t.r,L&&(P=ue(he(pc(L.e,0))),r=new $e(P,a),ei(d.a,r),lw(this,d,o,r,!1),a=n+L.o*i,o=L,r=new $e(P,a),ei(d.a,r),lw(this,d,o,r,!1)),r=new $e(H,a),ei(d.a,r),lw(this,d,o,r,!1)))},f.yg=function(t){return t.i.n.a+t.n.a+t.a.a},f.zg=function(){return Je(),bn},f.Ag=function(){return Je(),Kt},C(vse,"NorthToSouthRoutingStrategy",1866),T(1867,668,{},xLe),f.xg=function(t,n,i){var r,o,a,d,b,v,x,S,M,L,P,z,H;if(!(t.r&&!t.q))for(S=n-t.o*i,x=new G(t.n);x.a<x.c.c.length;)for(v=c(Q(x),12),M=Lo(W(V(Vr,1),Be,8,0,[v.i.n,v.n,v.a])).a,b=new G(v.g);b.a<b.c.c.length;)d=c(Q(b),17),vs(d)||(z=d.d,H=Lo(W(V(Vr,1),Be,8,0,[z.i.n,z.n,z.a])).a,p.Math.abs(M-H)>dd&&(a=S,o=t,r=new $e(M,a),ei(d.a,r),lw(this,d,o,r,!1),L=t.r,L&&(P=ue(he(pc(L.e,0))),r=new $e(P,a),ei(d.a,r),lw(this,d,o,r,!1),a=n-L.o*i,o=L,r=new $e(P,a),ei(d.a,r),lw(this,d,o,r,!1)),r=new $e(H,a),ei(d.a,r),lw(this,d,o,r,!1)))},f.yg=function(t){return t.i.n.a+t.n.a+t.a.a},f.zg=function(){return Je(),Kt},f.Ag=function(){return Je(),bn},C(vse,"SouthToNorthRoutingStrategy",1867),T(1865,668,{},kLe),f.xg=function(t,n,i){var r,o,a,d,b,v,x,S,M,L,P,z,H;if(!(t.r&&!t.q))for(S=n+t.o*i,x=new G(t.n);x.a<x.c.c.length;)for(v=c(Q(x),12),M=Lo(W(V(Vr,1),Be,8,0,[v.i.n,v.n,v.a])).b,b=new G(v.g);b.a<b.c.c.length;)d=c(Q(b),17),vs(d)||(z=d.d,H=Lo(W(V(Vr,1),Be,8,0,[z.i.n,z.n,z.a])).b,p.Math.abs(M-H)>dd&&(a=S,o=t,r=new $e(a,M),ei(d.a,r),lw(this,d,o,r,!0),L=t.r,L&&(P=ue(he(pc(L.e,0))),r=new $e(a,P),ei(d.a,r),lw(this,d,o,r,!0),a=n+L.o*i,o=L,r=new $e(a,P),ei(d.a,r),lw(this,d,o,r,!0)),r=new $e(a,H),ei(d.a,r),lw(this,d,o,r,!0)))},f.yg=function(t){return t.i.n.b+t.n.b+t.a.b},f.zg=function(){return Je(),nn},f.Ag=function(){return Je(),Yt},C(vse,"WestToEastRoutingStrategy",1865),T(819,1,{},Cye),f.Ib=function(){return Mh(this.a)},f.b=0,f.c=!1,f.d=!1,f.f=0,C(Ev,"NubSpline",819),T(415,1,{415:1},wnt,NHe),C(Ev,"NubSpline/PolarCP",415),T(1457,1,Xr,IYe),f.pg=function(t){return Wqt(c(t,37))},f.If=function(t,n){$en(this,c(t,37),n)};var Npt,_pt,Dpt,Lpt,Ppt;C(Ev,"SplineEdgeRouter",1457),T(275,1,{275:1},$q),f.Ib=function(){return this.a+" ->("+this.c+") "+this.b},f.c=0,C(Ev,"SplineEdgeRouter/Dependency",275),T(457,23,{3:1,34:1,23:1,457:1},z1e);var op,y3,Ipt=mn(Ev,"SplineEdgeRouter/SideToProcess",457,On,ZAt,dEt),Rpt;T(1458,1,Jn,g1),f.Mb=function(t){return BT(),!c(t,134).o},C(Ev,"SplineEdgeRouter/lambda$0$Type",1458),T(1459,1,{},gg),f.Xe=function(t){return BT(),c(t,134).v+1},C(Ev,"SplineEdgeRouter/lambda$1$Type",1459),T(1460,1,ln,pRe),f.Ad=function(t){ICt(this.a,this.b,c(t,49))},C(Ev,"SplineEdgeRouter/lambda$2$Type",1460),T(1461,1,ln,bRe),f.Ad=function(t){RCt(this.a,this.b,c(t,49))},C(Ev,"SplineEdgeRouter/lambda$3$Type",1461),T(134,1,{34:1,134:1},Oet,Lye),f.Dd=function(t){return H9t(this,c(t,134))},f.b=0,f.e=!1,f.f=0,f.g=0,f.j=!1,f.k=!1,f.n=0,f.o=!1,f.p=!1,f.q=!1,f.s=0,f.u=0,f.v=0,f.F=0,C(Ev,"SplineSegment",134),T(460,1,{460:1},m2),f.a=0,f.b=!1,f.c=!1,f.d=!1,f.e=!1,f.f=0,C(Ev,"SplineSegment/EdgeInformation",460),T(1179,1,{},xA),C(J1,yxe,1179),T(1180,1,Yn,qR),f.Le=function(t,n){return TGt(c(t,121),c(n,121))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(J1,Aot,1180),T(1178,1,{},LPe),C(J1,"MrTree",1178),T(402,23,{3:1,34:1,23:1,402:1,173:1,177:1},tF),f.bg=function(){return Xet(this)},f.og=function(){return Xet(this)};var xJ,fC,hC,dC,C9e=mn(J1,"TreeLayoutPhases",402,On,oDt,gEt),$pt;T(1093,207,kb,gze),f.kf=function(t,n){var i,r,o,a,d,b,v,x;for(et(Ze(ke(t,(Uo(),Z9e))))||J7((i=new g6((v0(),new wg(t))),i)),d=n.dh(kse),d.Tg("build tGraph",1),b=(v=new J_,ec(v,t),Ee(v,(Li(),pC),t),x=new wn,fWt(t,v,x),CWt(t,v,x),v),d.Ug(),d=n.dh(kse),d.Tg("Split graph",1),a=mWt(this.a,b),d.Ug(),o=new G(a);o.a<o.c.c.length;)r=c(Q(o),121),QFt(this.b,r,n.dh(.5999999940395355/a.c.length));d=n.dh(kse),d.Tg("Pack components",1),b=ytn(a),d.Ug(),d=n.dh(kse),d.Tg("Apply layout results",1),sZt(b),d.Ug()},C(J1,"TreeLayoutProvider",1093),T(1829,1,Jd,p1),f.Ic=function(t){ws(this,t)},f.Jc=function(){return Ct(),j6(),S9},C(J1,"TreeUtil/1",1829),T(1830,1,Jd,Nu),f.Ic=function(t){ws(this,t)},f.Jc=function(){return Ct(),j6(),S9},C(J1,"TreeUtil/2",1830),T(1820,1,Jn,sj),f.Mb=function(t){return et(Ze(R(c(t,41),(Li(),cp))))},C(J1,"TreeUtil/lambda$0$Type",1820),T(1826,1,Jn,N_e),f.Mb=function(t){return this.a.Gc(c(t,41))},C(J1,"TreeUtil/lambda$10$Type",1826),T(1827,1,{},__e),f.Kb=function(t){return vDt(this.a,c(t,41))},C(J1,"TreeUtil/lambda$11$Type",1827),T(1828,1,Jn,mRe),f.Mb=function(t){return nPt(this.a,this.b,c(t,41))},C(J1,"TreeUtil/lambda$12$Type",1828),T(1821,1,Jn,D_e),f.Mb=function(t){return M$t(this.a,c(t,65))},C(J1,"TreeUtil/lambda$3$Type",1821),T(1822,1,Yn,w2),f.Le=function(t,n){return sTt(c(t,65),c(n,65))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(J1,"TreeUtil/lambda$4$Type",1822),T(1823,1,Jn,L_e),f.Mb=function(t){return A$t(this.a,c(t,65))},C(J1,"TreeUtil/lambda$7$Type",1823),T(1824,1,Yn,hm),f.Le=function(t,n){return rTt(c(t,65),c(n,65))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(J1,"TreeUtil/lambda$8$Type",1824),T(1825,1,{},Ts),f.Kb=function(t){return c(t,65).b},C(J1,"TreeUtil/lambda$9$Type",1825),T(497,151,{3:1,497:1,105:1,151:1}),f.g=0,C(fE,"TGraphElement",497),T(65,497,{3:1,65:1,497:1,105:1,151:1},Epe),f.Ib=function(){return this.b&&this.c?nb(this.b)+"->"+nb(this.c):"e_"+Ri(this)},C(fE,"TEdge",65),T(121,151,{3:1,121:1,105:1,151:1},J_),f.Ib=function(){var t,n,i,r,o;for(o=null,r=_n(this.b,0);r.b!=r.d.c;)i=c(An(r),41),o+=(i.c==null||i.c.length==0?"n_"+i.g:"n_"+i.c)+`
`;for(n=_n(this.a,0);n.b!=n.d.c;)t=c(An(n),65),o+=(t.b&&t.c?nb(t.b)+"->"+nb(t.c):"e_"+Ri(t))+`
`;return o};var Ztn=C(fE,"TGraph",121);T(640,497,{3:1,497:1,640:1,105:1,151:1}),C(fE,"TShape",640),T(41,640,{3:1,497:1,41:1,640:1,105:1,151:1},Ete),f.Ib=function(){return nb(this)};var kJ=C(fE,"TNode",41);T(239,1,Jd,k1),f.Ic=function(t){ws(this,t)},f.Jc=function(){var t;return t=_n(this.a.d,0),new ix(t)},C(fE,"TNode/2",239),T(335,1,ts,ix),f.Nb=function(t){gs(this,t)},f.Pb=function(){return c(An(this.a),65).c},f.Ob=function(){return XN(this.a)},f.Qb=function(){tte(this.a)},C(fE,"TNode/2/1",335),T(1910,1,Di,$c),f.If=function(t,n){gtn(this,c(t,121),n)},C(_c,"CompactionProcessor",1910),T(1911,1,Yn,P_e),f.Le=function(t,n){return EIt(this.a,c(t,41),c(n,41))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(_c,"CompactionProcessor/lambda$0$Type",1911),T(1912,1,Jn,vRe),f.Mb=function(t){return zAt(this.b,this.a,c(t,49))},f.a=0,f.b=0,C(_c,"CompactionProcessor/lambda$1$Type",1912),T(1921,1,Yn,oa),f.Le=function(t,n){return MMt(c(t,41),c(n,41))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(_c,"CompactionProcessor/lambda$10$Type",1921),T(1922,1,Yn,oj),f.Le=function(t,n){return Xjt(c(t,41),c(n,41))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(_c,"CompactionProcessor/lambda$11$Type",1922),T(1923,1,Yn,y4),f.Le=function(t,n){return AMt(c(t,41),c(n,41))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(_c,"CompactionProcessor/lambda$12$Type",1923),T(1913,1,Jn,I_e),f.Mb=function(t){return Ljt(this.a,c(t,49))},f.a=0,C(_c,"CompactionProcessor/lambda$2$Type",1913),T(1914,1,Jn,R_e),f.Mb=function(t){return Pjt(this.a,c(t,49))},f.a=0,C(_c,"CompactionProcessor/lambda$3$Type",1914),T(1915,1,Jn,Vy),f.Mb=function(t){return c(t,41).c.indexOf(yG)==-1},C(_c,"CompactionProcessor/lambda$4$Type",1915),T(1916,1,{},$_e),f.Kb=function(t){return $_t(this.a,c(t,41))},f.a=0,C(_c,"CompactionProcessor/lambda$5$Type",1916),T(1917,1,{},B_e),f.Kb=function(t){return JLt(this.a,c(t,41))},f.a=0,C(_c,"CompactionProcessor/lambda$6$Type",1917),T(1918,1,Yn,z_e),f.Le=function(t,n){return nLt(this.a,c(t,243),c(n,243))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(_c,"CompactionProcessor/lambda$7$Type",1918),T(1919,1,Yn,F_e),f.Le=function(t,n){return iLt(this.a,c(t,41),c(n,41))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(_c,"CompactionProcessor/lambda$8$Type",1919),T(1920,1,Yn,cj),f.Le=function(t,n){return Vjt(c(t,41),c(n,41))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(_c,"CompactionProcessor/lambda$9$Type",1920),T(1908,1,Di,FO),f.If=function(t,n){cVt(c(t,121),n)},C(_c,"DirectionProcessor",1908),T(G0,1,Di,fze),f.If=function(t,n){EWt(this,c(t,121),n)},C(_c,"FanProcessor",G0),T(1263,1,Di,x4),f.If=function(t,n){$nt(c(t,121),n)},C(_c,"GraphBoundsProcessor",1263),T(1264,1,{},_W),f.We=function(t){return c(t,41).e.a},C(_c,"GraphBoundsProcessor/lambda$0$Type",1264),T(1265,1,{},pu),f.We=function(t){return c(t,41).e.b},C(_c,"GraphBoundsProcessor/lambda$1$Type",1265),T(1266,1,{},kA),f.We=function(t){return p8t(c(t,41))},C(_c,"GraphBoundsProcessor/lambda$2$Type",1266),T(1267,1,{},OA),f.We=function(t){return b8t(c(t,41))},C(_c,"GraphBoundsProcessor/lambda$3$Type",1267),T(265,23,{3:1,34:1,23:1,265:1,177:1},Nm),f.bg=function(){switch(this.g){case 0:return new BLe;case 1:return new fze;case 2:return new $Le;case 3:return new jA;case 4:return new QR;case 8:return new HR;case 5:return new FO;case 6:return new Vh;case 7:return new $c;case 9:return new x4;case 10:return new _u;default:throw J(new qt(Tre+(this.f!=null?this.f:""+this.g)))}};var M9e,A9e,N9e,_9e,D9e,L9e,P9e,I9e,R9e,$9e,Ble,enn=mn(_c,Ere,265,On,bVe,pEt),Bpt;T(1907,1,Di,HR),f.If=function(t,n){hen(c(t,121),n)},C(_c,"LevelCoordinatesProcessor",1907),T(1905,1,Di,QR),f.If=function(t,n){NJt(this,c(t,121),n)},f.a=0,C(_c,"LevelHeightProcessor",1905),T(1906,1,Jd,DW),f.Ic=function(t){ws(this,t)},f.Jc=function(){return Ct(),j6(),S9},C(_c,"LevelHeightProcessor/1",1906),T(1901,1,Di,$Le),f.If=function(t,n){QXt(this,c(t,121),n)},C(_c,"LevelProcessor",1901),T(1902,1,Jn,SA),f.Mb=function(t){return et(Ze(R(c(t,41),(Li(),cp))))},C(_c,"LevelProcessor/lambda$0$Type",1902),T(1903,1,Di,jA),f.If=function(t,n){IQt(this,c(t,121),n)},f.a=0,C(_c,"NeighborsProcessor",1903),T(1904,1,Jd,TA),f.Ic=function(t){ws(this,t)},f.Jc=function(){return Ct(),j6(),S9},C(_c,"NeighborsProcessor/1",1904),T(1909,1,Di,Vh),f.If=function(t,n){jWt(this,c(t,121),n)},f.a=0,C(_c,"NodePositionProcessor",1909),T(1899,1,Di,BLe),f.If=function(t,n){hYt(this,c(t,121),n)},C(_c,"RootProcessor",1899),T(1924,1,Di,_u),f.If=function(t,n){yzt(c(t,121),n)},C(_c,"Untreeifyer",1924),T(386,23,{3:1,34:1,23:1,386:1},LY);var bP,zle,B9e,z9e=mn(NL,"EdgeRoutingMode",386,On,YNt,bEt),zpt,mP,G9,Fle,F9e,q9e,qle,Hle,H9e,Qle,Q9e,Gle,gC,Ule,OJ,SJ,Af,oh,U9,pC,bC,Kg,G9e,Fpt,Jle,cp,wP,vP;T(854,1,jf,dK),f.tf=function(t){ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,s4e),""),Cct),"Turns on Tree compaction which decreases the size of the whole tree by placing nodes of multiple levels in one large level"),(Bt(),!1)),(q0(),Pr)),ir),gt((Th(),Nt))))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,o4e),""),"Edge End Texture Length"),"Should be set to the length of the texture at the end of an edge. This value can be used to improve the Edge Routing."),7),us),kr),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,c4e),""),"Tree Level"),"The index for the tree level the node is in"),Pe(0)),js),Lr),gt(fr)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,l4e),""),Cct),"When set to a positive number this option will force the algorithm to place the node to the specified position within the trees layer if weighting is set to constraint"),Pe(-1)),js),Lr),gt(fr)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,u4e),""),"Weighting of Nodes"),"Which weighting to use when computing a node order."),X9e),Ui),o8e),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,a4e),""),"Edge Routing Mode"),"Chooses an Edge Routing algorithm."),U9e),Ui),z9e),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,f4e),""),"Search Order"),"Which search order to use when computing a spanning tree."),J9e),Ui),l8e),gt(Nt)))),gst((new E2,t))};var qpt,Hpt,Qpt,U9e,Gpt,Upt,J9e,Jpt,Xpt,X9e;C(NL,"MrTreeMetaDataProvider",854),T(999,1,jf,E2),f.tf=function(t){gst(t)};var Vpt,V9e,W9e,Iw,K9e,Y9e,Xle,Wpt,Kpt,Ypt,Zpt,ebt,tbt,nbt,Z9e,e8e,t8e,ibt,x3,jJ,n8e,rbt,i8e,Vle,sbt,obt,cbt,r8e,lbt,xd,s8e;C(NL,"MrTreeOptions",999),T(qg,1,{},lj),f.uf=function(){var t;return t=new gze,t},f.vf=function(t){},C(NL,"MrTreeOptions/MrtreeFactory",qg),T(354,23,{3:1,34:1,23:1,354:1},nF);var Wle,TJ,Kle,Yle,o8e=mn(NL,"OrderWeighting",354,On,iDt,mEt),ubt;T(430,23,{3:1,34:1,23:1,430:1},F1e);var c8e,Zle,l8e=mn(NL,"TreeifyingOrder",430,On,eNt,wEt),abt;T(1463,1,Xr,FB),f.pg=function(t){return c(t,121),fbt},f.If=function(t,n){aIt(this,c(t,121),n)};var fbt;C("org.eclipse.elk.alg.mrtree.p1treeify","DFSTreeifyer",1463),T(1464,1,Xr,jN),f.pg=function(t){return c(t,121),hbt},f.If=function(t,n){XXt(this,c(t,121),n)};var hbt;C(l9,"NodeOrderer",1464),T(1471,1,{},GR),f.rd=function(t){return pFe(t)},C(l9,"NodeOrderer/0methodref$lambda$6$Type",1471),T(1465,1,Jn,UR),f.Mb=function(t){return A5(),et(Ze(R(c(t,41),(Li(),cp))))},C(l9,"NodeOrderer/lambda$0$Type",1465),T(1466,1,Jn,JR),f.Mb=function(t){return A5(),c(R(c(t,41),(Uo(),x3)),15).a<0},C(l9,"NodeOrderer/lambda$1$Type",1466),T(1467,1,Jn,H_e),f.Mb=function(t){return GPt(this.a,c(t,41))},C(l9,"NodeOrderer/lambda$2$Type",1467),T(1468,1,Jn,q_e),f.Mb=function(t){return I_t(this.a,c(t,41))},C(l9,"NodeOrderer/lambda$3$Type",1468),T(1469,1,Yn,XR),f.Le=function(t,n){return dPt(c(t,41),c(n,41))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(l9,"NodeOrderer/lambda$4$Type",1469),T(1470,1,Jn,VR),f.Mb=function(t){return A5(),c(R(c(t,41),(Li(),Hle)),15).a!=0},C(l9,"NodeOrderer/lambda$5$Type",1470),T(1472,1,Xr,EN),f.pg=function(t){return c(t,121),dbt},f.If=function(t,n){eWt(this,c(t,121),n)},f.b=0;var dbt;C("org.eclipse.elk.alg.mrtree.p3place","NodePlacer",1472),T(1473,1,Xr,gK),f.pg=function(t){return c(t,121),gbt},f.If=function(t,n){PVt(c(t,121),n)};var gbt,tnn=C(Au,"EdgeRouter",1473);T(1475,1,Yn,uj),f.Le=function(t,n){return fc(c(t,15).a,c(n,15).a)},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Au,"EdgeRouter/0methodref$compare$Type",1475),T(1480,1,{},EA),f.We=function(t){return ue(he(t))},C(Au,"EdgeRouter/1methodref$doubleValue$Type",1480),T(1482,1,Yn,dm),f.Le=function(t,n){return ji(ue(he(t)),ue(he(n)))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Au,"EdgeRouter/2methodref$compare$Type",1482),T(1484,1,Yn,aj),f.Le=function(t,n){return ji(ue(he(t)),ue(he(n)))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Au,"EdgeRouter/3methodref$compare$Type",1484),T(1486,1,{},qO),f.We=function(t){return ue(he(t))},C(Au,"EdgeRouter/4methodref$doubleValue$Type",1486),T(1488,1,Yn,CA),f.Le=function(t,n){return ji(ue(he(t)),ue(he(n)))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Au,"EdgeRouter/5methodref$compare$Type",1488),T(1490,1,Yn,WR),f.Le=function(t,n){return ji(ue(he(t)),ue(he(n)))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Au,"EdgeRouter/6methodref$compare$Type",1490),T(1474,1,{},KR),f.Kb=function(t){return L1(),c(R(c(t,41),(Uo(),xd)),15)},C(Au,"EdgeRouter/lambda$0$Type",1474),T(1485,1,{},MA),f.Kb=function(t){return c7t(c(t,41))},C(Au,"EdgeRouter/lambda$11$Type",1485),T(1487,1,{},xRe),f.Kb=function(t){return LCt(this.b,this.a,c(t,41))},f.a=0,f.b=0,C(Au,"EdgeRouter/lambda$13$Type",1487),T(1489,1,{},yRe),f.Kb=function(t){return l7t(this.b,this.a,c(t,41))},f.a=0,f.b=0,C(Au,"EdgeRouter/lambda$15$Type",1489),T(1491,1,Yn,YR),f.Le=function(t,n){return YBt(c(t,65),c(n,65))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Au,"EdgeRouter/lambda$17$Type",1491),T(1492,1,Yn,LW),f.Le=function(t,n){return ZBt(c(t,65),c(n,65))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Au,"EdgeRouter/lambda$18$Type",1492),T(1493,1,Yn,ZR),f.Le=function(t,n){return tzt(c(t,65),c(n,65))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Au,"EdgeRouter/lambda$19$Type",1493),T(1476,1,Jn,Q_e),f.Mb=function(t){return yNt(this.a,c(t,41))},f.a=0,C(Au,"EdgeRouter/lambda$2$Type",1476),T(1494,1,Yn,e$),f.Le=function(t,n){return ezt(c(t,65),c(n,65))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Au,"EdgeRouter/lambda$20$Type",1494),T(1477,1,Yn,t$),f.Le=function(t,n){return SCt(c(t,41),c(n,41))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Au,"EdgeRouter/lambda$3$Type",1477),T(1478,1,Yn,AA),f.Le=function(t,n){return jCt(c(t,41),c(n,41))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Au,"EdgeRouter/lambda$4$Type",1478),T(1479,1,{},n$),f.Kb=function(t){return f7t(c(t,41))},C(Au,"EdgeRouter/lambda$5$Type",1479),T(1481,1,{},kRe),f.Kb=function(t){return PCt(this.b,this.a,c(t,41))},f.a=0,f.b=0,C(Au,"EdgeRouter/lambda$7$Type",1481),T(1483,1,{},ORe),f.Kb=function(t){return a7t(this.b,this.a,c(t,41))},f.a=0,f.b=0,C(Au,"EdgeRouter/lambda$9$Type",1483),T(669,1,{669:1},jYe),f.e=0,f.f=!1,f.g=!1,C(Au,"MultiLevelEdgeNodeNodeGap",669),T(1881,1,Yn,i$),f.Le=function(t,n){return NNt(c(t,243),c(n,243))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Au,"MultiLevelEdgeNodeNodeGap/lambda$0$Type",1881),T(1882,1,Yn,r$),f.Le=function(t,n){return _Nt(c(t,243),c(n,243))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(Au,"MultiLevelEdgeNodeNodeGap/lambda$1$Type",1882);var k3;T(490,23,{3:1,34:1,23:1,490:1,173:1,177:1},q1e),f.bg=function(){return dKe(this)},f.og=function(){return dKe(this)};var EJ,O3,u8e=mn(d4e,"RadialLayoutPhases",490,On,tNt,vEt),pbt;T(1094,207,kb,PPe),f.kf=function(t,n){var i,r,o,a,d,b;if(i=gnt(this,t),n.Tg("Radial layout",i.c.length),et(Ze(ke(t,(F0(),y8e))))||J7((r=new g6((v0(),new wg(t))),r)),b=Zqt(t),ii(t,(vx(),k3),b),!b)throw J(new qt(Act));for(o=ue(he(ke(t,AJ))),o==0&&(o=zet(t)),ii(t,AJ,o),d=new G(gnt(this,t));d.a<d.c.c.length;)a=c(Q(d),43),a.If(t,n.dh(1));n.Ug()},C(d4e,"RadialLayoutProvider",1094),T(548,1,Yn,Mz),f.Le=function(t,n){return SVt(this.a,this.b,c(t,19),c(n,19))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},f.a=0,f.b=0,C(d4e,"RadialUtil/lambda$0$Type",548),T(1361,1,Di,s$),f.If=function(t,n){ben(c(t,19),n)},C(p4e,"CalculateGraphSize",1361),T(1362,1,Di,o$),f.If=function(t,n){PKt(c(t,19))},C(p4e,"EdgeAngleCalculator",1362),T(365,23,{3:1,34:1,23:1,365:1,177:1},l_),f.bg=function(){switch(this.g){case 0:return new hj;case 1:return new PW;case 2:return new u$;case 3:return new s$;case 4:return new o$;default:throw J(new qt(Tre+(this.f!=null?this.f:""+this.g)))}};var eue,tue,nue,iue,rue,bbt=mn(p4e,Ere,365,On,UDt,yEt),mbt;T(648,1,{}),f.e=1,f.g=0,C(Ose,"AbstractRadiusExtensionCompaction",648),T(1832,648,{},GBe),f.Bg=function(t){var n,i,r,o,a,d,b,v,x;for(this.c=c(ke(t,(vx(),k3)),19),NK(this,this.c),this.d=ane(c(ke(t,(F0(),yP)),304)),v=c(ke(t,oue),15),v&&Qj(this,v.a),b=he(ke(t,(Dn(),lh))),tx(this,(zt(b),b)),x=wv(this.c),this.d&&this.d.Fg(x),zVt(this,x),d=new Ho(W(V(Mn,1),_ct,19,0,[this.c])),i=0;i<2;i++)for(n=0;n<x.c.length;n++)o=new Ho(W(V(Mn,1),_ct,19,0,[(ht(n,x.c.length),c(x.c[n],19))])),a=n<x.c.length-1?(ht(n+1,x.c.length),c(x.c[n+1],19)):(ht(0,x.c.length),c(x.c[0],19)),r=n==0?c(Xe(x,x.c.length-1),19):(ht(n-1,x.c.length),c(x.c[n-1],19)),NZe(this,(ht(n,x.c.length),c(x.c[n],19),d),r,a,o)},C(Ose,"AnnulusWedgeCompaction",1832),T(1359,1,Di,PW),f.If=function(t,n){uIt(c(t,19),n)},C(Ose,"GeneralCompactor",1359),T(1831,648,{},c$),f.Bg=function(t){var n,i,r,o;i=c(ke(t,(vx(),k3)),19),this.f=i,this.b=ane(c(ke(t,(F0(),yP)),304)),o=c(ke(t,oue),15),o&&Qj(this,o.a),r=he(ke(t,(Dn(),lh))),tx(this,(zt(r),r)),n=wv(i),this.b&&this.b.Fg(n),get(this,n)},f.a=0,C(Ose,"RadialCompaction",1831),T(1840,1,{},k4),f.Cg=function(t){var n,i,r,o,a,d;for(this.a=t,n=0,d=wv(t),r=0,a=new G(d);a.a<a.c.c.length;)for(o=c(Q(a),19),++r,i=r;i<d.c.length;i++)nKt(this,o,(ht(i,d.c.length),c(d.c[i],19)))&&(n+=1);return n},C(b4e,"CrossingMinimizationPosition",1840),T(1838,1,{},l$),f.Cg=function(t){var n,i,r,o,a,d,b,v,x,S,M,L,P;for(r=0,i=new Ht(Vt(z1(t).a.Jc(),new U));hn(i);)n=c(sn(i),74),b=to(c(re((!n.c&&(n.c=new Et(vn,n,5,8)),n.c),0),83)),x=b.i+b.g/2,S=b.j+b.f/2,o=t.i+t.g/2,a=t.j+t.f/2,M=new as,M.a=x-o,M.b=S-a,d=new $e(M.a,M.b),TS(d,t.g,t.f),M.a-=d.a,M.b-=d.b,o=x-M.a,a=S-M.b,v=new $e(M.a,M.b),TS(v,b.g,b.f),M.a-=v.a,M.b-=v.b,x=o+M.a,S=a+M.b,L=x-o,P=S-a,r+=p.Math.sqrt(L*L+P*P);return r},C(b4e,"EdgeLengthOptimization",1838),T(1839,1,{},fj),f.Cg=function(t){var n,i,r,o,a,d,b,v,x,S,M;for(r=0,i=new Ht(Vt(z1(t).a.Jc(),new U));hn(i);)n=c(sn(i),74),b=to(c(re((!n.c&&(n.c=new Et(vn,n,5,8)),n.c),0),83)),v=b.i+b.g/2,x=b.j+b.f/2,o=c(ke(b,(Dn(),Dk)),8),a=t.i+o.a+t.g/2,d=t.j+o.b+t.f,S=v-a,M=x-d,r+=p.Math.sqrt(S*S+M*M);return r},C(b4e,"EdgeLengthPositionOptimization",1839),T(1358,648,Di,hj),f.If=function(t,n){WQt(this,c(t,19),n)},C("org.eclipse.elk.alg.radial.intermediate.overlaps","RadiusExtensionOverlapRemoval",1358),T(1360,1,Di,u$),f.If=function(t,n){mMt(c(t,19),n)},C("org.eclipse.elk.alg.radial.intermediate.rotation","GeneralRotator",1360),T(431,23,{3:1,34:1,23:1,431:1},H1e);var a8e,sue,f8e=mn(hE,"AnnulusWedgeCriteria",431,On,nNt,xEt),wbt;T(387,23,{3:1,34:1,23:1,387:1},PY);var CJ,h8e,d8e,g8e=mn(hE,Dct,387,On,ZNt,kEt),vbt;T(855,1,jf,aK),f.tf=function(t){ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,m4e),""),"Center On Root"),"Centers the layout on the root of the tree i.e. so that the central node is also the center node of the final layout. This introduces additional whitespace."),(Bt(),!1)),(q0(),Pr)),ir),gt((Th(),Nt))))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,w4e),""),"Order ID"),"The id can be used to define an order for nodes of one radius. This can be used to sort them in the layer accordingly."),Pe(0)),js),Lr),gt(fr)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,v4e),""),"Radius"),"The radius option can be used to set the initial radius for the radial layouter."),0),us),kr),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,OG),""),"Rotate"),"The rotate option determines whether a rotation of the layout should be performed."),!1),Pr),ir),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,jse),""),Lct),"With the compacter option it can be determined how compaction on the graph is done. It can be chosen between none, the radial compaction or the compaction of wedges separately."),p8e),Ui),g8e),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Tse),""),"Compaction Step Size"),"Determine the size of steps with which the compaction is done. Step size 1 correlates to a compaction of 1 pixel per Iteration."),Pe(1)),js),Lr),gt(Nt)))),Yi(t,Tse,jse,null),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,y4e),""),"Sorter"),"Sort the nodes per radius according to the sorting algorithm. The strategies are none, by the given order id, or sorting them by polar coordinates."),m8e),Ui),_8e),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,x4e),""),"Annulus Wedge Criteria"),"Determine how the wedge for the node placement is calculated. It can be chosen between wedge determination by the number of leaves or by the maximum sum of diagonals."),w8e),Ui),f8e),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,k4e),""),"Translation Optimization"),"Find the optimal translation of the nodes of the first radii according to this criteria. For example edge crossings can be minimized."),b8e),Ui),M8e),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Ese),S4e),"Target Angle"),"The angle in radians that the layout should be rotated to after layout."),0),us),kr),gt(Nt)))),Yi(t,Ese,OG,null),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Cse),S4e),"Additional Wedge Space"),"If set to true, modifies the target angle by rotating further such that space is left for an edge to pass in between the nodes. This option should only be used in conjunction with top-down layout."),!1),Pr),ir),gt(Nt)))),Yi(t,Cse,OG,null),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,O4e),S4e),"Outgoing Edge Angles"),"Calculate the required angle of connected nodes to leave space for an incoming edge. This option should only be used in conjunction with top-down layout."),!1),Pr),ir),gt(Nt)))),cst((new qB,t))};var ybt,xbt,kbt,p8e,Obt,b8e,Sbt,jbt,Tbt,Ebt,Cbt,Mbt,Abt,m8e,Nbt,w8e;C(hE,"RadialMetaDataProvider",855),T(1001,1,jf,qB),f.tf=function(t){cst(t)};var v8e,oue,cue,_bt,Dbt,Lbt,Pbt,y8e,x8e,MJ,Ibt,Rbt,AJ,k8e,O8e,S8e,lue,yP,$bt,j8e;C(hE,"RadialOptions",1001),T(1002,1,{},NA),f.uf=function(){var t;return t=new PPe,t},f.vf=function(t){},C(hE,"RadialOptions/RadialFactory",1002),T(355,23,{3:1,34:1,23:1,355:1},iF);var T8e,E8e,C8e,uue,M8e=mn(hE,"RadialTranslationStrategy",355,On,rDt,OEt),Bbt;T(304,23,{3:1,34:1,23:1,304:1},IY);var A8e,aue,N8e,_8e=mn(hE,"SortingStrategy",304,On,o_t,SEt),zbt;T(1448,1,Xr,IW),f.pg=function(t){return c(t,19),null},f.If=function(t,n){bGt(this,c(t,19),n)},f.c=0,C("org.eclipse.elk.alg.radial.p1position","EadesRadial",1448),T(1836,1,{},a$),f.Dg=function(t){return cYe(t)},C(Pct,"AnnulusWedgeByLeafs",1836),T(1837,1,{},f$),f.Dg=function(t){return kZe(this,t)},C(Pct,"AnnulusWedgeByNodeSpace",1837),T(1449,1,Xr,h$),f.pg=function(t){return c(t,19),null},f.If=function(t,n){_$t(this,c(t,19),n)},C("org.eclipse.elk.alg.radial.p2routing","StraightLineEdgeRouter",1449),T(818,1,{},qde),f.Eg=function(t){},f.Fg=function(t){YDe(this,t)},C(j4e,"IDSorter",818),T(1835,1,Yn,d$),f.Le=function(t,n){return lIt(c(t,19),c(n,19))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(j4e,"IDSorter/lambda$0$Type",1835),T(1834,1,{},tVe),f.Eg=function(t){UQe(this,t)},f.Fg=function(t){var n;t.dc()||(this.e||(n=NFe(c(t.Xb(0),19)),UQe(this,n)),YDe(this.e,t))},C(j4e,"PolarCoordinateSorter",1834),T(441,23,{3:1,34:1,23:1,441:1},RY);var mC,NJ,fue,D8e=mn(Bct,"RectPackingLayoutPhases",441,On,s_t,jEt),Fbt;T(1098,207,kb,IPe),f.kf=function(t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt;if(n.Tg("Rectangle Packing",1),M=c(ke(t,(Ah(),yC)),100),v=et(Ze(ke(t,amt))),S=ue(he(ke(t,xC))),bt=et(Ze(ke(t,J8e))),de=(!t.a&&(t.a=new Me(Mn,t,10,11)),t.a),et(Ze(ke(t,vue)))||J7((o=new g6((v0(),new wg(t))),o)),pt=!1,bt&&de.i>=3)for(xe=c(re(de,0),19),We=c(re(de,1),19),a=0;a+2<de.i;)if(Se=xe,xe=We,We=c(re(de,a+2),19),Se.f>=xe.f+We.f+S||We.f>=Se.f+xe.f+S){pt=!0;break}else++a;else pt=!0;if(!pt){for(L=de.i,b=new cn(de);b.e!=b.i.gc();)d=c(un(b),19),ii(d,(Dn(),NP),Pe(L)),--L;Uit(t,new V4),n.Ug();return}for(i=(U7(this.a),Iu(this.a,(BH(),mC),c(ke(t,K8e),173)),Iu(this.a,NJ,c(ke(t,G8e),173)),Iu(this.a,fue,c(ke(t,X8e),173)),sge(this.a,(Dt=new wr,Wn(Dt,mC,(uQ(),gue)),Wn(Dt,NJ,due),et(Ze(ke(t,H8e)))&&Wn(Dt,mC,pue),et(Ze(ke(t,q8e)))&&Wn(Dt,mC,hue),Dt)),VT(this.a,t)),x=1/i.c.length,z=new G(i);z.a<z.c.c.length;){if(P=c(Q(z),43),n.Zg())return;P.If(t,n.dh(x))}for(X=0,H=0,se=new cn(de);se.e!=se.i.gc();)ie=c(un(se),19),X=p.Math.max(X,ie.i+ie.g),H=p.Math.max(H,ie.j+ie.f);rve(t,new $e(ue(he(ke(t,(Gd(),Ck)))),ue(he(ke(t,J9)))),new $e(X,H)),_It(de,M),v||uw(t,ue(he(ke(t,Ck)))+(M.b+M.c),ue(he(ke(t,J9)))+(M.d+M.a),!1,!0),et(Ze(ke(t,vue)))||J7((r=new g6((v0(),new wg(t))),r)),n.Ug()},C(Bct,"RectPackingLayoutProvider",1098),T(1496,1,Di,g$),f.If=function(t,n){IKt(c(t,19),n)},C(dE,"InteractiveNodeReorderer",1496),T(1497,1,Yn,_A),f.Le=function(t,n){return bRt(c(t,19),c(n,19))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(dE,"InteractiveNodeReorderer/lambda$0$Type",1497),T(406,23,{3:1,34:1,23:1,406:1,177:1},rF),f.bg=function(){switch(this.g){case 0:return new m$;case 1:return new g$;case 2:return new b$;case 3:return new p$}return null};var hue,due,gue,pue,qbt=mn(dE,Ere,406,On,sDt,TEt),Hbt;T(1499,1,Di,p$),f.If=function(t,n){pBt(c(t,19),n)},C(dE,"MinSizePostProcessor",1499),T(1498,1,Di,b$),f.If=function(t,n){wJt(c(t,19),n)},C(dE,"MinSizePreProcessor",1498),T(1688,1,Yn,DA),f.Le=function(t,n){return G8t(c(t,19),c(n,19))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(dE,"NodeSizeComparator",1688),T(1495,1,Di,m$),f.If=function(t,n){q_t(c(t,19))},C(dE,"NodeSizeReorderer",1495);var wC,J9,Ck,Qbt,Gbt,_J,bue,mue,vC,DJ,Yv;T(388,23,{3:1,34:1,23:1,388:1},$Y);var L8e,P8e,wue,I8e=mn(Mse,"OptimizationGoal",388,On,e_t,EEt),Ubt;T(857,1,jf,GB),f.tf=function(t){ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,T4e),""),"Try box layout first"),"Whether one should check whether the regions are stackable to see whether box layout would do the job. For example, nodes with the same height are not stackable inside a row. Therefore, box layout will perform better and faster."),(Bt(),!1)),(q0(),Pr)),ir),gt((Th(),Nt))))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,E4e),""),"Current position of a node in the order of nodes"),"The rectangles are ordered. Normally according to their definition the the model. This option specifies the current position of a node."),Pe(-1)),js),Lr),gt(fr)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,C4e),""),"Desired index of node"),"The rectangles are ordered. Normally according to their definition the the model. This option allows to specify a desired position that has preference over the original position."),Pe(-1)),js),Lr),gt(fr)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,M4e),""),"In new Row"),"If set to true this node begins in a new row. Consequently this node cannot be moved in a previous layer during compaction. Width approximation does does not take this into account."),!1),Pr),ir),gt(fr)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,A4e),""),"Order nodes by height"),"If set to true the nodes will be sorted by their height before computing the layout. The largest node will be in the first position."),!1),Pr),ir),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,N4e),Ase),"Width Approximation Strategy"),"Strategy for finding an initial width of the drawing."),z8e),Ui),eje),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,_4e),Ase),"Target Width"),"Option to place the rectangles in the given target width instead of approximating the width using the desired aspect ratio. The padding is not included in this. Meaning a drawing will have width of targetwidth + horizontal padding."),-1),us),kr),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,D4e),Ase),"Optimization Goal"),"Optimization goal for approximation of the bounding box given by the first iteration. Determines whether layout is sorted by the maximum scaling, aspect ratio, or area. Depending on the strategy the aspect ratio might be nearly ignored."),B8e),Ui),I8e),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,L4e),Ase),"Shift Last Placed."),"When placing a rectangle behind or below the last placed rectangle in the first iteration, it is sometimes possible to shift the rectangle further to the left or right, resulting in less whitespace. True (default) enables the shift and false disables it. Disabling the shift produces a greater approximated area by the first iteration and a layout, when using ONLY the first iteration (default not the case), where it is sometimes impossible to implement a size transformation of rectangles that will fill the bounding box and eliminate empty spaces."),!0),Pr),ir),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,P4e),"packing"),zct),"Strategy for finding an initial placement on nodes."),R8e),Ui),ije),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,I4e),Fct),"Row Height Reevaluation"),"During the compaction step the height of a row is normally not changed. If this options is set, the blocks of other rows might be added if they exceed the row height. If this is the case the whole row has to be packed again to be optimal regarding the new row height. This option should, therefore, be used with care since it might be computation heavy."),!1),Pr),ir),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,R4e),Fct),"Compaction iterations"),"Defines the number of compaction iterations. E.g. if set to 2 the width is initially approximated, then the drawing is compacted and based on the resulting drawing the target width is decreased or increased and a second compaction step is executed and the result compared to the first one. The best run is used based on the scale measure."),Pe(1)),js),Lr),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,$4e),"whiteSpaceElimination"),"White Space Approximation Strategy"),"Strategy for expanding nodes such that whitespace in the parent is eliminated."),$8e),Ui),oje),gt(Nt)))),Ost((new QB,t))};var Jbt,Xbt,Vbt,Wbt,Kbt,Ybt,Zbt,R8e,emt,tmt,$8e,nmt,imt,B8e,rmt,z8e,smt;C(Mse,"RectPackingMetaDataProvider",857),T(1007,1,jf,QB),f.tf=function(t){Ost(t)};var LJ,omt,F8e,xP,q8e,cmt,kP,lmt,umt,amt,fmt,hmt,vue,H8e,Q8e,yue,G8e,yC,U8e,dmt,xC,J8e,X8e,V8e,W8e,K8e,xue;C(Mse,"RectPackingOptions",1007),T(1008,1,{},w$),f.uf=function(){var t;return t=new IPe,t},f.vf=function(t){},C(Mse,"RectPackingOptions/RectpackingFactory",1008),T(1687,1,{},Qze),f.a=0,f.c=!1,C(u9,"AreaApproximation",1687);var Y8e=Ki(u9,"BestCandidateFilter");T(671,1,{527:1},LA),f.Gg=function(t,n,i){var r,o,a,d,b,v;for(v=new Fe,a=nr,b=new G(t);b.a<b.c.c.length;)d=c(Q(b),241),a=p.Math.min(a,(d.c+(i.b+i.c))*(d.b+(i.d+i.a)));for(o=new G(t);o.a<o.c.c.length;)r=c(Q(o),241),(r.c+(i.b+i.c))*(r.b+(i.d+i.a))==a&&It(v.c,r);return v},C(u9,"AreaFilter",671),T(672,1,{527:1},HO),f.Gg=function(t,n,i){var r,o,a,d,b,v;for(b=new Fe,v=nr,d=new G(t);d.a<d.c.c.length;)a=c(Q(d),241),v=p.Math.min(v,p.Math.abs((a.c+(i.b+i.c))/(a.b+(i.d+i.a))-n));for(o=new G(t);o.a<o.c.c.length;)r=c(Q(o),241),p.Math.abs((r.c+(i.b+i.c))/(r.b+(i.d+i.a))-n)==v&&It(b.c,r);return b},C(u9,"AspectRatioFilter",672),T(1441,1,Xr,v$),f.pg=function(t){return c(t,19),null},f.If=function(t,n){SXt(c(t,19),n)},C(u9,"GreedyWidthApproximator",1441),T(670,1,{527:1},dj),f.Gg=function(t,n,i){var r,o,a,d,b,v;for(v=new Fe,a=Qr,b=new G(t);b.a<b.c.c.length;)d=c(Q(b),241),a=p.Math.max(a,JF(d.c+(i.b+i.c),d.b+(i.d+i.a),d.a));for(o=new G(t);o.a<o.c.c.length;)r=c(Q(o),241),JF(r.c+(i.b+i.c),r.b+(i.d+i.a),r.a)==a&&It(v.c,r);return v},C(u9,"ScaleMeasureFilter",670),T(1442,1,Xr,PA),f.pg=function(t){return c(t,19),null},f.If=function(t,n){mGt(c(t,19),n)},C(u9,"TargetWidthWidthApproximator",1442),T(481,23,{3:1,34:1,23:1,481:1,173:1,177:1},Q1e),f.bg=function(){return _Ze(this)},f.og=function(){return _Ze(this)};var kue,Z8e,eje=mn(u9,"WidthApproximationStrategy",481,On,rNt,PEt),gmt;T(1443,1,Xr,y$),f.pg=function(t){return c(t,19),null},f.If=function(t,n){Ten(this,c(t,19),n)},C(SG,"Compactor",1443),T(1445,1,Xr,x$),f.pg=function(t){return c(t,19),null},f.If=function(t,n){rXt(c(t,19),n)},C(SG,"NoPlacement",1445),T(434,23,{3:1,34:1,23:1,434:1,173:1,177:1},BY),f.bg=function(){return $We(this)},f.og=function(){return $We(this)};var Oue,tje,nje,ije=mn(SG,"PackingStrategy",434,On,i_t,IEt),pmt;T(804,1,{},V1e),f.a=0,f.b=0,f.c=0,f.d=nr,f.e=0,f.f=nr,C(SG,"RowFillingAndCompaction",804),T(1444,1,Xr,RW),f.pg=function(t){return c(t,19),null},f.If=function(t,n){FYt(c(t,19),n)},C(SG,"SimplePlacement",1444),T(1446,1,Xr,$W),f.pg=function(t){return c(t,19),null},f.If=function(t,n){this.Hg(c(t,19),n)},f.Hg=function(t,n){Dtt(t,n)},C(B4e,"EqualWhitespaceEliminator",1446),T(1447,1446,Xr,k$),f.Hg=function(t,n){var i,r,o,a,d;n.Tg("To Aspect Ratio Whitesapce Eliminator",1),d=ue(he(ke(t,(Gd(),Ck)))),a=ue(he(ke(t,J9))),o=ue(he(ke(t,(Ah(),LJ)))),i=ue(he(ke(t,wC))),r=d/a,r<o?(d=a*o,ii(t,Ck,d)):(i+=d/o-a,ii(t,wC,i),ii(t,J9,a+i)),Dtt(t,n),n.Ug()},C(B4e,"ToAspectratioNodeExpander",1447),T(435,23,{3:1,34:1,23:1,435:1,173:1,177:1},zY),f.bg=function(){return NVe(this)},f.og=function(){return NVe(this)};var rje,Sue,sje,oje=mn(B4e,"WhiteSpaceEliminationStrategy",435,On,n_t,REt),bmt;T(175,1,{175:1},Cte),f.a=0,f.c=!1,f.d=0,f.e=0,f.f=0,f.g=0,f.i=0,f.k=!1,f.o=nr,f.p=nr,f.r=0,f.s=0,f.t=0,C(_L,"Block",175),T(211,1,{211:1},kq),f.a=0,f.b=0,f.d=0,f.e=0,f.f=0,C(_L,"BlockRow",211),T(320,1,{320:1},Dpe),f.b=0,f.c=0,f.d=0,f.e=0,f.f=0,C(_L,"BlockStack",320),T(241,1,{241:1},I0e,Rwe),f.a=0,f.b=0,f.c=0,f.d=0,f.e=0,f.g=0;var nnn=C(_L,"DrawingData",241);T(370,23,{3:1,34:1,23:1,370:1},u_);var Mk,S3,kC,OC,OP,mmt=mn(_L,"DrawingDataDescriptor",370,On,XDt,MEt),wmt;T(189,1,{189:1},Jpe),f.b=0,f.c=0,f.e=0,f.f=0,C(_L,"RectRow",189),T(757,1,{},ewe),f.j=0,C(Cv,Uot,757),T(1186,1,{},QO),f.$e=function(t){return A0(t.a,t.b)},C(Cv,xxe,1186),T(1187,1,{},G_e),f.$e=function(t){return rLt(this.a,t)},C(Cv,Jot,1187),T(1188,1,{},U_e),f.$e=function(t){return ozt(this.a,t)},C(Cv,Xot,1188),T(1189,1,{},J_e),f.$e=function(t){return rRt(this.a,t)},C(Cv,"ElkGraphImporter/lambda$3$Type",1189),T(1190,1,{},X_e),f.$e=function(t){return DGt(this.a,t)},C(Cv,Vot,1190),T(1095,207,kb,RPe),f.kf=function(t,n){var i,r,o,a,d,b,v,x,S,M,L,P;for(ga(t,($D(),BJ))&&(P=zn(ke(t,(pne(),Eje))),a=cye(rT(),P),a&&(d=c(B_(a.f),207),d.kf(t,n.dh(1)))),ii(t,Nue,(X_(),$J)),ii(t,_ue,(BD(),Aue)),ii(t,Due,(pD(),zJ)),b=c(ke(t,(pne(),Sje)),15).a,n.Tg("Overlap removal",1),et(Ze(ke(t,$mt))),v=new Or,x=new V_e(v),r=new ewe,i=kst(r,t),S=!0,o=0;o<b&&S;){if(et(Ze(ke(t,jje)))){if(v.a.$b(),LQt(new z$e(x),i.i),v.a.gc()==0)break;i.e=v}for(U7(this.b),Iu(this.b,(SD(),PJ),(c7(),SP)),Iu(this.b,IJ,i.g),Iu(this.b,RJ,(Rz(),Eue)),this.a=VT(this.b,i),L=new G(this.a);L.a<L.c.c.length;)M=c(Q(L),43),M.If(i,n.dh(1));iqt(r,i),S=et(Ze(R(i,(rS(),Ske)))),++o}Lrt(r,i),n.Ug()},C(Cv,"OverlapRemovalLayoutProvider",1095),T(1096,1,{},V_e),C(Cv,"OverlapRemovalLayoutProvider/lambda$0$Type",1096),T(440,23,{3:1,34:1,23:1,440:1},FY);var PJ,IJ,RJ,jue=mn(Cv,"SPOrEPhases",440,On,r_t,NEt),vmt;T(1196,1,{},$Pe),C(Cv,"ShrinkTree",1196),T(1097,207,kb,qLe),f.kf=function(t,n){var i,r,o,a,d;ga(t,($D(),BJ))&&(d=zn(ke(t,BJ)),o=cye(rT(),d),o&&(a=c(B_(o.f),207),a.kf(t,n.dh(1)))),r=new ewe,i=kst(r,t),cJt(this.a,i,n.dh(1)),Lrt(r,i)},C(Cv,"ShrinkTreeLayoutProvider",1097),T(311,151,{3:1,311:1,105:1,151:1},RHe),f.c=!1,C("org.eclipse.elk.alg.spore.graph","Graph",311),T(480,23,{3:1,34:1,23:1,480:1,173:1,177:1},LIe),f.bg=function(){return sWe(this)},f.og=function(){return sWe(this)};var Tue,cje=mn(Mv,Dct,480,On,fAt,AEt),ymt;T(550,23,{3:1,34:1,23:1,550:1,173:1,177:1},ABe),f.bg=function(){return new pj},f.og=function(){return new pj};var Eue,xmt=mn(Mv,"OverlapRemovalStrategy",550,On,aAt,_Et),kmt;T(433,23,{3:1,34:1,23:1,433:1},G1e);var $J,Cue,lje=mn(Mv,"RootSelection",433,On,iNt,DEt),Omt;T(331,23,{3:1,34:1,23:1,331:1},a_);var uje,Mue,Aue,aje,fje,hje=mn(Mv,"SpanningTreeCostFunction",331,On,VDt,LEt),Smt;T(1005,1,jf,pK),f.tf=function(t){hrt(t)};var dje,gje,jmt,Tmt,pje,bje,Nue,_ue,Due,Emt,Cmt,BJ;C(Mv,"SporeCompactionOptions",1005),T(1006,1,{},IA),f.uf=function(){var t;return t=new qLe,t},f.vf=function(t){},C(Mv,"SporeCompactionOptions/SporeCompactionFactory",1006),T(856,1,jf,UB),f.tf=function(t){ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,Nse),""),"Underlying Layout Algorithm"),"A layout algorithm that is applied to the graph before it is compacted. If this is null, nothing is applied before compaction."),(q0(),Nk)),nt),gt((Th(),Nt))))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Lse),"structure"),"Structure Extraction Strategy"),"This option defines what kind of triangulation or other partitioning of the plane is applied to the vertices."),kje),Ui),Cje),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,z4e),Pse),"Tree Construction Strategy"),"Whether a minimum spanning tree or a maximum spanning tree should be constructed."),yje),Ui),Aje),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,F4e),Pse),"Cost Function for Spanning Tree"),"The cost function is used in the creation of the spanning tree."),vje),Ui),hje),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,_se),Pse),"Root node for spanning tree construction"),"The identifier of the node that is preferred as the root of the spanning tree. If this is null, the first node is chosen."),null),Nk),nt),gt(Nt)))),Yi(t,_se,Dse,Lmt),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Dse),Pse),"Root selection for spanning tree"),"This sets the method used to select a root node for the construction of a spanning tree"),wje),Ui),lje),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,q4e),b3e),zct),"This option defines how the compaction is applied."),mje),Ui),cje),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,H4e),b3e),"Orthogonal Compaction"),"Restricts the translation of nodes to orthogonal directions in the compaction phase."),(Bt(),!1)),Pr),ir),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Q4e),Hct),"Upper limit for iterations of overlap removal"),null),Pe(64)),js),Lr),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,G4e),Hct),"Whether to run a supplementary scanline overlap check."),null),!0),Pr),ir),gt(Nt)))),git((new CN,t)),hrt((new pK,t))};var Mmt,mje,Amt,Nmt,_mt,Dmt,Lmt,Pmt,wje,Imt,vje,Rmt,yje,xje,kje,Oje;C(Mv,"SporeMetaDataProvider",856),T(1003,1,jf,CN),f.tf=function(t){git(t)};var $mt,Sje,jje,Tje,Bmt,Eje;C(Mv,"SporeOverlapRemovalOptions",1003),T(1004,1,{},gj),f.uf=function(){var t;return t=new RPe,t},f.vf=function(t){},C(Mv,"SporeOverlapRemovalOptions/SporeOverlapFactory",1004),T(531,23,{3:1,34:1,23:1,531:1,173:1,177:1},Pqe),f.bg=function(){return oWe(this)},f.og=function(){return oWe(this)};var SP,Cje=mn(Mv,"StructureExtractionStrategy",531,On,hAt,$Et),zmt;T(432,23,{3:1,34:1,23:1,432:1,173:1,177:1},U1e),f.bg=function(){return gKe(this)},f.og=function(){return gKe(this)};var Mje,zJ,Aje=mn(Mv,"TreeConstructionStrategy",432,On,sNt,BEt),Fmt;T(1435,1,Xr,$A),f.pg=function(t){return c(t,311),new wr},f.If=function(t,n){oqt(c(t,311),n)},C(Qct,"DelaunayTriangulationPhase",1435),T(1436,1,ln,W_e),f.Ad=function(t){qe(this.a,c(t,68).a)},C(Qct,"DelaunayTriangulationPhase/lambda$0$Type",1436),T(788,1,Xr,Fde),f.pg=function(t){return c(t,311),new wr},f.If=function(t,n){this.Ig(c(t,311),n)},f.Ig=function(t,n){var i,r,o;n.Tg("Minimum spanning tree construction",1),t.d?r=t.d.a:r=c(Xe(t.i,0),68).a,et(Ze(R(t,(rS(),_E))))?o=Tie(t.e,r,(i=t.b,i)):o=Tie(t.e,r,t.b),BVe(this,o,t),n.Ug()},C(Ise,"MinSTPhase",788),T(1438,788,Xr,TLe),f.Ig=function(t,n){var i,r,o,a;n.Tg("Maximum spanning tree construction",1),i=new K_e(t),t.d?o=t.d.c:o=c(Xe(t.i,0),68).c,et(Ze(R(t,(rS(),_E))))?a=Tie(t.e,o,(r=i,r)):a=Tie(t.e,o,i),BVe(this,a,t),n.Ug()},C(Ise,"MaxSTPhase",1438),T(1439,1,{},K_e),f.$e=function(t){return _8t(this.a,t)},C(Ise,"MaxSTPhase/lambda$0$Type",1439),T(1437,1,ln,Y_e),f.Ad=function(t){mjt(this.a,c(t,68))},C(Ise,"MinSTPhase/lambda$0$Type",1437),T(790,1,Xr,pj),f.pg=function(t){return c(t,311),new wr},f.If=function(t,n){wHt(this,c(t,311),n)},f.a=!1,C(Rse,"GrowTreePhase",790),T(791,1,ln,m0e),f.Ad=function(t){XIt(this.a,this.b,this.c,c(t,227))},C(Rse,"GrowTreePhase/lambda$0$Type",791),T(1440,1,Xr,T$),f.pg=function(t){return c(t,311),new wr},f.If=function(t,n){Azt(this,c(t,311),n)},C(Rse,"ShrinkTreeCompactionPhase",1440),T(789,1,ln,w0e),f.Ad=function(t){eUt(this.a,this.b,this.c,c(t,227))},C(Rse,"ShrinkTreeCompactionPhase/lambda$0$Type",789),T(389,23,{3:1,34:1,23:1,389:1},J1e);var Nje,Lue,_je=mn(U4e,"EdgeRoutingStrategy",389,On,cNt,zEt),qmt,Rw,zb,X9,Pue,V9,Hmt,jP,kd,Zv,SC;T(396,23,{3:1,34:1,23:1,396:1},sF);var Iue,Rue,$ue,Bue,Dje=mn(U4e,"VertiFlexLayoutPhases",396,On,cDt,FEt),Qmt;T(1099,207,kb,BPe),f.kf=function(t,n){var i,r,o,a,d,b,v,x,S,M,L;if(i=sUt(this,t),n.Tg(Oct,i.c.length),this.b=ue(he(ke(t,(Dn(),lh)))),et(Ze(ke(t,(q5(),Ije))))||J7((r=new g6((v0(),new wg(t))),r)),L=eHt(t),ii(t,(Qd(),SC),L),!L)throw J(new Wh(Act));for(a=new cn((!t.a&&(t.a=new Me(Mn,t,10,11)),t.a));a.e!=a.i.gc();){if(o=c(un(a),19),x=(!o.d&&(o.d=new Et(Ii,o,8,5)),o.d).i,x>1)throw J(new Wh("The given graph is not an acyclic tree!"));Cc(o,0),Nl(o,0)}for(Srt(this,L,0),d=0,v=new cn((!t.a&&(t.a=new Me(Mn,t,10,11)),t.a));v.e!=v.i.gc();)b=c(un(v),19),ii(b,jP,Pe(d)),d+=1;for(M=new G(i);M.a<M.c.c.length;)S=c(Q(M),43),S.If(t,n.dh(1));KUt(t),n.Ug()},f.b=0,C(U4e,"VertiFlexLayoutProvider",1099),T(858,1,jf,MN),f.tf=function(t){ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,J4e),""),"Fixed vertical position"),"The Y position that the node should be fixed at."),(q0(),us)),kr),gt((Th(),fr))))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,X4e),""),"Edge layout strategy"),"Strategy for the layout of the children. 'straight' for straight line drawings, 'bend' for a possible bend. When straight edges are prioritized the nodes will be reordered in order to guarantee that straight edges are possible. If bend points are enabled on the other hand, the given model order of the nodes is maintained and bend points are introduced to prevent edge node overlaps."),Lje),Ui),_je),gt(fr)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,V4e),""),"Layer distance"),"The distance to use between nodes of different layers if no vertical constraints are set."),50),us),kr),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,W4e),""),"Consider node model order"),"Consider node model as a secondary criterion when using straight line routing."),(Bt(),!0)),Pr),ir),gt(Nt)))),xrt((new bK,t))};var Gmt,Umt,Jmt,Lje,Xmt;C(K4e,"VertiFlexMetaDataProvider",858),T(1009,1,jf,bK),f.tf=function(t){xrt(t)};var zue,Vmt,Pje,Fue,Wmt,Ije,Rje,Kmt,W9;C(K4e,"VertiFlexOptions",1009),T(1010,1,{},E$),f.uf=function(){var t;return t=new BPe,t},f.vf=function(t){},C(K4e,"VertiFlexOptions/VertiflexFactory",1010),T(1450,1,Xr,Wy),f.pg=function(t){return c(t,19),null},f.If=function(t,n){wQt(this,c(t,19),n)},f.a=0,f.b=0,C(Gct,"NodeYPlacer",1450),T(557,23,{3:1,34:1,23:1,557:1,173:1,177:1},DFe),f.bg=function(){return cWe(this)},f.og=function(){return cWe(this)};var que,Ymt=mn(Gct,"NodeYPlacerStrategy",557,On,cAt,qEt),Zmt;T(824,1,Yn,xde),f.Le=function(t,n){return Yzt(this,c(t,19),c(n,19))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},f.a=!1,C($se,"NodeComparator",824),T(107,1,{107:1},xu),f.Ib=function(){return"X:"+this.c+",  Y:"+this.a},f.a=0,f.c=0,C($se,"OutlineNode",107),T(1451,1,Xr,C$),f.pg=function(t){return c(t,19),null},f.If=function(t,n){qUt(this,c(t,19),n)},f.a=!1,f.b=0,C($se,"RelativeXPlacer",1451),T(558,23,{3:1,34:1,23:1,558:1,173:1,177:1},_Fe),f.bg=function(){return lWe(this)},f.og=function(){return lWe(this)};var Hue,ewt=mn($se,"RelativeXPlacerStrategy",558,On,lAt,HEt),twt;T(1452,1,Xr,S$),f.pg=function(t){return c(t,19),null},f.If=function(t,n){EFt(this,c(t,19),n)},C(Uct,"AbsoluteXPlacer",1452),T(559,23,{3:1,34:1,23:1,559:1,173:1,177:1},sqe),f.bg=function(){return uWe(this)},f.og=function(){return uWe(this)};var Que,nwt=mn(Uct,"AbsoluteXPlacerStrategy",559,On,uAt,QEt),iwt;T(1454,1,Xr,GO),f.pg=function(t){return c(t,19),null},f.If=function(t,n){W$t(this,c(t,19),n)},C(Y4e,Jct,1454),T(498,23,{3:1,34:1,23:1,498:1,173:1,177:1},X1e),f.bg=function(){return jZe(this)},f.og=function(){return jZe(this)};var Gue,Uue,rwt=mn(Y4e,"EdgerouterStrategy",498,On,oNt,GEt),swt;T(1453,1,Xr,j$),f.pg=function(t){return c(t,19),null},f.If=function(t,n){_Bt(this,c(t,19),n)},C(Y4e,Xct,1453);var $je=Ki(tc,"IGraphElementVisitor");T(862,1,{528:1},kQe),f.Jg=function(t){var n;n=hVt(this,t),ec(n,c(Ut(this.b,t),105)),rJt(this,t,n)};var owt,cwt;C(Ux,"LayoutConfigurator",862);var inn=Ki(Ux,"LayoutConfigurator/IPropertyHolderOptionFilter");T(935,1,{837:1},O$),f.Lg=function(t,n){return L5(),!t.nf(n)},C(Ux,"LayoutConfigurator/lambda$0$Type",935),T(936,1,{2011:1},RA),f.Kg=function(t,n){return L5(),!t.nf(n)},C(Ux,"LayoutConfigurator/lambda$1$Type",936),T(937,1,{2011:1},BW),f.Kg=function(t,n){return zPe(t,n)},C(Ux,"LayoutConfigurator/lambda$2$Type",937),T(938,1,Jn,SRe),f.Mb=function(t){return iAt(this.a,this.b,c(t,2011))},C(Ux,"LayoutConfigurator/lambda$3$Type",938),T(860,1,{},M$),C(Ux,"RecursiveGraphLayoutEngine",860),T(194,63,H1,iLe,Wh),C(Ux,"UnsupportedConfigurationException",194),T(367,63,H1,Y4),C(Ux,"UnsupportedGraphException",367),T(756,1,{}),C(tc,"AbstractRandomListAccessor",756),T(403,756,{},DS),f.Mg=function(){return null},f.d=!0,f.e=!0,f.f=0,C(f9,"AlgorithmAssembler",403),T(1181,1,Jn,A$),f.Mb=function(t){return!!c(t,86)},C(f9,"AlgorithmAssembler/lambda$0$Type",1181),T(1182,1,{},Z_e),f.Kb=function(t){return U9t(this.a,c(t,86))},C(f9,"AlgorithmAssembler/lambda$1$Type",1182),T(1183,1,Jn,bj),f.Mb=function(t){return!!c(t,75)},C(f9,"AlgorithmAssembler/lambda$2$Type",1183),T(1184,1,ln,eDe),f.Ad=function(t){Fu(this.a,c(t,75))},C(f9,"AlgorithmAssembler/lambda$3$Type",1184),T(1185,1,ln,jRe),f.Ad=function(t){p7t(this.a,this.b,c(t,177))},C(f9,"AlgorithmAssembler/lambda$4$Type",1185),T(1311,1,Yn,N$),f.Le=function(t,n){return LAt(c(t,177),c(n,177))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(f9,"EnumBasedFactoryComparator",1311),T(75,756,{75:1},wr),f.Mg=function(){return new Or},f.a=0,C(f9,"LayoutProcessorConfiguration",75),T(1018,1,{528:1},bg),f.Jg=function(t){fD(uwt,new tDe(t))};var lwt,uwt,awt;C(Io,"DeprecatedLayoutOptionReplacer",1018),T(1019,1,ln,BA),f.Ad=function(t){FLt(c(t,176))},C(Io,"DeprecatedLayoutOptionReplacer/lambda$0$Type",1019),T(1020,1,ln,_$),f.Ad=function(t){uBt(c(t,176))},C(Io,"DeprecatedLayoutOptionReplacer/lambda$1$Type",1020),T(1021,1,{},tDe),f.Wd=function(t,n){d7t(this.a,c(t,149),c(n,42))},C(Io,"DeprecatedLayoutOptionReplacer/lambda$2$Type",1021),T(144,1,{697:1,144:1},mb),f.Fb=function(t){return abe(this,t)},f.Ng=function(){return this.b},f.Og=function(){return this.c},f.ve=function(){return this.e},f.Hb=function(){return Dg(this.c)},f.Ib=function(){return"Layout Algorithm: "+this.c};var rnn=C(Io,"LayoutAlgorithmData",144);T(271,1,{},b1),C(Io,"LayoutAlgorithmData/Builder",271),T(714,1,{528:1},zW),f.Jg=function(t){SGe(t)},C(Io,"LayoutAlgorithmResolver",714),T(236,1,{697:1,236:1},O5),f.Fb=function(t){return oe(t,236)?Ot(this.b,c(t,236).b):!1},f.Ng=function(){return this.a},f.Og=function(){return this.b},f.ve=function(){return this.d},f.Hb=function(){return Dg(this.b)},f.Ib=function(){return"Layout Type: "+this.b},C(Io,"LayoutCategoryData",236),T(358,1,{},Lp),C(Io,"LayoutCategoryData/Builder",358),T(869,1,{},tit);var Jue;C(Io,"LayoutMetaDataService",869),T(870,1,{},Tqe),C(Io,"LayoutMetaDataService/Registry",870),T(478,1,{478:1},Du),C(Io,"LayoutMetaDataService/Registry/Triple",478),T(871,1,Wx,Qf),f.Pg=function(){return new as},C(Io,"LayoutMetaDataService/lambda$0$Type",871),T(872,1,Av,D$),f.Qg=function(t){return Ms(c(t,8))},C(Io,"LayoutMetaDataService/lambda$1$Type",872),T(881,1,Wx,L$),f.Pg=function(){return new Fe},C(Io,"LayoutMetaDataService/lambda$10$Type",881),T(882,1,Av,P$),f.Qg=function(t){return new Fl(c(t,13))},C(Io,"LayoutMetaDataService/lambda$11$Type",882),T(883,1,Wx,I$),f.Pg=function(){return new Ai},C(Io,"LayoutMetaDataService/lambda$12$Type",883),T(884,1,Av,UO),f.Qg=function(t){return A_(c(t,66))},C(Io,"LayoutMetaDataService/lambda$13$Type",884),T(885,1,Wx,R$),f.Pg=function(){return new Or},C(Io,"LayoutMetaDataService/lambda$14$Type",885),T(886,1,Av,mj),f.Qg=function(t){return aee(c(t,47))},C(Io,"LayoutMetaDataService/lambda$15$Type",886),T(887,1,Wx,$$),f.Pg=function(){return new Ld},C(Io,"LayoutMetaDataService/lambda$16$Type",887),T(888,1,Av,FW),f.Qg=function(t){return Dq(c(t,47))},C(Io,"LayoutMetaDataService/lambda$17$Type",888),T(889,1,Wx,wj),f.Pg=function(){return new FK},C(Io,"LayoutMetaDataService/lambda$18$Type",889),T(890,1,Av,zA),f.Qg=function(t){return eFe(c(t,143))},C(Io,"LayoutMetaDataService/lambda$19$Type",890),T(873,1,Wx,B$),f.Pg=function(){return new nu},C(Io,"LayoutMetaDataService/lambda$2$Type",873),T(874,1,Av,z$),f.Qg=function(t){return new Ez(c(t,79))},C(Io,"LayoutMetaDataService/lambda$3$Type",874),T(875,1,Wx,F$),f.Pg=function(){return new Vj},C(Io,"LayoutMetaDataService/lambda$4$Type",875),T(876,1,Av,FA),f.Qg=function(t){return new kZ(c(t,125))},C(Io,"LayoutMetaDataService/lambda$5$Type",876),T(877,1,Wx,qA),f.Pg=function(){return new X4},C(Io,"LayoutMetaDataService/lambda$6$Type",877),T(878,1,Av,HA),f.Qg=function(t){return new b0e(c(t,100))},C(Io,"LayoutMetaDataService/lambda$7$Type",878),T(879,1,Wx,q$),f.Pg=function(){return new O4},C(Io,"LayoutMetaDataService/lambda$8$Type",879),T(880,1,Av,QA),f.Qg=function(t){return new NJe(c(t,380))},C(Io,"LayoutMetaDataService/lambda$9$Type",880);var Xue=Ki(bL,"IProperty");T(21,1,{34:1,697:1,21:1,149:1},it),f.Dd=function(t){return Djt(this,c(t,149))},f.Fb=function(t){return oe(t,21)?Ot(this.f,c(t,21).f):oe(t,149)&&Ot(this.f,c(t,149).Og())},f.Rg=function(){var t;if(oe(this.b,4)){if(t=$we(this.b),t==null)throw J(new oo(Yct+this.f+"'. Make sure it's type is registered with the "+(j1(KP),KP.k)+Z4e));return t}else return this.b},f.Ng=function(){return this.d},f.Og=function(){return this.f},f.ve=function(){return this.i},f.Hb=function(){return Dg(this.f)},f.Ib=function(){return"Layout Option: "+this.f},C(Io,"LayoutOptionData",21),T(25,1,{},tt),C(Io,"LayoutOptionData/Builder",25),T(161,23,{3:1,34:1,23:1,161:1},f_);var ch,K1,fr,Nt,Yg,$h=mn(Io,"LayoutOptionData/Target",161,On,YDt,UEt),fwt;T(287,23,{3:1,34:1,23:1,287:1},r5);var Pr,us,Ui,Ak,js,Bh,Nk,Bje,hwt=mn(Io,"LayoutOptionData/Type",287,On,fPt,JEt),dwt,jC,zje;T(120,1,{120:1},c5,pf,mq),f.Fb=function(t){var n;return t==null||!oe(t,120)?!1:(n=c(t,120),dc(this.c,n.c)&&dc(this.d,n.d)&&dc(this.b,n.b)&&dc(this.a,n.a))},f.Hb=function(){return jH(W(V(Br,1),Lt,1,5,[this.c,this.d,this.b,this.a]))},f.Ib=function(){return"Rect[x="+this.c+",y="+this.d+",w="+this.b+",h="+this.a+"]"},f.a=0,f.b=0,f.c=0,f.d=0,C(jL,"ElkRectangle",120),T(8,1,{3:1,4:1,8:1,419:1},as,wee,$e,Cs),f.Fb=function(t){return HXe(this,t)},f.Hb=function(){return o5(this.a)+oFt(o5(this.b))},f.ag=function(t){var n,i,r,o;for(r=0;r<t.length&&AWe((en(r,t.length),t.charCodeAt(r)),Fot);)++r;for(n=t.length;n>0&&AWe((en(n-1,t.length),t.charCodeAt(n-1)),qot);)--n;if(r>=n)throw J(new qt("The given string does not contain any numbers."));if(o=xv((fs(r,n,t.length),t.substr(r,n-r)),`,|;|\r|
`),o.length!=2)throw J(new qt("Exactly two numbers are expected, "+o.length+" were found."));try{this.a=gv(pv(o[0])),this.b=gv(pv(o[1]))}catch(a){throw a=vr(a),oe(a,133)?(i=a,J(new qt(Hot+i))):J(a)}},f.Ib=function(){return"("+this.a+","+this.b+")"},f.a=0,f.b=0;var Vr=C(jL,"KVector",8);T(79,66,{3:1,4:1,22:1,32:1,56:1,18:1,66:1,16:1,79:1,419:1},nu,Ez,LBe),f.Nc=function(){return TRt(this)},f.ag=function(t){var n,i,r,o,a,d;r=xv(t,`,|;|\\(|\\)|\\[|\\]|\\{|\\}| |	|
`),Ou(this);try{for(i=0,a=0,o=0,d=0;i<r.length;)r[i]!=null&&pv(r[i]).length>0&&(a%2==0?o=gv(r[i]):d=gv(r[i]),a>0&&a%2!=0&&ei(this,new $e(o,d)),++a),++i}catch(b){throw b=vr(b),oe(b,133)?(n=b,J(new qt("The given string does not match the expected format for vectors."+n))):J(b)}},f.Ib=function(){var t,n,i;for(t=new Lu("("),n=_n(this,0);n.b!=n.d.c;)i=c(An(n),8),Zn(t,i.a+","+i.b),n.b!=n.d.c&&(t.a+="; ");return(t.a+=")",t).a};var Fje=C(jL,"KVectorChain",79);T(259,23,{3:1,34:1,23:1,259:1},m7);var Vue,FJ,qJ,TP,EP,HJ,qje=mn(Xc,"Alignment",259,On,MLt,XEt),gwt;T(984,1,jf,AN),f.tf=function(t){Cit(t)};var Hje,Wue,pwt,Qje,Gje,bwt,Uje,mwt,wwt,Jje,Xje,vwt;C(Xc,"BoxLayouterOptions",984),T(985,1,{},GA),f.uf=function(){var t;return t=new Q$,t},f.vf=function(t){},C(Xc,"BoxLayouterOptions/BoxFactory",985),T(300,23,{3:1,34:1,23:1,300:1},w7);var TC,Kue,EC,CC,MC,Yue,Zue=mn(Xc,"ContentAlignment",300,On,CLt,VEt),ywt;T(696,1,jf,NN),f.tf=function(t){ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,elt),""),"Layout Algorithm"),"Select a specific layout algorithm."),(q0(),Nk)),nt),gt((Th(),Nt))))),ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,tlt),""),"Resolved Layout Algorithm"),"Meta data associated with the selected algorithm."),Bh),rnn),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,P3e),""),"Alignment"),"Alignment of the selected node relative to other nodes; the exact meaning depends on the used algorithm."),Vje),Ui),qje),gt(fr)))),ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,ZS),""),"Aspect Ratio"),"The desired aspect ratio of the drawing, that is the quotient of width by height."),us),kr),gt(Nt)))),ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,n5e),""),"Bend Points"),"A fixed list of bend points for the edge. This is used by the 'Fixed Layout' algorithm to specify a pre-defined routing for an edge. The vector chain must include the source point, any bend points, and the target point, so it must have at least two points."),Bh),Fje),gt(ch)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,bG),""),"Content Alignment"),"Specifies how the content of a node are aligned. Each node can individually control the alignment of its contents. I.e. if a node should be aligned top left in its parent node, the parent node should specify that option."),Kje),Ak),Zue),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,AL),""),"Debug Mode"),"Whether additional debug information shall be generated."),(Bt(),!1)),Pr),ir),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,hse),""),"Direction"),"Overall direction of edges: horizontal (right / left) or vertical (down / up)."),Yje),Ui),_C),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,ML),""),"Edge Routing"),"What kind of edge routing style should be applied for the content of a parent node. Algorithms may also set this option to single edges in order to mark them as splines. The bend point list of edges with this option set to SPLINES must be interpreted as control points for a piecewise cubic spline."),t7e),Ui),hae),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,e5e),""),"Expand Nodes"),"If active, nodes are expanded to fill the area of their parent."),!1),Pr),ir),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,pG),""),"Hierarchy Handling"),"Determines whether separate layout runs are triggered for different compound nodes in a hierarchical graph. Setting a node's hierarchy handling to `INCLUDE_CHILDREN` will lay out that node and all of its descendants in a single layout run, until a descendant is encountered which has its hierarchy handling set to `SEPARATE_CHILDREN`. In general, `SEPARATE_CHILDREN` will ensure that a new layout run is triggered for a node with that setting. Including multiple levels of hierarchy in a single layout run may allow cross-hierarchical edges to be laid out properly. If the root node is set to `INHERIT` (or not set at all), the default behavior is `SEPARATE_CHILDREN`."),i7e),Ui),U7e),_i(Nt,W(V($h,1),_e,161,0,[fr]))))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,gw),""),"Padding"),"The padding to be left to a parent element's border when placing child elements. This can also serve as an output option of a layout algorithm if node size calculation is setup appropriately."),g7e),Bh),Jke),_i(Nt,W(V($h,1),_e,161,0,[fr]))))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,e9),""),"Interactive"),"Whether the algorithm should be run in interactive mode for the content of a parent node. What this means exactly depends on how the specific algorithm interprets this option. Usually in the interactive mode algorithms try to modify the current layout as little as possible."),!1),Pr),ir),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,wG),""),"interactive Layout"),"Whether the graph should be changeable interactively and by setting constraints"),!1),Pr),ir),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,t9),""),"Omit Node Micro Layout"),"Node micro layout comprises the computation of node dimensions (if requested), the placement of ports and their labels, and the placement of node labels. The functionality is implemented independent of any specific layout algorithm and shouldn't have any negative impact on the layout algorithm's performance itself. Yet, if any unforeseen behavior occurs, this option allows to deactivate the micro layout."),!1),Pr),ir),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,KQ),""),"Port Constraints"),"Defines constraints of the position of the ports of a node."),v7e),Ui),V7e),gt(fr)))),ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,mG),""),"Position"),"The position of a node, port, or label. This is used by the 'Fixed Layout' algorithm to specify a pre-defined position."),Bh),Vr),_i(fr,W(V($h,1),_e,161,0,[Yg,K1]))))),ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,wL),""),"Priority"),"Defines the priority of an object; its meaning depends on the specific layout algorithm and the context where it is used."),js),Lr),_i(fr,W(V($h,1),_e,161,0,[ch]))))),ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,WQ),""),"Randomization Seed"),"Seed used for pseudo-random number generators to control the layout algorithm. If the value is 0, the seed shall be determined pseudo-randomly (e.g. from the system time)."),js),Lr),gt(Nt)))),ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,rE),""),"Separate Connected Components"),"Whether each connected component should be processed separately."),Pr),ir),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,U3e),""),"Junction Points"),"This option is not used as option, but as output of the layout algorithms. It is attached to edges and determines the points where junction symbols should be drawn in order to represent hyperedges with orthogonal routing. Whether such points are computed depends on the chosen layout algorithm and edge routing style. The points are put into the vector chain with no specific order."),o7e),Bh),Fje),gt(ch)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,W3e),""),"Comment Box"),"Whether the node should be regarded as a comment box instead of a regular node. In that case its placement should be similar to how labels are handled. Any edges incident to a comment box specify to which graph elements the comment is related."),!1),Pr),ir),gt(fr)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,K3e),""),"Hypernode"),"Whether the node should be handled as a hypernode."),!1),Pr),ir),gt(fr)))),ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,Ntn),""),"Label Manager"),"Label managers can shorten labels upon a layout algorithm's request."),Bh),ann),_i(Nt,W(V($h,1),_e,161,0,[K1]))))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,nlt),""),"Softwrapping Fuzziness"),"Determines the amount of fuzziness to be used when performing softwrapping on labels. The value expresses the percent of overhang that is permitted for each line. If the next line would take up less space than this threshold, it is appended to the current line instead of being placed in a new line."),0),us),kr),gt(K1)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,pse),""),"Margins"),"Margins define additional space around the actual bounds of a graph element. For instance, ports or labels being placed on the outside of a node's border might introduce such a margin. The margin is used to guarantee non-overlap of other graph elements with those ports or labels."),c7e),Bh),Uke),gt(fr)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,D3e),""),"No Layout"),"No layout is done for the associated element. This is used to mark parts of a diagram to avoid their inclusion in the layout graph, or to mark parts of the layout graph to prevent layout engines from processing them. If you wish to exclude the contents of a compound node from automatic layout, while the node itself is still considered on its own layer, use the 'Fixed Layout' algorithm for that node."),!1),Pr),ir),_i(fr,W(V($h,1),_e,161,0,[ch,Yg,K1]))))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,ilt),""),"Scale Factor"),"The scaling factor to be applied to the corresponding node in recursive layout. It causes the corresponding node's size to be adjusted, and its ports and labels to be sized and placed accordingly after the layout of that node has been determined (and before the node itself and its siblings are arranged). The scaling is not reverted afterwards, so the resulting layout graph contains the adjusted size and position data. This option is currently not supported if 'Layout Hierarchy' is set."),1),us),kr),gt(fr)))),ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,rlt),""),"Child Area Width"),"The width of the area occupied by the laid out children of a node."),us),kr),gt(Nt)))),ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,slt),""),"Child Area Height"),"The height of the area occupied by the laid out children of a node."),us),kr),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,yL),""),Vct),"Turns topdown layout on and off. If this option is enabled, hierarchical layout will be computed first for the root node and then for its children recursively. Layouts are then scaled down to fit the area provided by their parents. Graphs must follow a certain structure for topdown layout to work properly. {@link TopdownNodeTypes.PARALLEL_NODE} nodes must have children of type {@link TopdownNodeTypes.HIERARCHICAL_NODE} and must define {@link topdown.hierarchicalNodeWidth} and {@link topdown.hierarchicalNodeAspectRatio} for their children. Furthermore they need to be laid out using an algorithm that is a {@link TopdownLayoutProvider}. Hierarchical nodes can also be parents of other hierarchical nodes and can optionally use a {@link TopdownSizeApproximator} to dynamically set sizes during topdown layout. In this case {@link topdown.hierarchicalNodeWidth} and {@link topdown.hierarchicalNodeAspectRatio} should be set on the node itself rather than the parent. The values are then used by the size approximator as base values. Hierarchical nodes require the layout option {@link nodeSize.fixedGraphSize} to be true to prevent the algorithm used there from resizing the hierarchical node. This option is not supported if 'Hierarchy Handling' is set to 'INCLUDE_CHILDREN'"),!1),Pr),ir),gt(Nt)))),Yi(t,yL,pw,null),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,olt),""),"Animate"),"Whether the shift from the old layout to the new computed layout shall be animated."),!0),Pr),ir),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,clt),""),"Animation Time Factor"),"Factor for computation of animation time. The higher the value, the longer the animation time. If the value is 0, the resulting time is always equal to the minimum defined by 'Minimal Animation Time'."),Pe(100)),js),Lr),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,llt),""),"Layout Ancestors"),"Whether the hierarchy levels on the path from the selected element to the root of the diagram shall be included in the layout process."),!1),Pr),ir),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,ult),""),"Maximal Animation Time"),"The maximal time for animations, in milliseconds."),Pe(4e3)),js),Lr),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,alt),""),"Minimal Animation Time"),"The minimal time for animations, in milliseconds."),Pe(400)),js),Lr),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,flt),""),"Progress Bar"),"Whether a progress bar shall be displayed during layout computations."),!1),Pr),ir),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,hlt),""),"Validate Graph"),"Whether the graph shall be validated before any layout algorithm is applied. If this option is enabled and at least one error is found, the layout process is aborted and a message is shown to the user."),!1),Pr),ir),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,dlt),""),"Validate Options"),"Whether layout options shall be validated before any layout algorithm is applied. If this option is enabled and at least one error is found, the layout process is aborted and a message is shown to the user."),!0),Pr),ir),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,glt),""),"Zoom to Fit"),"Whether the zoom level shall be set to view the whole diagram after layout."),!1),Pr),ir),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,t5e),"box"),"Box Layout Mode"),"Configures the packing mode used by the {@link BoxLayoutProvider}. If SIMPLE is not required (neither priorities are used nor the interactive mode), GROUP_DEC can improve the packing and decrease the area. GROUP_MIXED and GROUP_INC may, in very specific scenarios, work better."),Wje),Ui),lTe),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,plt),"json"),"Shape Coords"),"For layouts transferred into JSON graphs, specify the coordinate system to be used for nodes, ports, and labels of nodes and ports."),s7e),Ui),Y7e),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,blt),"json"),"Edge Coords"),"For layouts transferred into JSON graphs, specify the coordinate system to be used for edge route points and edge labels."),r7e),Ui),D7e),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,x3e),Lh),"Comment Comment Spacing"),"Spacing to be preserved between a comment box and other comment boxes connected to the same node. The space left between comment boxes of different nodes is controlled by the node-node spacing."),10),us),kr),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,k3e),Lh),"Comment Node Spacing"),"Spacing to be preserved between a node and its connected comment boxes. The space left between a node and the comments of another node is controlled by the node-node spacing."),10),us),kr),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,O3e),Lh),"Components Spacing"),"Spacing to be preserved between pairs of connected components. This option is only relevant if 'separateConnectedComponents' is activated."),20),us),kr),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,S3e),Lh),"Edge Spacing"),"Spacing to be preserved between any two edges. Note that while this can somewhat easily be satisfied for the segments of orthogonally drawn edges, it is harder for general polylines or splines."),10),us),kr),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Ore),Lh),"Edge Label Spacing"),"The minimal distance to be preserved between a label and the edge it is associated with. Note that the placement of a label is influenced by the 'edgelabels.placement' option."),2),us),kr),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,fse),Lh),"Edge Node Spacing"),"Spacing to be preserved between nodes and edges."),10),us),kr),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,j3e),Lh),"Label Spacing"),"Determines the amount of space to be left between two labels of the same graph element."),0),us),kr),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,C3e),Lh),"Label Node Spacing"),"Spacing to be preserved between labels and the border of node they are associated with. Note that the placement of a label is influenced by the 'nodelabels.placement' option."),5),us),kr),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,T3e),Lh),"Horizontal spacing between Label and Port"),"Horizontal spacing to be preserved between labels and the ports they are associated with. Note that the placement of a label is influenced by the 'portlabels.placement' option."),1),us),kr),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,E3e),Lh),"Vertical spacing between Label and Port"),"Vertical spacing to be preserved between labels and the ports they are associated with. Note that the placement of a label is influenced by the 'portlabels.placement' option."),1),us),kr),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,dw),Lh),"Node Spacing"),"The minimal distance to be preserved between each two nodes."),20),us),kr),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,M3e),Lh),"Node Self Loop Spacing"),"Spacing to be preserved between a node and its self loops."),10),us),kr),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,A3e),Lh),"Port Spacing"),"Spacing between pairs of ports of the same node."),10),us),kr),_i(Nt,W(V($h,1),_e,161,0,[fr]))))),ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,N3e),Lh),"Individual Spacing"),"Allows to specify individual spacing values for graph elements that shall be different from the value specified for the element's parent."),Bh),b2t),_i(fr,W(V($h,1),_e,161,0,[ch,Yg,K1]))))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Z3e),Lh),"Additional Port Space"),"Additional space around the sets of ports on each node side. For each side of a node, this option can reserve additional space before and after the ports on each side. For example, a top spacing of 20 makes sure that the first port on the western and eastern side is 20 units away from the northern border."),M7e),Bh),Uke),gt(Nt)))),ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,gse),vlt),"Layout Partition"),"Partition to which the node belongs. This requires Layout Partitioning to be active. Nodes with lower partition IDs will appear to the left of nodes with higher partition IDs (assuming a left-to-right layout direction)."),js),Lr),_i(Nt,W(V($h,1),_e,161,0,[fr]))))),Yi(t,gse,dse,_wt),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,dse),vlt),"Layout Partitioning"),"Whether to activate partitioned layout. This will allow to group nodes through the Layout Partition option. a pair of nodes with different partition indices is then placed such that the node with lower index is placed to the left of the other node (with left-to-right layout direction). Depending on the layout algorithm, this may only be guaranteed to work if all nodes have a layout partition configured, or at least if edges that cross partitions are not part of a partition-crossing cycle."),p7e),Pr),ir),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,$3e),ylt),"Node Label Padding"),"Define padding for node labels that are placed inside of a node."),u7e),Bh),Jke),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,i9),ylt),"Node Label Placement"),"Hints for where node labels are to be placed; if empty, the node label's position is not modified."),a7e),Ak),Ws),_i(fr,W(V($h,1),_e,161,0,[K1]))))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,F3e),TG),"Port Alignment"),"Defines the default port distribution for a node. May be overridden for each side individually."),m7e),Ui),IC),gt(fr)))),ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,q3e),TG),"Port Alignment (North)"),"Defines how ports on the northern side are placed, overriding the node's general port alignment."),Ui),IC),gt(fr)))),ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,H3e),TG),"Port Alignment (South)"),"Defines how ports on the southern side are placed, overriding the node's general port alignment."),Ui),IC),gt(fr)))),ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,Q3e),TG),"Port Alignment (West)"),"Defines how ports on the western side are placed, overriding the node's general port alignment."),Ui),IC),gt(fr)))),ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,G3e),TG),"Port Alignment (East)"),"Defines how ports on the eastern side are placed, overriding the node's general port alignment."),Ui),IC),gt(fr)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Jx),qse),"Node Size Constraints"),"What should be taken into account when calculating a node's size. Empty size constraints specify that a node's size is already fixed and should not be changed."),f7e),Ak),BC),gt(fr)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,sk),qse),"Node Size Options"),"Options modifying the behavior of the size constraints set on a node. Each member of the set specifies something that should be taken into account when calculating node sizes. The empty set corresponds to no further modifications."),d7e),Ak),Z7e),gt(fr)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,ok),qse),"Node Size Minimum"),"The minimal size to which a node can be reduced."),h7e),Bh),Vr),gt(fr)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,n9),qse),"Fixed Graph Size"),"By default, the fixed layout provider will enlarge a graph until it is large enough to contain its children. If this option is set, it won't do so."),!1),Pr),ir),gt(Nt)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,X3e),ase),"Edge Label Placement"),"Gives a hint on where to put edge labels."),Zje),Ui),L7e),gt(K1)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,vL),ase),"Inline Edge Labels"),"If true, an edge label is placed directly on its edge. May only apply to center edge labels. This kind of label placement is only advisable if the label's rendering is such that it is not crossed by its edge and thus stays legible."),!1),Pr),ir),gt(K1)))),ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,_tn),"font"),"Font Name"),"Font name used for a label."),Nk),nt),gt(K1)))),ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,mlt),"font"),"Font Size"),"Font size used for a label."),js),Lr),gt(K1)))),ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,Y3e),Hse),"Port Anchor Offset"),"The offset to the port position where connections shall be attached."),Bh),Vr),gt(Yg)))),ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,V3e),Hse),"Port Index"),"The index of a port in the fixed order around a node. The order is assumed as clockwise, starting with the leftmost port on the top side. This option must be set if 'Port Constraints' is set to FIXED_ORDER and no specific positions are given for the ports. Additionally, the option 'Port Side' must be defined in this case."),js),Lr),gt(Yg)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,L3e),Hse),"Port Side"),"The side of a node on which a port is situated. This option must be set if 'Port Constraints' is set to FIXED_SIDE or FIXED_ORDER and no specific positions are given for the ports."),k7e),Ui),$s),gt(Yg)))),ft(t,new it(ut(lt(at(rt(ct(st(ot(new tt,_3e),Hse),"Port Border Offset"),"The offset of ports on the node border. With a positive offset the port is moved outside of the node, while with a negative offset the port is moved towards the inside. An offset of 0 means that the port is placed directly on the node border, i.e. if the port side is north, the port's south border touches the nodes's north border; if the port side is east, the port's west border touches the nodes's east border; if the port side is south, the port's north border touches the node's south border; if the port side is west, the port's east border touches the node's west border."),us),kr),gt(Yg)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,r9),s5e),"Port Label Placement"),"Decides on a placement method for port labels; if empty, the node label's position is not modified."),y7e),Ak),KJ),gt(fr)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,B3e),s5e),"Port Labels Next to Port"),"Use 'portLabels.placement': NEXT_TO_PORT_OF_POSSIBLE."),!1),Pr),ir),gt(fr)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,z3e),s5e),"Treat Port Labels as Group"),"If this option is true (default), the labels of a port will be treated as a group when it comes to centering them next to their port. If this option is false, only the first label will be centered next to the port, with the others being placed below. This only applies to labels of eastern and western ports and will have no effect if labels are not placed next to their port."),!0),Pr),ir),gt(fr)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,zse),d9),"Number of size categories"),"Defines the number of categories to use for the FIXED_INTEGER_RATIO_BOXES size approximator."),Pe(3)),js),Lr),gt(Nt)))),Yi(t,zse,Fse,Qwt),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,i5e),d9),"Weight of a node containing children for determining the graph size"),"When determining the graph size for the size categorisation, this value determines how many times a node containing children is weighted more than a simple node. For example setting this value to four would result in a graph containing a simple node and a hierarchical node to be counted as having a size of five."),Pe(4)),js),Lr),gt(Nt)))),Yi(t,i5e,zse,null),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,xL),d9),"Topdown Scale Factor"),"The scaling factor to be applied to the nodes laid out within the node in recursive topdown layout. The difference to 'Scale Factor' is that the node itself is not scaled. This value has to be set on hierarchical nodes."),1),us),kr),gt(Nt)))),Yi(t,xL,pw,Fwt),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,Fse),d9),"Topdown Size Approximator"),"The size approximator to be used to set sizes of hierarchical nodes during topdown layout. The default value is null, which results in nodes keeping whatever size is defined for them e.g. through parent parallel node or by manually setting the size."),null),Bh),snn),gt(fr)))),Yi(t,Fse,pw,qwt),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,kL),d9),"Topdown Hierarchical Node Width"),"The fixed size of a hierarchical node when using topdown layout. If this value is set on a parallel node it applies to its children, when set on a hierarchical node it applies to the node itself."),150),us),kr),_i(Nt,W(V($h,1),_e,161,0,[fr]))))),Yi(t,kL,pw,null),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,OL),d9),"Topdown Hierarchical Node Aspect Ratio"),"The fixed aspect ratio of a hierarchical node when using topdown layout. Default is 1/sqrt(2). If this value is set on a parallel node it applies to its children, when set on a hierarchical node it applies to the node itself."),1.414),us),kr),_i(Nt,W(V($h,1),_e,161,0,[fr]))))),Yi(t,OL,pw,null),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,pw),d9),"Topdown Node Type"),"The different node types used for topdown layout. If the node type is set to {@link TopdownNodeTypes.PARALLEL_NODE} the algorithm must be set to a {@link TopdownLayoutProvider} such as {@link TopdownPacking}. The {@link nodeSize.fixedGraphSize} option is technically only required for hierarchical nodes."),null),Ui),tTe),gt(fr)))),Yi(t,pw,n9,null),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,r5e),d9),"Topdown Scale Cap"),"Determines the upper limit for the topdown scale factor. The default value is 1.0 which ensures that nested children never end up appearing larger than their parents in terms of unit sizes such as the font size. If the limit is larger, nodes will fully utilize the available space, but it is counteriniuitive for inner nodes to have a larger scale than outer nodes."),1),us),kr),gt(Nt)))),Yi(t,r5e,pw,zwt),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,I3e),xlt),"Activate Inside Self Loops"),"Whether this node allows to route self loops inside of it instead of around it. If set to true, this will make the node a compound node if it isn't already, and will require the layout algorithm to support compound nodes with hierarchical ports."),!1),Pr),ir),gt(fr)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,R3e),xlt),"Inside Self Loop"),"Whether a self loop should be routed inside a node instead of around that node."),!1),Pr),ir),gt(ch)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,J3e),"edge"),"Edge Thickness"),"The thickness of an edge. This is a hint on the line width used to draw an edge, possibly requiring more space to be reserved for it."),1),us),kr),gt(ch)))),ft(t,new it(ut(lt(at(vt(rt(ct(st(ot(new tt,wlt),"edge"),"Edge Type"),"The type of an edge. This is usually used for UML class diagrams, where associations must be handled differently from generalizations."),n7e),Ui),z7e),gt(ch)))),l7(t,new O5(n7(y6(v6(new Lp,Qt),"Layered"),'The layer-based method was introduced by Sugiyama, Tagawa and Toda in 1981. It emphasizes the direction of edges by pointing as many edges as possible into the same direction. The nodes are arranged in layers, which are sometimes called "hierarchies", and then reordered such that the number of edge crossings is minimized. Afterwards, concrete coordinates are computed for the nodes and edge bend points.'))),l7(t,new O5(n7(y6(v6(new Lp,"org.eclipse.elk.orthogonal"),"Orthogonal"),`Orthogonal methods that follow the "topology-shape-metrics" approach by Batini, Nardelli and Tamassia '86. The first phase determines the topology of the drawing by applying a planarization technique, which results in a planar representation of the graph. The orthogonal shape is computed in the second phase, which aims at minimizing the number of edge bends, and is called orthogonalization. The third phase leads to concrete coordinates for nodes and edge bend points by applying a compaction method, thus defining the metrics.`))),l7(t,new O5(n7(y6(v6(new Lp,il),"Force"),"Layout algorithms that follow physical analogies by simulating a system of attractive and repulsive forces. The first successful method of this kind was proposed by Eades in 1984."))),l7(t,new O5(n7(y6(v6(new Lp,"org.eclipse.elk.circle"),"Circle"),"Circular layout algorithms emphasize cycles or biconnected components of a graph by arranging them in circles. This is useful if a drawing is desired where such components are clearly grouped, or where cycles are shown as prominent OPTIONS of the graph."))),l7(t,new O5(n7(y6(v6(new Lp,h4e),"Tree"),"Specialized layout methods for trees, i.e. acyclic graphs. The regular structure of graphs that have no undirected cycles can be emphasized using an algorithm of this type."))),l7(t,new O5(n7(y6(v6(new Lp,"org.eclipse.elk.planar"),"Planar"),"Algorithms that require a planar or upward planar graph. Most of these algorithms are theoretically interesting, but not practically usable."))),l7(t,new O5(n7(y6(v6(new Lp,Oa),"Radial"),"Radial layout algorithms usually position the nodes of the graph on concentric circles."))),hit((new JB,t)),Cit((new AN,t)),Rnt((new XB,t))};var _k,xwt,Vje,K9,kwt,Owt,Wje,ey,ty,Swt,CP,Kje,MP,Fb,Yje,QJ,eae,Zje,e7e,t7e,jwt,n7e,Twt,j3,i7e,Ewt,AP,tae,AC,nae,Cwt,r7e,Mwt,s7e,T3,o7e,Y1,c7e,l7e,u7e,E3,a7e,qb,f7e,ny,C3,h7e,lp,d7e,GJ,NC,zh,g7e,Awt,p7e,Nwt,_wt,b7e,m7e,iae,rae,sae,oae,w7e,fu,Y9,v7e,cae,lae,iy,y7e,x7e,M3,k7e,Dk,NP,uae,ry,Dwt,aae,Lwt,Pwt,Iwt,Rwt,O7e,S7e,Lk,j7e,UJ,T7e,E7e,lh,$wt,C7e,M7e,A7e,Z9,sy,e8,Pk,Bwt,zwt,JJ,Fwt,XJ,qwt,Hwt,Qwt,Gwt;C(Xc,"CoreOptions",696),T(87,23,{3:1,34:1,23:1,87:1},h_);var Fh,go,yo,qh,Ca,_C=mn(Xc,"Direction",87,On,$Dt,WEt),Uwt;T(280,23,{3:1,34:1,23:1,280:1},oF);var VJ,_P,N7e,_7e,D7e=mn(Xc,"EdgeCoords",280,On,lDt,KEt),Jwt;T(281,23,{3:1,34:1,23:1,281:1},qY);var t8,oy,n8,L7e=mn(Xc,"EdgeLabelPlacement",281,On,l_t,YEt),Xwt;T(225,23,{3:1,34:1,23:1,225:1},cF);var i8,DP,Ik,fae,hae=mn(Xc,"EdgeRouting",225,On,uDt,ZEt),Vwt;T(328,23,{3:1,34:1,23:1,328:1},v7);var P7e,I7e,R7e,$7e,dae,B7e,z7e=mn(Xc,"EdgeType",328,On,ELt,eCt),Wwt;T(982,1,jf,JB),f.tf=function(t){hit(t)};var F7e,q7e,H7e,Q7e,Kwt,G7e,DC;C(Xc,"FixedLayouterOptions",982),T(983,1,{},H$),f.uf=function(){var t;return t=new U$,t},f.vf=function(t){},C(Xc,"FixedLayouterOptions/FixedFactory",983),T(348,23,{3:1,34:1,23:1,348:1},HY);var Zg,WJ,LC,U7e=mn(Xc,"HierarchyHandling",348,On,a_t,tCt),Ywt,snn=Ki(Xc,"ITopdownSizeApproximator");T(293,23,{3:1,34:1,23:1,293:1},lF);var n1,up,LP,PP,Zwt=mn(Xc,"LabelSide",293,On,aDt,nCt),e2t;T(96,23,{3:1,34:1,23:1,96:1},lx);var Z1,Nf,Ka,_f,Vu,Df,Ya,i1,Lf,Ws=mn(Xc,"NodeLabelPlacement",96,On,_Pt,iCt),t2t;T(260,23,{3:1,34:1,23:1,260:1},d_);var J7e,PC,ap,X7e,IP,IC=mn(Xc,"PortAlignment",260,On,ZDt,rCt),n2t;T(103,23,{3:1,34:1,23:1,103:1},y7);var Hb,xc,r1,r8,Hh,fp,V7e=mn(Xc,"PortConstraints",103,On,ALt,sCt),i2t;T(282,23,{3:1,34:1,23:1,282:1},x7);var RC,$C,eg,RP,hp,Rk,KJ=mn(Xc,"PortLabelPlacement",282,On,NLt,oCt),r2t;T(64,23,{3:1,34:1,23:1,64:1},g_);var nn,Kt,Ma,Aa,wl,ol,Qh,Pf,Xl,Il,Pc,Vl,vl,yl,If,Wu,Ku,Za,bn,$o,Yt,$s=mn(Xc,"PortSide",64,On,BDt,lCt),s2t;T(986,1,jf,XB),f.tf=function(t){Rnt(t)};var o2t,c2t,W7e,l2t,u2t;C(Xc,"RandomLayouterOptions",986),T(987,1,{},UA),f.uf=function(){var t;return t=new J$,t},f.vf=function(t){},C(Xc,"RandomLayouterOptions/RandomFactory",987),T(301,23,{3:1,34:1,23:1,301:1},QY);var $P,gae,K7e,Y7e=mn(Xc,"ShapeCoords",301,On,c_t,cCt),a2t;T(381,23,{3:1,34:1,23:1,381:1},uF);var cy,BP,zP,Qb,BC=mn(Xc,"SizeConstraint",381,On,fDt,uCt),f2t;T(267,23,{3:1,34:1,23:1,267:1},ux);var FP,YJ,s8,pae,qP,zC,ZJ,eX,tX,Z7e=mn(Xc,"SizeOptions",267,On,BPt,aCt),h2t;T(283,23,{3:1,34:1,23:1,283:1},GY);var ly,eTe,nX,tTe=mn(Xc,"TopdownNodeTypes",283,On,u_t,fCt),d2t;T(290,23,CG);var nTe,bae,iTe,rTe,HP=mn(Xc,"TopdownSizeApproximator",290,On,hDt,hCt);T(978,290,CG,vFe),f.Sg=function(t){return gYe(t)},mn(Xc,"TopdownSizeApproximator/1",978,HP,null,null),T(979,290,CG,iqe),f.Sg=function(t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt,Dt;for(n=c(ke(t,(Dn(),ry)),144),We=(w0(),P=new Wj,P),GD(We,t),pt=new wn,a=new cn((!t.a&&(t.a=new Me(Mn,t,10,11)),t.a));a.e!=a.i.gc();)r=c(un(a),19),se=(L=new Wj,L),kQ(se,We),GD(se,r),Dt=gYe(r),_m(se,p.Math.max(r.g,Dt.a),p.Math.max(r.f,Dt.b)),gl(pt.f,r,se);for(o=new cn((!t.a&&(t.a=new Me(Mn,t,10,11)),t.a));o.e!=o.i.gc();)for(r=c(un(o),19),S=new cn((!r.e&&(r.e=new Et(Ii,r,7,4)),r.e));S.e!=S.i.gc();)x=c(un(S),74),Se=c(Ao(co(pt.f,r)),19),xe=c(Ut(pt,re((!x.c&&(x.c=new Et(vn,x,5,8)),x.c),0)),19),de=(M=new vj,M),Nn((!de.b&&(de.b=new Et(vn,de,4,7)),de.b),Se),Nn((!de.c&&(de.c=new Et(vn,de,5,8)),de.c),xe),xQ(de,Xi(Se)),GD(de,x);H=c(B_(n.f),207);try{H.kf(We,new VA),mpe(n.f,H)}catch(Rt){throw Rt=vr(Rt),oe(Rt,102)?(z=Rt,J(z)):J(Rt)}return ga(We,ty)||ga(We,ey)||Die(We),v=ue(he(ke(We,ty))),b=ue(he(ke(We,ey))),d=v/b,i=ue(he(ke(We,sy)))*p.Math.sqrt((!We.a&&(We.a=new Me(Mn,We,10,11)),We.a).i),bt=c(ke(We,zh),100),ie=bt.b+bt.c+1,X=bt.d+bt.a+1,new $e(p.Math.max(ie,i),p.Math.max(X,i/d))},mn(Xc,"TopdownSizeApproximator/2",979,HP,null,null),T(980,290,CG,AHe),f.Sg=function(t){var n,i,r,o,a,d;return i=ue(he(ke(t,(Dn(),sy)))),n=i/ue(he(ke(t,Z9))),r=XWt(t),a=c(ke(t,zh),100),o=ue(he(Ve(lh))),Xi(t)&&(o=ue(he(ke(Xi(t),lh)))),d=S1(new $e(i,n),r),ki(d,new $e(-(a.b+a.c)-o,-(a.d+a.a)-o))},mn(Xc,"TopdownSizeApproximator/3",980,HP,null,null),T(981,290,CG,rqe),f.Sg=function(t){var n,i,r,o,a,d,b,v,x,S;for(d=new cn((!t.a&&(t.a=new Me(Mn,t,10,11)),t.a));d.e!=d.i.gc();)a=c(un(d),19),ke(a,(Dn(),XJ))!=null&&(!a.a&&(a.a=new Me(Mn,a,10,11)),!!a.a)&&(!a.a&&(a.a=new Me(Mn,a,10,11)),a.a).i>0?(i=c(ke(a,XJ),525),S=i.Sg(a),x=c(ke(a,zh),100),_m(a,p.Math.max(a.g,S.a+x.b+x.c),p.Math.max(a.f,S.b+x.d+x.a))):(!a.a&&(a.a=new Me(Mn,a,10,11)),a.a).i!=0&&_m(a,ue(he(ke(a,sy))),ue(he(ke(a,sy)))/ue(he(ke(a,Z9))));n=c(ke(t,(Dn(),ry)),144),v=c(B_(n.f),207);try{v.kf(t,new VA),mpe(n.f,v)}catch(M){throw M=vr(M),oe(M,102)?(b=M,J(b)):J(M)}return ii(t,_k,g9),SGe(t),Die(t),o=ue(he(ke(t,ty))),r=ue(he(ke(t,ey))),new $e(o,r)},mn(Xc,"TopdownSizeApproximator/4",981,HP,null,null);var g2t;T(346,1,{861:1},V4),f.Tg=function(t,n){return CZe(this,t,n)},f.Ug=function(){net(this)},f.Vg=function(){return this.q},f.Wg=function(){return this.f?bq(this.f):null},f.Xg=function(){return bq(this.a)},f.Yg=function(){return this.p},f.Zg=function(){return!1},f.$g=function(){return this.n},f._g=function(){return this.p!=null&&!this.b},f.ah=function(t){var n;this.n&&(n=t,qe(this.f,n))},f.bh=function(t,n){var i,r;this.n&&t&&C_t(this,(i=new kqe,r=hie(i,t),IZt(i),r),(OH(),wae))},f.dh=function(t){var n;return this.b?null:(n=bPt(this,this.g),ei(this.a,n),n.i=this,this.d=t,n)},f.eh=function(t){t>0&&!this.b&&dme(this,t)},f.b=!1,f.c=0,f.d=-1,f.e=null,f.f=null,f.g=-1,f.j=!1,f.k=!1,f.n=!1,f.o=0,f.q=0,f.r=0,C(tc,"BasicProgressMonitor",346),T(713,207,kb,Q$),f.kf=function(t,n){Uit(t,n)},C(tc,"BoxLayoutProvider",713),T(974,1,Yn,nDe),f.Le=function(t,n){return DJt(this,c(t,19),c(n,19))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},f.a=!1,C(tc,"BoxLayoutProvider/1",974),T(168,1,{168:1},eH,PBe),f.Ib=function(){return this.c?oye(this.c):Mh(this.b)},C(tc,"BoxLayoutProvider/Group",168),T(327,23,{3:1,34:1,23:1,327:1},aF);var sTe,oTe,cTe,mae,lTe=mn(tc,"BoxLayoutProvider/PackingMode",327,On,dDt,dCt),p2t;T(975,1,Yn,gm),f.Le=function(t,n){return DAt(c(t,168),c(n,168))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(tc,"BoxLayoutProvider/lambda$0$Type",975),T(976,1,Yn,JA),f.Le=function(t,n){return kAt(c(t,168),c(n,168))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(tc,"BoxLayoutProvider/lambda$1$Type",976),T(977,1,Yn,qW),f.Le=function(t,n){return OAt(c(t,168),c(n,168))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(tc,"BoxLayoutProvider/lambda$2$Type",977),T(1350,1,{837:1},G$),f.Lg=function(t,n){return Lz(),!oe(n,176)||zPe((L5(),c(t,176)),n)},C(tc,"ElkSpacings/AbstractSpacingsBuilder/lambda$0$Type",1350),T(1351,1,ln,iDe),f.Ad=function(t){ERt(this.a,c(t,149))},C(tc,"ElkSpacings/AbstractSpacingsBuilder/lambda$1$Type",1351),T(1352,1,ln,pm),f.Ad=function(t){c(t,105),Lz()},C(tc,"ElkSpacings/AbstractSpacingsBuilder/lambda$2$Type",1352),T(1356,1,ln,rDe),f.Ad=function(t){ZPt(this.a,c(t,105))},C(tc,"ElkSpacings/AbstractSpacingsBuilder/lambda$3$Type",1356),T(1354,1,Jn,TRe),f.Mb=function(t){return fRt(this.a,this.b,c(t,149))},C(tc,"ElkSpacings/AbstractSpacingsBuilder/lambda$4$Type",1354),T(1353,1,Jn,ERe),f.Mb=function(t){return u7t(this.a,this.b,c(t,837))},C(tc,"ElkSpacings/AbstractSpacingsBuilder/lambda$5$Type",1353),T(1355,1,ln,CRe),f.Ad=function(t){bMt(this.a,this.b,c(t,149))},C(tc,"ElkSpacings/AbstractSpacingsBuilder/lambda$6$Type",1355),T(939,1,{},XA),f.Kb=function(t){return E$e(t)},f.Fb=function(t){return this===t},C(tc,"ElkUtil/lambda$0$Type",939),T(940,1,ln,MRe),f.Ad=function(t){LGt(this.a,this.b,c(t,74))},f.a=0,f.b=0,C(tc,"ElkUtil/lambda$1$Type",940),T(941,1,ln,ARe),f.Ad=function(t){h9t(this.a,this.b,c(t,171))},f.a=0,f.b=0,C(tc,"ElkUtil/lambda$2$Type",941),T(942,1,ln,NRe),f.Ad=function(t){sjt(this.a,this.b,c(t,158))},f.a=0,f.b=0,C(tc,"ElkUtil/lambda$3$Type",942),T(943,1,ln,sDe),f.Ad=function(t){$Ct(this.a,c(t,373))},C(tc,"ElkUtil/lambda$4$Type",943),T(332,1,{34:1,332:1},FSt),f.Dd=function(t){return Njt(this,c(t,245))},f.Fb=function(t){var n;return oe(t,332)?(n=c(t,332),this.a==n.a):!1},f.Hb=function(){return xs(this.a)},f.Ib=function(){return this.a+" (exclusive)"},f.a=0,C(tc,"ExclusiveBounds/ExclusiveLowerBound",332),T(1100,207,kb,U$),f.kf=function(t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie,se,de,Se,xe,We,pt,bt;for(n.Tg("Fixed Layout",1),a=c(ke(t,(Dn(),e7e)),225),M=0,L=0,se=new cn((!t.a&&(t.a=new Me(Mn,t,10,11)),t.a));se.e!=se.i.gc();){for(X=c(un(se),19),bt=c(ke(X,(SH(),DC)),8),bt&&(aa(X,bt.a,bt.b),c(ke(X,q7e),185).Gc((Cu(),cy))&&(P=c(ke(X,Q7e),8),P.a>0&&P.b>0&&uw(X,P.a,P.b,!0,!0))),M=p.Math.max(M,X.i+X.g),L=p.Math.max(L,X.j+X.f),x=new cn((!X.n&&(X.n=new Me(Bo,X,1,7)),X.n));x.e!=x.i.gc();)b=c(un(x),158),bt=c(ke(b,DC),8),bt&&aa(b,bt.a,bt.b),M=p.Math.max(M,X.i+b.i+b.g),L=p.Math.max(L,X.j+b.j+b.f);for(xe=new cn((!X.c&&(X.c=new Me(hu,X,9,9)),X.c));xe.e!=xe.i.gc();)for(Se=c(un(xe),127),bt=c(ke(Se,DC),8),bt&&aa(Se,bt.a,bt.b),We=X.i+Se.i,pt=X.j+Se.j,M=p.Math.max(M,We+Se.g),L=p.Math.max(L,pt+Se.f),v=new cn((!Se.n&&(Se.n=new Me(Bo,Se,1,7)),Se.n));v.e!=v.i.gc();)b=c(un(v),158),bt=c(ke(b,DC),8),bt&&aa(b,bt.a,bt.b),M=p.Math.max(M,We+b.i+b.g),L=p.Math.max(L,pt+b.j+b.f);for(o=new Ht(Vt(z1(X).a.Jc(),new U));hn(o);)i=c(sn(o),74),S=lst(i),M=p.Math.max(M,S.a),L=p.Math.max(L,S.b);for(r=new Ht(Vt(wQ(X).a.Jc(),new U));hn(r);)i=c(sn(r),74),Xi(Bne(i))!=t&&(S=lst(i),M=p.Math.max(M,S.a),L=p.Math.max(L,S.b))}if(a==($1(),i8))for(ie=new cn((!t.a&&(t.a=new Me(Mn,t,10,11)),t.a));ie.e!=ie.i.gc();)for(X=c(un(ie),19),r=new Ht(Vt(z1(X).a.Jc(),new U));hn(r);)i=c(sn(r),74),d=DWt(i),d.b==0?ii(i,T3,null):ii(i,T3,d);et(Ze(ke(t,(SH(),H7e))))||(de=c(ke(t,Kwt),100),H=M+de.b+de.c,z=L+de.d+de.a,uw(t,H,z,!0,!0)),n.Ug()},C(tc,"FixedLayoutProvider",1100),T(380,151,{3:1,419:1,380:1,105:1,151:1},O4,NJe),f.ag=function(t){var n,i,r,o,a,d,b,v,x;if(t)try{for(v=xv(t,";,;"),a=v,d=0,b=a.length;d<b;++d){if(o=a[d],i=xv(o,"\\:"),r=Bye(rT(),i[0]),!r)throw J(new qt("Invalid option id: "+i[0]));if(x=Rye(r,i[1]),x==null)throw J(new qt("Invalid option value: "+i[1]));x==null?(!this.q&&(this.q=new wn),E5(this.q,r)):(!this.q&&(this.q=new wn),oi(this.q,r,x))}}catch(S){throw S=vr(S),oe(S,102)?(n=S,J(new vWe(n))):J(S)}},f.Ib=function(){var t;return t=zn(ql(qc((this.q?this.q:(Ct(),Ct(),Yd)).vc().Mc(),new JO),GLt(new Yze,new f1,new er,new Zl,W(V(ml,1),_e,132,0,[])))),t};var b2t=C(tc,"IndividualSpacings",380);T(973,1,{},JO),f.Kb=function(t){return _At(c(t,45))},C(tc,"IndividualSpacings/lambda$0$Type",973),T(715,1,{},PFe),f.c=0,C(tc,"InstancePool",715),T(1833,1,{},jl),C(tc,"LoggedGraph",1833),T(412,23,{3:1,34:1,23:1,412:1},fF);var uTe,wae,aTe,fTe,m2t=mn(tc,"LoggedGraph/Type",412,On,gDt,gCt),w2t;T(621,1,{861:1},VA),f.Tg=function(t,n){return!1},f.Ug=function(){},f.Vg=function(){return 0},f.Wg=function(){return null},f.Xg=function(){return null},f.Yg=function(){return null},f.Zg=function(){return!1},f.$g=function(){return!1},f._g=function(){return!1},f.ah=function(t){},f.bh=function(t,n){},f.dh=function(t){return this},f.eh=function(t){},C(tc,"NullElkProgressMonitor",621),T(49,1,{22:1,49:1},HW,Ps),f.Ic=function(t){ws(this,t)},f.Fb=function(t){var n,i,r;return oe(t,49)?(i=c(t,49),n=this.a==null?i.a==null:yi(this.a,i.a),r=this.b==null?i.b==null:yi(this.b,i.b),n&&r):!1},f.Hb=function(){var t,n,i,r,o,a;return i=this.a==null?0:Ri(this.a),t=i&_r,n=i&-65536,a=this.b==null?0:Ri(this.b),r=a&_r,o=a&-65536,t^o>>16&_r|n^r<<16},f.Jc=function(){return new oDe(this)},f.Ib=function(){return this.a==null&&this.b==null?"pair(null,null)":this.a==null?"pair(null,"+jo(this.b)+")":this.b==null?"pair("+jo(this.a)+",null)":"pair("+jo(this.a)+","+jo(this.b)+")"},C(tc,"Pair",49),T(988,1,ts,oDe),f.Nb=function(t){gs(this,t)},f.Ob=function(){return!this.c&&(!this.b&&this.a.a!=null||this.a.b!=null)},f.Pb=function(){if(!this.c&&!this.b&&this.a.a!=null)return this.b=!0,this.a.a;if(!this.c&&this.a.b!=null)return this.c=!0,this.a.b;throw J(new Co)},f.Qb=function(){throw this.c&&this.a.b!=null?this.a.b=null:this.b&&this.a.a!=null&&(this.a.a=null),J(new Tl)},f.b=!1,f.c=!1,C(tc,"Pair/1",988),T(1089,207,kb,J$),f.kf=function(t,n){var i,r,o,a,d;if(n.Tg("Random Layout",1),(!t.a&&(t.a=new Me(Mn,t,10,11)),t.a).i==0){n.Ug();return}a=c(ke(t,(_we(),l2t)),15),a&&a.a!=0?o=new Lq(a.a):o=new Ute,i=UN(he(ke(t,o2t))),d=UN(he(ke(t,u2t))),r=c(ke(t,c2t),100),ien(t,o,i,d,r),n.Ug()},C(tc,"RandomLayoutProvider",1089),T(243,1,{243:1},SZ),f.Fb=function(t){return dc(this.a,c(t,243).a)&&dc(this.b,c(t,243).b)&&dc(this.c,c(t,243).c)},f.Hb=function(){return jH(W(V(Br,1),Lt,1,5,[this.a,this.b,this.c]))},f.Ib=function(){return"("+this.a+Jc+this.b+Jc+this.c+")"},C(tc,"Triple",243);var v2t;T(554,1,{}),f.Jf=function(){return new $e(this.f.i,this.f.j)},f.mf=function(t){return EHe(t,(Dn(),fu))?ke(this.f,y2t):ke(this.f,t)},f.Kf=function(){return new $e(this.f.g,this.f.f)},f.Lf=function(){return this.g},f.nf=function(t){return ga(this.f,t)},f.Mf=function(t){Cc(this.f,t.a),Nl(this.f,t.b)},f.Nf=function(t){ob(this.f,t.a),sb(this.f,t.b)},f.Of=function(t){this.g=t},f.g=0;var y2t;C(gE,"ElkGraphAdapters/AbstractElkGraphElementAdapter",554),T(556,1,{845:1},dz),f.Pf=function(){var t,n;if(!this.b)for(this.b=Tq(tee(this.a).i),n=new cn(tee(this.a));n.e!=n.i.gc();)t=c(un(n),158),qe(this.b,new KK(t));return this.b},f.b=null,C(gE,"ElkGraphAdapters/ElkEdgeAdapter",556),T(250,554,{},wg),f.Qf=function(){return LYe(this)},f.a=null,C(gE,"ElkGraphAdapters/ElkGraphAdapter",250),T(637,554,{190:1},KK),C(gE,"ElkGraphAdapters/ElkLabelAdapter",637),T(555,554,{692:1},EF),f.Pf=function(){return tFt(this)},f.Tf=function(){var t;return t=c(ke(this.f,(Dn(),Y1)),125),!t&&(t=new Vj),t},f.Vf=function(){return nFt(this)},f.Xf=function(t){var n;n=new kZ(t),ii(this.f,(Dn(),Y1),n)},f.Yf=function(t){ii(this.f,(Dn(),zh),new b0e(t))},f.Rf=function(){return this.d},f.Sf=function(){var t,n;if(!this.a)for(this.a=new Fe,n=new Ht(Vt(wQ(c(this.f,19)).a.Jc(),new U));hn(n);)t=c(sn(n),74),qe(this.a,new dz(t));return this.a},f.Uf=function(){var t,n;if(!this.c)for(this.c=new Fe,n=new Ht(Vt(z1(c(this.f,19)).a.Jc(),new U));hn(n);)t=c(sn(n),74),qe(this.c,new dz(t));return this.c},f.Wf=function(){return gq(c(this.f,19)).i!=0||et(Ze(c(this.f,19).mf((Dn(),AP))))},f.Zf=function(){WLt(this,(v0(),v2t))},f.a=null,f.b=null,f.c=null,f.d=null,f.e=null,C(gE,"ElkGraphAdapters/ElkNodeAdapter",555),T(1261,554,{844:1},cDe),f.Pf=function(){return uFt(this)},f.Sf=function(){var t,n;if(!this.a)for(this.a=Pd(c(this.f,127).gh().i),n=new cn(c(this.f,127).gh());n.e!=n.i.gc();)t=c(un(n),74),qe(this.a,new dz(t));return this.a},f.Uf=function(){var t,n;if(!this.c)for(this.c=Pd(c(this.f,127).hh().i),n=new cn(c(this.f,127).hh());n.e!=n.i.gc();)t=c(un(n),74),qe(this.c,new dz(t));return this.c},f.$f=function(){return c(c(this.f,127).mf((Dn(),M3)),64)},f._f=function(){var t,n,i,r,o,a,d,b;for(r=yh(c(this.f,127)),i=new cn(c(this.f,127).hh());i.e!=i.i.gc();)for(t=c(un(i),74),b=new cn((!t.c&&(t.c=new Et(vn,t,5,8)),t.c));b.e!=b.i.gc();){if(d=c(un(b),83),nv(to(d),r))return!0;if(to(d)==r&&et(Ze(ke(t,(Dn(),tae)))))return!0}for(n=new cn(c(this.f,127).gh());n.e!=n.i.gc();)for(t=c(un(n),74),a=new cn((!t.b&&(t.b=new Et(vn,t,4,7)),t.b));a.e!=a.i.gc();)if(o=c(un(a),83),nv(to(o),r))return!0;return!1},f.a=null,f.b=null,f.c=null,C(gE,"ElkGraphAdapters/ElkPortAdapter",1261),T(1262,1,Yn,XO),f.Le=function(t,n){return jVt(c(t,127),c(n,127))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(gE,"ElkGraphAdapters/PortComparator",1262);var dp=Ki(Sa,"EObject"),o8=Ki(Kx,Slt),Yu=Ki(Kx,jlt),QP=Ki(Kx,Tlt),GP=Ki(Kx,"ElkShape"),vn=Ki(Kx,Elt),Ii=Ki(Kx,c5e),Hi=Ki(Kx,Clt),UP=Ki(Sa,Mlt),FC=Ki(Sa,"EFactory"),x2t,vae=Ki(Sa,Alt),uh=Ki(Sa,"EPackage"),Wr,k2t,O2t,hTe,iX,S2t,dTe,gTe,pTe,s1,j2t,T2t,Bo=Ki(Kx,l5e),Mn=Ki(Kx,u5e),hu=Ki(Kx,a5e);T(94,1,Nlt),f.qh=function(){return this.rh(),null},f.rh=function(){return null},f.sh=function(){return this.rh(),!1},f.th=function(){return!1},f.uh=function(t){vi(this,t)},C(uk,"BasicNotifierImpl",94),T(101,94,Plt),f.Vh=function(){return wu(this)},f.vh=function(t,n){return t},f.wh=function(){throw J(new $n)},f.xh=function(t){var n;return n=Hs(c(_t(this.Ah(),this.Ch()),20)),this.Mh().Qh(this,n.n,n.f,t)},f.yh=function(t,n){throw J(new $n)},f.zh=function(t,n,i){return Qu(this,t,n,i)},f.Ah=function(){var t;return this.wh()&&(t=this.wh().Lk(),t)?t:this.fi()},f.Bh=function(){return Kne(this)},f.Ch=function(){throw J(new $n)},f.Dh=function(){var t,n;return n=this.Xh().Mk(),!n&&this.wh().Rk(n=(a7(),t=_pe(ud(this.Ah())),t==null?Eae:new y_(this,t))),n},f.Eh=function(t,n){return t},f.Fh=function(t){var n;return n=t.nk(),n?t.Jj():Vi(this.Ah(),t)},f.Gh=function(){var t;return t=this.wh(),t?t.Ok():null},f.Hh=function(){return this.wh()?this.wh().Lk():null},f.Ih=function(t,n,i){return JH(this,t,n,i)},f.Jh=function(t){return W6(this,t)},f.Kh=function(t,n){return Pee(this,t,n)},f.Lh=function(){var t;return t=this.wh(),!!t&&t.Pk()},f.Mh=function(){throw J(new $n)},f.Nh=function(){return qH(this)},f.Oh=function(t,n,i,r){return z5(this,t,n,r)},f.Ph=function(t,n,i){var r;return r=c(_t(this.Ah(),n),69),r.uk().xk(this,this.ei(),n-this.gi(),t,i)},f.Qh=function(t,n,i,r){return vq(this,t,n,r)},f.Rh=function(t,n,i){var r;return r=c(_t(this.Ah(),n),69),r.uk().yk(this,this.ei(),n-this.gi(),t,i)},f.Sh=function(){return!!this.wh()&&!!this.wh().Nk()},f.Th=function(t){return cne(this,t)},f.Uh=function(t){return HHe(this,t)},f.Wh=function(t){return Qrt(this,t)},f.Xh=function(){throw J(new $n)},f.Yh=function(){return this.wh()?this.wh().Nk():null},f.Zh=function(){return qH(this)},f.$h=function(t,n){Une(this,t,n)},f._h=function(t){this.Xh().Qk(t)},f.ai=function(t){this.Xh().Tk(t)},f.bi=function(t){this.Xh().Sk(t)},f.ci=function(t,n){var i,r,o,a;return a=this.Gh(),a&&t&&(n=Ns(a.Cl(),this,n),a.Gl(this)),r=this.Mh(),r&&((uie(this,this.Mh(),this.Ch()).Bb&Is)!=0?(o=r.Nh(),o&&(t?!a&&o.Gl(this):o.Fl(this))):(n=(i=this.Ch(),i>=0?this.xh(n):this.Mh().Qh(this,-1-i,null,n)),n=this.zh(null,-1,n))),this.ai(t),n},f.di=function(t){var n,i,r,o,a,d,b,v;if(i=this.Ah(),a=Vi(i,t),n=this.gi(),a>=n)return c(t,69).uk().Bk(this,this.ei(),a-n);if(a<=-1)if(d=qx((Dl(),ps),i,t),d){if(qs(),c(d,69).vk()||(d=S5(uo(ps,d))),o=(r=this.Fh(d),c(r>=0?this.Ih(r,!0,!0):ow(this,d,!0),164)),v=d.Gk(),v>1||v==-1)return c(c(o,222).Ql(t,!1),78)}else throw J(new qt(V0+t.ve()+Qse));else if(t.Hk())return r=this.Fh(t),c(r>=0?this.Ih(r,!1,!0):ow(this,t,!1),78);return b=new ZRe(this,t),b},f.ei=function(){return zbe(this)},f.fi=function(){return(j0(),Gt).S},f.gi=function(){return pn(this.fi())},f.hi=function(t){Hne(this,t)},f.Ib=function(){return kf(this)},C(Xt,"BasicEObjectImpl",101);var E2t;T(118,101,{110:1,95:1,94:1,57:1,115:1,52:1,101:1,118:1}),f.ii=function(t){var n;return n=Bbe(this),n[t]},f.ji=function(t,n){var i;i=Bbe(this),dr(i,t,n)},f.ki=function(t){var n;n=Bbe(this),dr(n,t,null)},f.qh=function(){return c(Wt(this,4),131)},f.rh=function(){throw J(new $n)},f.sh=function(){return(this.Db&4)!=0},f.wh=function(){throw J(new $n)},f.li=function(t){R5(this,2,t)},f.yh=function(t,n){this.Db=n<<16|this.Db&255,this.li(t)},f.Ah=function(){return al(this)},f.Ch=function(){return this.Db>>16},f.Dh=function(){var t,n;return a7(),n=_pe(ud((t=c(Wt(this,16),29),t||this.fi()))),n==null?Eae:new y_(this,n)},f.th=function(){return(this.Db&1)==0},f.Gh=function(){return c(Wt(this,128),2013)},f.Hh=function(){return c(Wt(this,16),29)},f.Lh=function(){return(this.Db&32)!=0},f.Mh=function(){return c(Wt(this,2),52)},f.Sh=function(){return(this.Db&64)!=0},f.Xh=function(){throw J(new $n)},f.Yh=function(){return c(Wt(this,64),291)},f._h=function(t){R5(this,16,t)},f.ai=function(t){R5(this,128,t)},f.bi=function(t){R5(this,64,t)},f.ei=function(){return tl(this)},f.Db=0,C(Xt,"MinimalEObjectImpl",118),T(119,118,{110:1,95:1,94:1,57:1,115:1,52:1,101:1,118:1,119:1}),f.li=function(t){this.Cb=t},f.Mh=function(){return this.Cb},C(Xt,"MinimalEObjectImpl/Container",119),T(2062,119,{110:1,344:1,105:1,95:1,94:1,57:1,115:1,52:1,101:1,118:1,119:1}),f.Ih=function(t,n,i){return t2e(this,t,n,i)},f.Rh=function(t,n,i){return Q2e(this,t,n,i)},f.Th=function(t){return Upe(this,t)},f.$h=function(t,n){zme(this,t,n)},f.fi=function(){return oc(),T2t},f.hi=function(t){Mme(this,t)},f.lf=function(){return eYe(this)},f.fh=function(){return!this.o&&(this.o=new Al((oc(),s1),e0,this,0)),this.o},f.mf=function(t){return ke(this,t)},f.nf=function(t){return ga(this,t)},f.of=function(t,n){return ii(this,t,n)},C(jb,"EMapPropertyHolderImpl",2062),T(566,119,{110:1,373:1,95:1,94:1,57:1,115:1,52:1,101:1,118:1,119:1},y2),f.Ih=function(t,n,i){switch(t){case 0:return this.a;case 1:return this.b}return JH(this,t,n,i)},f.Th=function(t){switch(t){case 0:return this.a!=0;case 1:return this.b!=0}return cne(this,t)},f.$h=function(t,n){switch(t){case 0:nH(this,ue(he(n)));return;case 1:tH(this,ue(he(n)));return}Une(this,t,n)},f.fi=function(){return oc(),k2t},f.hi=function(t){switch(t){case 0:nH(this,0);return;case 1:tH(this,0);return}Hne(this,t)},f.Ib=function(){var t;return(this.Db&64)!=0?kf(this):(t=new Ba(kf(this)),t.a+=" (x: ",rx(t,this.a),t.a+=", y: ",rx(t,this.b),t.a+=")",t.a)},f.a=0,f.b=0,C(jb,"ElkBendPointImpl",566),T(734,2062,{110:1,344:1,176:1,105:1,95:1,94:1,57:1,115:1,52:1,101:1,118:1,119:1}),f.Ih=function(t,n,i){return owe(this,t,n,i)},f.Ph=function(t,n,i){return Pne(this,t,n,i)},f.Rh=function(t,n,i){return wte(this,t,n,i)},f.Th=function(t){return kme(this,t)},f.$h=function(t,n){y2e(this,t,n)},f.fi=function(){return oc(),S2t},f.hi=function(t){nwe(this,t)},f.ih=function(){return this.k},f.jh=function(){return tee(this)},f.Ib=function(){return Gte(this)},f.k=null,C(jb,"ElkGraphElementImpl",734),T(735,734,{110:1,344:1,176:1,278:1,105:1,95:1,94:1,57:1,115:1,52:1,101:1,118:1,119:1}),f.Ih=function(t,n,i){return wwe(this,t,n,i)},f.Th=function(t){return Cwe(this,t)},f.$h=function(t,n){x2e(this,t,n)},f.fi=function(){return oc(),j2t},f.hi=function(t){Mwe(this,t)},f.kh=function(){return this.f},f.lh=function(){return this.g},f.mh=function(){return this.i},f.nh=function(){return this.j},f.oh=function(t,n){_m(this,t,n)},f.ph=function(t,n){aa(this,t,n)},f.Ib=function(){return Fne(this)},f.f=0,f.g=0,f.i=0,f.j=0,C(jb,"ElkShapeImpl",735),T(736,735,{110:1,344:1,83:1,176:1,278:1,105:1,95:1,94:1,57:1,115:1,52:1,101:1,118:1,119:1}),f.Ih=function(t,n,i){return Vwe(this,t,n,i)},f.Ph=function(t,n,i){return g2e(this,t,n,i)},f.Rh=function(t,n,i){return p2e(this,t,n,i)},f.Th=function(t){return Lme(this,t)},f.$h=function(t,n){Cve(this,t,n)},f.fi=function(){return oc(),O2t},f.hi=function(t){Qwe(this,t)},f.gh=function(){return!this.d&&(this.d=new Et(Ii,this,8,5)),this.d},f.hh=function(){return!this.e&&(this.e=new Et(Ii,this,7,4)),this.e},C(jb,"ElkConnectableShapeImpl",736),T(273,734,{110:1,344:1,74:1,176:1,273:1,105:1,95:1,94:1,57:1,115:1,52:1,101:1,118:1,119:1},vj),f.xh=function(t){return a2e(this,t)},f.Ih=function(t,n,i){switch(t){case 3:return V2(this);case 4:return!this.b&&(this.b=new Et(vn,this,4,7)),this.b;case 5:return!this.c&&(this.c=new Et(vn,this,5,8)),this.c;case 6:return!this.a&&(this.a=new Me(Hi,this,6,6)),this.a;case 7:return Bt(),!this.b&&(this.b=new Et(vn,this,4,7)),!(this.b.i<=1&&(!this.c&&(this.c=new Et(vn,this,5,8)),this.c.i<=1));case 8:return Bt(),!!PT(this);case 9:return Bt(),!!sw(this);case 10:return Bt(),!this.b&&(this.b=new Et(vn,this,4,7)),this.b.i!=0&&(!this.c&&(this.c=new Et(vn,this,5,8)),this.c.i!=0)}return owe(this,t,n,i)},f.Ph=function(t,n,i){var r;switch(n){case 3:return this.Cb&&(i=(r=this.Db>>16,r>=0?a2e(this,i):this.Cb.Qh(this,-1-r,null,i))),Gge(this,c(t,19),i);case 4:return!this.b&&(this.b=new Et(vn,this,4,7)),Uc(this.b,t,i);case 5:return!this.c&&(this.c=new Et(vn,this,5,8)),Uc(this.c,t,i);case 6:return!this.a&&(this.a=new Me(Hi,this,6,6)),Uc(this.a,t,i)}return Pne(this,t,n,i)},f.Rh=function(t,n,i){switch(n){case 3:return Gge(this,null,i);case 4:return!this.b&&(this.b=new Et(vn,this,4,7)),Ns(this.b,t,i);case 5:return!this.c&&(this.c=new Et(vn,this,5,8)),Ns(this.c,t,i);case 6:return!this.a&&(this.a=new Me(Hi,this,6,6)),Ns(this.a,t,i)}return wte(this,t,n,i)},f.Th=function(t){switch(t){case 3:return!!V2(this);case 4:return!!this.b&&this.b.i!=0;case 5:return!!this.c&&this.c.i!=0;case 6:return!!this.a&&this.a.i!=0;case 7:return!this.b&&(this.b=new Et(vn,this,4,7)),!(this.b.i<=1&&(!this.c&&(this.c=new Et(vn,this,5,8)),this.c.i<=1));case 8:return PT(this);case 9:return sw(this);case 10:return!this.b&&(this.b=new Et(vn,this,4,7)),this.b.i!=0&&(!this.c&&(this.c=new Et(vn,this,5,8)),this.c.i!=0)}return kme(this,t)},f.$h=function(t,n){switch(t){case 3:xQ(this,c(n,19));return;case 4:!this.b&&(this.b=new Et(vn,this,4,7)),En(this.b),!this.b&&(this.b=new Et(vn,this,4,7)),ur(this.b,c(n,18));return;case 5:!this.c&&(this.c=new Et(vn,this,5,8)),En(this.c),!this.c&&(this.c=new Et(vn,this,5,8)),ur(this.c,c(n,18));return;case 6:!this.a&&(this.a=new Me(Hi,this,6,6)),En(this.a),!this.a&&(this.a=new Me(Hi,this,6,6)),ur(this.a,c(n,18));return}y2e(this,t,n)},f.fi=function(){return oc(),hTe},f.hi=function(t){switch(t){case 3:xQ(this,null);return;case 4:!this.b&&(this.b=new Et(vn,this,4,7)),En(this.b);return;case 5:!this.c&&(this.c=new Et(vn,this,5,8)),En(this.c);return;case 6:!this.a&&(this.a=new Me(Hi,this,6,6)),En(this.a);return}nwe(this,t)},f.Ib=function(){return urt(this)},C(jb,"ElkEdgeImpl",273),T(446,2062,{110:1,344:1,171:1,446:1,105:1,95:1,94:1,57:1,115:1,52:1,101:1,118:1,119:1},VO),f.xh=function(t){return o2e(this,t)},f.Ih=function(t,n,i){switch(t){case 1:return this.j;case 2:return this.k;case 3:return this.b;case 4:return this.c;case 5:return!this.a&&(this.a=new Ar(Yu,this,5)),this.a;case 6:return BHe(this);case 7:return n?hne(this):this.i;case 8:return n?fne(this):this.f;case 9:return!this.g&&(this.g=new Et(Hi,this,9,10)),this.g;case 10:return!this.e&&(this.e=new Et(Hi,this,10,9)),this.e;case 11:return this.d}return t2e(this,t,n,i)},f.Ph=function(t,n,i){var r,o,a;switch(n){case 6:return this.Cb&&(i=(o=this.Db>>16,o>=0?o2e(this,i):this.Cb.Qh(this,-1-o,null,i))),Uge(this,c(t,74),i);case 9:return!this.g&&(this.g=new Et(Hi,this,9,10)),Uc(this.g,t,i);case 10:return!this.e&&(this.e=new Et(Hi,this,10,9)),Uc(this.e,t,i)}return a=c(_t((r=c(Wt(this,16),29),r||(oc(),iX)),n),69),a.uk().xk(this,tl(this),n-pn((oc(),iX)),t,i)},f.Rh=function(t,n,i){switch(n){case 5:return!this.a&&(this.a=new Ar(Yu,this,5)),Ns(this.a,t,i);case 6:return Uge(this,null,i);case 9:return!this.g&&(this.g=new Et(Hi,this,9,10)),Ns(this.g,t,i);case 10:return!this.e&&(this.e=new Et(Hi,this,10,9)),Ns(this.e,t,i)}return Q2e(this,t,n,i)},f.Th=function(t){switch(t){case 1:return this.j!=0;case 2:return this.k!=0;case 3:return this.b!=0;case 4:return this.c!=0;case 5:return!!this.a&&this.a.i!=0;case 6:return!!BHe(this);case 7:return!!this.i;case 8:return!!this.f;case 9:return!!this.g&&this.g.i!=0;case 10:return!!this.e&&this.e.i!=0;case 11:return this.d!=null}return Upe(this,t)},f.$h=function(t,n){switch(t){case 1:Vm(this,ue(he(n)));return;case 2:Wm(this,ue(he(n)));return;case 3:Jm(this,ue(he(n)));return;case 4:Xm(this,ue(he(n)));return;case 5:!this.a&&(this.a=new Ar(Yu,this,5)),En(this.a),!this.a&&(this.a=new Ar(Yu,this,5)),ur(this.a,c(n,18));return;case 6:rnt(this,c(n,74));return;case 7:uH(this,c(n,83));return;case 8:lH(this,c(n,83));return;case 9:!this.g&&(this.g=new Et(Hi,this,9,10)),En(this.g),!this.g&&(this.g=new Et(Hi,this,9,10)),ur(this.g,c(n,18));return;case 10:!this.e&&(this.e=new Et(Hi,this,10,9)),En(this.e),!this.e&&(this.e=new Et(Hi,this,10,9)),ur(this.e,c(n,18));return;case 11:fme(this,zn(n));return}zme(this,t,n)},f.fi=function(){return oc(),iX},f.hi=function(t){switch(t){case 1:Vm(this,0);return;case 2:Wm(this,0);return;case 3:Jm(this,0);return;case 4:Xm(this,0);return;case 5:!this.a&&(this.a=new Ar(Yu,this,5)),En(this.a);return;case 6:rnt(this,null);return;case 7:uH(this,null);return;case 8:lH(this,null);return;case 9:!this.g&&(this.g=new Et(Hi,this,9,10)),En(this.g);return;case 10:!this.e&&(this.e=new Et(Hi,this,10,9)),En(this.e);return;case 11:fme(this,null);return}Mme(this,t)},f.Ib=function(){return ptt(this)},f.b=0,f.c=0,f.d=null,f.j=0,f.k=0,C(jb,"ElkEdgeSectionImpl",446),T(162,119,{110:1,95:1,94:1,159:1,57:1,115:1,52:1,101:1,162:1,118:1,119:1}),f.Ih=function(t,n,i){var r;return t==0?(!this.Ab&&(this.Ab=new Me(si,this,0,3)),this.Ab):pa(this,t-pn(this.fi()),_t((r=c(Wt(this,16),29),r||this.fi()),t),n,i)},f.Ph=function(t,n,i){var r,o;return n==0?(!this.Ab&&(this.Ab=new Me(si,this,0,3)),Uc(this.Ab,t,i)):(o=c(_t((r=c(Wt(this,16),29),r||this.fi()),n),69),o.uk().xk(this,tl(this),n-pn(this.fi()),t,i))},f.Rh=function(t,n,i){var r,o;return n==0?(!this.Ab&&(this.Ab=new Me(si,this,0,3)),Ns(this.Ab,t,i)):(o=c(_t((r=c(Wt(this,16),29),r||this.fi()),n),69),o.uk().yk(this,tl(this),n-pn(this.fi()),t,i))},f.Th=function(t){var n;return t==0?!!this.Ab&&this.Ab.i!=0:da(this,t-pn(this.fi()),_t((n=c(Wt(this,16),29),n||this.fi()),t))},f.Wh=function(t){return Uye(this,t)},f.$h=function(t,n){var i;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab),!this.Ab&&(this.Ab=new Me(si,this,0,3)),ur(this.Ab,c(n,18));return}xa(this,t-pn(this.fi()),_t((i=c(Wt(this,16),29),i||this.fi()),t),n)},f.ai=function(t){R5(this,128,t)},f.fi=function(){return Mt(),G2t},f.hi=function(t){var n;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab);return}ya(this,t-pn(this.fi()),_t((n=c(Wt(this,16),29),n||this.fi()),t))},f.mi=function(){this.Bb|=1},f.ni=function(t){return qT(this,t)},f.Bb=0,C(Xt,"EModelElementImpl",162),T(717,162,{110:1,95:1,94:1,472:1,159:1,57:1,115:1,52:1,101:1,162:1,118:1,119:1},D4),f.oi=function(t,n){return Rrt(this,t,n)},f.pi=function(t){var n,i,r,o,a;if(this.a!=Bu(t)||(t.Bb&256)!=0)throw J(new qt(Use+t.zb+xw));for(r=vo(t);gc(r.a).i!=0;){if(i=c(eL(r,0,(n=c(re(gc(r.a),0),88),a=n.c,oe(a,89)?c(a,29):(Mt(),rf))),29),rw(i))return o=Bu(i).ti().pi(i),c(o,52)._h(t),o;r=vo(i)}return(t.D!=null?t.D:t.B)=="java.util.Map$Entry"?new wFe(t):new _0e(t)},f.qi=function(t,n){return aw(this,t,n)},f.Ih=function(t,n,i){var r;switch(t){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),this.Ab;case 1:return this.a}return pa(this,t-pn((Mt(),mp)),_t((r=c(Wt(this,16),29),r||mp),t),n,i)},f.Ph=function(t,n,i){var r,o;switch(n){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),Uc(this.Ab,t,i);case 1:return this.a&&(i=c(this.a,52).Qh(this,4,uh,i)),Zme(this,c(t,244),i)}return o=c(_t((r=c(Wt(this,16),29),r||(Mt(),mp)),n),69),o.uk().xk(this,tl(this),n-pn((Mt(),mp)),t,i)},f.Rh=function(t,n,i){var r,o;switch(n){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),Ns(this.Ab,t,i);case 1:return Zme(this,null,i)}return o=c(_t((r=c(Wt(this,16),29),r||(Mt(),mp)),n),69),o.uk().yk(this,tl(this),n-pn((Mt(),mp)),t,i)},f.Th=function(t){var n;switch(t){case 0:return!!this.Ab&&this.Ab.i!=0;case 1:return!!this.a}return da(this,t-pn((Mt(),mp)),_t((n=c(Wt(this,16),29),n||mp),t))},f.$h=function(t,n){var i;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab),!this.Ab&&(this.Ab=new Me(si,this,0,3)),ur(this.Ab,c(n,18));return;case 1:FZe(this,c(n,244));return}xa(this,t-pn((Mt(),mp)),_t((i=c(Wt(this,16),29),i||mp),t),n)},f.fi=function(){return Mt(),mp},f.hi=function(t){var n;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab);return;case 1:FZe(this,null);return}ya(this,t-pn((Mt(),mp)),_t((n=c(Wt(this,16),29),n||mp),t))};var qC,bTe,C2t;C(Xt,"EFactoryImpl",717),T(1029,717,{110:1,2092:1,95:1,94:1,472:1,159:1,57:1,115:1,52:1,101:1,162:1,118:1,119:1},Pp),f.oi=function(t,n){switch(t.fk()){case 12:return c(n,149).Og();case 13:return jo(n);default:throw J(new qt(p9+t.ve()+xw))}},f.pi=function(t){var n,i,r,o,a,d,b,v;switch(t.G==-1&&(t.G=(n=Bu(t),n?$g(n.si(),t):-1)),t.G){case 4:return a=new WA,a;case 6:return d=new Wj,d;case 7:return b=new Rde,b;case 8:return r=new vj,r;case 9:return i=new y2,i;case 10:return o=new VO,o;case 11:return v=new KA,v;default:throw J(new qt(Use+t.zb+xw))}},f.qi=function(t,n){switch(t.fk()){case 13:case 12:return null;default:throw J(new qt(p9+t.ve()+xw))}},C(jb,"ElkGraphFactoryImpl",1029),T(444,162,{110:1,95:1,94:1,159:1,199:1,57:1,115:1,52:1,101:1,162:1,118:1,119:1}),f.Dh=function(){var t,n;return n=(t=c(Wt(this,16),29),_pe(ud(t||this.fi()))),n==null?(a7(),a7(),Eae):new RBe(this,n)},f.Ih=function(t,n,i){var r;switch(t){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),this.Ab;case 1:return this.ve()}return pa(this,t-pn(this.fi()),_t((r=c(Wt(this,16),29),r||this.fi()),t),n,i)},f.Th=function(t){var n;switch(t){case 0:return!!this.Ab&&this.Ab.i!=0;case 1:return this.zb!=null}return da(this,t-pn(this.fi()),_t((n=c(Wt(this,16),29),n||this.fi()),t))},f.$h=function(t,n){var i;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab),!this.Ab&&(this.Ab=new Me(si,this,0,3)),ur(this.Ab,c(n,18));return;case 1:this.ri(zn(n));return}xa(this,t-pn(this.fi()),_t((i=c(Wt(this,16),29),i||this.fi()),t),n)},f.fi=function(){return Mt(),U2t},f.hi=function(t){var n;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab);return;case 1:this.ri(null);return}ya(this,t-pn(this.fi()),_t((n=c(Wt(this,16),29),n||this.fi()),t))},f.ve=function(){return this.zb},f.ri=function(t){Gc(this,t)},f.Ib=function(){return pT(this)},f.zb=null,C(Xt,"ENamedElementImpl",444),T(187,444,{110:1,95:1,94:1,159:1,199:1,57:1,244:1,115:1,52:1,101:1,162:1,187:1,118:1,119:1,687:1},mHe),f.xh=function(t){return WYe(this,t)},f.Ih=function(t,n,i){var r;switch(t){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),this.Ab;case 1:return this.zb;case 2:return this.yb;case 3:return this.xb;case 4:return this.sb;case 5:return!this.rb&&(this.rb=new G2(this,ah,this)),this.rb;case 6:return!this.vb&&(this.vb=new h5(uh,this,6,7)),this.vb;case 7:return n?this.Db>>16==7?c(this.Cb,244):null:XHe(this)}return pa(this,t-pn((Mt(),r0)),_t((r=c(Wt(this,16),29),r||r0),t),n,i)},f.Ph=function(t,n,i){var r,o,a;switch(n){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),Uc(this.Ab,t,i);case 4:return this.sb&&(i=c(this.sb,52).Qh(this,1,FC,i)),iwe(this,c(t,472),i);case 5:return!this.rb&&(this.rb=new G2(this,ah,this)),Uc(this.rb,t,i);case 6:return!this.vb&&(this.vb=new h5(uh,this,6,7)),Uc(this.vb,t,i);case 7:return this.Cb&&(i=(o=this.Db>>16,o>=0?WYe(this,i):this.Cb.Qh(this,-1-o,null,i))),Qu(this,t,7,i)}return a=c(_t((r=c(Wt(this,16),29),r||(Mt(),r0)),n),69),a.uk().xk(this,tl(this),n-pn((Mt(),r0)),t,i)},f.Rh=function(t,n,i){var r,o;switch(n){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),Ns(this.Ab,t,i);case 4:return iwe(this,null,i);case 5:return!this.rb&&(this.rb=new G2(this,ah,this)),Ns(this.rb,t,i);case 6:return!this.vb&&(this.vb=new h5(uh,this,6,7)),Ns(this.vb,t,i);case 7:return Qu(this,null,7,i)}return o=c(_t((r=c(Wt(this,16),29),r||(Mt(),r0)),n),69),o.uk().yk(this,tl(this),n-pn((Mt(),r0)),t,i)},f.Th=function(t){var n;switch(t){case 0:return!!this.Ab&&this.Ab.i!=0;case 1:return this.zb!=null;case 2:return this.yb!=null;case 3:return this.xb!=null;case 4:return!!this.sb;case 5:return!!this.rb&&this.rb.i!=0;case 6:return!!this.vb&&this.vb.i!=0;case 7:return!!XHe(this)}return da(this,t-pn((Mt(),r0)),_t((n=c(Wt(this,16),29),n||r0),t))},f.Wh=function(t){var n;return n=HJt(this,t),n||Uye(this,t)},f.$h=function(t,n){var i;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab),!this.Ab&&(this.Ab=new Me(si,this,0,3)),ur(this.Ab,c(n,18));return;case 1:Gc(this,zn(n));return;case 2:gH(this,zn(n));return;case 3:dH(this,zn(n));return;case 4:zne(this,c(n,472));return;case 5:!this.rb&&(this.rb=new G2(this,ah,this)),En(this.rb),!this.rb&&(this.rb=new G2(this,ah,this)),ur(this.rb,c(n,18));return;case 6:!this.vb&&(this.vb=new h5(uh,this,6,7)),En(this.vb),!this.vb&&(this.vb=new h5(uh,this,6,7)),ur(this.vb,c(n,18));return}xa(this,t-pn((Mt(),r0)),_t((i=c(Wt(this,16),29),i||r0),t),n)},f.bi=function(t){var n,i;if(t&&this.rb)for(i=new cn(this.rb);i.e!=i.i.gc();)n=un(i),oe(n,361)&&(c(n,361).w=null);R5(this,64,t)},f.fi=function(){return Mt(),r0},f.hi=function(t){var n;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab);return;case 1:Gc(this,null);return;case 2:gH(this,null);return;case 3:dH(this,null);return;case 4:zne(this,null);return;case 5:!this.rb&&(this.rb=new G2(this,ah,this)),En(this.rb);return;case 6:!this.vb&&(this.vb=new h5(uh,this,6,7)),En(this.vb);return}ya(this,t-pn((Mt(),r0)),_t((n=c(Wt(this,16),29),n||r0),t))},f.mi=function(){jne(this)},f.si=function(){return!this.rb&&(this.rb=new G2(this,ah,this)),this.rb},f.ti=function(){return this.sb},f.ui=function(){return this.ub},f.vi=function(){return this.xb},f.wi=function(){return this.yb},f.xi=function(t){this.ub=t},f.Ib=function(){var t;return(this.Db&64)!=0?pT(this):(t=new Ba(pT(this)),t.a+=" (nsURI: ",Ys(t,this.yb),t.a+=", nsPrefix: ",Ys(t,this.xb),t.a+=")",t.a)},f.xb=null,f.yb=null,C(Xt,"EPackageImpl",187),T(563,187,{110:1,2094:1,563:1,95:1,94:1,159:1,199:1,57:1,244:1,115:1,52:1,101:1,162:1,187:1,118:1,119:1,687:1},Ott),f.q=!1,f.r=!1;var M2t=!1;C(jb,"ElkGraphPackageImpl",563),T(363,735,{110:1,344:1,176:1,158:1,278:1,363:1,105:1,95:1,94:1,57:1,115:1,52:1,101:1,118:1,119:1},WA),f.xh=function(t){return c2e(this,t)},f.Ih=function(t,n,i){switch(t){case 7:return Rpe(this);case 8:return this.a}return wwe(this,t,n,i)},f.Ph=function(t,n,i){var r;switch(n){case 7:return this.Cb&&(i=(r=this.Db>>16,r>=0?c2e(this,i):this.Cb.Qh(this,-1-r,null,i))),U0e(this,c(t,176),i)}return Pne(this,t,n,i)},f.Rh=function(t,n,i){return n==7?U0e(this,null,i):wte(this,t,n,i)},f.Th=function(t){switch(t){case 7:return!!Rpe(this);case 8:return!Ot("",this.a)}return Cwe(this,t)},f.$h=function(t,n){switch(t){case 7:Qve(this,c(n,176));return;case 8:lme(this,zn(n));return}x2e(this,t,n)},f.fi=function(){return oc(),dTe},f.hi=function(t){switch(t){case 7:Qve(this,null);return;case 8:lme(this,"");return}Mwe(this,t)},f.Ib=function(){return cet(this)},f.a="",C(jb,"ElkLabelImpl",363),T(209,736,{110:1,344:1,83:1,176:1,19:1,278:1,209:1,105:1,95:1,94:1,57:1,115:1,52:1,101:1,118:1,119:1},Wj),f.xh=function(t){return f2e(this,t)},f.Ih=function(t,n,i){switch(t){case 9:return!this.c&&(this.c=new Me(hu,this,9,9)),this.c;case 10:return!this.a&&(this.a=new Me(Mn,this,10,11)),this.a;case 11:return Xi(this);case 12:return!this.b&&(this.b=new Me(Ii,this,12,3)),this.b;case 13:return Bt(),!this.a&&(this.a=new Me(Mn,this,10,11)),this.a.i>0}return Vwe(this,t,n,i)},f.Ph=function(t,n,i){var r;switch(n){case 9:return!this.c&&(this.c=new Me(hu,this,9,9)),Uc(this.c,t,i);case 10:return!this.a&&(this.a=new Me(Mn,this,10,11)),Uc(this.a,t,i);case 11:return this.Cb&&(i=(r=this.Db>>16,r>=0?f2e(this,i):this.Cb.Qh(this,-1-r,null,i))),i0e(this,c(t,19),i);case 12:return!this.b&&(this.b=new Me(Ii,this,12,3)),Uc(this.b,t,i)}return g2e(this,t,n,i)},f.Rh=function(t,n,i){switch(n){case 9:return!this.c&&(this.c=new Me(hu,this,9,9)),Ns(this.c,t,i);case 10:return!this.a&&(this.a=new Me(Mn,this,10,11)),Ns(this.a,t,i);case 11:return i0e(this,null,i);case 12:return!this.b&&(this.b=new Me(Ii,this,12,3)),Ns(this.b,t,i)}return p2e(this,t,n,i)},f.Th=function(t){switch(t){case 9:return!!this.c&&this.c.i!=0;case 10:return!!this.a&&this.a.i!=0;case 11:return!!Xi(this);case 12:return!!this.b&&this.b.i!=0;case 13:return!this.a&&(this.a=new Me(Mn,this,10,11)),this.a.i>0}return Lme(this,t)},f.$h=function(t,n){switch(t){case 9:!this.c&&(this.c=new Me(hu,this,9,9)),En(this.c),!this.c&&(this.c=new Me(hu,this,9,9)),ur(this.c,c(n,18));return;case 10:!this.a&&(this.a=new Me(Mn,this,10,11)),En(this.a),!this.a&&(this.a=new Me(Mn,this,10,11)),ur(this.a,c(n,18));return;case 11:kQ(this,c(n,19));return;case 12:!this.b&&(this.b=new Me(Ii,this,12,3)),En(this.b),!this.b&&(this.b=new Me(Ii,this,12,3)),ur(this.b,c(n,18));return}Cve(this,t,n)},f.fi=function(){return oc(),gTe},f.hi=function(t){switch(t){case 9:!this.c&&(this.c=new Me(hu,this,9,9)),En(this.c);return;case 10:!this.a&&(this.a=new Me(Mn,this,10,11)),En(this.a);return;case 11:kQ(this,null);return;case 12:!this.b&&(this.b=new Me(Ii,this,12,3)),En(this.b);return}Qwe(this,t)},f.Ib=function(){return oye(this)},C(jb,"ElkNodeImpl",209),T(196,736,{110:1,344:1,83:1,176:1,127:1,278:1,196:1,105:1,95:1,94:1,57:1,115:1,52:1,101:1,118:1,119:1},Rde),f.xh=function(t){return l2e(this,t)},f.Ih=function(t,n,i){return t==9?yh(this):Vwe(this,t,n,i)},f.Ph=function(t,n,i){var r;switch(n){case 9:return this.Cb&&(i=(r=this.Db>>16,r>=0?l2e(this,i):this.Cb.Qh(this,-1-r,null,i))),Jge(this,c(t,19),i)}return g2e(this,t,n,i)},f.Rh=function(t,n,i){return n==9?Jge(this,null,i):p2e(this,t,n,i)},f.Th=function(t){return t==9?!!yh(this):Lme(this,t)},f.$h=function(t,n){switch(t){case 9:Bve(this,c(n,19));return}Cve(this,t,n)},f.fi=function(){return oc(),pTe},f.hi=function(t){switch(t){case 9:Bve(this,null);return}Qwe(this,t)},f.Ib=function(){return iit(this)},C(jb,"ElkPortImpl",196);var A2t=Ki(_s,"BasicEMap/Entry");T(1103,119,{110:1,45:1,95:1,94:1,138:1,57:1,115:1,52:1,101:1,118:1,119:1},KA),f.Fb=function(t){return this===t},f.jd=function(){return this.b},f.Hb=function(){return Lm(this)},f.Ai=function(t){rme(this,c(t,149))},f.Ih=function(t,n,i){switch(t){case 0:return this.b;case 1:return this.c}return JH(this,t,n,i)},f.Th=function(t){switch(t){case 0:return!!this.b;case 1:return this.c!=null}return cne(this,t)},f.$h=function(t,n){switch(t){case 0:rme(this,c(n,149));return;case 1:sme(this,n);return}Une(this,t,n)},f.fi=function(){return oc(),s1},f.hi=function(t){switch(t){case 0:rme(this,null);return;case 1:sme(this,null);return}Hne(this,t)},f.yi=function(){var t;return this.a==-1&&(t=this.b,this.a=t?Ri(t):0),this.a},f.kd=function(){return this.c},f.zi=function(t){this.a=t},f.ld=function(t){var n;return n=this.c,sme(this,t),n},f.Ib=function(){var t;return(this.Db&64)!=0?kf(this):(t=new b0,Zn(Zn(Zn(t,this.b?this.b.Og():pl),jre),A7(this.c)),t.a)},f.a=-1,f.c=null;var e0=C(jb,"ElkPropertyToValueMapEntryImpl",1103);T(989,1,{},X$),C(hs,"JsonAdapter",989),T(218,63,H1,Kh),C(hs,"JsonImportException",218),T(859,1,{},wtt),C(hs,"JsonImporter",859),T(893,1,{},$Re),f.Bi=function(t){oZe(this.a,this.b,c(t,142))},C(hs,"JsonImporter/lambda$0$Type",893),T(894,1,{},BRe),f.Bi=function(t){Vet(this.a,this.b,c(t,142))},C(hs,"JsonImporter/lambda$1$Type",894),T(902,1,{},lDe),f.Bi=function(t){Jqe(this.a,c(t,150))},C(hs,"JsonImporter/lambda$10$Type",902),T(904,1,{},zRe),f.Bi=function(t){Pet(this.a,this.b,c(t,142))},C(hs,"JsonImporter/lambda$11$Type",904),T(905,1,{},FRe),f.Bi=function(t){Iet(this.a,this.b,c(t,142))},C(hs,"JsonImporter/lambda$12$Type",905),T(911,1,{},iHe),f.Bi=function(t){iet(this.a,this.b,this.c,this.d,c(t,142))},C(hs,"JsonImporter/lambda$13$Type",911),T(910,1,{},rHe),f.Bi=function(t){jit(this.a,this.b,this.c,this.d,c(t,150))},C(hs,"JsonImporter/lambda$14$Type",910),T(906,1,{},qRe),f.Bi=function(t){pze(this.a,this.b,zn(t))},C(hs,"JsonImporter/lambda$15$Type",906),T(907,1,{},HRe),f.Bi=function(t){bze(this.a,this.b,zn(t))},C(hs,"JsonImporter/lambda$16$Type",907),T(908,1,{},XRe),f.Bi=function(t){FYe(this.b,this.a,c(t,142))},C(hs,"JsonImporter/lambda$17$Type",908),T(909,1,{},VRe),f.Bi=function(t){qYe(this.b,this.a,c(t,142))},C(hs,"JsonImporter/lambda$18$Type",909),T(914,1,{},uDe),f.Bi=function(t){JZe(this.a,c(t,150))},C(hs,"JsonImporter/lambda$19$Type",914),T(895,1,{},aDe),f.Bi=function(t){ZYe(this.a,c(t,142))},C(hs,"JsonImporter/lambda$2$Type",895),T(912,1,{},fDe),f.Bi=function(t){Vm(this.a,ue(he(t)))},C(hs,"JsonImporter/lambda$20$Type",912),T(913,1,{},hDe),f.Bi=function(t){Wm(this.a,ue(he(t)))},C(hs,"JsonImporter/lambda$21$Type",913),T(917,1,{},dDe),f.Bi=function(t){UZe(this.a,c(t,150))},C(hs,"JsonImporter/lambda$22$Type",917),T(915,1,{},gDe),f.Bi=function(t){Jm(this.a,ue(he(t)))},C(hs,"JsonImporter/lambda$23$Type",915),T(916,1,{},pDe),f.Bi=function(t){Xm(this.a,ue(he(t)))},C(hs,"JsonImporter/lambda$24$Type",916),T(919,1,{},bDe),f.Bi=function(t){mZe(this.a,c(t,142))},C(hs,"JsonImporter/lambda$25$Type",919),T(918,1,{},mDe),f.Bi=function(t){Xqe(this.a,c(t,150))},C(hs,"JsonImporter/lambda$26$Type",918),T(920,1,ln,WRe),f.Ad=function(t){DLt(this.b,this.a,zn(t))},C(hs,"JsonImporter/lambda$27$Type",920),T(921,1,ln,KRe),f.Ad=function(t){LLt(this.b,this.a,zn(t))},C(hs,"JsonImporter/lambda$28$Type",921),T(922,1,{},QRe),f.Bi=function(t){Ntt(this.a,this.b,c(t,142))},C(hs,"JsonImporter/lambda$29$Type",922),T(898,1,{},wDe),f.Bi=function(t){uKe(this.a,c(t,150))},C(hs,"JsonImporter/lambda$3$Type",898),T(923,1,{},GRe),f.Bi=function(t){ent(this.a,this.b,c(t,142))},C(hs,"JsonImporter/lambda$30$Type",923),T(924,1,{},vDe),f.Bi=function(t){_Je(this.a,he(t))},C(hs,"JsonImporter/lambda$31$Type",924),T(925,1,{},yDe),f.Bi=function(t){DJe(this.a,he(t))},C(hs,"JsonImporter/lambda$32$Type",925),T(926,1,{},xDe),f.Bi=function(t){LJe(this.a,he(t))},C(hs,"JsonImporter/lambda$33$Type",926),T(927,1,{},kDe),f.Bi=function(t){PJe(this.a,he(t))},C(hs,"JsonImporter/lambda$34$Type",927),T(928,1,{},ODe),f.Bi=function(t){IHt(this.a,c(t,57))},C(hs,"JsonImporter/lambda$35$Type",928),T(929,1,{},SDe),f.Bi=function(t){RHt(this.a,c(t,57))},C(hs,"JsonImporter/lambda$36$Type",929),T(933,1,{},nHe),C(hs,"JsonImporter/lambda$37$Type",933),T(930,1,ln,Fze),f.Ad=function(t){fIt(this.a,this.c,this.b,c(t,373))},C(hs,"JsonImporter/lambda$38$Type",930),T(931,1,ln,URe),f.Ad=function(t){A8t(this.a,this.b,c(t,171))},C(hs,"JsonImporter/lambda$39$Type",931),T(896,1,{},jDe),f.Bi=function(t){Vm(this.a,ue(he(t)))},C(hs,"JsonImporter/lambda$4$Type",896),T(932,1,ln,JRe),f.Ad=function(t){N8t(this.a,this.b,c(t,171))},C(hs,"JsonImporter/lambda$40$Type",932),T(934,1,ln,qze),f.Ad=function(t){hIt(this.a,this.b,this.c,c(t,8))},C(hs,"JsonImporter/lambda$41$Type",934),T(897,1,{},TDe),f.Bi=function(t){Wm(this.a,ue(he(t)))},C(hs,"JsonImporter/lambda$5$Type",897),T(901,1,{},EDe),f.Bi=function(t){aKe(this.a,c(t,150))},C(hs,"JsonImporter/lambda$6$Type",901),T(899,1,{},CDe),f.Bi=function(t){Jm(this.a,ue(he(t)))},C(hs,"JsonImporter/lambda$7$Type",899),T(900,1,{},MDe),f.Bi=function(t){Xm(this.a,ue(he(t)))},C(hs,"JsonImporter/lambda$8$Type",900),T(903,1,{},ADe),f.Bi=function(t){wZe(this.a,c(t,142))},C(hs,"JsonImporter/lambda$9$Type",903),T(953,1,ln,NDe),f.Ad=function(t){y5(this.a,new J2(zn(t)))},C(hs,"JsonMetaDataConverter/lambda$0$Type",953),T(954,1,ln,_De),f.Ad=function(t){NMt(this.a,c(t,235))},C(hs,"JsonMetaDataConverter/lambda$1$Type",954),T(955,1,ln,DDe),f.Ad=function(t){ANt(this.a,c(t,144))},C(hs,"JsonMetaDataConverter/lambda$2$Type",955),T(956,1,ln,LDe),f.Ad=function(t){_Mt(this.a,c(t,161))},C(hs,"JsonMetaDataConverter/lambda$3$Type",956),T(235,23,{3:1,34:1,23:1,235:1},s5);var rX,sX,yae,JP,oX,XP,xae,kae,VP=mn(bL,"GraphFeature",235,On,hPt,pCt),N2t;T(11,1,{34:1,149:1},gi,qi,wt,Gr),f.Dd=function(t){return _jt(this,c(t,149))},f.Fb=function(t){return EHe(this,t)},f.Rg=function(){return Ve(this)},f.Og=function(){return this.b},f.Hb=function(){return Dg(this.b)},f.Ib=function(){return this.b},C(bL,"Property",11),T(664,1,Yn,IK),f.Le=function(t,n){return S$t(this,c(t,105),c(n,105))},f.Fb=function(t){return this===t},f.Me=function(){return new Xn(this)},C(bL,"PropertyHolderComparator",664),T(705,1,ts,kde),f.Nb=function(t){gs(this,t)},f.Pb=function(){return $Lt(this)},f.Qb=function(){TPe()},f.Ob=function(){return!!this.a},C(NG,"ElkGraphUtil/AncestorIterator",705);var mTe=Ki(_s,"EList");T(71,56,{22:1,32:1,56:1,18:1,16:1,71:1,61:1}),f._c=function(t,n){wT(this,t,n)},f.Ec=function(t){return Nn(this,t)},f.ad=function(t,n){return Nme(this,t,n)},f.Fc=function(t){return ur(this,t)},f.Gi=function(){return new a5(this)},f.Hi=function(){return new v_(this)},f.Ii=function(t){return uD(this,t)},f.Ji=function(){return!0},f.Ki=function(t,n){},f.Li=function(){},f.Mi=function(t,n){zee(this,t,n)},f.Ni=function(t,n,i){},f.Oi=function(t,n){},f.Pi=function(t,n,i){},f.Fb=function(t){return znt(this,t)},f.Hb=function(){return Tme(this)},f.Qi=function(){return!1},f.Jc=function(){return new cn(this)},f.cd=function(){return new f5(this)},f.dd=function(t){var n;if(n=this.gc(),t<0||t>n)throw J(new F2(t,n));return new UZ(this,t)},f.Si=function(t,n){this.Ri(t,this.bd(n))},f.Kc=function(t){return Vq(this,t)},f.Ui=function(t,n){return n},f.fd=function(t,n){return Dx(this,t,n)},f.Ib=function(){return Owe(this)},f.Wi=function(){return!0},f.Xi=function(t,n){return fS(this,n)},C(_s,"AbstractEList",71),T(67,71,md,S4,Um,vme),f.Ci=function(t,n){return Ine(this,t,n)},f.Di=function(t){return kYe(this,t)},f.Ei=function(t,n){kD(this,t,n)},f.Fi=function(t){U_(this,t)},f.Yi=function(t){return Pbe(this,t)},f.$b=function(){eT(this)},f.Gc=function(t){return ES(this,t)},f.Xb=function(t){return re(this,t)},f.Zi=function(t){var n,i,r;++this.j,i=this.g==null?0:this.g.length,t>i&&(r=this.g,n=i+(i/2|0)+4,n<t&&(n=t),this.g=this.$i(n),r!=null&&mc(r,0,this.g,0,this.i))},f.bd=function(t){return GYe(this,t)},f.dc=function(){return this.i==0},f.Ri=function(t,n){return Vne(this,t,n)},f.$i=function(t){return ye(Br,Lt,1,t,5,1)},f.Ti=function(t){return this.g[t]},f.ed=function(t){return F5(this,t)},f.Vi=function(t,n){return Wee(this,t,n)},f.gc=function(){return this.i},f.Nc=function(){return tbe(this)},f.Oc=function(t){return Nwe(this,t)},f.i=0;var wTe=C(_s,"BasicEList",67),vTe=Ki(_s,"TreeIterator");T(704,67,ioe),f.Nb=function(t){gs(this,t)},f.Ob=function(){return this.g==null&&!this.c?Ipe(this):this.g==null||this.i!=0&&c(this.g[this.i-1],51).Ob()},f.Pb=function(){return mQ(this)},f.Qb=function(){if(!this.e)throw J(new oo("There is no valid object to remove."));this.e.Qb()},f.c=!1,C(_s,"AbstractTreeIterator",704),T(611,704,ioe,WY),f._i=function(t){var n;return n=c(t,57).Dh().Jc(),oe(n,289)&&c(n,289).ul(new YA),n},C(NG,"ElkGraphUtil/PropertiesSkippingTreeIterator",611),T(957,1,{},YA),C(NG,"ElkGraphUtil/PropertiesSkippingTreeIterator/1",957);var WP,Oae,KP=C(NG,"ElkReflect",null);T(891,1,Av,yj),f.Qg=function(t){return Oq(),w_t(c(t,185))},C(NG,"ElkReflect/lambda$0$Type",891);var gp;Ki(_s,"ResourceLocator"),T(1056,1,{}),C(_s,"DelegatingResourceLocator",1056),T(1057,1056,{}),C("org.eclipse.emf.common","EMFPlugin",1057);var Sae=Ki(vut,"Adapter"),onn=Ki(vut,"Notification");T(1155,1,j5e),f.aj=function(){return this.d},f.bj=function(t){},f.cj=function(t){this.d=t},f.dj=function(t){this.d==t&&(this.d=null)},f.d=null,C(uk,"AdapterImpl",1155),T(2072,71,yut),f.Ci=function(t,n){return Twe(this,t,n)},f.Di=function(t){var n,i,r;if(++this.j,t.dc())return!1;for(n=this.Cj(),r=t.Jc();r.Ob();)i=r.Pb(),this.pj(this.Xi(n,i)),++n;return!0},f.Ei=function(t,n){KBe(this,t,n)},f.Fi=function(t){Cqe(this,t)},f.nj=function(){return this.qj()},f.$b=function(){O_(this,this.Cj(),this.Dj())},f.Gc=function(t){return this.sj(t)},f.Hc=function(t){return this.tj(t)},f.oj=function(t,n){this.zj().Sm()},f.pj=function(t){this.zj().Sm()},f.qj=function(){return this.zj()},f.rj=function(){this.zj().Sm()},f.sj=function(t){return this.zj().Sm()},f.tj=function(t){return this.zj().Sm()},f.uj=function(t){return this.zj().Sm()},f.vj=function(t){return this.zj().Sm()},f.wj=function(){return this.zj().Sm()},f.xj=function(t){return this.zj().Sm()},f.yj=function(){return this.zj().Sm()},f.Aj=function(t){return this.zj().Sm()},f.Bj=function(t,n){return this.zj().Sm()},f.Cj=function(){return this.zj().Sm()},f.Dj=function(){return this.zj().Sm()},f.Ej=function(t){return this.zj().Sm()},f.Fj=function(){return this.zj().Sm()},f.Fb=function(t){return this.uj(t)},f.Xb=function(t){return this.Ui(t,this.vj(t))},f.Hb=function(){return this.wj()},f.bd=function(t){return this.xj(t)},f.dc=function(){return this.yj()},f.Ri=function(t,n){return F2e(this,t,n)},f.Ti=function(t){return this.vj(t)},f.ed=function(t){return QF(this,t)},f.Kc=function(t){var n;return n=this.bd(t),n>=0?(this.ed(n),!0):!1},f.Vi=function(t,n){return this.Bj(t,this.Xi(t,n))},f.gc=function(){return this.Cj()},f.Nc=function(){return this.Dj()},f.Oc=function(t){return this.Ej(t)},f.Ib=function(){return this.Fj()},C(_s,"DelegatingEList",2072),T(2073,2072,yut),f.Ci=function(t,n){return yye(this,t,n)},f.Di=function(t){return this.Ci(this.Cj(),t)},f.Ei=function(t,n){Stt(this,t,n)},f.Fi=function(t){dtt(this,t)},f.Ji=function(){return!this.Kj()},f.$b=function(){XT(this)},f.Gj=function(t,n,i,r,o){return new jHe(this,t,n,i,r,o)},f.Hj=function(t){vi(this.hj(),t)},f.Ij=function(){return null},f.Jj=function(){return-1},f.hj=function(){return null},f.Kj=function(){return!1},f.Lj=function(t,n){return n},f.Mj=function(t,n){return n},f.Nj=function(){return!1},f.Oj=function(){return!this.yj()},f.Ri=function(t,n){var i,r;return this.Nj()?(r=this.Oj(),i=F2e(this,t,n),this.Hj(this.Gj(7,Pe(n),i,t,r)),i):F2e(this,t,n)},f.ed=function(t){var n,i,r,o;return this.Nj()?(i=null,r=this.Oj(),n=this.Gj(4,o=QF(this,t),null,t,r),this.Kj()&&o?(i=this.Mj(o,i),i?(i.lj(n),i.mj()):this.Hj(n)):i?(i.lj(n),i.mj()):this.Hj(n),o):(o=QF(this,t),this.Kj()&&o&&(i=this.Mj(o,null),i&&i.mj()),o)},f.Vi=function(t,n){return Rit(this,t,n)},C(uk,"DelegatingNotifyingListImpl",2073),T(152,1,LL),f.lj=function(t){return T2e(this,t)},f.mj=function(){Gee(this)},f.ej=function(){return this.d},f.Ij=function(){return null},f.Pj=function(){return null},f.fj=function(t){return-1},f.gj=function(){return xnt(this)},f.hj=function(){return null},f.ij=function(){return Vve(this)},f.jj=function(){return this.o<0?this.o<-2?-2-this.o-1:-1:this.o},f.Qj=function(){return!1},f.kj=function(t){var n,i,r,o,a,d,b,v,x,S,M;switch(this.d){case 1:case 2:switch(o=t.ej(),o){case 1:case 2:if(a=t.hj(),ve(a)===ve(this.hj())&&this.fj(null)==t.fj(null))return this.g=t.gj(),t.ej()==1&&(this.d=1),!0}case 4:{switch(o=t.ej(),o){case 4:{if(a=t.hj(),ve(a)===ve(this.hj())&&this.fj(null)==t.fj(null))return x=$ye(this),v=this.o<0?this.o<-2?-2-this.o-1:-1:this.o,d=t.jj(),this.d=6,M=new Um(2),v<=d?(Nn(M,this.n),Nn(M,t.ij()),this.g=W(V(Fn,1),ci,30,15,[this.o=v,d+1])):(Nn(M,t.ij()),Nn(M,this.n),this.g=W(V(Fn,1),ci,30,15,[this.o=d,v])),this.n=M,x||(this.o=-2-this.o-1),!0;break}}break}case 6:{switch(o=t.ej(),o){case 4:{if(a=t.hj(),ve(a)===ve(this.hj())&&this.fj(null)==t.fj(null)){for(x=$ye(this),d=t.jj(),S=c(this.g,54),r=ye(Fn,ci,30,S.length+1,15,1),n=0;n<S.length&&(b=S[n],b<=d);)r[n++]=b,++d;for(i=c(this.n,16),i._c(n,t.ij()),r[n]=d;++n<r.length;)r[n]=S[n-1];return this.g=r,x||(this.o=-2-r[0]),!0}break}}break}}return!1},f.Ib=function(){var t,n,i,r;switch(r=new Ba(qp(this.Pm)+"@"+(n=Ri(this)>>>0,n.toString(16))),r.a+=" (eventType: ",this.d){case 1:{r.a+="SET";break}case 2:{r.a+="UNSET";break}case 3:{r.a+="ADD";break}case 5:{r.a+="ADD_MANY";break}case 4:{r.a+="REMOVE";break}case 6:{r.a+="REMOVE_MANY";break}case 7:{r.a+="MOVE";break}case 8:{r.a+="REMOVING_ADAPTER";break}case 9:{r.a+="RESOLVE";break}default:{oY(r,this.d);break}}if(ait(this)&&(r.a+=", touch: true"),r.a+=", position: ",oY(r,this.o<0?this.o<-2?-2-this.o-1:-1:this.o),r.a+=", notifier: ",S7(r,this.hj()),r.a+=", feature: ",S7(r,this.Ij()),r.a+=", oldValue: ",S7(r,Vve(this)),r.a+=", newValue: ",this.d==6&&oe(this.g,54)){for(i=c(this.g,54),r.a+="[",t=0;t<i.length;)r.a+=i[t],++t<i.length&&(r.a+=Jc);r.a+="]"}else S7(r,xnt(this));return r.a+=", isTouch: ",xg(r,ait(this)),r.a+=", wasSet: ",xg(r,$ye(this)),r.a+=")",r.a},f.d=0,f.e=0,f.f=0,f.j=0,f.k=0,f.o=0,f.p=0,C(uk,"NotificationImpl",152),T(1169,152,LL,jHe),f.Ij=function(){return this.a.Ij()},f.fj=function(t){return this.a.Jj()},f.hj=function(){return this.a.hj()},C(uk,"DelegatingNotifyingListImpl/1",1169),T(255,67,md,V$,m0),f.Ec=function(t){return pKe(this,c(t,374))},f.lj=function(t){return pKe(this,t)},f.mj=function(){var t,n,i;for(t=0;t<this.i;++t)n=c(this.g[t],374),i=n.hj(),i!=null&&n.ej()!=-1&&c(i,95).uh(n)},f.$i=function(t){return ye(onn,Lt,374,t,0,1)},C(uk,"NotificationChainImpl",255),T(1502,94,Nlt),f.rh=function(){return this.e},f.th=function(){return(this.f&1)!=0},f.f=1,C(uk,"NotifierImpl",1502),T(2070,67,md),f.Ci=function(t,n){return gie(this,t,n)},f.Di=function(t){return this.Ci(this.i,t)},f.Ei=function(t,n){vve(this,t,n)},f.Fi=function(t){Wne(this,t)},f.Ji=function(){return!this.Kj()},f.$b=function(){En(this)},f.Gj=function(t,n,i,r,o){return new THe(this,t,n,i,r,o)},f.Hj=function(t){vi(this.hj(),t)},f.Ij=function(){return null},f.Jj=function(){return-1},f.hj=function(){return null},f.Kj=function(){return!1},f.Rj=function(){return!1},f.Lj=function(t,n){return n},f.Mj=function(t,n){return n},f.Nj=function(){return!1},f.Oj=function(){return this.i!=0},f.Ri=function(t,n){return vT(this,t,n)},f.ed=function(t){return vv(this,t)},f.Vi=function(t,n){return trt(this,t,n)},f.Sj=function(t,n){return n},f.Tj=function(t,n){return n},f.Uj=function(t,n,i){return i},C(uk,"NotifyingListImpl",2070),T(1168,152,LL,THe),f.Ij=function(){return this.a.Ij()},f.fj=function(t){return this.a.Jj()},f.hj=function(){return this.a.hj()},C(uk,"NotifyingListImpl/1",1168),T(958,67,md,ZBe),f.Gc=function(t){return this.i>10?((!this.b||this.c.j!=this.a)&&(this.b=new q2(this),this.a=this.j),$a(this.b,t)):ES(this,t)},f.Wi=function(){return!0},f.a=0,C(_s,"AbstractEList/1",958),T(306,99,GQ,F2),C(_s,"AbstractEList/BasicIndexOutOfBoundsException",306),T(39,1,ts,cn),f.Nb=function(t){gs(this,t)},f.Vj=function(){if(this.i.j!=this.f)throw J(new ua)},f.Wj=function(){return un(this)},f.Ob=function(){return this.e!=this.i.gc()},f.Pb=function(){return this.Wj()},f.Qb=function(){MT(this)},f.e=0,f.f=0,f.g=-1,C(_s,"AbstractEList/EIterator",39),T(288,39,Ud,f5,UZ),f.Qb=function(){MT(this)},f.Rb=function(t){jKe(this,t)},f.Xj=function(){var t;try{return t=this.d.Xb(--this.e),this.Vj(),this.g=this.e,t}catch(n){throw n=vr(n),oe(n,99)?(this.Vj(),J(new Co)):J(n)}},f.Yj=function(t){OYe(this,t)},f.Sb=function(){return this.e!=0},f.Tb=function(){return this.e},f.Ub=function(){return this.Xj()},f.Vb=function(){return this.e-1},f.Wb=function(t){this.Yj(t)},C(_s,"AbstractEList/EListIterator",288),T(356,39,ts,a5),f.Wj=function(){return lne(this)},f.Qb=function(){throw J(new $n)},C(_s,"AbstractEList/NonResolvingEIterator",356),T(393,288,Ud,v_,a0e),f.Rb=function(t){throw J(new $n)},f.Wj=function(){var t;try{return t=this.c.Ti(this.e),this.Vj(),this.g=this.e++,t}catch(n){throw n=vr(n),oe(n,99)?(this.Vj(),J(new Co)):J(n)}},f.Xj=function(){var t;try{return t=this.c.Ti(--this.e),this.Vj(),this.g=this.e,t}catch(n){throw n=vr(n),oe(n,99)?(this.Vj(),J(new Co)):J(n)}},f.Qb=function(){throw J(new $n)},f.Wb=function(t){throw J(new $n)},C(_s,"AbstractEList/NonResolvingEListIterator",393),T(2059,71,xut),f.Ci=function(t,n){var i,r,o,a,d,b,v,x,S,M,L;if(o=n.gc(),o!=0){for(x=c(Wt(this.a,4),131),S=x==null?0:x.length,L=S+o,r=Nte(this,L),M=S-t,M>0&&mc(x,t,r,t+o,M),v=n.Jc(),d=0;d<o;++d)b=v.Pb(),i=t+d,eZ(r,i,fS(this,b));for(SS(this,r),a=0;a<o;++a)b=r[t],this.Ki(t,b),++t;return!0}else return++this.j,!1},f.Di=function(t){var n,i,r,o,a,d,b,v,x;if(r=t.gc(),r!=0){for(v=(i=c(Wt(this.a,4),131),i==null?0:i.length),x=v+r,n=Nte(this,x),b=t.Jc(),a=v;a<x;++a)d=b.Pb(),eZ(n,a,fS(this,d));for(SS(this,n),o=v;o<x;++o)d=n[o],this.Ki(o,d);return!0}else return++this.j,!1},f.Ei=function(t,n){var i,r,o,a;r=c(Wt(this.a,4),131),o=r==null?0:r.length,i=Nte(this,o+1),a=fS(this,n),t!=o&&mc(r,t,i,t+1,o-t),dr(i,t,a),SS(this,i),this.Ki(t,n)},f.Fi=function(t){var n,i,r;r=(i=c(Wt(this.a,4),131),i==null?0:i.length),n=Nte(this,r+1),eZ(n,r,fS(this,t)),SS(this,n),this.Ki(r,t)},f.Gi=function(){return new nUe(this)},f.Hi=function(){return new cqe(this)},f.Ii=function(t){var n,i;if(i=(n=c(Wt(this.a,4),131),n==null?0:n.length),t<0||t>i)throw J(new F2(t,i));return new Rqe(this,t)},f.$b=function(){var t,n;++this.j,t=c(Wt(this.a,4),131),n=t==null?0:t.length,SS(this,null),zee(this,n,t)},f.Gc=function(t){var n,i,r,o,a;if(n=c(Wt(this.a,4),131),n!=null){if(t!=null){for(r=n,o=0,a=r.length;o<a;++o)if(i=r[o],yi(t,i))return!0}else for(r=n,o=0,a=r.length;o<a;++o)if(i=r[o],ve(i)===ve(t))return!0}return!1},f.Xb=function(t){var n,i;if(n=c(Wt(this.a,4),131),i=n==null?0:n.length,t>=i)throw J(new F2(t,i));return n[t]},f.bd=function(t){var n,i,r;if(n=c(Wt(this.a,4),131),n!=null){if(t!=null){for(i=0,r=n.length;i<r;++i)if(yi(t,n[i]))return i}else for(i=0,r=n.length;i<r;++i)if(ve(n[i])===ve(t))return i}return-1},f.dc=function(){return c(Wt(this.a,4),131)==null},f.Jc=function(){return new tUe(this)},f.cd=function(){return new oqe(this)},f.dd=function(t){var n,i;if(i=(n=c(Wt(this.a,4),131),n==null?0:n.length),t<0||t>i)throw J(new F2(t,i));return new Iqe(this,t)},f.Ri=function(t,n){var i,r,o;if(i=_Ke(this),o=i==null?0:i.length,t>=o)throw J(new zc(toe+t+Tb+o));if(n>=o)throw J(new zc(noe+n+Tb+o));return r=i[n],t!=n&&(t<n?mc(i,t,i,t+1,n-t):mc(i,n+1,i,n,t-n),dr(i,t,r),SS(this,i)),r},f.Ti=function(t){return c(Wt(this.a,4),131)[t]},f.ed=function(t){return zGt(this,t)},f.Vi=function(t,n){var i,r;return i=_Ke(this),r=i[t],eZ(i,t,fS(this,n)),SS(this,i),r},f.gc=function(){var t;return t=c(Wt(this.a,4),131),t==null?0:t.length},f.Nc=function(){var t,n,i;return t=c(Wt(this.a,4),131),i=t==null?0:t.length,n=ye(Sae,coe,420,i,0,1),i>0&&mc(t,0,n,0,i),n},f.Oc=function(t){var n,i,r;return n=c(Wt(this.a,4),131),r=n==null?0:n.length,r>0&&(t.length<r&&(i=lD(ju(t).c,r),t=i),mc(n,0,t,0,r)),t.length>r&&dr(t,r,null),t};var _2t;C(_s,"ArrayDelegatingEList",2059),T(1043,39,ts,tUe),f.Vj=function(){if(this.b.j!=this.f||ve(c(Wt(this.b.a,4),131))!==ve(this.a))throw J(new ua)},f.Qb=function(){MT(this),this.a=c(Wt(this.b.a,4),131)},C(_s,"ArrayDelegatingEList/EIterator",1043),T(719,288,Ud,oqe,Iqe),f.Vj=function(){if(this.b.j!=this.f||ve(c(Wt(this.b.a,4),131))!==ve(this.a))throw J(new ua)},f.Yj=function(t){OYe(this,t),this.a=c(Wt(this.b.a,4),131)},f.Qb=function(){MT(this),this.a=c(Wt(this.b.a,4),131)},C(_s,"ArrayDelegatingEList/EListIterator",719),T(1044,356,ts,nUe),f.Vj=function(){if(this.b.j!=this.f||ve(c(Wt(this.b.a,4),131))!==ve(this.a))throw J(new ua)},C(_s,"ArrayDelegatingEList/NonResolvingEIterator",1044),T(720,393,Ud,cqe,Rqe),f.Vj=function(){if(this.b.j!=this.f||ve(c(Wt(this.b.a,4),131))!==ve(this.a))throw J(new ua)},C(_s,"ArrayDelegatingEList/NonResolvingEListIterator",720),T(612,306,GQ,JY),C(_s,"BasicEList/BasicIndexOutOfBoundsException",612),T(706,67,md,K1e),f._c=function(t,n){throw J(new $n)},f.Ec=function(t){throw J(new $n)},f.ad=function(t,n){throw J(new $n)},f.Fc=function(t){throw J(new $n)},f.$b=function(){throw J(new $n)},f.Zi=function(t){throw J(new $n)},f.Jc=function(){return this.Gi()},f.cd=function(){return this.Hi()},f.dd=function(t){return this.Ii(t)},f.Ri=function(t,n){throw J(new $n)},f.Si=function(t,n){throw J(new $n)},f.ed=function(t){throw J(new $n)},f.Kc=function(t){throw J(new $n)},f.fd=function(t,n){throw J(new $n)},C(_s,"BasicEList/UnmodifiableEList",706),T(718,1,{3:1,22:1,18:1,16:1,61:1,593:1}),f._c=function(t,n){yjt(this,t,c(n,45))},f.Ec=function(t){return w7t(this,c(t,45))},f.Ic=function(t){ws(this,t)},f.Xb=function(t){return c(re(this.c,t),138)},f.Ri=function(t,n){return c(this.c.Ri(t,n),45)},f.Si=function(t,n){xjt(this,t,c(n,45))},f.ed=function(t){return c(this.c.ed(t),45)},f.fd=function(t,n){return DMt(this,t,c(n,45))},f.gd=function(t){cb(this,t)},f.Lc=function(){return new Tt(this,16)},f.Mc=function(){return new jt(null,new Tt(this,16))},f.ad=function(t,n){return this.c.ad(t,n)},f.Fc=function(t){return this.c.Fc(t)},f.$b=function(){this.c.$b()},f.Gc=function(t){return this.c.Gc(t)},f.Hc=function(t){return mD(this.c,t)},f.Zj=function(){var t,n,i;if(this.d==null){for(this.d=ye(wTe,T5e,67,2*this.f+1,0,1),i=this.e,this.f=0,n=this.c.Jc();n.e!=n.i.gc();)t=c(n.Wj(),138),WH(this,t);this.e=i}},f.Fb=function(t){return Mze(this,t)},f.Hb=function(){return Tme(this.c)},f.bd=function(t){return this.c.bd(t)},f.$j=function(){this.c=new PDe(this)},f.dc=function(){return this.f==0},f.Jc=function(){return this.c.Jc()},f.cd=function(){return this.c.cd()},f.dd=function(t){return this.c.dd(t)},f._j=function(){return V_(this)},f.ak=function(t,n,i){return new Hze(t,n,i)},f.bk=function(){return new ZA},f.Kc=function(t){return MXe(this,t)},f.gc=function(){return this.f},f.hd=function(t,n){return new nd(this.c,t,n)},f.Nc=function(){return this.c.Nc()},f.Oc=function(t){return this.c.Oc(t)},f.Ib=function(){return Owe(this.c)},f.e=0,f.f=0,C(_s,"BasicEMap",718),T(1038,67,md,PDe),f.Ki=function(t,n){i9t(this,c(n,138))},f.Ni=function(t,n,i){var r;++(r=this,c(n,138),r).a.e},f.Oi=function(t,n){r9t(this,c(n,138))},f.Pi=function(t,n,i){Zjt(this,c(n,138),c(i,138))},f.Mi=function(t,n){kVe(this.a)},C(_s,"BasicEMap/1",1038),T(1039,67,md,ZA),f.$i=function(t){return ye(cnn,kut,618,t,0,1)},C(_s,"BasicEMap/2",1039),T(1040,Nh,Ll,IDe),f.$b=function(){this.a.c.$b()},f.Gc=function(t){return Wte(this.a,t)},f.Jc=function(){return this.a.f==0?(_6(),YP.a):new yPe(this.a)},f.Kc=function(t){var n;return n=this.a.f,zH(this.a,t),this.a.f!=n},f.gc=function(){return this.a.f},C(_s,"BasicEMap/3",1040),T(1041,32,Ov,RDe),f.$b=function(){this.a.c.$b()},f.Gc=function(t){return Fnt(this.a,t)},f.Jc=function(){return this.a.f==0?(_6(),YP.a):new xPe(this.a)},f.gc=function(){return this.a.f},C(_s,"BasicEMap/4",1041),T(1042,Nh,Ll,$De),f.$b=function(){this.a.c.$b()},f.Gc=function(t){var n,i,r,o,a,d,b,v,x;if(this.a.f>0&&oe(t,45)&&(this.a.Zj(),v=c(t,45),b=v.jd(),o=b==null?0:Ri(b),a=Xge(this.a,o),n=this.a.d[a],n)){for(i=c(n.g,375),x=n.i,d=0;d<x;++d)if(r=i[d],r.yi()==o&&r.Fb(v))return!0}return!1},f.Jc=function(){return this.a.f==0?(_6(),YP.a):new lee(this.a)},f.Kc=function(t){return Mtt(this,t)},f.gc=function(){return this.a.f},C(_s,"BasicEMap/5",1042),T(619,1,ts,lee),f.Nb=function(t){gs(this,t)},f.Ob=function(){return this.b!=-1},f.Pb=function(){var t;if(this.f.e!=this.c)throw J(new ua);if(this.b==-1)throw J(new Co);return this.d=this.a,this.e=this.b,rZe(this),t=c(this.f.d[this.d].g[this.e],138),this.ck(t)},f.Qb=function(){if(this.f.e!=this.c)throw J(new ua);if(this.e==-1)throw J(new Tl);this.f.c.Kc(re(this.f.d[this.d],this.e)),this.c=this.f.e,this.e=-1,this.a==this.d&&this.b!=-1&&--this.b},f.ck=function(t){return t},f.a=0,f.b=-1,f.c=0,f.d=0,f.e=0,C(_s,"BasicEMap/BasicEMapIterator",619),T(1036,619,ts,yPe),f.ck=function(t){return t.jd()},C(_s,"BasicEMap/BasicEMapKeyIterator",1036),T(1037,619,ts,xPe),f.ck=function(t){return t.kd()},C(_s,"BasicEMap/BasicEMapValueIterator",1037),T(1035,1,fw,BDe),f.wc=function(t){fD(this,t)},f.$b=function(){this.a.c.$b()},f._b=function(t){return s$e(this,t)},f.uc=function(t){return Fnt(this.a,t)},f.vc=function(){return mLt(this.a)},f.Fb=function(t){return Mze(this.a,t)},f.xc=function(t){return Zf(this.a,t)},f.Hb=function(){return Tme(this.a.c)},f.dc=function(){return this.a.f==0},f.ec=function(){return pLt(this.a)},f.yc=function(t,n){return PD(this.a,t,n)},f.Ac=function(t){return zH(this.a,t)},f.gc=function(){return this.a.f},f.Ib=function(){return Owe(this.a.c)},f.Bc=function(){return bLt(this.a)},C(_s,"BasicEMap/DelegatingMap",1035),T(618,1,{45:1,138:1,618:1},Hze),f.Fb=function(t){var n;return oe(t,45)?(n=c(t,45),(this.b!=null?yi(this.b,n.jd()):ve(this.b)===ve(n.jd()))&&(this.c!=null?yi(this.c,n.kd()):ve(this.c)===ve(n.kd()))):!1},f.yi=function(){return this.a},f.jd=function(){return this.b},f.kd=function(){return this.c},f.Hb=function(){return this.a^(this.c==null?0:Ri(this.c))},f.zi=function(t){this.a=t},f.Ai=function(t){throw J(new zp)},f.ld=function(t){var n;return n=this.c,this.c=t,n},f.Ib=function(){return this.b+"->"+this.c},f.a=0;var cnn=C(_s,"BasicEMap/EntryImpl",618);T(538,1,{},pg),C(_s,"BasicEMap/View",538);var YP;T(776,1,{}),f.Fb=function(t){return Mve((Ct(),Rs),t)},f.Hb=function(){return $me((Ct(),Rs))},f.Ib=function(){return Mh((Ct(),Rs))},C(_s,"ECollections/BasicEmptyUnmodifiableEList",776),T(1314,1,Ud,ca),f.Nb=function(t){gs(this,t)},f.Rb=function(t){throw J(new $n)},f.Ob=function(){return!1},f.Sb=function(){return!1},f.Pb=function(){throw J(new Co)},f.Tb=function(){return 0},f.Ub=function(){throw J(new Co)},f.Vb=function(){return-1},f.Qb=function(){throw J(new $n)},f.Wb=function(t){throw J(new $n)},C(_s,"ECollections/BasicEmptyUnmodifiableEList/1",1314),T(1312,776,{22:1,18:1,16:1,61:1},ELe),f._c=function(t,n){HPe()},f.Ec=function(t){return QPe()},f.ad=function(t,n){return GPe()},f.Fc=function(t){return UPe()},f.$b=function(){JPe()},f.Gc=function(t){return!1},f.Hc=function(t){return!1},f.Ic=function(t){ws(this,t)},f.Xb=function(t){return tge((Ct(),t)),null},f.bd=function(t){return-1},f.dc=function(){return!0},f.Jc=function(){return this.a},f.cd=function(){return this.a},f.dd=function(t){return this.a},f.Ri=function(t,n){return XPe()},f.Si=function(t,n){VPe()},f.ed=function(t){return WPe()},f.Kc=function(t){return KPe()},f.fd=function(t,n){return YPe()},f.gc=function(){return 0},f.gd=function(t){cb(this,t)},f.Lc=function(){return new Tt(this,16)},f.Mc=function(){return new jt(null,new Tt(this,16))},f.hd=function(t,n){return Ct(),new nd(Rs,t,n)},f.Nc=function(){return V0e((Ct(),Rs))},f.Oc=function(t){return Ct(),jT(Rs,t)},C(_s,"ECollections/EmptyUnmodifiableEList",1312),T(1313,776,{22:1,18:1,16:1,61:1,593:1},CLe),f._c=function(t,n){HPe()},f.Ec=function(t){return QPe()},f.ad=function(t,n){return GPe()},f.Fc=function(t){return UPe()},f.$b=function(){JPe()},f.Gc=function(t){return!1},f.Hc=function(t){return!1},f.Ic=function(t){ws(this,t)},f.Xb=function(t){return tge((Ct(),t)),null},f.bd=function(t){return-1},f.dc=function(){return!0},f.Jc=function(){return this.a},f.cd=function(){return this.a},f.dd=function(t){return this.a},f.Ri=function(t,n){return XPe()},f.Si=function(t,n){VPe()},f.ed=function(t){return WPe()},f.Kc=function(t){return KPe()},f.fd=function(t,n){return YPe()},f.gc=function(){return 0},f.gd=function(t){cb(this,t)},f.Lc=function(){return new Tt(this,16)},f.Mc=function(){return new jt(null,new Tt(this,16))},f.hd=function(t,n){return Ct(),new nd(Rs,t,n)},f.Nc=function(){return V0e((Ct(),Rs))},f.Oc=function(t){return Ct(),jT(Rs,t)},f._j=function(){return Ct(),Ct(),Yd},C(_s,"ECollections/EmptyUnmodifiableEMap",1313);var yTe=Ki(_s,"Enumerator"),cX;T(291,1,{291:1},rie),f.Fb=function(t){var n;return this===t?!0:oe(t,291)?(n=c(t,291),this.f==n.f&&tMt(this.i,n.i)&&DZ(this.a,(this.f&256)!=0?(n.f&256)!=0?n.a:null:(n.f&256)!=0?null:n.a)&&DZ(this.d,n.d)&&DZ(this.g,n.g)&&DZ(this.e,n.e)&&azt(this,n)):!1},f.Hb=function(){return this.f},f.Ib=function(){return kit(this)},f.f=0;var D2t=0,L2t=0,P2t=0,I2t=0,xTe=0,kTe=0,OTe=0,STe=0,jTe=0,R2t,HC=0,QC=0,$2t=0,B2t=0,lX,TTe;C(_s,"URI",291),T(1102,44,Gx,MLe),f.yc=function(t,n){return c(lo(this,zn(t),c(n,291)),291)},C(_s,"URI/URICache",1102),T(495,67,md,W$,VF),f.Qi=function(){return!0},C(_s,"UniqueEList",495),T(585,63,H1,Uq),C(_s,"WrappedException",585);var si=Ki(Sa,jut),uy=Ki(Sa,Tut),xl=Ki(Sa,Eut),ay=Ki(Sa,Cut),ah=Ki(Sa,Mut),ef=Ki(Sa,"EClass"),jae=Ki(Sa,"EDataType"),z2t;T(1210,44,Gx,ALe),f.xc=function(t){return Kr(t)?Tc(this,t):Ao(co(this.f,t))},C(Sa,"EDataType/Internal/ConversionDelegate/Factory/Registry/Impl",1210);var uX=Ki(Sa,"EEnum"),tg=Ki(Sa,Aut),Ks=Ki(Sa,Nut),tf=Ki(Sa,_ut),nf,$w=Ki(Sa,Dut),fy=Ki(Sa,Lut);T(1034,1,{},lf),f.Ib=function(){return"NIL"},C(Sa,"EStructuralFeature/Internal/DynamicValueHolder/1",1034);var F2t;T(1033,44,Gx,NLe),f.xc=function(t){return Kr(t)?Tc(this,t):Ao(co(this.f,t))},C(Sa,"EStructuralFeature/Internal/SettingDelegate/Factory/Registry/Impl",1033);var cl=Ki(Sa,Put),$k=Ki(Sa,"EValidator/PatternMatcher"),ETe,CTe,Gt,t0,hy,pp,q2t,H2t,Q2t,bp,n0,mp,Bw,Gh,G2t,U2t,rf,i0,J2t,r0,dy,A3,Bs,X2t,V2t,zw,aX=Ki(Gi,"FeatureMap/Entry");T(537,1,{76:1},hF),f.Jk=function(){return this.a},f.kd=function(){return this.b},C(Xt,"BasicEObjectImpl/1",537),T(1032,1,loe,ZRe),f.Dk=function(t){return Pee(this.a,this.b,t)},f.Oj=function(){return HHe(this.a,this.b)},f.Wb=function(t){Ppe(this.a,this.b,t)},f.Ek=function(){VMt(this.a,this.b)},C(Xt,"BasicEObjectImpl/4",1032),T(2060,1,{115:1}),f.Kk=function(t){this.e=t==0?W2t:ye(Br,Lt,1,t,5,1)},f.ii=function(t){return this.e[t]},f.ji=function(t,n){this.e[t]=n},f.ki=function(t){this.e[t]=null},f.Lk=function(){return this.c},f.Mk=function(){throw J(new $n)},f.Nk=function(){throw J(new $n)},f.Ok=function(){return this.d},f.Pk=function(){return this.e!=null},f.Qk=function(t){this.c=t},f.Rk=function(t){throw J(new $n)},f.Sk=function(t){throw J(new $n)},f.Tk=function(t){this.d=t};var W2t;C(Xt,"BasicEObjectImpl/EPropertiesHolderBaseImpl",2060),T(195,2060,{115:1},la),f.Mk=function(){return this.a},f.Nk=function(){return this.b},f.Rk=function(t){this.a=t},f.Sk=function(t){this.b=t},C(Xt,"BasicEObjectImpl/EPropertiesHolderImpl",195),T(505,101,Plt,xj),f.rh=function(){return this.f},f.wh=function(){return this.k},f.yh=function(t,n){this.g=t,this.i=n},f.Ah=function(){return(this.j&2)==0?this.fi():this.Xh().Lk()},f.Ch=function(){return this.i},f.th=function(){return(this.j&1)!=0},f.Mh=function(){return this.g},f.Sh=function(){return(this.j&4)!=0},f.Xh=function(){return!this.k&&(this.k=new la),this.k},f._h=function(t){this.Xh().Qk(t),t?this.j|=2:this.j&=-3},f.bi=function(t){this.Xh().Sk(t),t?this.j|=4:this.j&=-5},f.fi=function(){return(j0(),Gt).S},f.i=0,f.j=1,C(Xt,"EObjectImpl",505),T(792,505,{110:1,95:1,94:1,57:1,115:1,52:1,101:1},_0e),f.ii=function(t){return this.e[t]},f.ji=function(t,n){this.e[t]=n},f.ki=function(t){this.e[t]=null},f.Ah=function(){return this.d},f.Fh=function(t){return Vi(this.d,t)},f.Hh=function(){return this.d},f.Lh=function(){return this.e!=null},f.Xh=function(){return!this.k&&(this.k=new K$),this.k},f._h=function(t){this.d=t},f.ei=function(){var t;return this.e==null&&(t=pn(this.d),this.e=t==0?K2t:ye(Br,Lt,1,t,5,1)),this},f.gi=function(){return 0};var K2t;C(Xt,"DynamicEObjectImpl",792),T(1500,792,{110:1,45:1,95:1,94:1,138:1,57:1,115:1,52:1,101:1},wFe),f.Fb=function(t){return this===t},f.Hb=function(){return Lm(this)},f._h=function(t){this.d=t,this.b=JD(t,"key"),this.c=JD(t,mE)},f.yi=function(){var t;return this.a==-1&&(t=Vee(this,this.b),this.a=t==null?0:Ri(t)),this.a},f.jd=function(){return Vee(this,this.b)},f.kd=function(){return Vee(this,this.c)},f.zi=function(t){this.a=t},f.Ai=function(t){Ppe(this,this.b,t)},f.ld=function(t){var n;return n=Vee(this,this.c),Ppe(this,this.c,t),n},f.a=0,C(Xt,"DynamicEObjectImpl/BasicEMapEntry",1500),T(1501,1,{115:1},K$),f.Kk=function(t){throw J(new $n)},f.ii=function(t){throw J(new $n)},f.ji=function(t,n){throw J(new $n)},f.ki=function(t){throw J(new $n)},f.Lk=function(){throw J(new $n)},f.Mk=function(){return this.a},f.Nk=function(){return this.b},f.Ok=function(){return this.c},f.Pk=function(){throw J(new $n)},f.Qk=function(t){throw J(new $n)},f.Rk=function(t){this.a=t},f.Sk=function(t){this.b=t},f.Tk=function(t){this.c=t},C(Xt,"DynamicEObjectImpl/DynamicEPropertiesHolderImpl",1501),T(508,162,{110:1,95:1,94:1,594:1,159:1,57:1,115:1,52:1,101:1,508:1,162:1,118:1,119:1},eN),f.xh=function(t){return u2e(this,t)},f.Ih=function(t,n,i){var r;switch(t){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),this.Ab;case 1:return this.d;case 2:return i?(!this.b&&(this.b=new yu((Mt(),Bs),Yo,this)),this.b):(!this.b&&(this.b=new yu((Mt(),Bs),Yo,this)),V_(this.b));case 3:return VHe(this);case 4:return!this.a&&(this.a=new Ar(dp,this,4)),this.a;case 5:return!this.c&&(this.c=new mx(dp,this,5)),this.c}return pa(this,t-pn((Mt(),t0)),_t((r=c(Wt(this,16),29),r||t0),t),n,i)},f.Ph=function(t,n,i){var r,o,a;switch(n){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),Uc(this.Ab,t,i);case 3:return this.Cb&&(i=(o=this.Db>>16,o>=0?u2e(this,i):this.Cb.Qh(this,-1-o,null,i))),J0e(this,c(t,159),i)}return a=c(_t((r=c(Wt(this,16),29),r||(Mt(),t0)),n),69),a.uk().xk(this,tl(this),n-pn((Mt(),t0)),t,i)},f.Rh=function(t,n,i){var r,o;switch(n){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),Ns(this.Ab,t,i);case 2:return!this.b&&(this.b=new yu((Mt(),Bs),Yo,this)),_F(this.b,t,i);case 3:return J0e(this,null,i);case 4:return!this.a&&(this.a=new Ar(dp,this,4)),Ns(this.a,t,i)}return o=c(_t((r=c(Wt(this,16),29),r||(Mt(),t0)),n),69),o.uk().yk(this,tl(this),n-pn((Mt(),t0)),t,i)},f.Th=function(t){var n;switch(t){case 0:return!!this.Ab&&this.Ab.i!=0;case 1:return this.d!=null;case 2:return!!this.b&&this.b.f!=0;case 3:return!!VHe(this);case 4:return!!this.a&&this.a.i!=0;case 5:return!!this.c&&this.c.i!=0}return da(this,t-pn((Mt(),t0)),_t((n=c(Wt(this,16),29),n||t0),t))},f.$h=function(t,n){var i;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab),!this.Ab&&(this.Ab=new Me(si,this,0,3)),ur(this.Ab,c(n,18));return;case 1:BCt(this,zn(n));return;case 2:!this.b&&(this.b=new yu((Mt(),Bs),Yo,this)),bH(this.b,n);return;case 3:unt(this,c(n,159));return;case 4:!this.a&&(this.a=new Ar(dp,this,4)),En(this.a),!this.a&&(this.a=new Ar(dp,this,4)),ur(this.a,c(n,18));return;case 5:!this.c&&(this.c=new mx(dp,this,5)),En(this.c),!this.c&&(this.c=new mx(dp,this,5)),ur(this.c,c(n,18));return}xa(this,t-pn((Mt(),t0)),_t((i=c(Wt(this,16),29),i||t0),t),n)},f.fi=function(){return Mt(),t0},f.hi=function(t){var n;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab);return;case 1:cme(this,null);return;case 2:!this.b&&(this.b=new yu((Mt(),Bs),Yo,this)),this.b.c.$b();return;case 3:unt(this,null);return;case 4:!this.a&&(this.a=new Ar(dp,this,4)),En(this.a);return;case 5:!this.c&&(this.c=new mx(dp,this,5)),En(this.c);return}ya(this,t-pn((Mt(),t0)),_t((n=c(Wt(this,16),29),n||t0),t))},f.Ib=function(){return UWe(this)},f.d=null,C(Xt,"EAnnotationImpl",508),T(145,718,E5e,Al),f.Ei=function(t,n){rjt(this,t,c(n,45))},f.Uk=function(t,n){return oTt(this,c(t,45),n)},f.Yi=function(t){return c(c(this.c,72).Yi(t),138)},f.Gi=function(){return c(this.c,72).Gi()},f.Hi=function(){return c(this.c,72).Hi()},f.Ii=function(t){return c(this.c,72).Ii(t)},f.Vk=function(t,n){return _F(this,t,n)},f.Dk=function(t){return c(this.c,78).Dk(t)},f.$j=function(){},f.Oj=function(){return c(this.c,78).Oj()},f.ak=function(t,n,i){var r;return r=c(Bu(this.b).ti().pi(this.b),138),r.zi(t),r.Ai(n),r.ld(i),r},f.bk=function(){return new Sde(this)},f.Wb=function(t){bH(this,t)},f.Ek=function(){c(this.c,78).Ek()},C(Gi,"EcoreEMap",145),T(170,145,E5e,yu),f.Zj=function(){var t,n,i,r,o,a;if(this.d==null){for(a=ye(wTe,T5e,67,2*this.f+1,0,1),i=this.c.Jc();i.e!=i.i.gc();)n=c(i.Wj(),138),r=n.yi(),o=(r&di)%a.length,t=a[o],!t&&(t=a[o]=new Sde(this)),t.Ec(n);this.d=a}},C(Xt,"EAnnotationImpl/1",170),T(294,444,{110:1,95:1,94:1,159:1,199:1,57:1,115:1,473:1,52:1,101:1,162:1,294:1,118:1,119:1}),f.Ih=function(t,n,i){var r,o;switch(t){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),this.Ab;case 1:return this.zb;case 2:return Bt(),(this.Bb&256)!=0;case 3:return Bt(),(this.Bb&512)!=0;case 4:return Pe(this.s);case 5:return Pe(this.t);case 6:return Bt(),!!this.Hk();case 7:return Bt(),o=this.s,o>=1;case 8:return n?Qa(this):this.r;case 9:return this.q}return pa(this,t-pn(this.fi()),_t((r=c(Wt(this,16),29),r||this.fi()),t),n,i)},f.Rh=function(t,n,i){var r,o;switch(n){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),Ns(this.Ab,t,i);case 9:return VZ(this,i)}return o=c(_t((r=c(Wt(this,16),29),r||this.fi()),n),69),o.uk().yk(this,tl(this),n-pn(this.fi()),t,i)},f.Th=function(t){var n,i;switch(t){case 0:return!!this.Ab&&this.Ab.i!=0;case 1:return this.zb!=null;case 2:return(this.Bb&256)==0;case 3:return(this.Bb&512)==0;case 4:return this.s!=0;case 5:return this.t!=1;case 6:return this.Hk();case 7:return i=this.s,i>=1;case 8:return!!this.r&&!this.q.e&&$m(this.q).i==0;case 9:return!!this.q&&!(this.r&&!this.q.e&&$m(this.q).i==0)}return da(this,t-pn(this.fi()),_t((n=c(Wt(this,16),29),n||this.fi()),t))},f.$h=function(t,n){var i,r;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab),!this.Ab&&(this.Ab=new Me(si,this,0,3)),ur(this.Ab,c(n,18));return;case 1:this.ri(zn(n));return;case 2:Ig(this,et(Ze(n)));return;case 3:Rg(this,et(Ze(n)));return;case 4:_g(this,c(n,15).a);return;case 5:this.Xk(c(n,15).a);return;case 8:db(this,c(n,146));return;case 9:r=Ch(this,c(n,88),null),r&&r.mj();return}xa(this,t-pn(this.fi()),_t((i=c(Wt(this,16),29),i||this.fi()),t),n)},f.fi=function(){return Mt(),V2t},f.hi=function(t){var n,i;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab);return;case 1:this.ri(null);return;case 2:Ig(this,!0);return;case 3:Rg(this,!0);return;case 4:_g(this,0);return;case 5:this.Xk(1);return;case 8:db(this,null);return;case 9:i=Ch(this,null,null),i&&i.mj();return}ya(this,t-pn(this.fi()),_t((n=c(Wt(this,16),29),n||this.fi()),t))},f.mi=function(){Qa(this),this.Bb|=1},f.Fk=function(){return Qa(this)},f.Gk=function(){return this.t},f.Hk=function(){var t;return t=this.t,t>1||t==-1},f.Qi=function(){return(this.Bb&512)!=0},f.Wk=function(t,n){return rwe(this,t,n)},f.Xk=function(t){iv(this,t)},f.Ib=function(){return yve(this)},f.s=0,f.t=1,C(Xt,"ETypedElementImpl",294),T(454,294,{110:1,95:1,94:1,159:1,199:1,57:1,182:1,69:1,115:1,473:1,52:1,101:1,162:1,454:1,294:1,118:1,119:1,689:1}),f.xh=function(t){return $Ye(this,t)},f.Ih=function(t,n,i){var r,o;switch(t){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),this.Ab;case 1:return this.zb;case 2:return Bt(),(this.Bb&256)!=0;case 3:return Bt(),(this.Bb&512)!=0;case 4:return Pe(this.s);case 5:return Pe(this.t);case 6:return Bt(),!!this.Hk();case 7:return Bt(),o=this.s,o>=1;case 8:return n?Qa(this):this.r;case 9:return this.q;case 10:return Bt(),(this.Bb&Ga)!=0;case 11:return Bt(),(this.Bb&q1)!=0;case 12:return Bt(),(this.Bb&jv)!=0;case 13:return this.j;case 14:return _S(this);case 15:return Bt(),(this.Bb&Pl)!=0;case 16:return Bt(),(this.Bb&ad)!=0;case 17:return W2(this)}return pa(this,t-pn(this.fi()),_t((r=c(Wt(this,16),29),r||this.fi()),t),n,i)},f.Ph=function(t,n,i){var r,o,a;switch(n){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),Uc(this.Ab,t,i);case 17:return this.Cb&&(i=(o=this.Db>>16,o>=0?$Ye(this,i):this.Cb.Qh(this,-1-o,null,i))),Qu(this,t,17,i)}return a=c(_t((r=c(Wt(this,16),29),r||this.fi()),n),69),a.uk().xk(this,tl(this),n-pn(this.fi()),t,i)},f.Rh=function(t,n,i){var r,o;switch(n){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),Ns(this.Ab,t,i);case 9:return VZ(this,i);case 17:return Qu(this,null,17,i)}return o=c(_t((r=c(Wt(this,16),29),r||this.fi()),n),69),o.uk().yk(this,tl(this),n-pn(this.fi()),t,i)},f.Th=function(t){var n,i;switch(t){case 0:return!!this.Ab&&this.Ab.i!=0;case 1:return this.zb!=null;case 2:return(this.Bb&256)==0;case 3:return(this.Bb&512)==0;case 4:return this.s!=0;case 5:return this.t!=1;case 6:return this.Hk();case 7:return i=this.s,i>=1;case 8:return!!this.r&&!this.q.e&&$m(this.q).i==0;case 9:return!!this.q&&!(this.r&&!this.q.e&&$m(this.q).i==0);case 10:return(this.Bb&Ga)==0;case 11:return(this.Bb&q1)!=0;case 12:return(this.Bb&jv)!=0;case 13:return this.j!=null;case 14:return _S(this)!=null;case 15:return(this.Bb&Pl)!=0;case 16:return(this.Bb&ad)!=0;case 17:return!!W2(this)}return da(this,t-pn(this.fi()),_t((n=c(Wt(this,16),29),n||this.fi()),t))},f.$h=function(t,n){var i,r;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab),!this.Ab&&(this.Ab=new Me(si,this,0,3)),ur(this.Ab,c(n,18));return;case 1:xee(this,zn(n));return;case 2:Ig(this,et(Ze(n)));return;case 3:Rg(this,et(Ze(n)));return;case 4:_g(this,c(n,15).a);return;case 5:this.Xk(c(n,15).a);return;case 8:db(this,c(n,146));return;case 9:r=Ch(this,c(n,88),null),r&&r.mj();return;case 10:bS(this,et(Ze(n)));return;case 11:vS(this,et(Ze(n)));return;case 12:mS(this,et(Ze(n)));return;case 13:Z1e(this,zn(n));return;case 15:wS(this,et(Ze(n)));return;case 16:yS(this,et(Ze(n)));return}xa(this,t-pn(this.fi()),_t((i=c(Wt(this,16),29),i||this.fi()),t),n)},f.fi=function(){return Mt(),X2t},f.hi=function(t){var n,i;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab);return;case 1:oe(this.Cb,89)&&bv(ru(c(this.Cb,89)),4),Gc(this,null);return;case 2:Ig(this,!0);return;case 3:Rg(this,!0);return;case 4:_g(this,0);return;case 5:this.Xk(1);return;case 8:db(this,null);return;case 9:i=Ch(this,null,null),i&&i.mj();return;case 10:bS(this,!0);return;case 11:vS(this,!1);return;case 12:mS(this,!1);return;case 13:this.i=null,aH(this,null);return;case 15:wS(this,!1);return;case 16:yS(this,!1);return}ya(this,t-pn(this.fi()),_t((n=c(Wt(this,16),29),n||this.fi()),t))},f.mi=function(){Q6(uo((Dl(),ps),this)),Qa(this),this.Bb|=1},f.nk=function(){return this.f},f.gk=function(){return _S(this)},f.ok=function(){return W2(this)},f.sk=function(){return null},f.Yk=function(){return this.k},f.Jj=function(){return this.n},f.tk=function(){return rQ(this)},f.uk=function(){var t,n,i,r,o,a,d,b,v;return this.p||(i=W2(this),(i.i==null&&ud(i),i.i).length,r=this.sk(),r&&pn(W2(r)),o=Qa(this),d=o.ik(),t=d?(d.i&1)!=0?d==kl?ir:d==Fn?Lr:d==py?O9:d==ns?kr:d==qw?Ow:d==L3?Sw:d==Rl?ak:CE:d:null,n=_S(this),b=o.gk(),D$t(this),(this.Bb&ad)!=0&&((a=b2e((Dl(),ps),i))&&a!=this||(a=S5(uo(ps,this))))?this.p=new t$e(this,a):this.Hk()?this.$k()?r?(this.Bb&Pl)!=0?t?this._k()?this.p=new Yp(47,t,this,r):this.p=new Yp(5,t,this,r):this._k()?this.p=new rb(46,this,r):this.p=new rb(4,this,r):t?this._k()?this.p=new Yp(49,t,this,r):this.p=new Yp(7,t,this,r):this._k()?this.p=new rb(48,this,r):this.p=new rb(6,this,r):(this.Bb&Pl)!=0?t?t==Mb?this.p=new Tg(50,A2t,this):this._k()?this.p=new Tg(43,t,this):this.p=new Tg(1,t,this):this._k()?this.p=new Cg(42,this):this.p=new Cg(0,this):t?t==Mb?this.p=new Tg(41,A2t,this):this._k()?this.p=new Tg(45,t,this):this.p=new Tg(3,t,this):this._k()?this.p=new Cg(44,this):this.p=new Cg(2,this):oe(o,160)?t==aX?this.p=new Cg(40,this):(this.Bb&512)!=0?(this.Bb&Pl)!=0?t?this.p=new Tg(9,t,this):this.p=new Cg(8,this):t?this.p=new Tg(11,t,this):this.p=new Cg(10,this):(this.Bb&Pl)!=0?t?this.p=new Tg(13,t,this):this.p=new Cg(12,this):t?this.p=new Tg(15,t,this):this.p=new Cg(14,this):r?(v=r.t,v>1||v==-1?this._k()?(this.Bb&Pl)!=0?t?this.p=new Yp(25,t,this,r):this.p=new rb(24,this,r):t?this.p=new Yp(27,t,this,r):this.p=new rb(26,this,r):(this.Bb&Pl)!=0?t?this.p=new Yp(29,t,this,r):this.p=new rb(28,this,r):t?this.p=new Yp(31,t,this,r):this.p=new rb(30,this,r):this._k()?(this.Bb&Pl)!=0?t?this.p=new Yp(33,t,this,r):this.p=new rb(32,this,r):t?this.p=new Yp(35,t,this,r):this.p=new rb(34,this,r):(this.Bb&Pl)!=0?t?this.p=new Yp(37,t,this,r):this.p=new rb(36,this,r):t?this.p=new Yp(39,t,this,r):this.p=new rb(38,this,r)):this._k()?(this.Bb&Pl)!=0?t?this.p=new Tg(17,t,this):this.p=new Cg(16,this):t?this.p=new Tg(19,t,this):this.p=new Cg(18,this):(this.Bb&Pl)!=0?t?this.p=new Tg(21,t,this):this.p=new Cg(20,this):t?this.p=new Tg(23,t,this):this.p=new Cg(22,this):this.Zk()?this._k()?this.p=new Uze(c(o,29),this,r):this.p=new Lpe(c(o,29),this,r):oe(o,160)?t==aX?this.p=new Cg(40,this):(this.Bb&Pl)!=0?t?this.p=new HFe(n,b,this,(Yte(),d==Fn?PTe:d==kl?ATe:d==qw?ITe:d==py?LTe:d==ns?DTe:d==L3?RTe:d==Rl?NTe:d==Na?_Te:Cae)):this.p=new oHe(c(o,160),n,b,this):t?this.p=new qFe(n,b,this,(Yte(),d==Fn?PTe:d==kl?ATe:d==qw?ITe:d==py?LTe:d==ns?DTe:d==L3?RTe:d==Rl?NTe:d==Na?_Te:Cae)):this.p=new sHe(c(o,160),n,b,this):this.$k()?r?(this.Bb&Pl)!=0?this._k()?this.p=new Xze(c(o,29),this,r):this.p=new k0e(c(o,29),this,r):this._k()?this.p=new Jze(c(o,29),this,r):this.p=new jZ(c(o,29),this,r):(this.Bb&Pl)!=0?this._k()?this.p=new FBe(c(o,29),this):this.p=new Rge(c(o,29),this):this._k()?this.p=new zBe(c(o,29),this):this.p=new aZ(c(o,29),this):this._k()?r?(this.Bb&Pl)!=0?this.p=new Vze(c(o,29),this,r):this.p=new y0e(c(o,29),this,r):(this.Bb&Pl)!=0?this.p=new HBe(c(o,29),this):this.p=new $ge(c(o,29),this):r?(this.Bb&Pl)!=0?this.p=new Wze(c(o,29),this,r):this.p=new x0e(c(o,29),this,r):(this.Bb&Pl)!=0?this.p=new qBe(c(o,29),this):this.p=new WF(c(o,29),this)),this.p},f.pk=function(){return(this.Bb&Ga)!=0},f.Zk=function(){return!1},f.$k=function(){return!1},f.qk=function(){return(this.Bb&ad)!=0},f.vk=function(){return Kee(this)},f._k=function(){return!1},f.rk=function(){return(this.Bb&Pl)!=0},f.al=function(t){this.k=t},f.ri=function(t){xee(this,t)},f.Ib=function(){return CQ(this)},f.e=!1,f.n=0,C(Xt,"EStructuralFeatureImpl",454),T(336,454,{110:1,95:1,94:1,38:1,159:1,199:1,57:1,182:1,69:1,115:1,473:1,52:1,101:1,336:1,162:1,454:1,294:1,118:1,119:1,689:1},HK),f.Ih=function(t,n,i){var r,o;switch(t){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),this.Ab;case 1:return this.zb;case 2:return Bt(),(this.Bb&256)!=0;case 3:return Bt(),(this.Bb&512)!=0;case 4:return Pe(this.s);case 5:return Pe(this.t);case 6:return Bt(),!!gve(this);case 7:return Bt(),o=this.s,o>=1;case 8:return n?Qa(this):this.r;case 9:return this.q;case 10:return Bt(),(this.Bb&Ga)!=0;case 11:return Bt(),(this.Bb&q1)!=0;case 12:return Bt(),(this.Bb&jv)!=0;case 13:return this.j;case 14:return _S(this);case 15:return Bt(),(this.Bb&Pl)!=0;case 16:return Bt(),(this.Bb&ad)!=0;case 17:return W2(this);case 18:return Bt(),(this.Bb&nc)!=0;case 19:return n?vte(this):gUe(this)}return pa(this,t-pn((Mt(),hy)),_t((r=c(Wt(this,16),29),r||hy),t),n,i)},f.Th=function(t){var n,i;switch(t){case 0:return!!this.Ab&&this.Ab.i!=0;case 1:return this.zb!=null;case 2:return(this.Bb&256)==0;case 3:return(this.Bb&512)==0;case 4:return this.s!=0;case 5:return this.t!=1;case 6:return gve(this);case 7:return i=this.s,i>=1;case 8:return!!this.r&&!this.q.e&&$m(this.q).i==0;case 9:return!!this.q&&!(this.r&&!this.q.e&&$m(this.q).i==0);case 10:return(this.Bb&Ga)==0;case 11:return(this.Bb&q1)!=0;case 12:return(this.Bb&jv)!=0;case 13:return this.j!=null;case 14:return _S(this)!=null;case 15:return(this.Bb&Pl)!=0;case 16:return(this.Bb&ad)!=0;case 17:return!!W2(this);case 18:return(this.Bb&nc)!=0;case 19:return!!gUe(this)}return da(this,t-pn((Mt(),hy)),_t((n=c(Wt(this,16),29),n||hy),t))},f.$h=function(t,n){var i,r;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab),!this.Ab&&(this.Ab=new Me(si,this,0,3)),ur(this.Ab,c(n,18));return;case 1:xee(this,zn(n));return;case 2:Ig(this,et(Ze(n)));return;case 3:Rg(this,et(Ze(n)));return;case 4:_g(this,c(n,15).a);return;case 5:kPe(this,c(n,15).a);return;case 8:db(this,c(n,146));return;case 9:r=Ch(this,c(n,88),null),r&&r.mj();return;case 10:bS(this,et(Ze(n)));return;case 11:vS(this,et(Ze(n)));return;case 12:mS(this,et(Ze(n)));return;case 13:Z1e(this,zn(n));return;case 15:wS(this,et(Ze(n)));return;case 16:yS(this,et(Ze(n)));return;case 18:Hte(this,et(Ze(n)));return}xa(this,t-pn((Mt(),hy)),_t((i=c(Wt(this,16),29),i||hy),t),n)},f.fi=function(){return Mt(),hy},f.hi=function(t){var n,i;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab);return;case 1:oe(this.Cb,89)&&bv(ru(c(this.Cb,89)),4),Gc(this,null);return;case 2:Ig(this,!0);return;case 3:Rg(this,!0);return;case 4:_g(this,0);return;case 5:this.b=0,iv(this,1);return;case 8:db(this,null);return;case 9:i=Ch(this,null,null),i&&i.mj();return;case 10:bS(this,!0);return;case 11:vS(this,!1);return;case 12:mS(this,!1);return;case 13:this.i=null,aH(this,null);return;case 15:wS(this,!1);return;case 16:yS(this,!1);return;case 18:Hte(this,!1);return}ya(this,t-pn((Mt(),hy)),_t((n=c(Wt(this,16),29),n||hy),t))},f.mi=function(){vte(this),Q6(uo((Dl(),ps),this)),Qa(this),this.Bb|=1},f.Hk=function(){return gve(this)},f.Wk=function(t,n){return this.b=0,this.a=null,rwe(this,t,n)},f.Xk=function(t){kPe(this,t)},f.Ib=function(){var t;return(this.Db&64)!=0?CQ(this):(t=new Ba(CQ(this)),t.a+=" (iD: ",xg(t,(this.Bb&nc)!=0),t.a+=")",t.a)},f.b=0,C(Xt,"EAttributeImpl",336),T(361,444,{110:1,95:1,94:1,146:1,159:1,199:1,57:1,115:1,52:1,101:1,361:1,162:1,118:1,119:1,688:1}),f.bl=function(t){return t.Ah()==this},f.xh=function(t){return Sne(this,t)},f.yh=function(t,n){this.w=null,this.Db=n<<16|this.Db&255,this.Cb=t},f.Ih=function(t,n,i){var r;switch(t){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),this.Ab;case 1:return this.zb;case 2:return this.D!=null?this.D:this.B;case 3:return rw(this);case 4:return this.gk();case 5:return this.F;case 6:return n?Bu(this):J6(this);case 7:return!this.A&&(this.A=new El(cl,this,7)),this.A}return pa(this,t-pn(this.fi()),_t((r=c(Wt(this,16),29),r||this.fi()),t),n,i)},f.Ph=function(t,n,i){var r,o,a;switch(n){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),Uc(this.Ab,t,i);case 6:return this.Cb&&(i=(o=this.Db>>16,o>=0?Sne(this,i):this.Cb.Qh(this,-1-o,null,i))),Qu(this,t,6,i)}return a=c(_t((r=c(Wt(this,16),29),r||this.fi()),n),69),a.uk().xk(this,tl(this),n-pn(this.fi()),t,i)},f.Rh=function(t,n,i){var r,o;switch(n){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),Ns(this.Ab,t,i);case 6:return Qu(this,null,6,i);case 7:return!this.A&&(this.A=new El(cl,this,7)),Ns(this.A,t,i)}return o=c(_t((r=c(Wt(this,16),29),r||this.fi()),n),69),o.uk().yk(this,tl(this),n-pn(this.fi()),t,i)},f.Th=function(t){var n;switch(t){case 0:return!!this.Ab&&this.Ab.i!=0;case 1:return this.zb!=null;case 2:return this.D!=null&&this.D==this.F;case 3:return!!rw(this);case 4:return this.gk()!=null;case 5:return this.F!=null&&this.F!=this.D&&this.F!=this.B;case 6:return!!J6(this);case 7:return!!this.A&&this.A.i!=0}return da(this,t-pn(this.fi()),_t((n=c(Wt(this,16),29),n||this.fi()),t))},f.$h=function(t,n){var i;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab),!this.Ab&&(this.Ab=new Me(si,this,0,3)),ur(this.Ab,c(n,18));return;case 1:Sq(this,zn(n));return;case 2:KY(this,zn(n));return;case 5:zS(this,zn(n));return;case 7:!this.A&&(this.A=new El(cl,this,7)),En(this.A),!this.A&&(this.A=new El(cl,this,7)),ur(this.A,c(n,18));return}xa(this,t-pn(this.fi()),_t((i=c(Wt(this,16),29),i||this.fi()),t),n)},f.fi=function(){return Mt(),q2t},f.hi=function(t){var n;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab);return;case 1:oe(this.Cb,187)&&(c(this.Cb,187).tb=null),Gc(this,null);return;case 2:hS(this,null),tS(this,this.D);return;case 5:zS(this,null);return;case 7:!this.A&&(this.A=new El(cl,this,7)),En(this.A);return}ya(this,t-pn(this.fi()),_t((n=c(Wt(this,16),29),n||this.fi()),t))},f.fk=function(){var t;return this.G==-1&&(this.G=(t=Bu(this),t?$g(t.si(),this):-1)),this.G},f.gk=function(){return null},f.hk=function(){return Bu(this)},f.cl=function(){return this.v},f.ik=function(){return rw(this)},f.jk=function(){return this.D!=null?this.D:this.B},f.kk=function(){return this.F},f.dk=function(t){return die(this,t)},f.dl=function(t){this.v=t},f.el=function(t){eVe(this,t)},f.fl=function(t){this.C=t},f.ri=function(t){Sq(this,t)},f.Ib=function(){return IH(this)},f.C=null,f.D=null,f.G=-1,C(Xt,"EClassifierImpl",361),T(89,361,{110:1,95:1,94:1,29:1,146:1,159:1,199:1,57:1,115:1,52:1,101:1,89:1,361:1,162:1,474:1,118:1,119:1,688:1},y1),f.bl=function(t){return G7t(this,t.Ah())},f.Ih=function(t,n,i){var r;switch(t){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),this.Ab;case 1:return this.zb;case 2:return this.D!=null?this.D:this.B;case 3:return rw(this);case 4:return null;case 5:return this.F;case 6:return n?Bu(this):J6(this);case 7:return!this.A&&(this.A=new El(cl,this,7)),this.A;case 8:return Bt(),(this.Bb&256)!=0;case 9:return Bt(),(this.Bb&512)!=0;case 10:return vo(this);case 11:return!this.q&&(this.q=new Me(tf,this,11,10)),this.q;case 12:return Fx(this);case 13:return GT(this);case 14:return GT(this),this.r;case 15:return Fx(this),this.k;case 16:return ive(this);case 17:return mie(this);case 18:return ud(this);case 19:return yQ(this);case 20:return Fx(this),this.o;case 21:return!this.s&&(this.s=new Me(xl,this,21,17)),this.s;case 22:return gc(this);case 23:return iie(this)}return pa(this,t-pn((Mt(),pp)),_t((r=c(Wt(this,16),29),r||pp),t),n,i)},f.Ph=function(t,n,i){var r,o,a;switch(n){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),Uc(this.Ab,t,i);case 6:return this.Cb&&(i=(o=this.Db>>16,o>=0?Sne(this,i):this.Cb.Qh(this,-1-o,null,i))),Qu(this,t,6,i);case 11:return!this.q&&(this.q=new Me(tf,this,11,10)),Uc(this.q,t,i);case 21:return!this.s&&(this.s=new Me(xl,this,21,17)),Uc(this.s,t,i)}return a=c(_t((r=c(Wt(this,16),29),r||(Mt(),pp)),n),69),a.uk().xk(this,tl(this),n-pn((Mt(),pp)),t,i)},f.Rh=function(t,n,i){var r,o;switch(n){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),Ns(this.Ab,t,i);case 6:return Qu(this,null,6,i);case 7:return!this.A&&(this.A=new El(cl,this,7)),Ns(this.A,t,i);case 11:return!this.q&&(this.q=new Me(tf,this,11,10)),Ns(this.q,t,i);case 21:return!this.s&&(this.s=new Me(xl,this,21,17)),Ns(this.s,t,i);case 22:return Ns(gc(this),t,i)}return o=c(_t((r=c(Wt(this,16),29),r||(Mt(),pp)),n),69),o.uk().yk(this,tl(this),n-pn((Mt(),pp)),t,i)},f.Th=function(t){var n;switch(t){case 0:return!!this.Ab&&this.Ab.i!=0;case 1:return this.zb!=null;case 2:return this.D!=null&&this.D==this.F;case 3:return!!rw(this);case 4:return!1;case 5:return this.F!=null&&this.F!=this.D&&this.F!=this.B;case 6:return!!J6(this);case 7:return!!this.A&&this.A.i!=0;case 8:return(this.Bb&256)!=0;case 9:return(this.Bb&512)!=0;case 10:return!!this.u&&gc(this.u.a).i!=0&&!(this.n&&dne(this.n));case 11:return!!this.q&&this.q.i!=0;case 12:return Fx(this).i!=0;case 13:return GT(this).i!=0;case 14:return GT(this),this.r.i!=0;case 15:return Fx(this),this.k.i!=0;case 16:return ive(this).i!=0;case 17:return mie(this).i!=0;case 18:return ud(this).i!=0;case 19:return yQ(this).i!=0;case 20:return Fx(this),!!this.o;case 21:return!!this.s&&this.s.i!=0;case 22:return!!this.n&&dne(this.n);case 23:return iie(this).i!=0}return da(this,t-pn((Mt(),pp)),_t((n=c(Wt(this,16),29),n||pp),t))},f.Wh=function(t){var n;return n=this.i==null||this.q&&this.q.i!=0?null:JD(this,t),n||Uye(this,t)},f.$h=function(t,n){var i;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab),!this.Ab&&(this.Ab=new Me(si,this,0,3)),ur(this.Ab,c(n,18));return;case 1:Sq(this,zn(n));return;case 2:KY(this,zn(n));return;case 5:zS(this,zn(n));return;case 7:!this.A&&(this.A=new El(cl,this,7)),En(this.A),!this.A&&(this.A=new El(cl,this,7)),ur(this.A,c(n,18));return;case 8:cwe(this,et(Ze(n)));return;case 9:lwe(this,et(Ze(n)));return;case 10:XT(vo(this)),ur(vo(this),c(n,18));return;case 11:!this.q&&(this.q=new Me(tf,this,11,10)),En(this.q),!this.q&&(this.q=new Me(tf,this,11,10)),ur(this.q,c(n,18));return;case 21:!this.s&&(this.s=new Me(xl,this,21,17)),En(this.s),!this.s&&(this.s=new Me(xl,this,21,17)),ur(this.s,c(n,18));return;case 22:En(gc(this)),ur(gc(this),c(n,18));return}xa(this,t-pn((Mt(),pp)),_t((i=c(Wt(this,16),29),i||pp),t),n)},f.fi=function(){return Mt(),pp},f.hi=function(t){var n;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab);return;case 1:oe(this.Cb,187)&&(c(this.Cb,187).tb=null),Gc(this,null);return;case 2:hS(this,null),tS(this,this.D);return;case 5:zS(this,null);return;case 7:!this.A&&(this.A=new El(cl,this,7)),En(this.A);return;case 8:cwe(this,!1);return;case 9:lwe(this,!1);return;case 10:this.u&&XT(this.u);return;case 11:!this.q&&(this.q=new Me(tf,this,11,10)),En(this.q);return;case 21:!this.s&&(this.s=new Me(xl,this,21,17)),En(this.s);return;case 22:this.n&&En(this.n);return}ya(this,t-pn((Mt(),pp)),_t((n=c(Wt(this,16),29),n||pp),t))},f.mi=function(){var t,n;if(Fx(this),GT(this),ive(this),mie(this),ud(this),yQ(this),iie(this),eT(xCt(ru(this))),this.s)for(t=0,n=this.s.i;t<n;++t)x_(re(this.s,t));if(this.q)for(t=0,n=this.q.i;t<n;++t)x_(re(this.q,t));Pg((Dl(),ps),this).ve(),this.Bb|=1},f.Ib=function(){return O2e(this)},f.k=null,f.r=null;var GC,Y2t,Tae;C(Xt,"EClassImpl",89),T(2071,2070,$ut),f.Ci=function(t,n){return gie(this,t,n)},f.Di=function(t){return gie(this,this.i,t)},f.Ei=function(t,n){vve(this,t,n)},f.Fi=function(t){Wne(this,t)},f.Uk=function(t,n){return Uc(this,t,n)},f.Yi=function(t){return Pbe(this,t)},f.Vk=function(t,n){return Ns(this,t,n)},f.Vi=function(t,n){return trt(this,t,n)},f.Gi=function(){return new a5(this)},f.Hi=function(){return new v_(this)},f.Ii=function(t){return uD(this,t)},C(Gi,"NotifyingInternalEListImpl",2071),T(630,2071,To),f.Gc=function(t){return krt(this,t)},f.Gj=function(t,n,i,r,o){return X7(this,t,n,i,r,o)},f.Hj=function(t){b6(this,t)},f.Dk=function(t){return this},f.Jk=function(){return _t(this.e.Ah(),this.Jj())},f.Ij=function(){return this.Jk()},f.Jj=function(){return Vi(this.e.Ah(),this.Jk())},f.gl=function(){return c(this.Jk().Fk(),29).ik()},f.hl=function(){return Hs(c(this.Jk(),20)).n},f.hj=function(){return this.e},f.il=function(){return!0},f.jl=function(){return!1},f.kl=function(){return!1},f.ll=function(){return!1},f.bd=function(t){return $g(this,t)},f.Lj=function(t,n){var i;return i=c(t,52),this.kl()?this.il()?i.Oh(this.e,this.hl(),this.gl(),n):i.Oh(this.e,Vi(i.Ah(),Hs(c(this.Jk(),20))),null,n):i.Oh(this.e,-1-this.Jj(),null,n)},f.Mj=function(t,n){var i;return i=c(t,52),this.kl()?this.il()?i.Qh(this.e,this.hl(),this.gl(),n):i.Qh(this.e,Vi(i.Ah(),Hs(c(this.Jk(),20))),null,n):i.Qh(this.e,-1-this.Jj(),null,n)},f.$k=function(){return!1},f.ml=function(){return!0},f.dk=function(t){return bGe(this.d,t)},f.Nj=function(){return wu(this.e)},f.Oj=function(){return this.i!=0},f.$i=function(t){return lD(this.d,t)},f.Ui=function(t,n){return this.ml()&&this.ll()?X5(this,t,c(n,57)):n},f.nl=function(t){return t.Sh()?I0(this.e,c(t,52)):t},f.Wb=function(t){U$e(this,t)},f.Nc=function(){return KUe(this)},f.Oc=function(t){var n;if(this.ll())for(n=this.i-1;n>=0;--n)re(this,n);return Nwe(this,t)},f.Ek=function(){En(this)},f.Xi=function(t,n){return CXe(this,t,n)},C(Gi,"EcoreEList",630),T(494,630,To,__),f.Ji=function(){return!1},f.Jj=function(){return this.c},f.Kj=function(){return!1},f.ml=function(){return!0},f.Qi=function(){return!0},f.Ui=function(t,n){return n},f.Wi=function(){return!1},f.c=0,C(Gi,"EObjectEList",494),T(82,494,To,Ar),f.Kj=function(){return!0},f.kl=function(){return!1},f.$k=function(){return!0},C(Gi,"EObjectContainmentEList",82),T(547,82,To,OF),f.Li=function(){this.b=!0},f.Oj=function(){return this.b},f.Ek=function(){var t;En(this),wu(this.e)?(t=this.b,this.b=!1,vi(this.e,new bf(this.e,2,this.c,t,!1))):this.b=!1},f.b=!1,C(Gi,"EObjectContainmentEList/Unsettable",547),T(1142,547,To,zFe),f.Ri=function(t,n){var i,r;return i=c(vT(this,t,n),88),wu(this.e)&&b6(this,new W_(this.a,7,(Mt(),H2t),Pe(n),(r=i.c,oe(r,89)?c(r,29):rf),t)),i},f.Sj=function(t,n){return dBt(this,c(t,88),n)},f.Tj=function(t,n){return hBt(this,c(t,88),n)},f.Uj=function(t,n,i){return bqt(this,c(t,88),c(n,88),i)},f.Gj=function(t,n,i,r,o){switch(t){case 3:return X7(this,t,n,i,r,this.i>1);case 5:return X7(this,t,n,i,r,this.i-c(i,16).gc()>0);default:return new _1(this.e,t,this.c,n,i,r,!0)}},f.Rj=function(){return!0},f.Oj=function(){return dne(this)},f.Ek=function(){En(this)},C(Xt,"EClassImpl/1",1142),T(1156,1155,j5e),f.bj=function(t){var n,i,r,o,a,d,b;if(i=t.ej(),i!=8){if(r=XBt(t),r==0)switch(i){case 1:case 9:{b=t.ij(),b!=null&&(n=ru(c(b,474)),!n.c&&(n.c=new Gf),Vq(n.c,t.hj())),d=t.gj(),d!=null&&(o=c(d,474),(o.Bb&1)==0&&(n=ru(o),!n.c&&(n.c=new Gf),Nn(n.c,c(t.hj(),29))));break}case 3:{d=t.gj(),d!=null&&(o=c(d,474),(o.Bb&1)==0&&(n=ru(o),!n.c&&(n.c=new Gf),Nn(n.c,c(t.hj(),29))));break}case 5:{if(d=t.gj(),d!=null)for(a=c(d,18).Jc();a.Ob();)o=c(a.Pb(),474),(o.Bb&1)==0&&(n=ru(o),!n.c&&(n.c=new Gf),Nn(n.c,c(t.hj(),29)));break}case 4:{b=t.ij(),b!=null&&(o=c(b,474),(o.Bb&1)==0&&(n=ru(o),!n.c&&(n.c=new Gf),Vq(n.c,t.hj())));break}case 6:{if(b=t.ij(),b!=null)for(a=c(b,18).Jc();a.Ob();)o=c(a.Pb(),474),(o.Bb&1)==0&&(n=ru(o),!n.c&&(n.c=new Gf),Vq(n.c,t.hj()));break}}this.ol(r)}},f.ol=function(t){Vnt(this,t)},f.b=63,C(Xt,"ESuperAdapter",1156),T(1157,1156,j5e,zDe),f.ol=function(t){bv(this,t)},C(Xt,"EClassImpl/10",1157),T(1146,706,To),f.Ci=function(t,n){return Ine(this,t,n)},f.Di=function(t){return kYe(this,t)},f.Ei=function(t,n){kD(this,t,n)},f.Fi=function(t){U_(this,t)},f.Yi=function(t){return Pbe(this,t)},f.Vi=function(t,n){return Wee(this,t,n)},f.Uk=function(t,n){throw J(new $n)},f.Gi=function(){return new a5(this)},f.Hi=function(){return new v_(this)},f.Ii=function(t){return uD(this,t)},f.Vk=function(t,n){throw J(new $n)},f.Dk=function(t){return this},f.Oj=function(){return this.i!=0},f.Wb=function(t){throw J(new $n)},f.Ek=function(){throw J(new $n)},C(Gi,"EcoreEList/UnmodifiableEList",1146),T(334,1146,To,fx),f.Wi=function(){return!1},C(Gi,"EcoreEList/UnmodifiableEList/FastCompare",334),T(1149,334,To,JVe),f.bd=function(t){var n,i,r;if(oe(t,182)&&(n=c(t,182),i=n.Jj(),i!=-1)){for(r=this.i;i<r;++i)if(ve(this.g[i])===ve(t))return i}return-1},C(Xt,"EClassImpl/1EAllStructuralFeaturesList",1149),T(1143,495,md,zl),f.$i=function(t){return ye(Ks,But,88,t,0,1)},f.Wi=function(){return!1},C(Xt,"EClassImpl/1EGenericSuperTypeEList",1143),T(631,495,md,bh),f.$i=function(t){return ye(xl,Zx,182,t,0,1)},f.Wi=function(){return!1},C(Xt,"EClassImpl/1EStructuralFeatureUniqueEList",631),T(750,495,md,Ip),f.$i=function(t){return ye(fy,Zx,20,t,0,1)},f.Wi=function(){return!1},C(Xt,"EClassImpl/1ReferenceList",750),T(1144,495,md,FDe),f.Ki=function(t,n){cMt(this,c(n,38))},f.$i=function(t){return ye(ay,Zx,38,t,0,1)},f.Wi=function(){return!1},C(Xt,"EClassImpl/2",1144),T(1145,495,md,Y$),f.$i=function(t){return ye(ay,Zx,38,t,0,1)},f.Wi=function(){return!1},C(Xt,"EClassImpl/3",1145),T(1147,334,To,nFe),f.Ec=function(t){return LDt(this,c(t,38))},f.Fi=function(t){c8t(this,c(t,38))},C(Xt,"EClassImpl/4",1147),T(1148,334,To,iFe),f.Ec=function(t){return PDt(this,c(t,20))},f.Fi=function(t){l8t(this,c(t,20))},C(Xt,"EClassImpl/5",1148),T(1150,495,md,Z$),f.$i=function(t){return ye(tf,C5e,62,t,0,1)},f.Wi=function(){return!1},C(Xt,"EClassImpl/6",1150),T(1151,495,md,eB),f.$i=function(t){return ye(fy,Zx,20,t,0,1)},f.Wi=function(){return!1},C(Xt,"EClassImpl/7",1151),T(2074,2073,{3:1,4:1,22:1,32:1,56:1,18:1,16:1,71:1,61:1,72:1}),f.Ci=function(t,n){return yye(this,t,n)},f.Di=function(t){return yye(this,this.Cj(),t)},f.Ei=function(t,n){Stt(this,t,n)},f.Fi=function(t){dtt(this,t)},f.Uk=function(t,n){return zzt(this,t,n)},f.Vk=function(t,n){return pzt(this,t,n)},f.Vi=function(t,n){return Rit(this,t,n)},f.Yi=function(t){return this.vj(t)},f.Gi=function(){return new a5(this)},f.nj=function(){return this.qj()},f.Hi=function(){return new v_(this)},f.Ii=function(t){return uD(this,t)},C(Gi,"DelegatingNotifyingInternalEListImpl",2074),T(751,2074,M5e),f.Ji=function(){var t;return t=_t(al(this.b),this.Jj()).Fk(),oe(t,160)&&!oe(t,462)&&(t.ik().i&1)==0},f.Gc=function(t){var n,i,r,o,a,d,b,v;if(this.ml()){if(v=this.Cj(),v>4)if(this.dk(t)){if(this.$k()){if(r=c(t,52),i=r.Bh(),b=i==this.b&&(this.kl()?r.vh(r.Ch(),c(_t(al(this.b),this.Jj()).Fk(),29).ik())==Hs(c(_t(al(this.b),this.Jj()),20)).n:-1-r.Ch()==this.Jj()),this.ll()&&!b&&!i&&r.Gh()){for(o=0;o<v;++o)if(n=FZ(this,this.vj(o)),ve(n)===ve(t))return!0}return b}else if(this.kl()&&!this.jl()){if(a=c(t,57).Jh(Hs(c(_t(al(this.b),this.Jj()),20))),ve(a)===ve(this.b))return!0;if(a==null||!c(a,57).Sh())return!1}}else return!1;if(d=this.sj(t),this.ll()&&!d){for(o=0;o<v;++o)if(r=FZ(this,this.vj(o)),ve(r)===ve(t))return!0}return d}else return this.sj(t)},f.Gj=function(t,n,i,r,o){return new _1(this.b,t,this.Jj(),n,i,r,o)},f.Hj=function(t){vi(this.b,t)},f.Dk=function(t){return this},f.Ij=function(){return _t(al(this.b),this.Jj())},f.Jj=function(){return Vi(al(this.b),_t(al(this.b),this.Jj()))},f.hj=function(){return this.b},f.il=function(){return!!_t(al(this.b),this.Jj()).Fk().ik()},f.Kj=function(){var t,n;return n=_t(al(this.b),this.Jj()),oe(n,104)?(t=c(n,20),(t.Bb&nc)!=0||!!Hs(c(n,20))):!1},f.jl=function(){var t,n,i,r;return n=_t(al(this.b),this.Jj()),oe(n,104)?(t=c(n,20),i=Hs(t),!!i&&(r=i.t,r>1||r==-1)):!1},f.kl=function(){var t,n,i;return n=_t(al(this.b),this.Jj()),oe(n,104)?(t=c(n,20),i=Hs(t),!!i):!1},f.ll=function(){var t,n;return n=_t(al(this.b),this.Jj()),oe(n,104)?(t=c(n,20),(t.Bb&Is)!=0):!1},f.bd=function(t){var n,i,r,o;if(r=this.xj(t),r>=0)return r;if(this.ml()){for(i=0,o=this.Cj();i<o;++i)if(n=FZ(this,this.vj(i)),ve(n)===ve(t))return i}return-1},f.Lj=function(t,n){var i;return i=c(t,52),this.kl()?this.il()?i.Oh(this.b,Hs(c(_t(al(this.b),this.Jj()),20)).n,c(_t(al(this.b),this.Jj()).Fk(),29).ik(),n):i.Oh(this.b,Vi(i.Ah(),Hs(c(_t(al(this.b),this.Jj()),20))),null,n):i.Oh(this.b,-1-this.Jj(),null,n)},f.Mj=function(t,n){var i;return i=c(t,52),this.kl()?this.il()?i.Qh(this.b,Hs(c(_t(al(this.b),this.Jj()),20)).n,c(_t(al(this.b),this.Jj()).Fk(),29).ik(),n):i.Qh(this.b,Vi(i.Ah(),Hs(c(_t(al(this.b),this.Jj()),20))),null,n):i.Qh(this.b,-1-this.Jj(),null,n)},f.$k=function(){var t,n;return n=_t(al(this.b),this.Jj()),oe(n,104)?(t=c(n,20),(t.Bb&nc)!=0):!1},f.ml=function(){return oe(_t(al(this.b),this.Jj()).Fk(),89)},f.dk=function(t){return _t(al(this.b),this.Jj()).Fk().dk(t)},f.Nj=function(){return wu(this.b)},f.Oj=function(){return!this.yj()},f.Qi=function(){return _t(al(this.b),this.Jj()).Qi()},f.Ui=function(t,n){return eL(this,t,n)},f.Wb=function(t){XT(this),ur(this,c(t,16))},f.Nc=function(){var t;if(this.ll())for(t=this.Cj()-1;t>=0;--t)eL(this,t,this.vj(t));return this.Dj()},f.Oc=function(t){var n;if(this.ll())for(n=this.Cj()-1;n>=0;--n)eL(this,n,this.vj(n));return this.Ej(t)},f.Ek=function(){XT(this)},f.Xi=function(t,n){return WUe(this,t,n)},C(Gi,"DelegatingEcoreEList",751),T(1152,751,M5e,eze),f.oj=function(t,n){g7t(this,t,c(n,29))},f.pj=function(t){ojt(this,c(t,29))},f.vj=function(t){var n,i;return n=c(re(gc(this.a),t),88),i=n.c,oe(i,89)?c(i,29):(Mt(),rf)},f.Aj=function(t){var n,i;return n=c(vv(gc(this.a),t),88),i=n.c,oe(i,89)?c(i,29):(Mt(),rf)},f.Bj=function(t,n){return Fzt(this,t,c(n,29))},f.Ji=function(){return!1},f.Gj=function(t,n,i,r,o){return null},f.qj=function(){return new qDe(this)},f.rj=function(){En(gc(this.a))},f.sj=function(t){return JWe(this,t)},f.tj=function(t){var n,i;for(i=t.Jc();i.Ob();)if(n=i.Pb(),!JWe(this,n))return!1;return!0},f.uj=function(t){var n,i,r;if(oe(t,16)&&(r=c(t,16),r.gc()==gc(this.a).i)){for(n=r.Jc(),i=new cn(this);n.Ob();)if(ve(n.Pb())!==ve(un(i)))return!1;return!0}return!1},f.wj=function(){var t,n,i,r,o;for(i=1,n=new cn(gc(this.a));n.e!=n.i.gc();)t=c(un(n),88),r=(o=t.c,oe(o,89)?c(o,29):(Mt(),rf)),i=31*i+(r?Lm(r):0);return i},f.xj=function(t){var n,i,r,o;for(r=0,i=new cn(gc(this.a));i.e!=i.i.gc();){if(n=c(un(i),88),ve(t)===ve((o=n.c,oe(o,89)?c(o,29):(Mt(),rf))))return r;++r}return-1},f.yj=function(){return gc(this.a).i==0},f.zj=function(){return null},f.Cj=function(){return gc(this.a).i},f.Dj=function(){var t,n,i,r,o,a;for(a=gc(this.a).i,o=ye(Br,Lt,1,a,5,1),i=0,n=new cn(gc(this.a));n.e!=n.i.gc();)t=c(un(n),88),o[i++]=(r=t.c,oe(r,89)?c(r,29):(Mt(),rf));return o},f.Ej=function(t){var n,i,r,o,a,d,b;for(b=gc(this.a).i,t.length<b&&(o=lD(ju(t).c,b),t=o),t.length>b&&dr(t,b,null),r=0,i=new cn(gc(this.a));i.e!=i.i.gc();)n=c(un(i),88),a=(d=n.c,oe(d,89)?c(d,29):(Mt(),rf)),dr(t,r++,a);return t},f.Fj=function(){var t,n,i,r,o;for(o=new yg,o.a+="[",t=gc(this.a),n=0,r=gc(this.a).i;n<r;)Ys(o,A7((i=c(re(t,n),88).c,oe(i,89)?c(i,29):(Mt(),rf)))),++n<r&&(o.a+=Jc);return o.a+="]",o.a},f.Hj=function(t){},f.Jj=function(){return 10},f.il=function(){return!0},f.Kj=function(){return!1},f.jl=function(){return!1},f.kl=function(){return!1},f.ll=function(){return!0},f.$k=function(){return!1},f.ml=function(){return!0},f.dk=function(t){return oe(t,89)},f.Oj=function(){return E_t(this.a)},f.Qi=function(){return!0},f.Wi=function(){return!0},C(Xt,"EClassImpl/8",1152),T(1153,2041,US,qDe),f.dd=function(t){return uD(this.a,t)},f.gc=function(){return gc(this.a.a).i},C(Xt,"EClassImpl/8/1",1153),T(1154,495,md,QW),f.$i=function(t){return ye(ah,Lt,146,t,0,1)},f.Wi=function(){return!1},C(Xt,"EClassImpl/9",1154),T(1141,47,uxe,_Le),C(Xt,"EClassImpl/MyHashSet",1141),T(570,361,{110:1,95:1,94:1,146:1,160:1,839:1,159:1,199:1,57:1,115:1,52:1,101:1,361:1,162:1,118:1,119:1,688:1},mz),f.Ih=function(t,n,i){var r;switch(t){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),this.Ab;case 1:return this.zb;case 2:return this.D!=null?this.D:this.B;case 3:return rw(this);case 4:return this.gk();case 5:return this.F;case 6:return n?Bu(this):J6(this);case 7:return!this.A&&(this.A=new El(cl,this,7)),this.A;case 8:return Bt(),(this.Bb&256)!=0}return pa(this,t-pn(this.fi()),_t((r=c(Wt(this,16),29),r||this.fi()),t),n,i)},f.Th=function(t){var n;switch(t){case 0:return!!this.Ab&&this.Ab.i!=0;case 1:return this.zb!=null;case 2:return this.D!=null&&this.D==this.F;case 3:return!!rw(this);case 4:return this.gk()!=null;case 5:return this.F!=null&&this.F!=this.D&&this.F!=this.B;case 6:return!!J6(this);case 7:return!!this.A&&this.A.i!=0;case 8:return(this.Bb&256)==0}return da(this,t-pn(this.fi()),_t((n=c(Wt(this,16),29),n||this.fi()),t))},f.$h=function(t,n){var i;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab),!this.Ab&&(this.Ab=new Me(si,this,0,3)),ur(this.Ab,c(n,18));return;case 1:Sq(this,zn(n));return;case 2:KY(this,zn(n));return;case 5:zS(this,zn(n));return;case 7:!this.A&&(this.A=new El(cl,this,7)),En(this.A),!this.A&&(this.A=new El(cl,this,7)),ur(this.A,c(n,18));return;case 8:MH(this,et(Ze(n)));return}xa(this,t-pn(this.fi()),_t((i=c(Wt(this,16),29),i||this.fi()),t),n)},f.fi=function(){return Mt(),Q2t},f.hi=function(t){var n;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab);return;case 1:oe(this.Cb,187)&&(c(this.Cb,187).tb=null),Gc(this,null);return;case 2:hS(this,null),tS(this,this.D);return;case 5:zS(this,null);return;case 7:!this.A&&(this.A=new El(cl,this,7)),En(this.A);return;case 8:MH(this,!0);return}ya(this,t-pn(this.fi()),_t((n=c(Wt(this,16),29),n||this.fi()),t))},f.mi=function(){Pg((Dl(),ps),this).ve(),this.Bb|=1},f.mk=function(){var t,n,i;if(!this.c&&(t=$tt(Bu(this)),!t.dc()))for(i=t.Jc();i.Ob();)n=zn(i.Pb()),qT(this,n)&&y$t(this);return this.b},f.gk=function(){var t;if(!this.e){t=null;try{t=rw(this)}catch(n){if(n=vr(n),!oe(n,102))throw J(n)}this.d=null,t&&(t.i&1)!=0&&(t==kl?this.d=(Bt(),K0):t==Fn?this.d=Pe(0):t==py?this.d=new Fs(0):t==ns?this.d=0:t==qw?this.d=fv(0):t==L3?this.d=pS(0):t==Rl?this.d=iD(0):this.d=dD(0)),this.e=!0}return this.d},f.lk=function(){return(this.Bb&256)!=0},f.pl=function(t){t&&(this.D="org.eclipse.emf.common.util.AbstractEnumerator")},f.el=function(t){eVe(this,t),this.pl(t)},f.fl=function(t){this.C=t,this.e=!1},f.Ib=function(){var t;return(this.Db&64)!=0?IH(this):(t=new Ba(IH(this)),t.a+=" (serializable: ",xg(t,(this.Bb&256)!=0),t.a+=")",t.a)},f.c=!1,f.d=null,f.e=!1,C(Xt,"EDataTypeImpl",570),T(462,570,{110:1,95:1,94:1,146:1,160:1,839:1,682:1,159:1,199:1,57:1,115:1,52:1,101:1,361:1,462:1,162:1,118:1,119:1,688:1},DLe),f.Ih=function(t,n,i){var r;switch(t){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),this.Ab;case 1:return this.zb;case 2:return this.D!=null?this.D:this.B;case 3:return rw(this);case 4:return Xme(this);case 5:return this.F;case 6:return n?Bu(this):J6(this);case 7:return!this.A&&(this.A=new El(cl,this,7)),this.A;case 8:return Bt(),(this.Bb&256)!=0;case 9:return!this.a&&(this.a=new Me(tg,this,9,5)),this.a}return pa(this,t-pn((Mt(),bp)),_t((r=c(Wt(this,16),29),r||bp),t),n,i)},f.Ph=function(t,n,i){var r,o,a;switch(n){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),Uc(this.Ab,t,i);case 6:return this.Cb&&(i=(o=this.Db>>16,o>=0?Sne(this,i):this.Cb.Qh(this,-1-o,null,i))),Qu(this,t,6,i);case 9:return!this.a&&(this.a=new Me(tg,this,9,5)),Uc(this.a,t,i)}return a=c(_t((r=c(Wt(this,16),29),r||(Mt(),bp)),n),69),a.uk().xk(this,tl(this),n-pn((Mt(),bp)),t,i)},f.Rh=function(t,n,i){var r,o;switch(n){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),Ns(this.Ab,t,i);case 6:return Qu(this,null,6,i);case 7:return!this.A&&(this.A=new El(cl,this,7)),Ns(this.A,t,i);case 9:return!this.a&&(this.a=new Me(tg,this,9,5)),Ns(this.a,t,i)}return o=c(_t((r=c(Wt(this,16),29),r||(Mt(),bp)),n),69),o.uk().yk(this,tl(this),n-pn((Mt(),bp)),t,i)},f.Th=function(t){var n;switch(t){case 0:return!!this.Ab&&this.Ab.i!=0;case 1:return this.zb!=null;case 2:return this.D!=null&&this.D==this.F;case 3:return!!rw(this);case 4:return!!Xme(this);case 5:return this.F!=null&&this.F!=this.D&&this.F!=this.B;case 6:return!!J6(this);case 7:return!!this.A&&this.A.i!=0;case 8:return(this.Bb&256)==0;case 9:return!!this.a&&this.a.i!=0}return da(this,t-pn((Mt(),bp)),_t((n=c(Wt(this,16),29),n||bp),t))},f.$h=function(t,n){var i;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab),!this.Ab&&(this.Ab=new Me(si,this,0,3)),ur(this.Ab,c(n,18));return;case 1:Sq(this,zn(n));return;case 2:KY(this,zn(n));return;case 5:zS(this,zn(n));return;case 7:!this.A&&(this.A=new El(cl,this,7)),En(this.A),!this.A&&(this.A=new El(cl,this,7)),ur(this.A,c(n,18));return;case 8:MH(this,et(Ze(n)));return;case 9:!this.a&&(this.a=new Me(tg,this,9,5)),En(this.a),!this.a&&(this.a=new Me(tg,this,9,5)),ur(this.a,c(n,18));return}xa(this,t-pn((Mt(),bp)),_t((i=c(Wt(this,16),29),i||bp),t),n)},f.fi=function(){return Mt(),bp},f.hi=function(t){var n;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab);return;case 1:oe(this.Cb,187)&&(c(this.Cb,187).tb=null),Gc(this,null);return;case 2:hS(this,null),tS(this,this.D);return;case 5:zS(this,null);return;case 7:!this.A&&(this.A=new El(cl,this,7)),En(this.A);return;case 8:MH(this,!0);return;case 9:!this.a&&(this.a=new Me(tg,this,9,5)),En(this.a);return}ya(this,t-pn((Mt(),bp)),_t((n=c(Wt(this,16),29),n||bp),t))},f.mi=function(){var t,n;if(this.a)for(t=0,n=this.a.i;t<n;++t)x_(re(this.a,t));Pg((Dl(),ps),this).ve(),this.Bb|=1},f.gk=function(){return Xme(this)},f.dk=function(t){return t!=null},f.pl=function(t){},C(Xt,"EEnumImpl",462),T(575,444,{110:1,95:1,94:1,2018:1,691:1,159:1,199:1,57:1,115:1,52:1,101:1,575:1,162:1,118:1,119:1},WDe),f.ve=function(){return this.zb},f.xh=function(t){return VYe(this,t)},f.Ih=function(t,n,i){var r,o;switch(t){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),this.Ab;case 1:return this.zb;case 2:return Pe(this.d);case 3:return this.b?this.b:this.a;case 4:return o=this.c,o??this.zb;case 5:return this.Db>>16==5?c(this.Cb,682):null}return pa(this,t-pn((Mt(),n0)),_t((r=c(Wt(this,16),29),r||n0),t),n,i)},f.Ph=function(t,n,i){var r,o,a;switch(n){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),Uc(this.Ab,t,i);case 5:return this.Cb&&(i=(o=this.Db>>16,o>=0?VYe(this,i):this.Cb.Qh(this,-1-o,null,i))),Qu(this,t,5,i)}return a=c(_t((r=c(Wt(this,16),29),r||(Mt(),n0)),n),69),a.uk().xk(this,tl(this),n-pn((Mt(),n0)),t,i)},f.Rh=function(t,n,i){var r,o;switch(n){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),Ns(this.Ab,t,i);case 5:return Qu(this,null,5,i)}return o=c(_t((r=c(Wt(this,16),29),r||(Mt(),n0)),n),69),o.uk().yk(this,tl(this),n-pn((Mt(),n0)),t,i)},f.Th=function(t){var n;switch(t){case 0:return!!this.Ab&&this.Ab.i!=0;case 1:return this.zb!=null;case 2:return this.d!=0;case 3:return!!this.b;case 4:return this.c!=null;case 5:return!!(this.Db>>16==5&&c(this.Cb,682))}return da(this,t-pn((Mt(),n0)),_t((n=c(Wt(this,16),29),n||n0),t))},f.$h=function(t,n){var i;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab),!this.Ab&&(this.Ab=new Me(si,this,0,3)),ur(this.Ab,c(n,18));return;case 1:Gc(this,zn(n));return;case 2:ite(this,c(n,15).a);return;case 3:rtt(this,c(n,2018));return;case 4:ste(this,zn(n));return}xa(this,t-pn((Mt(),n0)),_t((i=c(Wt(this,16),29),i||n0),t),n)},f.fi=function(){return Mt(),n0},f.hi=function(t){var n;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab);return;case 1:Gc(this,null);return;case 2:ite(this,0);return;case 3:rtt(this,null);return;case 4:ste(this,null);return}ya(this,t-pn((Mt(),n0)),_t((n=c(Wt(this,16),29),n||n0),t))},f.Ib=function(){var t;return t=this.c,t??this.zb},f.b=null,f.c=null,f.d=0,C(Xt,"EEnumLiteralImpl",575);var lnn=Ki(Xt,"EFactoryImpl/InternalEDateTimeFormat");T(488,1,{2093:1},HN),C(Xt,"EFactoryImpl/1ClientInternalEDateTimeFormat",488),T(251,119,{110:1,95:1,94:1,88:1,57:1,115:1,52:1,101:1,251:1,118:1,119:1},Om),f.zh=function(t,n,i){var r;return i=Qu(this,t,n,i),this.e&&oe(t,182)&&(r=vQ(this,this.e),r!=this.c&&(i=FS(this,r,i))),i},f.Ih=function(t,n,i){var r;switch(t){case 0:return this.f;case 1:return!this.d&&(this.d=new Ar(Ks,this,1)),this.d;case 2:return n?AQ(this):this.c;case 3:return this.b;case 4:return this.e;case 5:return n?bne(this):this.a}return pa(this,t-pn((Mt(),Bw)),_t((r=c(Wt(this,16),29),r||Bw),t),n,i)},f.Rh=function(t,n,i){var r,o;switch(n){case 0:return LWe(this,null,i);case 1:return!this.d&&(this.d=new Ar(Ks,this,1)),Ns(this.d,t,i);case 3:return DWe(this,null,i)}return o=c(_t((r=c(Wt(this,16),29),r||(Mt(),Bw)),n),69),o.uk().yk(this,tl(this),n-pn((Mt(),Bw)),t,i)},f.Th=function(t){var n;switch(t){case 0:return!!this.f;case 1:return!!this.d&&this.d.i!=0;case 2:return!!this.c;case 3:return!!this.b;case 4:return!!this.e;case 5:return!!this.a}return da(this,t-pn((Mt(),Bw)),_t((n=c(Wt(this,16),29),n||Bw),t))},f.$h=function(t,n){var i;switch(t){case 0:gZe(this,c(n,88));return;case 1:!this.d&&(this.d=new Ar(Ks,this,1)),En(this.d),!this.d&&(this.d=new Ar(Ks,this,1)),ur(this.d,c(n,18));return;case 3:S2e(this,c(n,88));return;case 4:H2e(this,c(n,842));return;case 5:eS(this,c(n,146));return}xa(this,t-pn((Mt(),Bw)),_t((i=c(Wt(this,16),29),i||Bw),t),n)},f.fi=function(){return Mt(),Bw},f.hi=function(t){var n;switch(t){case 0:gZe(this,null);return;case 1:!this.d&&(this.d=new Ar(Ks,this,1)),En(this.d);return;case 3:S2e(this,null);return;case 4:H2e(this,null);return;case 5:eS(this,null);return}ya(this,t-pn((Mt(),Bw)),_t((n=c(Wt(this,16),29),n||Bw),t))},f.Ib=function(){var t;return t=new Lu(kf(this)),t.a+=" (expression: ",kie(this,t),t.a+=")",t.a};var MTe;C(Xt,"EGenericTypeImpl",251),T(2046,2041,IG),f.Ei=function(t,n){YBe(this,t,n)},f.Uk=function(t,n){return YBe(this,this.gc(),t),n},f.Yi=function(t){return pc(this.nj(),t)},f.Gi=function(){return this.Hi()},f.nj=function(){return new JDe(this)},f.Hi=function(){return this.Ii(0)},f.Ii=function(t){return this.nj().dd(t)},f.Vk=function(t,n){return uv(this,t,!0),n},f.Ri=function(t,n){var i,r;return r=Ene(this,n),i=this.dd(t),i.Rb(r),r},f.Si=function(t,n){var i;uv(this,n,!0),i=this.dd(t),i.Rb(n)},C(Gi,"AbstractSequentialInternalEList",2046),T(485,2046,IG,y_),f.Yi=function(t){return pc(this.nj(),t)},f.Gi=function(){return this.b==null?(Sg(),Sg(),ZP):this.ql()},f.nj=function(){return new w$e(this.a,this.b)},f.Hi=function(){return this.b==null?(Sg(),Sg(),ZP):this.ql()},f.Ii=function(t){var n,i;if(this.b==null){if(t<0||t>1)throw J(new zc(wE+t+", size=0"));return Sg(),Sg(),ZP}for(i=this.ql(),n=0;n<t;++n)wH(i);return i},f.dc=function(){var t,n,i,r,o,a;if(this.b!=null){for(i=0;i<this.b.length;++i)if(t=this.b[i],!this.tl()||this.a.Uh(t)){if(a=this.a.Kh(t,!1),qs(),c(t,69).vk()){for(n=c(a,164),r=0,o=n.gc();r<o;++r)if(jqe(n.Rl(r))&&n.Sl(r)!=null)return!1}else if(t.Hk()){if(!c(a,18).dc())return!1}else if(a!=null)return!1}}return!0},f.Jc=function(){return ame(this)},f.dd=function(t){var n,i;if(this.b==null){if(t!=0)throw J(new zc(wE+t+", size=0"));return Sg(),Sg(),ZP}for(i=this.sl()?this.rl():this.ql(),n=0;n<t;++n)wH(i);return i},f.Ri=function(t,n){throw J(new $n)},f.Si=function(t,n){throw J(new $n)},f.ql=function(){return new CF(this.a,this.b)},f.rl=function(){return new Ige(this.a,this.b)},f.sl=function(){return!0},f.gc=function(){var t,n,i,r,o,a,d;if(o=0,this.b!=null){for(i=0;i<this.b.length;++i)if(t=this.b[i],!this.tl()||this.a.Uh(t))if(d=this.a.Kh(t,!1),qs(),c(t,69).vk())for(n=c(d,164),r=0,a=n.gc();r<a;++r)jqe(n.Rl(r))&&n.Sl(r)!=null&&++o;else t.Hk()?o+=c(d,18).gc():d!=null&&++o}return o},f.tl=function(){return!0};var Eae;C(Gi,"EContentsEList",485),T(1158,485,IG,RBe),f.ql=function(){return new $Be(this.a,this.b)},f.rl=function(){return new BBe(this.a,this.b)},f.tl=function(){return!1},C(Xt,"ENamedElementImpl/1",1158),T(289,1,RG,CF),f.Nb=function(t){gs(this,t)},f.Rb=function(t){throw J(new $n)},f.ul=function(t){if(this.g!=0||this.e)throw J(new oo("Iterator already in use or already filtered"));this.e=t},f.Ob=function(){var t,n,i,r,o,a;switch(this.g){case 3:case 2:return!0;case 1:return!1;case-3:this.p?this.p.Pb():++this.n;default:if(!this.k||(this.p?!pet(this,this.p):!ott(this))){for(;this.d<this.c.length;)if(n=this.c[this.d++],(!this.e||n.nk()!=o8||n.Jj()!=0)&&(!this.tl()||this.b.Uh(n))){if(a=this.b.Kh(n,this.sl()),this.f=(qs(),c(n,69).vk()),this.f||n.Hk()){if(this.sl()?(r=c(a,16),this.k=r):(r=c(a,72),this.k=this.j=r),oe(this.k,59)?(this.p=null,this.o=this.k.gc(),this.n=0):this.p=this.j?this.j.Hi():this.k.cd(),this.p?pet(this,this.p):ott(this))return o=this.p?this.p.Pb():this.j?this.j.Yi(this.n++):this.k.Xb(this.n++),this.f?(t=c(o,76),t.Jk(),i=t.kd(),this.i=i):(i=o,this.i=i),this.g=3,!0}else if(a!=null)return this.k=null,this.p=null,i=a,this.i=i,this.g=2,!0}return this.k=null,this.p=null,this.f=!1,this.g=1,!1}else return o=this.p?this.p.Pb():this.j?this.j.Yi(this.n++):this.k.Xb(this.n++),this.f?(t=c(o,76),t.Jk(),i=t.kd(),this.i=i):(i=o,this.i=i),this.g=3,!0}},f.Sb=function(){var t,n,i,r,o,a;switch(this.g){case-3:case-2:return!0;case-1:return!1;case 3:this.p?this.p.Ub():--this.n;default:if(!this.k||(this.p?!bet(this,this.p):!Eet(this))){for(;this.d>0;)if(n=this.c[--this.d],(!this.e||n.nk()!=o8||n.Jj()!=0)&&(!this.tl()||this.b.Uh(n))){if(a=this.b.Kh(n,this.sl()),this.f=(qs(),c(n,69).vk()),this.f||n.Hk()){if(this.sl()?(r=c(a,16),this.k=r):(r=c(a,72),this.k=this.j=r),oe(this.k,59)?(this.o=this.k.gc(),this.n=this.o):this.p=this.j?this.j.Ii(this.k.gc()):this.k.dd(this.k.gc()),this.p?bet(this,this.p):Eet(this))return o=this.p?this.p.Ub():this.j?this.j.Yi(--this.n):this.k.Xb(--this.n),this.f?(t=c(o,76),t.Jk(),i=t.kd(),this.i=i):(i=o,this.i=i),this.g=-3,!0}else if(a!=null)return this.k=null,this.p=null,i=a,this.i=i,this.g=-2,!0}return this.k=null,this.p=null,this.g=-1,!1}else return o=this.p?this.p.Ub():this.j?this.j.Yi(--this.n):this.k.Xb(--this.n),this.f?(t=c(o,76),t.Jk(),i=t.kd(),this.i=i):(i=o,this.i=i),this.g=-3,!0}},f.Pb=function(){return wH(this)},f.Tb=function(){return this.a},f.Ub=function(){var t;if(this.g<-1||this.Sb())return--this.a,this.g=0,t=this.i,this.Sb(),t;throw J(new Co)},f.Vb=function(){return this.a-1},f.Qb=function(){throw J(new $n)},f.sl=function(){return!1},f.Wb=function(t){throw J(new $n)},f.tl=function(){return!0},f.a=0,f.d=0,f.f=!1,f.g=0,f.n=0,f.o=0;var ZP;C(Gi,"EContentsEList/FeatureIteratorImpl",289),T(707,289,RG,Ige),f.sl=function(){return!0},C(Gi,"EContentsEList/ResolvingFeatureIteratorImpl",707),T(1159,707,RG,BBe),f.tl=function(){return!1},C(Xt,"ENamedElementImpl/1/1",1159),T(1160,289,RG,$Be),f.tl=function(){return!1},C(Xt,"ENamedElementImpl/1/2",1160),T(40,152,LL,ev,Mee,Ur,Hee,_1,bf,Jbe,jQe,Xbe,TQe,hbe,EQe,Kbe,CQe,dbe,MQe,Vbe,AQe,B7,W_,uee,Wbe,NQe,gbe,_Qe),f.Ij=function(){return Mbe(this)},f.Pj=function(){var t;return t=Mbe(this),t?t.gk():null},f.fj=function(t){return this.b==-1&&this.a&&(this.b=this.c.Eh(this.a.Jj(),this.a.nk())),this.c.vh(this.b,t)},f.hj=function(){return this.c},f.Qj=function(){var t;return t=Mbe(this),t?t.rk():!1},f.b=-1,C(Xt,"ENotificationImpl",40),T(408,294,{110:1,95:1,94:1,159:1,199:1,57:1,62:1,115:1,473:1,52:1,101:1,162:1,408:1,294:1,118:1,119:1},QK),f.xh=function(t){return KYe(this,t)},f.Ih=function(t,n,i){var r,o,a;switch(t){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),this.Ab;case 1:return this.zb;case 2:return Bt(),(this.Bb&256)!=0;case 3:return Bt(),(this.Bb&512)!=0;case 4:return Pe(this.s);case 5:return Pe(this.t);case 6:return Bt(),a=this.t,a>1||a==-1;case 7:return Bt(),o=this.s,o>=1;case 8:return n?Qa(this):this.r;case 9:return this.q;case 10:return this.Db>>16==10?c(this.Cb,29):null;case 11:return!this.d&&(this.d=new El(cl,this,11)),this.d;case 12:return!this.c&&(this.c=new Me($w,this,12,10)),this.c;case 13:return!this.a&&(this.a=new S_(this,this)),this.a;case 14:return ou(this)}return pa(this,t-pn((Mt(),i0)),_t((r=c(Wt(this,16),29),r||i0),t),n,i)},f.Ph=function(t,n,i){var r,o,a;switch(n){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),Uc(this.Ab,t,i);case 10:return this.Cb&&(i=(o=this.Db>>16,o>=0?KYe(this,i):this.Cb.Qh(this,-1-o,null,i))),Qu(this,t,10,i);case 12:return!this.c&&(this.c=new Me($w,this,12,10)),Uc(this.c,t,i)}return a=c(_t((r=c(Wt(this,16),29),r||(Mt(),i0)),n),69),a.uk().xk(this,tl(this),n-pn((Mt(),i0)),t,i)},f.Rh=function(t,n,i){var r,o;switch(n){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),Ns(this.Ab,t,i);case 9:return VZ(this,i);case 10:return Qu(this,null,10,i);case 11:return!this.d&&(this.d=new El(cl,this,11)),Ns(this.d,t,i);case 12:return!this.c&&(this.c=new Me($w,this,12,10)),Ns(this.c,t,i);case 14:return Ns(ou(this),t,i)}return o=c(_t((r=c(Wt(this,16),29),r||(Mt(),i0)),n),69),o.uk().yk(this,tl(this),n-pn((Mt(),i0)),t,i)},f.Th=function(t){var n,i,r;switch(t){case 0:return!!this.Ab&&this.Ab.i!=0;case 1:return this.zb!=null;case 2:return(this.Bb&256)==0;case 3:return(this.Bb&512)==0;case 4:return this.s!=0;case 5:return this.t!=1;case 6:return r=this.t,r>1||r==-1;case 7:return i=this.s,i>=1;case 8:return!!this.r&&!this.q.e&&$m(this.q).i==0;case 9:return!!this.q&&!(this.r&&!this.q.e&&$m(this.q).i==0);case 10:return!!(this.Db>>16==10&&c(this.Cb,29));case 11:return!!this.d&&this.d.i!=0;case 12:return!!this.c&&this.c.i!=0;case 13:return!!this.a&&ou(this.a.a).i!=0&&!(this.b&&gne(this.b));case 14:return!!this.b&&gne(this.b)}return da(this,t-pn((Mt(),i0)),_t((n=c(Wt(this,16),29),n||i0),t))},f.$h=function(t,n){var i,r;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab),!this.Ab&&(this.Ab=new Me(si,this,0,3)),ur(this.Ab,c(n,18));return;case 1:Gc(this,zn(n));return;case 2:Ig(this,et(Ze(n)));return;case 3:Rg(this,et(Ze(n)));return;case 4:_g(this,c(n,15).a);return;case 5:iv(this,c(n,15).a);return;case 8:db(this,c(n,146));return;case 9:r=Ch(this,c(n,88),null),r&&r.mj();return;case 11:!this.d&&(this.d=new El(cl,this,11)),En(this.d),!this.d&&(this.d=new El(cl,this,11)),ur(this.d,c(n,18));return;case 12:!this.c&&(this.c=new Me($w,this,12,10)),En(this.c),!this.c&&(this.c=new Me($w,this,12,10)),ur(this.c,c(n,18));return;case 13:!this.a&&(this.a=new S_(this,this)),XT(this.a),!this.a&&(this.a=new S_(this,this)),ur(this.a,c(n,18));return;case 14:En(ou(this)),ur(ou(this),c(n,18));return}xa(this,t-pn((Mt(),i0)),_t((i=c(Wt(this,16),29),i||i0),t),n)},f.fi=function(){return Mt(),i0},f.hi=function(t){var n,i;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab);return;case 1:Gc(this,null);return;case 2:Ig(this,!0);return;case 3:Rg(this,!0);return;case 4:_g(this,0);return;case 5:iv(this,1);return;case 8:db(this,null);return;case 9:i=Ch(this,null,null),i&&i.mj();return;case 11:!this.d&&(this.d=new El(cl,this,11)),En(this.d);return;case 12:!this.c&&(this.c=new Me($w,this,12,10)),En(this.c);return;case 13:this.a&&XT(this.a);return;case 14:this.b&&En(this.b);return}ya(this,t-pn((Mt(),i0)),_t((n=c(Wt(this,16),29),n||i0),t))},f.mi=function(){var t,n;if(this.c)for(t=0,n=this.c.i;t<n;++t)x_(re(this.c,t));Qa(this),this.Bb|=1},C(Xt,"EOperationImpl",408),T(503,751,M5e,S_),f.oj=function(t,n){v7t(this,t,c(n,146))},f.pj=function(t){cjt(this,c(t,146))},f.vj=function(t){var n,i;return n=c(re(ou(this.a),t),88),i=n.c,i||(Mt(),Gh)},f.Aj=function(t){var n,i;return n=c(vv(ou(this.a),t),88),i=n.c,i||(Mt(),Gh)},f.Bj=function(t,n){return IBt(this,t,c(n,146))},f.Ji=function(){return!1},f.Gj=function(t,n,i,r,o){return null},f.qj=function(){return new HDe(this)},f.rj=function(){En(ou(this.a))},f.sj=function(t){return WWe(this,t)},f.tj=function(t){var n,i;for(i=t.Jc();i.Ob();)if(n=i.Pb(),!WWe(this,n))return!1;return!0},f.uj=function(t){var n,i,r;if(oe(t,16)&&(r=c(t,16),r.gc()==ou(this.a).i)){for(n=r.Jc(),i=new cn(this);n.Ob();)if(ve(n.Pb())!==ve(un(i)))return!1;return!0}return!1},f.wj=function(){var t,n,i,r,o;for(i=1,n=new cn(ou(this.a));n.e!=n.i.gc();)t=c(un(n),88),r=(o=t.c,o||(Mt(),Gh)),i=31*i+(r?Ri(r):0);return i},f.xj=function(t){var n,i,r,o;for(r=0,i=new cn(ou(this.a));i.e!=i.i.gc();){if(n=c(un(i),88),ve(t)===ve((o=n.c,o||(Mt(),Gh))))return r;++r}return-1},f.yj=function(){return ou(this.a).i==0},f.zj=function(){return null},f.Cj=function(){return ou(this.a).i},f.Dj=function(){var t,n,i,r,o,a;for(a=ou(this.a).i,o=ye(Br,Lt,1,a,5,1),i=0,n=new cn(ou(this.a));n.e!=n.i.gc();)t=c(un(n),88),o[i++]=(r=t.c,r||(Mt(),Gh));return o},f.Ej=function(t){var n,i,r,o,a,d,b;for(b=ou(this.a).i,t.length<b&&(o=lD(ju(t).c,b),t=o),t.length>b&&dr(t,b,null),r=0,i=new cn(ou(this.a));i.e!=i.i.gc();)n=c(un(i),88),a=(d=n.c,d||(Mt(),Gh)),dr(t,r++,a);return t},f.Fj=function(){var t,n,i,r,o;for(o=new yg,o.a+="[",t=ou(this.a),n=0,r=ou(this.a).i;n<r;)Ys(o,A7((i=c(re(t,n),88).c,i||(Mt(),Gh)))),++n<r&&(o.a+=Jc);return o.a+="]",o.a},f.Hj=function(t){},f.Jj=function(){return 13},f.il=function(){return!0},f.Kj=function(){return!1},f.jl=function(){return!1},f.kl=function(){return!1},f.ll=function(){return!0},f.$k=function(){return!1},f.ml=function(){return!0},f.dk=function(t){return oe(t,146)},f.Oj=function(){return N_t(this.a)},f.Qi=function(){return!0},f.Wi=function(){return!0},C(Xt,"EOperationImpl/1",503),T(1342,2041,US,HDe),f.dd=function(t){return uD(this.a,t)},f.gc=function(){return ou(this.a.a).i},C(Xt,"EOperationImpl/1/1",1342),T(1343,547,To,FFe),f.Ri=function(t,n){var i,r;return i=c(vT(this,t,n),88),wu(this.e)&&b6(this,new W_(this.a,7,(Mt(),J2t),Pe(n),(r=i.c,r||Gh),t)),i},f.Sj=function(t,n){return n$t(this,c(t,88),n)},f.Tj=function(t,n){return i$t(this,c(t,88),n)},f.Uj=function(t,n,i){return VBt(this,c(t,88),c(n,88),i)},f.Gj=function(t,n,i,r,o){switch(t){case 3:return X7(this,t,n,i,r,this.i>1);case 5:return X7(this,t,n,i,r,this.i-c(i,16).gc()>0);default:return new _1(this.e,t,this.c,n,i,r,!0)}},f.Rj=function(){return!0},f.Oj=function(){return gne(this)},f.Ek=function(){En(this)},C(Xt,"EOperationImpl/2",1343),T(496,1,{2016:1,496:1},e$e),C(Xt,"EPackageImpl/1",496),T(14,82,To,Me),f.gl=function(){return this.d},f.hl=function(){return this.b},f.kl=function(){return!0},f.b=0,C(Gi,"EObjectContainmentWithInverseEList",14),T(362,14,To,h5),f.ll=function(){return!0},f.Ui=function(t,n){return X5(this,t,c(n,57))},C(Gi,"EObjectContainmentWithInverseEList/Resolving",362),T(313,362,To,G2),f.Li=function(){this.a.tb=null},C(Xt,"EPackageImpl/2",313),T(1255,1,{},tN),C(Xt,"EPackageImpl/3",1255),T(728,44,Gx,$de),f._b=function(t){return Kr(t)?fee(this,t):!!co(this.f,t)},C(Xt,"EPackageRegistryImpl",728),T(507,294,{110:1,95:1,94:1,159:1,199:1,57:1,2095:1,115:1,473:1,52:1,101:1,162:1,507:1,294:1,118:1,119:1},GK),f.xh=function(t){return YYe(this,t)},f.Ih=function(t,n,i){var r,o,a;switch(t){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),this.Ab;case 1:return this.zb;case 2:return Bt(),(this.Bb&256)!=0;case 3:return Bt(),(this.Bb&512)!=0;case 4:return Pe(this.s);case 5:return Pe(this.t);case 6:return Bt(),a=this.t,a>1||a==-1;case 7:return Bt(),o=this.s,o>=1;case 8:return n?Qa(this):this.r;case 9:return this.q;case 10:return this.Db>>16==10?c(this.Cb,62):null}return pa(this,t-pn((Mt(),dy)),_t((r=c(Wt(this,16),29),r||dy),t),n,i)},f.Ph=function(t,n,i){var r,o,a;switch(n){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),Uc(this.Ab,t,i);case 10:return this.Cb&&(i=(o=this.Db>>16,o>=0?YYe(this,i):this.Cb.Qh(this,-1-o,null,i))),Qu(this,t,10,i)}return a=c(_t((r=c(Wt(this,16),29),r||(Mt(),dy)),n),69),a.uk().xk(this,tl(this),n-pn((Mt(),dy)),t,i)},f.Rh=function(t,n,i){var r,o;switch(n){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),Ns(this.Ab,t,i);case 9:return VZ(this,i);case 10:return Qu(this,null,10,i)}return o=c(_t((r=c(Wt(this,16),29),r||(Mt(),dy)),n),69),o.uk().yk(this,tl(this),n-pn((Mt(),dy)),t,i)},f.Th=function(t){var n,i,r;switch(t){case 0:return!!this.Ab&&this.Ab.i!=0;case 1:return this.zb!=null;case 2:return(this.Bb&256)==0;case 3:return(this.Bb&512)==0;case 4:return this.s!=0;case 5:return this.t!=1;case 6:return r=this.t,r>1||r==-1;case 7:return i=this.s,i>=1;case 8:return!!this.r&&!this.q.e&&$m(this.q).i==0;case 9:return!!this.q&&!(this.r&&!this.q.e&&$m(this.q).i==0);case 10:return!!(this.Db>>16==10&&c(this.Cb,62))}return da(this,t-pn((Mt(),dy)),_t((n=c(Wt(this,16),29),n||dy),t))},f.fi=function(){return Mt(),dy},C(Xt,"EParameterImpl",507),T(104,454,{110:1,95:1,94:1,159:1,199:1,57:1,20:1,182:1,69:1,115:1,473:1,52:1,101:1,162:1,104:1,454:1,294:1,118:1,119:1,689:1},Fge),f.Ih=function(t,n,i){var r,o,a,d;switch(t){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),this.Ab;case 1:return this.zb;case 2:return Bt(),(this.Bb&256)!=0;case 3:return Bt(),(this.Bb&512)!=0;case 4:return Pe(this.s);case 5:return Pe(this.t);case 6:return Bt(),d=this.t,d>1||d==-1;case 7:return Bt(),o=this.s,o>=1;case 8:return n?Qa(this):this.r;case 9:return this.q;case 10:return Bt(),(this.Bb&Ga)!=0;case 11:return Bt(),(this.Bb&q1)!=0;case 12:return Bt(),(this.Bb&jv)!=0;case 13:return this.j;case 14:return _S(this);case 15:return Bt(),(this.Bb&Pl)!=0;case 16:return Bt(),(this.Bb&ad)!=0;case 17:return W2(this);case 18:return Bt(),(this.Bb&nc)!=0;case 19:return Bt(),a=Hs(this),!!(a&&(a.Bb&nc)!=0);case 20:return Bt(),(this.Bb&Is)!=0;case 21:return n?Hs(this):this.b;case 22:return n?Ime(this):ZGe(this);case 23:return!this.a&&(this.a=new mx(ay,this,23)),this.a}return pa(this,t-pn((Mt(),A3)),_t((r=c(Wt(this,16),29),r||A3),t),n,i)},f.Th=function(t){var n,i,r,o;switch(t){case 0:return!!this.Ab&&this.Ab.i!=0;case 1:return this.zb!=null;case 2:return(this.Bb&256)==0;case 3:return(this.Bb&512)==0;case 4:return this.s!=0;case 5:return this.t!=1;case 6:return o=this.t,o>1||o==-1;case 7:return i=this.s,i>=1;case 8:return!!this.r&&!this.q.e&&$m(this.q).i==0;case 9:return!!this.q&&!(this.r&&!this.q.e&&$m(this.q).i==0);case 10:return(this.Bb&Ga)==0;case 11:return(this.Bb&q1)!=0;case 12:return(this.Bb&jv)!=0;case 13:return this.j!=null;case 14:return _S(this)!=null;case 15:return(this.Bb&Pl)!=0;case 16:return(this.Bb&ad)!=0;case 17:return!!W2(this);case 18:return(this.Bb&nc)!=0;case 19:return r=Hs(this),!!r&&(r.Bb&nc)!=0;case 20:return(this.Bb&Is)==0;case 21:return!!this.b;case 22:return!!ZGe(this);case 23:return!!this.a&&this.a.i!=0}return da(this,t-pn((Mt(),A3)),_t((n=c(Wt(this,16),29),n||A3),t))},f.$h=function(t,n){var i,r;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab),!this.Ab&&(this.Ab=new Me(si,this,0,3)),ur(this.Ab,c(n,18));return;case 1:xee(this,zn(n));return;case 2:Ig(this,et(Ze(n)));return;case 3:Rg(this,et(Ze(n)));return;case 4:_g(this,c(n,15).a);return;case 5:iv(this,c(n,15).a);return;case 8:db(this,c(n,146));return;case 9:r=Ch(this,c(n,88),null),r&&r.mj();return;case 10:bS(this,et(Ze(n)));return;case 11:vS(this,et(Ze(n)));return;case 12:mS(this,et(Ze(n)));return;case 13:Z1e(this,zn(n));return;case 15:wS(this,et(Ze(n)));return;case 16:yS(this,et(Ze(n)));return;case 18:MNt(this,et(Ze(n)));return;case 20:gwe(this,et(Ze(n)));return;case 21:hme(this,c(n,20));return;case 23:!this.a&&(this.a=new mx(ay,this,23)),En(this.a),!this.a&&(this.a=new mx(ay,this,23)),ur(this.a,c(n,18));return}xa(this,t-pn((Mt(),A3)),_t((i=c(Wt(this,16),29),i||A3),t),n)},f.fi=function(){return Mt(),A3},f.hi=function(t){var n,i;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab);return;case 1:oe(this.Cb,89)&&bv(ru(c(this.Cb,89)),4),Gc(this,null);return;case 2:Ig(this,!0);return;case 3:Rg(this,!0);return;case 4:_g(this,0);return;case 5:iv(this,1);return;case 8:db(this,null);return;case 9:i=Ch(this,null,null),i&&i.mj();return;case 10:bS(this,!0);return;case 11:vS(this,!1);return;case 12:mS(this,!1);return;case 13:this.i=null,aH(this,null);return;case 15:wS(this,!1);return;case 16:yS(this,!1);return;case 18:pwe(this,!1),oe(this.Cb,89)&&bv(ru(c(this.Cb,89)),2);return;case 20:gwe(this,!0);return;case 21:hme(this,null);return;case 23:!this.a&&(this.a=new mx(ay,this,23)),En(this.a);return}ya(this,t-pn((Mt(),A3)),_t((n=c(Wt(this,16),29),n||A3),t))},f.mi=function(){Ime(this),Q6(uo((Dl(),ps),this)),Qa(this),this.Bb|=1},f.sk=function(){return Hs(this)},f.Zk=function(){var t;return t=Hs(this),!!t&&(t.Bb&nc)!=0},f.$k=function(){return(this.Bb&nc)!=0},f._k=function(){return(this.Bb&Is)!=0},f.Wk=function(t,n){return this.c=null,rwe(this,t,n)},f.Ib=function(){var t;return(this.Db&64)!=0?CQ(this):(t=new Ba(CQ(this)),t.a+=" (containment: ",xg(t,(this.Bb&nc)!=0),t.a+=", resolveProxies: ",xg(t,(this.Bb&Is)!=0),t.a+=")",t.a)},C(Xt,"EReferenceImpl",104),T(553,119,{110:1,45:1,95:1,94:1,138:1,57:1,115:1,52:1,101:1,553:1,118:1,119:1},Ad),f.Fb=function(t){return this===t},f.jd=function(){return this.b},f.kd=function(){return this.c},f.Hb=function(){return Lm(this)},f.Ai=function(t){zCt(this,zn(t))},f.ld=function(t){return MCt(this,zn(t))},f.Ih=function(t,n,i){var r;switch(t){case 0:return this.b;case 1:return this.c}return pa(this,t-pn((Mt(),Bs)),_t((r=c(Wt(this,16),29),r||Bs),t),n,i)},f.Th=function(t){var n;switch(t){case 0:return this.b!=null;case 1:return this.c!=null}return da(this,t-pn((Mt(),Bs)),_t((n=c(Wt(this,16),29),n||Bs),t))},f.$h=function(t,n){var i;switch(t){case 0:FCt(this,zn(n));return;case 1:ome(this,zn(n));return}xa(this,t-pn((Mt(),Bs)),_t((i=c(Wt(this,16),29),i||Bs),t),n)},f.fi=function(){return Mt(),Bs},f.hi=function(t){var n;switch(t){case 0:ume(this,null);return;case 1:ome(this,null);return}ya(this,t-pn((Mt(),Bs)),_t((n=c(Wt(this,16),29),n||Bs),t))},f.yi=function(){var t;return this.a==-1&&(t=this.b,this.a=t==null?0:Dg(t)),this.a},f.zi=function(t){this.a=t},f.Ib=function(){var t;return(this.Db&64)!=0?kf(this):(t=new Ba(kf(this)),t.a+=" (key: ",Ys(t,this.b),t.a+=", value: ",Ys(t,this.c),t.a+=")",t.a)},f.a=-1,f.b=null,f.c=null;var Yo=C(Xt,"EStringToStringMapEntryImpl",553),Z2t=Ki(Gi,"FeatureMap/Entry/Internal");T(569,1,$G),f.vl=function(t){return this.wl(c(t,52))},f.wl=function(t){return this.vl(t)},f.Fb=function(t){var n,i;return this===t?!0:oe(t,76)?(n=c(t,76),n.Jk()==this.c?(i=this.kd(),i==null?n.kd()==null:yi(i,n.kd())):!1):!1},f.Jk=function(){return this.c},f.Hb=function(){var t;return t=this.kd(),Ri(this.c)^(t==null?0:Ri(t))},f.Ib=function(){var t,n;return t=this.c,n=Bu(t.ok()).vi(),t.ve(),(n!=null&&n.length!=0?n+":"+t.ve():t.ve())+"="+this.kd()},C(Xt,"EStructuralFeatureImpl/BasicFeatureMapEntry",569),T(784,569,$G,e0e),f.wl=function(t){return new e0e(this.c,t)},f.kd=function(){return this.a},f.xl=function(t,n,i){return yIt(this,t,this.a,n,i)},f.yl=function(t,n,i){return xIt(this,t,this.a,n,i)},C(Xt,"EStructuralFeatureImpl/ContainmentUpdatingFeatureMapEntry",784),T(1316,1,{},t$e),f.wk=function(t,n,i,r,o){var a;return a=c(W6(t,this.b),222),a.Wl(this.a).Dk(r)},f.xk=function(t,n,i,r,o){var a;return a=c(W6(t,this.b),222),a.Nl(this.a,r,o)},f.yk=function(t,n,i,r,o){var a;return a=c(W6(t,this.b),222),a.Ol(this.a,r,o)},f.zk=function(t,n,i){var r;return r=c(W6(t,this.b),222),r.Wl(this.a).Oj()},f.Ak=function(t,n,i,r){var o;o=c(W6(t,this.b),222),o.Wl(this.a).Wb(r)},f.Bk=function(t,n,i){return c(W6(t,this.b),222).Wl(this.a)},f.Ck=function(t,n,i){var r;r=c(W6(t,this.b),222),r.Wl(this.a).Ek()},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateFeatureMapDelegator",1316),T(90,1,{},Tg,Yp,Cg,rb),f.wk=function(t,n,i,r,o){var a;if(a=n.ii(i),a==null&&n.ji(i,a=zQ(this,t)),!o)switch(this.e){case 50:case 41:return c(a,593)._j();case 40:return c(a,222).Tl()}return a},f.xk=function(t,n,i,r,o){var a,d;return d=n.ii(i),d==null&&n.ji(i,d=zQ(this,t)),a=c(d,72).Uk(r,o),a},f.yk=function(t,n,i,r,o){var a;return a=n.ii(i),a!=null&&(o=c(a,72).Vk(r,o)),o},f.zk=function(t,n,i){var r;return r=n.ii(i),r!=null&&c(r,78).Oj()},f.Ak=function(t,n,i,r){var o;o=c(n.ii(i),78),!o&&n.ji(i,o=zQ(this,t)),o.Wb(r)},f.Bk=function(t,n,i){var r,o;return o=n.ii(i),o==null&&n.ji(i,o=zQ(this,t)),oe(o,78)?c(o,78):(r=c(n.ii(i),16),new GDe(r))},f.Ck=function(t,n,i){var r;r=c(n.ii(i),78),!r&&n.ji(i,r=zQ(this,t)),r.Ek()},f.b=0,f.e=0,C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateMany",90),T(502,1,{}),f.xk=function(t,n,i,r,o){throw J(new $n)},f.yk=function(t,n,i,r,o){throw J(new $n)},f.Bk=function(t,n,i){return new tHe(this,t,n,i)};var o1;C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingle",502),T(1333,1,loe,tHe),f.Dk=function(t){return this.a.wk(this.c,this.d,this.b,t,!0)},f.Oj=function(){return this.a.zk(this.c,this.d,this.b)},f.Wb=function(t){this.a.Ak(this.c,this.d,this.b,t)},f.Ek=function(){this.a.Ck(this.c,this.d,this.b)},f.b=0,C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingle/1",1333),T(777,502,{},Lpe),f.wk=function(t,n,i,r,o){return uie(t,t.Mh(),t.Ch())==this.b?this._k()&&r?Kne(t):t.Mh():null},f.xk=function(t,n,i,r,o){var a,d;return t.Mh()&&(o=(a=t.Ch(),a>=0?t.xh(o):t.Mh().Qh(t,-1-a,null,o))),d=Vi(t.Ah(),this.e),t.zh(r,d,o)},f.yk=function(t,n,i,r,o){var a;return a=Vi(t.Ah(),this.e),t.zh(null,a,o)},f.zk=function(t,n,i){var r;return r=Vi(t.Ah(),this.e),!!t.Mh()&&t.Ch()==r},f.Ak=function(t,n,i,r){var o,a,d,b,v;if(r!=null&&!die(this.a,r))throw J(new m6(BG+(oe(r,57)?O2e(c(r,57).Ah()):Hbe(ju(r)))+zG+this.a+"'"));if(o=t.Mh(),d=Vi(t.Ah(),this.e),ve(r)!==ve(o)||t.Ch()!=d&&r!=null){if(jS(t,c(r,57)))throw J(new qt(bE+t.Ib()));v=null,o&&(v=(a=t.Ch(),a>=0?t.xh(v):t.Mh().Qh(t,-1-a,null,v))),b=c(r,52),b&&(v=b.Oh(t,Vi(b.Ah(),this.b),null,v)),v=t.zh(b,d,v),v&&v.mj()}else t.sh()&&t.th()&&vi(t,new Ur(t,1,d,r,r))},f.Ck=function(t,n,i){var r,o,a,d;r=t.Mh(),r?(d=(o=t.Ch(),o>=0?t.xh(null):t.Mh().Qh(t,-1-o,null,null)),a=Vi(t.Ah(),this.e),d=t.zh(null,a,d),d&&d.mj()):t.sh()&&t.th()&&vi(t,new B7(t,1,this.e,null,null))},f._k=function(){return!1},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleContainer",777),T(1317,777,{},Uze),f._k=function(){return!0},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleContainerResolving",1317),T(567,502,{}),f.wk=function(t,n,i,r,o){var a;return a=n.ii(i),a==null?this.b:ve(a)===ve(o1)?null:a},f.zk=function(t,n,i){var r;return r=n.ii(i),r!=null&&(ve(r)===ve(o1)||!yi(r,this.b))},f.Ak=function(t,n,i,r){var o,a;t.sh()&&t.th()?(o=(a=n.ii(i),a==null?this.b:ve(a)===ve(o1)?null:a),r==null?this.c!=null?(n.ji(i,null),r=this.b):this.b!=null?n.ji(i,o1):n.ji(i,null):(this.zl(r),n.ji(i,r)),vi(t,this.d.Al(t,1,this.e,o,r))):r==null?this.c!=null?n.ji(i,null):this.b!=null?n.ji(i,o1):n.ji(i,null):(this.zl(r),n.ji(i,r))},f.Ck=function(t,n,i){var r,o;t.sh()&&t.th()?(r=(o=n.ii(i),o==null?this.b:ve(o)===ve(o1)?null:o),n.ki(i),vi(t,this.d.Al(t,1,this.e,r,this.b))):n.ki(i)},f.zl=function(t){throw J(new tLe)},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleData",567),T(e3,1,{},p0),f.Al=function(t,n,i,r,o){return new B7(t,n,i,r,o)},f.Bl=function(t,n,i,r,o,a){return new uee(t,n,i,r,o,a)};var ATe,NTe,_Te,DTe,LTe,PTe,ITe,Cae,RTe;C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleData/NotificationCreator",e3),T(1334,e3,{},tB),f.Al=function(t,n,i,r,o){return new gbe(t,n,i,et(Ze(r)),et(Ze(o)))},f.Bl=function(t,n,i,r,o,a){return new _Qe(t,n,i,et(Ze(r)),et(Ze(o)),a)},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleData/NotificationCreator/1",1334),T(1335,e3,{},Nd),f.Al=function(t,n,i,r,o){return new Jbe(t,n,i,c(r,224).a,c(o,224).a)},f.Bl=function(t,n,i,r,o,a){return new jQe(t,n,i,c(r,224).a,c(o,224).a,a)},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleData/NotificationCreator/2",1335),T(1336,e3,{},nB),f.Al=function(t,n,i,r,o){return new Xbe(t,n,i,c(r,183).a,c(o,183).a)},f.Bl=function(t,n,i,r,o,a){return new TQe(t,n,i,c(r,183).a,c(o,183).a,a)},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleData/NotificationCreator/3",1336),T(1337,e3,{},bm),f.Al=function(t,n,i,r,o){return new hbe(t,n,i,ue(he(r)),ue(he(o)))},f.Bl=function(t,n,i,r,o,a){return new EQe(t,n,i,ue(he(r)),ue(he(o)),a)},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleData/NotificationCreator/4",1337),T(1338,e3,{},Ky),f.Al=function(t,n,i,r,o){return new Kbe(t,n,i,c(r,165).a,c(o,165).a)},f.Bl=function(t,n,i,r,o,a){return new CQe(t,n,i,c(r,165).a,c(o,165).a,a)},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleData/NotificationCreator/5",1338),T(1339,e3,{},mm),f.Al=function(t,n,i,r,o){return new dbe(t,n,i,c(r,15).a,c(o,15).a)},f.Bl=function(t,n,i,r,o,a){return new MQe(t,n,i,c(r,15).a,c(o,15).a,a)},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleData/NotificationCreator/6",1339),T(1340,e3,{},nN),f.Al=function(t,n,i,r,o){return new Vbe(t,n,i,c(r,192).a,c(o,192).a)},f.Bl=function(t,n,i,r,o,a){return new AQe(t,n,i,c(r,192).a,c(o,192).a,a)},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleData/NotificationCreator/7",1340),T(1341,e3,{},iN),f.Al=function(t,n,i,r,o){return new Wbe(t,n,i,c(r,193).a,c(o,193).a)},f.Bl=function(t,n,i,r,o,a){return new NQe(t,n,i,c(r,193).a,c(o,193).a,a)},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleData/NotificationCreator/8",1341),T(1319,567,{},sHe),f.zl=function(t){if(!this.a.dk(t))throw J(new m6(BG+ju(t)+zG+this.a+"'"))},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleDataDynamic",1319),T(1320,567,{},qFe),f.zl=function(t){},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleDataStatic",1320),T(778,567,{}),f.zk=function(t,n,i){var r;return r=n.ii(i),r!=null},f.Ak=function(t,n,i,r){var o,a;t.sh()&&t.th()?(o=!0,a=n.ii(i),a==null?(o=!1,a=this.b):ve(a)===ve(o1)&&(a=null),r==null?this.c!=null?(n.ji(i,null),r=this.b):n.ji(i,o1):(this.zl(r),n.ji(i,r)),vi(t,this.d.Bl(t,1,this.e,a,r,!o))):r==null?this.c!=null?n.ji(i,null):n.ji(i,o1):(this.zl(r),n.ji(i,r))},f.Ck=function(t,n,i){var r,o;t.sh()&&t.th()?(r=!0,o=n.ii(i),o==null?(r=!1,o=this.b):ve(o)===ve(o1)&&(o=null),n.ki(i),vi(t,this.d.Bl(t,2,this.e,o,this.b,r))):n.ki(i)},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleDataUnsettable",778),T(1321,778,{},oHe),f.zl=function(t){if(!this.a.dk(t))throw J(new m6(BG+ju(t)+zG+this.a+"'"))},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleDataUnsettableDynamic",1321),T(1322,778,{},HFe),f.zl=function(t){},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleDataUnsettableStatic",1322),T(407,502,{},WF),f.wk=function(t,n,i,r,o){var a,d,b,v,x;if(x=n.ii(i),this.rk()&&ve(x)===ve(o1))return null;if(this._k()&&r&&x!=null){if(b=c(x,52),b.Sh()&&(v=I0(t,b),b!=v)){if(!die(this.a,v))throw J(new m6(BG+ju(v)+zG+this.a+"'"));n.ji(i,x=v),this.$k()&&(a=c(v,52),d=b.Qh(t,this.b?Vi(b.Ah(),this.b):-1-Vi(t.Ah(),this.e),null,null),!a.Mh()&&(d=a.Oh(t,this.b?Vi(a.Ah(),this.b):-1-Vi(t.Ah(),this.e),null,d)),d&&d.mj()),t.sh()&&t.th()&&vi(t,new B7(t,9,this.e,b,v))}return x}else return x},f.xk=function(t,n,i,r,o){var a,d;return d=n.ii(i),ve(d)===ve(o1)&&(d=null),n.ji(i,r),this.Kj()?ve(d)!==ve(r)&&d!=null&&(a=c(d,52),o=a.Qh(t,Vi(a.Ah(),this.b),null,o)):this.$k()&&d!=null&&(o=c(d,52).Qh(t,-1-Vi(t.Ah(),this.e),null,o)),t.sh()&&t.th()&&(!o&&(o=new m0(4)),o.lj(new B7(t,1,this.e,d,r))),o},f.yk=function(t,n,i,r,o){var a;return a=n.ii(i),ve(a)===ve(o1)&&(a=null),n.ki(i),t.sh()&&t.th()&&(!o&&(o=new m0(4)),this.rk()?o.lj(new B7(t,2,this.e,a,null)):o.lj(new B7(t,1,this.e,a,null))),o},f.zk=function(t,n,i){var r;return r=n.ii(i),r!=null},f.Ak=function(t,n,i,r){var o,a,d,b,v;if(r!=null&&!die(this.a,r))throw J(new m6(BG+(oe(r,57)?O2e(c(r,57).Ah()):Hbe(ju(r)))+zG+this.a+"'"));v=n.ii(i),b=v!=null,this.rk()&&ve(v)===ve(o1)&&(v=null),d=null,this.Kj()?ve(v)!==ve(r)&&(v!=null&&(o=c(v,52),d=o.Qh(t,Vi(o.Ah(),this.b),null,d)),r!=null&&(o=c(r,52),d=o.Oh(t,Vi(o.Ah(),this.b),null,d))):this.$k()&&ve(v)!==ve(r)&&(v!=null&&(d=c(v,52).Qh(t,-1-Vi(t.Ah(),this.e),null,d)),r!=null&&(d=c(r,52).Oh(t,-1-Vi(t.Ah(),this.e),null,d))),r==null&&this.rk()?n.ji(i,o1):n.ji(i,r),t.sh()&&t.th()?(a=new uee(t,1,this.e,v,r,this.rk()&&!b),d?(d.lj(a),d.mj()):vi(t,a)):d&&d.mj()},f.Ck=function(t,n,i){var r,o,a,d,b;b=n.ii(i),d=b!=null,this.rk()&&ve(b)===ve(o1)&&(b=null),a=null,b!=null&&(this.Kj()?(r=c(b,52),a=r.Qh(t,Vi(r.Ah(),this.b),null,a)):this.$k()&&(a=c(b,52).Qh(t,-1-Vi(t.Ah(),this.e),null,a))),n.ki(i),t.sh()&&t.th()?(o=new uee(t,this.rk()?2:1,this.e,b,null,d),a?(a.lj(o),a.mj()):vi(t,o)):a&&a.mj()},f.Kj=function(){return!1},f.$k=function(){return!1},f._k=function(){return!1},f.rk=function(){return!1},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleEObject",407),T(568,407,{},aZ),f.$k=function(){return!0},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleEObjectContainment",568),T(1325,568,{},zBe),f._k=function(){return!0},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleEObjectContainmentResolving",1325),T(780,568,{},Rge),f.rk=function(){return!0},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleEObjectContainmentUnsettable",780),T(1327,780,{},FBe),f._k=function(){return!0},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleEObjectContainmentUnsettableResolving",1327),T(645,568,{},jZ),f.Kj=function(){return!0},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleEObjectContainmentWithInverse",645),T(1326,645,{},Jze),f._k=function(){return!0},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleEObjectContainmentWithInverseResolving",1326),T(781,645,{},k0e),f.rk=function(){return!0},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleEObjectContainmentWithInverseUnsettable",781),T(1328,781,{},Xze),f._k=function(){return!0},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleEObjectContainmentWithInverseUnsettableResolving",1328),T(646,407,{},$ge),f._k=function(){return!0},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleEObjectResolving",646),T(1329,646,{},HBe),f.rk=function(){return!0},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleEObjectResolvingUnsettable",1329),T(782,646,{},y0e),f.Kj=function(){return!0},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleEObjectResolvingWithInverse",782),T(1330,782,{},Vze),f.rk=function(){return!0},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleEObjectResolvingWithInverseUnsettable",1330),T(1323,407,{},qBe),f.rk=function(){return!0},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleEObjectUnsettable",1323),T(779,407,{},x0e),f.Kj=function(){return!0},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleEObjectWithInverse",779),T(1324,779,{},Wze),f.rk=function(){return!0},C(Xt,"EStructuralFeatureImpl/InternalSettingDelegateSingleEObjectWithInverseUnsettable",1324),T(783,569,$G,dpe),f.wl=function(t){return new dpe(this.a,this.c,t)},f.kd=function(){return this.b},f.xl=function(t,n,i){return wLt(this,t,this.b,i)},f.yl=function(t,n,i){return vLt(this,t,this.b,i)},C(Xt,"EStructuralFeatureImpl/InverseUpdatingFeatureMapEntry",783),T(1331,1,loe,GDe),f.Dk=function(t){return this.a},f.Oj=function(){return oe(this.a,98)?c(this.a,98).Oj():!this.a.dc()},f.Wb=function(t){this.a.$b(),this.a.Fc(c(t,16))},f.Ek=function(){oe(this.a,98)?c(this.a,98).Ek():this.a.$b()},C(Xt,"EStructuralFeatureImpl/SettingMany",1331),T(1332,569,$G,jGe),f.vl=function(t){return new pZ((Ci(),XC),this.b.oi(this.a,t))},f.kd=function(){return null},f.xl=function(t,n,i){return i},f.yl=function(t,n,i){return i},C(Xt,"EStructuralFeatureImpl/SimpleContentFeatureMapEntry",1332),T(647,569,$G,pZ),f.vl=function(t){return new pZ(this.c,t)},f.kd=function(){return this.a},f.xl=function(t,n,i){return i},f.yl=function(t,n,i){return i},C(Xt,"EStructuralFeatureImpl/SimpleFeatureMapEntry",647),T(399,495,md,Gf),f.$i=function(t){return ye(ef,Lt,29,t,0,1)},f.Wi=function(){return!1},C(Xt,"ESuperAdapter/1",399),T(449,444,{110:1,95:1,94:1,159:1,199:1,57:1,115:1,842:1,52:1,101:1,162:1,449:1,118:1,119:1},kj),f.Ih=function(t,n,i){var r;switch(t){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),this.Ab;case 1:return this.zb;case 2:return!this.a&&(this.a=new P7(this,Ks,this)),this.a}return pa(this,t-pn((Mt(),zw)),_t((r=c(Wt(this,16),29),r||zw),t),n,i)},f.Rh=function(t,n,i){var r,o;switch(n){case 0:return!this.Ab&&(this.Ab=new Me(si,this,0,3)),Ns(this.Ab,t,i);case 2:return!this.a&&(this.a=new P7(this,Ks,this)),Ns(this.a,t,i)}return o=c(_t((r=c(Wt(this,16),29),r||(Mt(),zw)),n),69),o.uk().yk(this,tl(this),n-pn((Mt(),zw)),t,i)},f.Th=function(t){var n;switch(t){case 0:return!!this.Ab&&this.Ab.i!=0;case 1:return this.zb!=null;case 2:return!!this.a&&this.a.i!=0}return da(this,t-pn((Mt(),zw)),_t((n=c(Wt(this,16),29),n||zw),t))},f.$h=function(t,n){var i;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab),!this.Ab&&(this.Ab=new Me(si,this,0,3)),ur(this.Ab,c(n,18));return;case 1:Gc(this,zn(n));return;case 2:!this.a&&(this.a=new P7(this,Ks,this)),En(this.a),!this.a&&(this.a=new P7(this,Ks,this)),ur(this.a,c(n,18));return}xa(this,t-pn((Mt(),zw)),_t((i=c(Wt(this,16),29),i||zw),t),n)},f.fi=function(){return Mt(),zw},f.hi=function(t){var n;switch(t){case 0:!this.Ab&&(this.Ab=new Me(si,this,0,3)),En(this.Ab);return;case 1:Gc(this,null);return;case 2:!this.a&&(this.a=new P7(this,Ks,this)),En(this.a);return}ya(this,t-pn((Mt(),zw)),_t((n=c(Wt(this,16),29),n||zw),t))},C(Xt,"ETypeParameterImpl",449),T(450,82,To,P7),f.Lj=function(t,n){return dHt(this,c(t,88),n)},f.Mj=function(t,n){return gHt(this,c(t,88),n)},C(Xt,"ETypeParameterImpl/1",450),T(644,44,Gx,UK),f.ec=function(){return new pz(this)},C(Xt,"ETypeParameterImpl/2",644),T(564,Nh,Ll,pz),f.Ec=function(t){return Oze(this,c(t,88))},f.Fc=function(t){var n,i,r;for(r=!1,i=t.Jc();i.Ob();)n=c(i.Pb(),88),oi(this.a,n,"")==null&&(r=!0);return r},f.$b=function(){sc(this.a)},f.Gc=function(t){return jc(this.a,t)},f.Jc=function(){var t;return t=new sv(new Bp(this.a).a),new bz(t)},f.Kc=function(t){return dUe(this,t)},f.gc=function(){return r7(this.a)},C(Xt,"ETypeParameterImpl/2/1",564),T(565,1,ts,bz),f.Nb=function(t){gs(this,t)},f.Pb=function(){return c(Ex(this.a).jd(),88)},f.Ob=function(){return this.a.b},f.Qb=function(){jJe(this.a)},C(Xt,"ETypeParameterImpl/2/1/1",565),T(1293,44,Gx,LLe),f._b=function(t){return Kr(t)?fee(this,t):!!co(this.f,t)},f.xc=function(t){var n,i;return n=Kr(t)?Tc(this,t):Ao(co(this.f,t)),oe(n,843)?(i=c(n,843),n=i.Ik(),oi(this,c(t,244),n),n):n??(t==null?(fY(),tvt):null)},C(Xt,"EValidatorRegistryImpl",1293),T(1315,717,{110:1,95:1,94:1,472:1,159:1,57:1,115:1,2019:1,52:1,101:1,162:1,118:1,119:1},j4),f.oi=function(t,n){switch(t.fk()){case 21:case 22:case 23:case 24:case 26:case 31:case 32:case 37:case 38:case 39:case 40:case 43:case 44:case 48:case 49:case 20:return n==null?null:jo(n);case 25:return CPt(n);case 27:return HLt(n);case 28:return QLt(n);case 29:return n==null?null:G$e(qC[0],c(n,208));case 41:return n==null?"":qp(c(n,299));case 42:return jo(n);case 50:return zn(n);default:throw J(new qt(p9+t.ve()+xw))}},f.pi=function(t){var n,i,r,o,a,d,b,v,x,S,M,L,P,z,H,X;switch(t.G==-1&&(t.G=(L=Bu(t),L?$g(L.si(),t):-1)),t.G){case 0:return i=new HK,i;case 1:return n=new eN,n;case 2:return r=new y1,r;case 4:return o=new mz,o;case 5:return a=new DLe,a;case 6:return d=new WDe,d;case 7:return b=new D4,b;case 10:return x=new xj,x;case 11:return S=new QK,S;case 12:return M=new mHe,M;case 13:return P=new GK,P;case 14:return z=new Fge,z;case 17:return H=new Ad,H;case 18:return v=new Om,v;case 19:return X=new kj,X;default:throw J(new qt(Use+t.zb+xw))}},f.qi=function(t,n){switch(t.fk()){case 20:return n==null?null:new o1e(n);case 21:return n==null?null:new O0(n);case 23:case 22:return n==null?null:EBt(n);case 26:case 24:return n==null?null:iD(Hu(n,-128,127)<<24>>24);case 25:return MUt(n);case 27:return fFt(n);case 28:return hFt(n);case 29:return DHt(n);case 32:case 31:return n==null?null:gv(n);case 38:case 37:return n==null?null:new Mde(n);case 40:case 39:return n==null?null:Pe(Hu(n,ls,di));case 41:return null;case 42:return n==null,null;case 44:case 43:return n==null?null:fv(BQ(n));case 49:case 48:return n==null?null:pS(Hu(n,FG,32767)<<16>>16);case 50:return n;default:throw J(new qt(p9+t.ve()+xw))}},C(Xt,"EcoreFactoryImpl",1315),T(552,187,{110:1,95:1,94:1,159:1,199:1,57:1,244:1,115:1,2017:1,52:1,101:1,162:1,187:1,552:1,118:1,119:1,687:1},$qe),f.gb=!1,f.hb=!1;var $Te,evt=!1;C(Xt,"EcorePackageImpl",552),T(1211,1,{843:1},WO),f.Ik=function(){return vBe(),nvt},C(Xt,"EcorePackageImpl/1",1211),T(1220,1,ui,KO),f.dk=function(t){return oe(t,159)},f.ek=function(t){return ye(UP,Lt,159,t,0,1)},C(Xt,"EcorePackageImpl/10",1220),T(1221,1,ui,T4),f.dk=function(t){return oe(t,199)},f.ek=function(t){return ye(vae,Lt,199,t,0,1)},C(Xt,"EcorePackageImpl/11",1221),T(1222,1,ui,iB),f.dk=function(t){return oe(t,57)},f.ek=function(t){return ye(dp,Lt,57,t,0,1)},C(Xt,"EcorePackageImpl/12",1222),T(1223,1,ui,rB),f.dk=function(t){return oe(t,408)},f.ek=function(t){return ye(tf,C5e,62,t,0,1)},C(Xt,"EcorePackageImpl/13",1223),T(1224,1,ui,YO),f.dk=function(t){return oe(t,244)},f.ek=function(t){return ye(uh,Lt,244,t,0,1)},C(Xt,"EcorePackageImpl/14",1224),T(1225,1,ui,sB),f.dk=function(t){return oe(t,507)},f.ek=function(t){return ye($w,Lt,2095,t,0,1)},C(Xt,"EcorePackageImpl/15",1225),T(1226,1,ui,Oj),f.dk=function(t){return oe(t,104)},f.ek=function(t){return ye(fy,Zx,20,t,0,1)},C(Xt,"EcorePackageImpl/16",1226),T(1227,1,ui,oB),f.dk=function(t){return oe(t,182)},f.ek=function(t){return ye(xl,Zx,182,t,0,1)},C(Xt,"EcorePackageImpl/17",1227),T(1228,1,ui,GW),f.dk=function(t){return oe(t,473)},f.ek=function(t){return ye(uy,Lt,473,t,0,1)},C(Xt,"EcorePackageImpl/18",1228),T(1229,1,ui,UW),f.dk=function(t){return oe(t,553)},f.ek=function(t){return ye(Yo,kut,553,t,0,1)},C(Xt,"EcorePackageImpl/19",1229),T(1212,1,ui,rc),f.dk=function(t){return oe(t,336)},f.ek=function(t){return ye(ay,Zx,38,t,0,1)},C(Xt,"EcorePackageImpl/2",1212),T(1230,1,ui,Yc),f.dk=function(t){return oe(t,251)},f.ek=function(t){return ye(Ks,But,88,t,0,1)},C(Xt,"EcorePackageImpl/20",1230),T(1231,1,ui,ro),f.dk=function(t){return oe(t,449)},f.ek=function(t){return ye(cl,Lt,842,t,0,1)},C(Xt,"EcorePackageImpl/21",1231),T(1232,1,ui,wo),f.dk=function(t){return L2(t)},f.ek=function(t){return ye(ir,Be,476,t,8,1)},C(Xt,"EcorePackageImpl/22",1232),T(1233,1,ui,kc),f.dk=function(t){return oe(t,198)},f.ek=function(t){return ye(Rl,Be,198,t,0,2)},C(Xt,"EcorePackageImpl/23",1233),T(1234,1,ui,m1),f.dk=function(t){return oe(t,224)},f.ek=function(t){return ye(ak,Be,224,t,0,1)},C(Xt,"EcorePackageImpl/24",1234),T(1235,1,ui,x2),f.dk=function(t){return oe(t,183)},f.ek=function(t){return ye(CE,Be,183,t,0,1)},C(Xt,"EcorePackageImpl/25",1235),T(1236,1,ui,E4),f.dk=function(t){return oe(t,208)},f.ek=function(t){return ye(KG,Be,208,t,0,1)},C(Xt,"EcorePackageImpl/26",1236),T(1237,1,ui,rN),f.dk=function(t){return!1},f.ek=function(t){return ye(nEe,Lt,2191,t,0,1)},C(Xt,"EcorePackageImpl/27",1237),T(1238,1,ui,wm),f.dk=function(t){return P2(t)},f.ek=function(t){return ye(kr,Be,347,t,7,1)},C(Xt,"EcorePackageImpl/28",1238),T(1239,1,ui,bu),f.dk=function(t){return oe(t,61)},f.ek=function(t){return ye(mTe,Tv,61,t,0,1)},C(Xt,"EcorePackageImpl/29",1239),T(1213,1,ui,k2),f.dk=function(t){return oe(t,508)},f.ek=function(t){return ye(si,{3:1,4:1,5:1,2012:1},594,t,0,1)},C(Xt,"EcorePackageImpl/3",1213),T(1240,1,ui,Yy),f.dk=function(t){return oe(t,575)},f.ek=function(t){return ye(yTe,Lt,2018,t,0,1)},C(Xt,"EcorePackageImpl/30",1240),T(1241,1,ui,sN),f.dk=function(t){return oe(t,164)},f.ek=function(t){return ye(HTe,Tv,164,t,0,1)},C(Xt,"EcorePackageImpl/31",1241),T(1242,1,ui,w1),f.dk=function(t){return oe(t,76)},f.ek=function(t){return ye(aX,Xut,76,t,0,1)},C(Xt,"EcorePackageImpl/32",1242),T(1243,1,ui,C4),f.dk=function(t){return oe(t,165)},f.ek=function(t){return ye(O9,Be,165,t,0,1)},C(Xt,"EcorePackageImpl/33",1243),T(1244,1,ui,ZO),f.dk=function(t){return oe(t,15)},f.ek=function(t){return ye(Lr,Be,15,t,0,1)},C(Xt,"EcorePackageImpl/34",1244),T(1245,1,ui,_d),f.dk=function(t){return oe(t,299)},f.ek=function(t){return ye(F5e,Lt,299,t,0,1)},C(Xt,"EcorePackageImpl/35",1245),T(1246,1,ui,oN),f.dk=function(t){return oe(t,192)},f.ek=function(t){return ye(Ow,Be,192,t,0,1)},C(Xt,"EcorePackageImpl/36",1246),T(1247,1,ui,Sj),f.dk=function(t){return oe(t,93)},f.ek=function(t){return ye(q5e,Lt,93,t,0,1)},C(Xt,"EcorePackageImpl/37",1247),T(1248,1,ui,cB),f.dk=function(t){return oe(t,595)},f.ek=function(t){return ye(BTe,Lt,595,t,0,1)},C(Xt,"EcorePackageImpl/38",1248),T(1249,1,ui,jj),f.dk=function(t){return!1},f.ek=function(t){return ye(iEe,Lt,2192,t,0,1)},C(Xt,"EcorePackageImpl/39",1249),T(1214,1,ui,Tj),f.dk=function(t){return oe(t,89)},f.ek=function(t){return ye(ef,Lt,29,t,0,1)},C(Xt,"EcorePackageImpl/4",1214),T(1250,1,ui,O2),f.dk=function(t){return oe(t,193)},f.ek=function(t){return ye(Sw,Be,193,t,0,1)},C(Xt,"EcorePackageImpl/40",1250),T(1251,1,ui,Ia),f.dk=function(t){return Kr(t)},f.ek=function(t){return ye(nt,Be,2,t,6,1)},C(Xt,"EcorePackageImpl/41",1251),T(1252,1,ui,S2),f.dk=function(t){return oe(t,592)},f.ek=function(t){return ye(vTe,Lt,592,t,0,1)},C(Xt,"EcorePackageImpl/42",1252),T(1253,1,ui,M4),f.dk=function(t){return!1},f.ek=function(t){return ye(rEe,Be,2193,t,0,1)},C(Xt,"EcorePackageImpl/43",1253),T(1254,1,ui,vm),f.dk=function(t){return oe(t,45)},f.ek=function(t){return ye(Mb,qQ,45,t,0,1)},C(Xt,"EcorePackageImpl/44",1254),T(1215,1,ui,cN),f.dk=function(t){return oe(t,146)},f.ek=function(t){return ye(ah,Lt,146,t,0,1)},C(Xt,"EcorePackageImpl/5",1215),T(1216,1,ui,lN),f.dk=function(t){return oe(t,160)},f.ek=function(t){return ye(jae,Lt,160,t,0,1)},C(Xt,"EcorePackageImpl/6",1216),T(1217,1,ui,lB),f.dk=function(t){return oe(t,462)},f.ek=function(t){return ye(uX,Lt,682,t,0,1)},C(Xt,"EcorePackageImpl/7",1217),T(1218,1,ui,e6),f.dk=function(t){return oe(t,575)},f.ek=function(t){return ye(tg,Lt,691,t,0,1)},C(Xt,"EcorePackageImpl/8",1218),T(1219,1,ui,uN),f.dk=function(t){return oe(t,472)},f.ek=function(t){return ye(FC,Lt,472,t,0,1)},C(Xt,"EcorePackageImpl/9",1219),T(1030,2059,xut,rPe),f.Ki=function(t,n){o$t(this,c(n,420))},f.Oi=function(t,n){jet(this,t,c(n,420))},C(Xt,"MinimalEObjectImpl/1ArrayDelegatingAdapterList",1030),T(1031,152,LL,Eqe),f.hj=function(){return this.a.a},C(Xt,"MinimalEObjectImpl/1ArrayDelegatingAdapterList/1",1031),T(1058,1057,{},I$e),C("org.eclipse.emf.ecore.plugin","EcorePlugin",1058);var BTe=Ki(Vut,"Resource");T(793,1502,Wut),f.Fl=function(t){},f.Gl=function(t){},f.Cl=function(){return!this.a&&(this.a=new RK(this)),this.a},f.Dl=function(t){var n,i,r,o,a;if(r=t.length,r>0)if(en(0,t.length),t.charCodeAt(0)==47){for(a=new Hc(4),o=1,n=1;n<r;++n)en(n,t.length),t.charCodeAt(n)==47&&(qe(a,o==n?"":(fs(o,n,t.length),t.substr(o,n-o))),o=n+1);return qe(a,(en(o,t.length+1),t.substr(o))),sqt(this,a)}else en(r-1,t.length),t.charCodeAt(r-1)==63&&(i=u0e(t,dl(63),r-2),i>0&&(t=(fs(0,i,t.length),t.substr(0,i))));return yGt(this,t)},f.El=function(){return this.c},f.Ib=function(){var t;return qp(this.Pm)+"@"+(t=Ri(this)>>>0,t.toString(16))+" uri='"+this.d+"'"},f.b=!1,C(uoe,"ResourceImpl",793),T(1503,793,Wut,UDe),C(uoe,"BinaryResourceImpl",1503),T(1171,704,ioe),f._i=function(t){return oe(t,57)?qAt(this,c(t,57)):oe(t,595)?new cn(c(t,595).Cl()):ve(t)===ve(this.f)?c(t,18).Jc():(_6(),YP.a)},f.Ob=function(){return mve(this)},f.a=!1,C(Gi,"EcoreUtil/ContentTreeIterator",1171),T(1504,1171,ioe,nqe),f._i=function(t){return ve(t)===ve(this.f)?c(t,16).Jc():new lGe(c(t,57))},C(uoe,"ResourceImpl/5",1504),T(654,2071,$ut,RK),f.Gc=function(t){return this.i<=4?ES(this,t):oe(t,52)&&c(t,52).Gh()==this.a},f.Ki=function(t,n){t==this.i-1&&(this.a.b||(this.a.b=!0))},f.Mi=function(t,n){t==0?this.a.b||(this.a.b=!0):zee(this,t,n)},f.Oi=function(t,n){},f.Pi=function(t,n,i){},f.Jj=function(){return 2},f.hj=function(){return this.a},f.Kj=function(){return!0},f.Lj=function(t,n){var i;return i=c(t,52),n=i.ci(this.a,n),n},f.Mj=function(t,n){var i;return i=c(t,52),i.ci(null,n)},f.Nj=function(){return!1},f.Qi=function(){return!0},f.$i=function(t){return ye(dp,Lt,57,t,0,1)},f.Wi=function(){return!1},C(uoe,"ResourceImpl/ContentsEList",654),T(962,2041,US,JDe),f.dd=function(t){return this.a.Ii(t)},f.gc=function(){return this.a.gc()},C(Gi,"AbstractSequentialInternalEList/1",962);var zTe,FTe,ps,qTe;T(632,1,{},fFe);var fX,hX;C(Gi,"BasicExtendedMetaData",632),T(1162,1,{},n$e),f.Hl=function(){return null},f.Il=function(){return this.a==-2&&y(this,THt(this.d,this.b)),this.a},f.Jl=function(){return null},f.Kl=function(){return Ct(),Ct(),Rs},f.ve=function(){return this.c==v9&&O(this,FKe(this.d,this.b)),this.c},f.Ll=function(){return 0},f.a=-2,f.c=v9,C(Gi,"BasicExtendedMetaData/EClassExtendedMetaDataImpl",1162),T(1163,1,{},LQe),f.Hl=function(){return this.a==(V6(),fX)&&q(this,gVt(this.f,this.b)),this.a},f.Il=function(){return 0},f.Jl=function(){return this.c==(V6(),fX)&&N(this,pVt(this.f,this.b)),this.c},f.Kl=function(){return!this.d&&Ce(this,YWt(this.f,this.b)),this.d},f.ve=function(){return this.e==v9&&Ft(this,FKe(this.f,this.b)),this.e},f.Ll=function(){return this.g==-2&&xn(this,Uqt(this.f,this.b)),this.g},f.e=v9,f.g=-2,C(Gi,"BasicExtendedMetaData/EDataTypeExtendedMetaDataImpl",1163),T(1161,1,{},r$e),f.b=!1,f.c=!1,C(Gi,"BasicExtendedMetaData/EPackageExtendedMetaDataImpl",1161),T(1164,1,{},PQe),f.c=-2,f.e=v9,f.f=v9,C(Gi,"BasicExtendedMetaData/EStructuralFeatureExtendedMetaDataImpl",1164),T(588,630,To,BF),f.Jj=function(){return this.c},f.ml=function(){return!1},f.Ui=function(t,n){return n},f.c=0,C(Gi,"EDataTypeEList",588);var HTe=Ki(Gi,"FeatureMap");T(77,588,{3:1,4:1,22:1,32:1,56:1,18:1,16:1,59:1,71:1,67:1,61:1,78:1,164:1,222:1,2015:1,72:1,98:1},ar),f._c=function(t,n){PJt(this,t,c(n,76))},f.Ec=function(t){return YUt(this,c(t,76))},f.Fi=function(t){QMt(this,c(t,76))},f.Lj=function(t,n){return cTt(this,c(t,76),n)},f.Mj=function(t,n){return f0e(this,c(t,76),n)},f.Ri=function(t,n){return sWt(this,t,n)},f.Ui=function(t,n){return VYt(this,t,c(n,76))},f.fd=function(t,n){return yXt(this,t,c(n,76))},f.Sj=function(t,n){return lTt(this,c(t,76),n)},f.Tj=function(t,n){return Aze(this,c(t,76),n)},f.Uj=function(t,n,i){return Iqt(this,c(t,76),c(n,76),i)},f.Xi=function(t,n){return Dne(this,t,c(n,76))},f.Ml=function(t,n){return fye(this,t,n)},f.ad=function(t,n){var i,r,o,a,d,b,v,x,S;for(x=new Um(n.gc()),o=n.Jc();o.Ob();)if(r=c(o.Pb(),76),a=r.Jk(),F1(this.e,a))(!a.Qi()||!Mq(this,a,r.kd())&&!ES(x,r))&&Nn(x,r);else{for(S=nl(this.e.Ah(),a),i=c(this.g,123),d=!0,b=0;b<this.i;++b)if(v=i[b],S.$l(v.Jk())){c(Dx(this,b,r),76),d=!1;break}d&&Nn(x,r)}return Nme(this,t,x)},f.Fc=function(t){var n,i,r,o,a,d,b,v,x;for(v=new Um(t.gc()),r=t.Jc();r.Ob();)if(i=c(r.Pb(),76),o=i.Jk(),F1(this.e,o))(!o.Qi()||!Mq(this,o,i.kd())&&!ES(v,i))&&Nn(v,i);else{for(x=nl(this.e.Ah(),o),n=c(this.g,123),a=!0,d=0;d<this.i;++d)if(b=n[d],x.$l(b.Jk())){c(Dx(this,d,i),76),a=!1;break}a&&Nn(v,i)}return ur(this,v)},f.Di=function(t){return this.j=-1,gie(this,this.i,t)},f.Nl=function(t,n,i){return iye(this,t,n,i)},f.Vk=function(t,n){return WD(this,t,n)},f.Ol=function(t,n,i){return _ye(this,t,n,i)},f.Pl=function(){return this},f.Ql=function(t,n){return ZD(this,t,n)},f.Rl=function(t){return c(re(this,t),76).Jk()},f.Sl=function(t){return c(re(this,t),76).kd()},f.Tl=function(){return this.b},f.Kj=function(){return!0},f.Rj=function(){return!0},f.Ul=function(t){return!ED(this,t)},f.$i=function(t){return ye(Z2t,Xut,345,t,0,1)},f.nl=function(t){return fZ(this,t)},f.Wb=function(t){P_(this,t)},f.Vl=function(t,n){PQ(this,t,n)},f.Wl=function(t){return qXe(this,t)},f.Xl=function(t){TYe(this,t)},C(Gi,"BasicFeatureMap",77),T(1939,1,Ud),f.Nb=function(t){gs(this,t)},f.Rb=function(t){if(this.g==-1)throw J(new Tl);tq(this);try{knt(this.e,this.b,this.a,t),this.d=this.e.j,XH(this)}catch(n){throw n=vr(n),oe(n,99)?J(new ua):J(n)}},f.Ob=function(){return Ate(this)},f.Sb=function(){return yWe(this)},f.Pb=function(){return XH(this)},f.Tb=function(){return this.a},f.Ub=function(){var t;if(yWe(this))return tq(this),this.g=--this.a,this.sl()&&(t=LT(this.e,this.b,this.c,this.a,this.j),this.j=t),this.i=0,this.j;throw J(new Co)},f.Vb=function(){return this.a-1},f.Qb=function(){if(this.g==-1)throw J(new Tl);tq(this);try{uet(this.e,this.b,this.g),this.d=this.e.j,this.g<this.a&&(--this.a,--this.c),--this.g}catch(t){throw t=vr(t),oe(t,99)?J(new ua):J(t)}},f.sl=function(){return!1},f.Wb=function(t){if(this.g==-1)throw J(new Tl);tq(this);try{Wit(this.e,this.b,this.g,t),this.d=this.e.j}catch(n){throw n=vr(n),oe(n,99)?J(new ua):J(n)}},f.a=0,f.c=0,f.d=0,f.f=!1,f.g=0,f.i=0,C(Gi,"FeatureMapUtil/BasicFeatureEIterator",1939),T(417,1939,Ud,oS),f.Yl=function(){var t,n,i;for(i=this.e.i,t=c(this.e.g,123);this.c<i;){if(n=t[this.c],this.k.$l(n.Jk()))return this.j=this.f?n:n.kd(),this.i=2,!0;++this.c}return this.i=1,this.g=-1,!1},f.Zl=function(){var t,n;for(t=c(this.e.g,123);--this.c>=0;)if(n=t[this.c],this.k.$l(n.Jk()))return this.j=this.f?n:n.kd(),this.i=-2,!0;return this.i=-1,this.g=-1,!1},C(Gi,"BasicFeatureMap/FeatureEIterator",417),T(673,417,Ud,XY),f.sl=function(){return!0},C(Gi,"BasicFeatureMap/ResolvingFeatureEIterator",673),T(960,485,IG,V$e),f.nj=function(){return this},C(Gi,"EContentsEList/1",960),T(961,485,IG,w$e),f.sl=function(){return!1},C(Gi,"EContentsEList/2",961),T(959,289,RG,W$e),f.ul=function(t){},f.Ob=function(){return!1},f.Sb=function(){return!1},C(Gi,"EContentsEList/FeatureIteratorImpl/1",959),T(832,588,To,wge),f.Li=function(){this.a=!0},f.Oj=function(){return this.a},f.Ek=function(){var t;En(this),wu(this.e)?(t=this.a,this.a=!1,vi(this.e,new bf(this.e,2,this.c,t,!1))):this.a=!1},f.a=!1,C(Gi,"EDataTypeEList/Unsettable",832),T(1937,588,To,rBe),f.Qi=function(){return!0},C(Gi,"EDataTypeUniqueEList",1937),T(1938,832,To,nBe),f.Qi=function(){return!0},C(Gi,"EDataTypeUniqueEList/Unsettable",1938),T(147,82,To,El),f.ll=function(){return!0},f.Ui=function(t,n){return X5(this,t,c(n,57))},C(Gi,"EObjectContainmentEList/Resolving",147),T(1165,547,To,tBe),f.ll=function(){return!0},f.Ui=function(t,n){return X5(this,t,c(n,57))},C(Gi,"EObjectContainmentEList/Unsettable/Resolving",1165),T(760,14,To,r0e),f.Li=function(){this.a=!0},f.Oj=function(){return this.a},f.Ek=function(){var t;En(this),wu(this.e)?(t=this.a,this.a=!1,vi(this.e,new bf(this.e,2,this.c,t,!1))):this.a=!1},f.a=!1,C(Gi,"EObjectContainmentWithInverseEList/Unsettable",760),T(1199,760,To,mze),f.ll=function(){return!0},f.Ui=function(t,n){return X5(this,t,c(n,57))},C(Gi,"EObjectContainmentWithInverseEList/Unsettable/Resolving",1199),T(752,494,To,mge),f.Li=function(){this.a=!0},f.Oj=function(){return this.a},f.Ek=function(){var t;En(this),wu(this.e)?(t=this.a,this.a=!1,vi(this.e,new bf(this.e,2,this.c,t,!1))):this.a=!1},f.a=!1,C(Gi,"EObjectEList/Unsettable",752),T(340,494,To,mx),f.ll=function(){return!0},f.Ui=function(t,n){return X5(this,t,c(n,57))},C(Gi,"EObjectResolvingEList",340),T(1842,752,To,iBe),f.ll=function(){return!0},f.Ui=function(t,n){return X5(this,t,c(n,57))},C(Gi,"EObjectResolvingEList/Unsettable",1842),T(1505,1,{},v1);var tvt;C(Gi,"EObjectValidator",1505),T(551,494,To,rq),f.gl=function(){return this.d},f.hl=function(){return this.b},f.Kj=function(){return!0},f.kl=function(){return!0},f.b=0,C(Gi,"EObjectWithInverseEList",551),T(1202,551,To,wze),f.jl=function(){return!0},C(Gi,"EObjectWithInverseEList/ManyInverse",1202),T(633,551,To,bZ),f.Li=function(){this.a=!0},f.Oj=function(){return this.a},f.Ek=function(){var t;En(this),wu(this.e)?(t=this.a,this.a=!1,vi(this.e,new bf(this.e,2,this.c,t,!1))):this.a=!1},f.a=!1,C(Gi,"EObjectWithInverseEList/Unsettable",633),T(1201,633,To,vze),f.jl=function(){return!0},C(Gi,"EObjectWithInverseEList/Unsettable/ManyInverse",1201),T(761,551,To,s0e),f.ll=function(){return!0},f.Ui=function(t,n){return X5(this,t,c(n,57))},C(Gi,"EObjectWithInverseResolvingEList",761),T(31,761,To,Et),f.jl=function(){return!0},C(Gi,"EObjectWithInverseResolvingEList/ManyInverse",31),T(762,633,To,o0e),f.ll=function(){return!0},f.Ui=function(t,n){return X5(this,t,c(n,57))},C(Gi,"EObjectWithInverseResolvingEList/Unsettable",762),T(1200,762,To,yze),f.jl=function(){return!0},C(Gi,"EObjectWithInverseResolvingEList/Unsettable/ManyInverse",1200),T(1166,630,To),f.Ji=function(){return(this.b&1792)==0},f.Li=function(){this.b|=1},f.il=function(){return(this.b&4)!=0},f.Kj=function(){return(this.b&40)!=0},f.jl=function(){return(this.b&16)!=0},f.kl=function(){return(this.b&8)!=0},f.ll=function(){return(this.b&q1)!=0},f.$k=function(){return(this.b&32)!=0},f.ml=function(){return(this.b&Ga)!=0},f.dk=function(t){return this.d?bGe(this.d,t):this.Jk().Fk().dk(t)},f.Oj=function(){return(this.b&2)!=0?(this.b&1)!=0:this.i!=0},f.Qi=function(){return(this.b&128)!=0},f.Ek=function(){var t;En(this),(this.b&2)!=0&&(wu(this.e)?(t=(this.b&1)!=0,this.b&=-2,b6(this,new bf(this.e,2,Vi(this.e.Ah(),this.Jk()),t,!1))):this.b&=-2)},f.Wi=function(){return(this.b&1536)==0},f.b=0,C(Gi,"EcoreEList/Generic",1166),T(1167,1166,To,bHe),f.Jk=function(){return this.a},C(Gi,"EcoreEList/Dynamic",1167),T(759,67,md,Sde),f.$i=function(t){return lD(this.a.a,t)},C(Gi,"EcoreEMap/1",759),T(758,82,To,epe),f.Ki=function(t,n){WH(this.b,c(n,138))},f.Mi=function(t,n){kVe(this.b)},f.Ni=function(t,n,i){var r;++(r=this.b,c(n,138),r).e},f.Oi=function(t,n){Fte(this.b,c(n,138))},f.Pi=function(t,n,i){Fte(this.b,c(i,138)),ve(i)===ve(n)&&c(i,138).zi(djt(c(n,138).jd())),WH(this.b,c(n,138))},C(Gi,"EcoreEMap/DelegateEObjectContainmentEList",758),T(1197,145,E5e,_Xe),C(Gi,"EcoreEMap/Unsettable",1197),T(1198,758,To,xze),f.Li=function(){this.a=!0},f.Oj=function(){return this.a},f.Ek=function(){var t;En(this),wu(this.e)?(t=this.a,this.a=!1,vi(this.e,new bf(this.e,2,this.c,t,!1))):this.a=!1},f.a=!1,C(Gi,"EcoreEMap/Unsettable/UnsettableDelegateEObjectContainmentEList",1198),T(1170,226,Gx,kqe),f.a=!1,f.b=!1,C(Gi,"EcoreUtil/Copier",1170),T(754,1,ts,lGe),f.Nb=function(t){gs(this,t)},f.Ob=function(){return xKe(this)},f.Pb=function(){var t;return xKe(this),t=this.b,this.b=null,t},f.Qb=function(){this.a.Qb()},C(Gi,"EcoreUtil/ProperContentIterator",754),T(1506,1505,{},Ij);var nvt;C(Gi,"EcoreValidator",1506);var ivt;Ki(Gi,"FeatureMapUtil/Validator"),T(1270,1,{2020:1},uB),f.$l=function(t){return!0},C(Gi,"FeatureMapUtil/1",1270),T(767,1,{2020:1},Qye),f.$l=function(t){var n;return this.c==t?!0:(n=Ze(Ut(this.a,t)),n==null?yVt(this,t)?(rUe(this.a,t,(Bt(),k9)),!0):(rUe(this.a,t,(Bt(),K0)),!1):n==(Bt(),k9))},f.e=!1;var Mae;C(Gi,"FeatureMapUtil/BasicValidator",767),T(768,44,Gx,gge),C(Gi,"FeatureMapUtil/BasicValidator/Cache",768),T(499,56,{22:1,32:1,56:1,18:1,16:1,61:1,78:1,72:1,98:1},p_),f._c=function(t,n){knt(this.c,this.b,t,n)},f.Ec=function(t){return fye(this.c,this.b,t)},f.ad=function(t,n){return FKt(this.c,this.b,t,n)},f.Fc=function(t){return C7(this,t)},f.Ei=function(t,n){gPt(this.c,this.b,t,n)},f.Uk=function(t,n){return iye(this.c,this.b,t,n)},f.Yi=function(t){return LQ(this.c,this.b,t,!1)},f.Gi=function(){return _$e(this.c,this.b)},f.Hi=function(){return W8t(this.c,this.b)},f.Ii=function(t){return yLt(this.c,this.b,t)},f.Vk=function(t,n){return ize(this,t,n)},f.$b=function(){J4(this)},f.Gc=function(t){return Mq(this.c,this.b,t)},f.Hc=function(t){return wIt(this.c,this.b,t)},f.Xb=function(t){return LQ(this.c,this.b,t,!0)},f.Dk=function(t){return this},f.bd=function(t){return ADt(this.c,this.b,t)},f.dc=function(){return dF(this)},f.Oj=function(){return!ED(this.c,this.b)},f.Jc=function(){return ePt(this.c,this.b)},f.cd=function(){return tPt(this.c,this.b)},f.dd=function(t){return k$t(this.c,this.b,t)},f.Ri=function(t,n){return zit(this.c,this.b,t,n)},f.Si=function(t,n){kLt(this.c,this.b,t,n)},f.ed=function(t){return uet(this.c,this.b,t)},f.Kc=function(t){return QVt(this.c,this.b,t)},f.fd=function(t,n){return Wit(this.c,this.b,t,n)},f.Wb=function(t){pQ(this.c,this.b),C7(this,c(t,16))},f.gc=function(){return O$t(this.c,this.b)},f.Nc=function(){return M_t(this.c,this.b)},f.Oc=function(t){return NDt(this.c,this.b,t)},f.Ib=function(){var t,n;for(n=new yg,n.a+="[",t=_$e(this.c,this.b);Ate(t);)Ys(n,A7(XH(t))),Ate(t)&&(n.a+=Jc);return n.a+="]",n.a},f.Ek=function(){pQ(this.c,this.b)},C(Gi,"FeatureMapUtil/FeatureEList",499),T(641,40,LL,Aee),f.fj=function(t){return mT(this,t)},f.kj=function(t){var n,i,r,o,a,d,b;switch(this.d){case 1:case 2:{if(a=t.hj(),ve(a)===ve(this.c)&&mT(this,null)==t.fj(null))return this.g=t.gj(),t.ej()==1&&(this.d=1),!0;break}case 3:{switch(o=t.ej(),o){case 3:{if(a=t.hj(),ve(a)===ve(this.c)&&mT(this,null)==t.fj(null))return this.d=5,n=new Um(2),Nn(n,this.g),Nn(n,t.gj()),this.g=n,!0;break}}break}case 5:{switch(o=t.ej(),o){case 3:{if(a=t.hj(),ve(a)===ve(this.c)&&mT(this,null)==t.fj(null))return i=c(this.g,18),i.Ec(t.gj()),!0;break}}break}case 4:{switch(o=t.ej(),o){case 3:{if(a=t.hj(),ve(a)===ve(this.c)&&mT(this,null)==t.fj(null))return this.d=1,this.g=t.gj(),!0;break}case 4:{if(a=t.hj(),ve(a)===ve(this.c)&&mT(this,null)==t.fj(null))return this.d=6,b=new Um(2),Nn(b,this.n),Nn(b,t.ij()),this.n=b,d=W(V(Fn,1),ci,30,15,[this.o,t.jj()]),this.g=d,!0;break}}break}case 6:{switch(o=t.ej(),o){case 4:{if(a=t.hj(),ve(a)===ve(this.c)&&mT(this,null)==t.fj(null))return i=c(this.n,18),i.Ec(t.ij()),d=c(this.g,54),r=ye(Fn,ci,30,d.length+1,15,1),mc(d,0,r,0,d.length),r[d.length]=t.jj(),this.g=r,!0;break}}break}}return!1},C(Gi,"FeatureMapUtil/FeatureENotificationImpl",641),T(560,499,{22:1,32:1,56:1,18:1,16:1,61:1,78:1,164:1,222:1,2015:1,72:1,98:1},HF),f.Ml=function(t,n){return fye(this.c,t,n)},f.Nl=function(t,n,i){return iye(this.c,t,n,i)},f.Ol=function(t,n,i){return _ye(this.c,t,n,i)},f.Pl=function(){return this},f.Ql=function(t,n){return ZD(this.c,t,n)},f.Rl=function(t){return c(LQ(this.c,this.b,t,!1),76).Jk()},f.Sl=function(t){return c(LQ(this.c,this.b,t,!1),76).kd()},f.Tl=function(){return this.a},f.Ul=function(t){return!ED(this.c,t)},f.Vl=function(t,n){PQ(this.c,t,n)},f.Wl=function(t){return qXe(this.c,t)},f.Xl=function(t){TYe(this.c,t)},C(Gi,"FeatureMapUtil/FeatureFeatureMap",560),T(1269,1,loe,i$e),f.Dk=function(t){return LQ(this.b,this.a,-1,t)},f.Oj=function(){return!ED(this.b,this.a)},f.Wb=function(t){PQ(this.b,this.a,t)},f.Ek=function(){pQ(this.b,this.a)},C(Gi,"FeatureMapUtil/FeatureValue",1269);var Bk,Aae,Nae,zk,rvt,eI=Ki(GG,"AnyType");T(677,63,H1,ZK),C(GG,"InvalidDatatypeValueException",677);var dX=Ki(GG,Yut),tI=Ki(GG,Zut),QTe=Ki(GG,eat),svt,ic,GTe,Gb,ovt,cvt,lvt,uvt,avt,fvt,hvt,dvt,gvt,pvt,bvt,N3,mvt,_3,UC,wvt,Fw,nI,iI,vvt,JC,XC;T(836,505,{110:1,95:1,94:1,57:1,52:1,101:1,849:1},Bde),f.Ih=function(t,n,i){switch(t){case 0:return i?(!this.c&&(this.c=new ar(this,0)),this.c):(!this.c&&(this.c=new ar(this,0)),this.c.b);case 1:return i?(!this.c&&(this.c=new ar(this,0)),c(Ec(this.c,(Ci(),Gb)),164)):(!this.c&&(this.c=new ar(this,0)),c(c(Ec(this.c,(Ci(),Gb)),164),222)).Tl();case 2:return i?(!this.b&&(this.b=new ar(this,2)),this.b):(!this.b&&(this.b=new ar(this,2)),this.b.b)}return pa(this,t-pn(this.fi()),_t((this.j&2)==0?this.fi():(!this.k&&(this.k=new la),this.k).Lk(),t),n,i)},f.Rh=function(t,n,i){var r;switch(n){case 0:return!this.c&&(this.c=new ar(this,0)),WD(this.c,t,i);case 1:return(!this.c&&(this.c=new ar(this,0)),c(c(Ec(this.c,(Ci(),Gb)),164),72)).Vk(t,i);case 2:return!this.b&&(this.b=new ar(this,2)),WD(this.b,t,i)}return r=c(_t((this.j&2)==0?this.fi():(!this.k&&(this.k=new la),this.k).Lk(),n),69),r.uk().yk(this,zbe(this),n-pn(this.fi()),t,i)},f.Th=function(t){switch(t){case 0:return!!this.c&&this.c.i!=0;case 1:return!(!this.c&&(this.c=new ar(this,0)),c(Ec(this.c,(Ci(),Gb)),164)).dc();case 2:return!!this.b&&this.b.i!=0}return da(this,t-pn(this.fi()),_t((this.j&2)==0?this.fi():(!this.k&&(this.k=new la),this.k).Lk(),t))},f.$h=function(t,n){switch(t){case 0:!this.c&&(this.c=new ar(this,0)),P_(this.c,n);return;case 1:(!this.c&&(this.c=new ar(this,0)),c(c(Ec(this.c,(Ci(),Gb)),164),222)).Wb(n);return;case 2:!this.b&&(this.b=new ar(this,2)),P_(this.b,n);return}xa(this,t-pn(this.fi()),_t((this.j&2)==0?this.fi():(!this.k&&(this.k=new la),this.k).Lk(),t),n)},f.fi=function(){return Ci(),GTe},f.hi=function(t){switch(t){case 0:!this.c&&(this.c=new ar(this,0)),En(this.c);return;case 1:(!this.c&&(this.c=new ar(this,0)),c(Ec(this.c,(Ci(),Gb)),164)).$b();return;case 2:!this.b&&(this.b=new ar(this,2)),En(this.b);return}ya(this,t-pn(this.fi()),_t((this.j&2)==0?this.fi():(!this.k&&(this.k=new la),this.k).Lk(),t))},f.Ib=function(){var t;return(this.j&4)!=0?kf(this):(t=new Ba(kf(this)),t.a+=" (mixed: ",S7(t,this.c),t.a+=", anyAttribute: ",S7(t,this.b),t.a+=")",t.a)},C(Dr,"AnyTypeImpl",836),T(678,505,{110:1,95:1,94:1,57:1,52:1,101:1,2098:1,678:1},pB),f.Ih=function(t,n,i){switch(t){case 0:return this.a;case 1:return this.b}return pa(this,t-pn((Ci(),N3)),_t((this.j&2)==0?N3:(!this.k&&(this.k=new la),this.k).Lk(),t),n,i)},f.Th=function(t){switch(t){case 0:return this.a!=null;case 1:return this.b!=null}return da(this,t-pn((Ci(),N3)),_t((this.j&2)==0?N3:(!this.k&&(this.k=new la),this.k).Lk(),t))},f.$h=function(t,n){switch(t){case 0:Wi(this,zn(n));return;case 1:Zc(this,zn(n));return}xa(this,t-pn((Ci(),N3)),_t((this.j&2)==0?N3:(!this.k&&(this.k=new la),this.k).Lk(),t),n)},f.fi=function(){return Ci(),N3},f.hi=function(t){switch(t){case 0:this.a=null;return;case 1:this.b=null;return}ya(this,t-pn((Ci(),N3)),_t((this.j&2)==0?N3:(!this.k&&(this.k=new la),this.k).Lk(),t))},f.Ib=function(){var t;return(this.j&4)!=0?kf(this):(t=new Ba(kf(this)),t.a+=" (data: ",Ys(t,this.a),t.a+=", target: ",Ys(t,this.b),t.a+=")",t.a)},f.a=null,f.b=null,C(Dr,"ProcessingInstructionImpl",678),T(679,836,{110:1,95:1,94:1,57:1,52:1,101:1,849:1,2099:1,679:1},PLe),f.Ih=function(t,n,i){switch(t){case 0:return i?(!this.c&&(this.c=new ar(this,0)),this.c):(!this.c&&(this.c=new ar(this,0)),this.c.b);case 1:return i?(!this.c&&(this.c=new ar(this,0)),c(Ec(this.c,(Ci(),Gb)),164)):(!this.c&&(this.c=new ar(this,0)),c(c(Ec(this.c,(Ci(),Gb)),164),222)).Tl();case 2:return i?(!this.b&&(this.b=new ar(this,2)),this.b):(!this.b&&(this.b=new ar(this,2)),this.b.b);case 3:return!this.c&&(this.c=new ar(this,0)),zn(ZD(this.c,(Ci(),UC),!0));case 4:return l0e(this.a,(!this.c&&(this.c=new ar(this,0)),zn(ZD(this.c,(Ci(),UC),!0))));case 5:return this.a}return pa(this,t-pn((Ci(),_3)),_t((this.j&2)==0?_3:(!this.k&&(this.k=new la),this.k).Lk(),t),n,i)},f.Th=function(t){switch(t){case 0:return!!this.c&&this.c.i!=0;case 1:return!(!this.c&&(this.c=new ar(this,0)),c(Ec(this.c,(Ci(),Gb)),164)).dc();case 2:return!!this.b&&this.b.i!=0;case 3:return!this.c&&(this.c=new ar(this,0)),zn(ZD(this.c,(Ci(),UC),!0))!=null;case 4:return l0e(this.a,(!this.c&&(this.c=new ar(this,0)),zn(ZD(this.c,(Ci(),UC),!0))))!=null;case 5:return!!this.a}return da(this,t-pn((Ci(),_3)),_t((this.j&2)==0?_3:(!this.k&&(this.k=new la),this.k).Lk(),t))},f.$h=function(t,n){switch(t){case 0:!this.c&&(this.c=new ar(this,0)),P_(this.c,n);return;case 1:(!this.c&&(this.c=new ar(this,0)),c(c(Ec(this.c,(Ci(),Gb)),164),222)).Wb(n);return;case 2:!this.b&&(this.b=new ar(this,2)),P_(this.b,n);return;case 3:Xpe(this,zn(n));return;case 4:Xpe(this,c0e(this.a,n));return;case 5:qr(this,c(n,160));return}xa(this,t-pn((Ci(),_3)),_t((this.j&2)==0?_3:(!this.k&&(this.k=new la),this.k).Lk(),t),n)},f.fi=function(){return Ci(),_3},f.hi=function(t){switch(t){case 0:!this.c&&(this.c=new ar(this,0)),En(this.c);return;case 1:(!this.c&&(this.c=new ar(this,0)),c(Ec(this.c,(Ci(),Gb)),164)).$b();return;case 2:!this.b&&(this.b=new ar(this,2)),En(this.b);return;case 3:!this.c&&(this.c=new ar(this,0)),PQ(this.c,(Ci(),UC),null);return;case 4:Xpe(this,c0e(this.a,null));return;case 5:this.a=null;return}ya(this,t-pn((Ci(),_3)),_t((this.j&2)==0?_3:(!this.k&&(this.k=new la),this.k).Lk(),t))},C(Dr,"SimpleAnyTypeImpl",679),T(680,505,{110:1,95:1,94:1,57:1,52:1,101:1,2100:1,680:1},ILe),f.Ih=function(t,n,i){switch(t){case 0:return i?(!this.a&&(this.a=new ar(this,0)),this.a):(!this.a&&(this.a=new ar(this,0)),this.a.b);case 1:return i?(!this.b&&(this.b=new Al((Mt(),Bs),Yo,this,1)),this.b):(!this.b&&(this.b=new Al((Mt(),Bs),Yo,this,1)),V_(this.b));case 2:return i?(!this.c&&(this.c=new Al((Mt(),Bs),Yo,this,2)),this.c):(!this.c&&(this.c=new Al((Mt(),Bs),Yo,this,2)),V_(this.c));case 3:return!this.a&&(this.a=new ar(this,0)),Ec(this.a,(Ci(),nI));case 4:return!this.a&&(this.a=new ar(this,0)),Ec(this.a,(Ci(),iI));case 5:return!this.a&&(this.a=new ar(this,0)),Ec(this.a,(Ci(),JC));case 6:return!this.a&&(this.a=new ar(this,0)),Ec(this.a,(Ci(),XC))}return pa(this,t-pn((Ci(),Fw)),_t((this.j&2)==0?Fw:(!this.k&&(this.k=new la),this.k).Lk(),t),n,i)},f.Rh=function(t,n,i){var r;switch(n){case 0:return!this.a&&(this.a=new ar(this,0)),WD(this.a,t,i);case 1:return!this.b&&(this.b=new Al((Mt(),Bs),Yo,this,1)),_F(this.b,t,i);case 2:return!this.c&&(this.c=new Al((Mt(),Bs),Yo,this,2)),_F(this.c,t,i);case 5:return!this.a&&(this.a=new ar(this,0)),ize(Ec(this.a,(Ci(),JC)),t,i)}return r=c(_t((this.j&2)==0?(Ci(),Fw):(!this.k&&(this.k=new la),this.k).Lk(),n),69),r.uk().yk(this,zbe(this),n-pn((Ci(),Fw)),t,i)},f.Th=function(t){switch(t){case 0:return!!this.a&&this.a.i!=0;case 1:return!!this.b&&this.b.f!=0;case 2:return!!this.c&&this.c.f!=0;case 3:return!this.a&&(this.a=new ar(this,0)),!dF(Ec(this.a,(Ci(),nI)));case 4:return!this.a&&(this.a=new ar(this,0)),!dF(Ec(this.a,(Ci(),iI)));case 5:return!this.a&&(this.a=new ar(this,0)),!dF(Ec(this.a,(Ci(),JC)));case 6:return!this.a&&(this.a=new ar(this,0)),!dF(Ec(this.a,(Ci(),XC)))}return da(this,t-pn((Ci(),Fw)),_t((this.j&2)==0?Fw:(!this.k&&(this.k=new la),this.k).Lk(),t))},f.$h=function(t,n){switch(t){case 0:!this.a&&(this.a=new ar(this,0)),P_(this.a,n);return;case 1:!this.b&&(this.b=new Al((Mt(),Bs),Yo,this,1)),bH(this.b,n);return;case 2:!this.c&&(this.c=new Al((Mt(),Bs),Yo,this,2)),bH(this.c,n);return;case 3:!this.a&&(this.a=new ar(this,0)),J4(Ec(this.a,(Ci(),nI))),!this.a&&(this.a=new ar(this,0)),C7(Ec(this.a,nI),c(n,18));return;case 4:!this.a&&(this.a=new ar(this,0)),J4(Ec(this.a,(Ci(),iI))),!this.a&&(this.a=new ar(this,0)),C7(Ec(this.a,iI),c(n,18));return;case 5:!this.a&&(this.a=new ar(this,0)),J4(Ec(this.a,(Ci(),JC))),!this.a&&(this.a=new ar(this,0)),C7(Ec(this.a,JC),c(n,18));return;case 6:!this.a&&(this.a=new ar(this,0)),J4(Ec(this.a,(Ci(),XC))),!this.a&&(this.a=new ar(this,0)),C7(Ec(this.a,XC),c(n,18));return}xa(this,t-pn((Ci(),Fw)),_t((this.j&2)==0?Fw:(!this.k&&(this.k=new la),this.k).Lk(),t),n)},f.fi=function(){return Ci(),Fw},f.hi=function(t){switch(t){case 0:!this.a&&(this.a=new ar(this,0)),En(this.a);return;case 1:!this.b&&(this.b=new Al((Mt(),Bs),Yo,this,1)),this.b.c.$b();return;case 2:!this.c&&(this.c=new Al((Mt(),Bs),Yo,this,2)),this.c.c.$b();return;case 3:!this.a&&(this.a=new ar(this,0)),J4(Ec(this.a,(Ci(),nI)));return;case 4:!this.a&&(this.a=new ar(this,0)),J4(Ec(this.a,(Ci(),iI)));return;case 5:!this.a&&(this.a=new ar(this,0)),J4(Ec(this.a,(Ci(),JC)));return;case 6:!this.a&&(this.a=new ar(this,0)),J4(Ec(this.a,(Ci(),XC)));return}ya(this,t-pn((Ci(),Fw)),_t((this.j&2)==0?Fw:(!this.k&&(this.k=new la),this.k).Lk(),t))},f.Ib=function(){var t;return(this.j&4)!=0?kf(this):(t=new Ba(kf(this)),t.a+=" (mixed: ",S7(t,this.a),t.a+=")",t.a)},C(Dr,"XMLTypeDocumentRootImpl",680),T(2007,717,{110:1,95:1,94:1,472:1,159:1,57:1,115:1,52:1,101:1,162:1,118:1,119:1,2101:1},Dd),f.oi=function(t,n){switch(t.fk()){case 7:case 8:case 9:case 10:case 16:case 22:case 23:case 24:case 25:case 26:case 32:case 33:case 34:case 36:case 37:case 44:case 45:case 50:case 51:case 53:case 55:case 56:case 57:case 58:case 60:case 61:case 4:return n==null?null:jo(n);case 19:case 28:case 29:case 35:case 38:case 39:case 41:case 46:case 52:case 54:case 5:return zn(n);case 6:return S7t(c(n,198));case 12:case 47:case 49:case 11:return Rrt(this,t,n);case 13:return n==null?null:JKt(c(n,249));case 15:case 14:return n==null?null:PMt(ue(he(n)));case 17:return pZe((Ci(),n));case 18:return pZe(n);case 21:case 20:return n==null?null:IMt(c(n,165).a);case 27:return j7t(c(n,198));case 30:return EYe((Ci(),c(n,16)));case 31:return EYe(c(n,16));case 40:return O7t((Ci(),n));case 42:return bZe((Ci(),n));case 43:return bZe(n);case 59:case 48:return k7t((Ci(),n));default:throw J(new qt(p9+t.ve()+xw))}},f.pi=function(t){var n,i,r,o,a;switch(t.G==-1&&(t.G=(i=Bu(t),i?$g(i.si(),t):-1)),t.G){case 0:return n=new Bde,n;case 1:return r=new pB,r;case 2:return o=new PLe,o;case 3:return a=new ILe,a;default:throw J(new qt(Use+t.zb+xw))}},f.qi=function(t,n){var i,r,o,a,d,b,v,x,S,M,L,P,z,H,X,ie;switch(t.fk()){case 5:case 52:case 4:return n;case 6:return nzt(n);case 8:case 7:return n==null?null:qqt(n);case 9:return n==null?null:iD(Hu((r=Nc(n,!0),r.length>0&&(en(0,r.length),r.charCodeAt(0)==43)?(en(1,r.length+1),r.substr(1)):r),-128,127)<<24>>24);case 10:return n==null?null:iD(Hu((o=Nc(n,!0),o.length>0&&(en(0,o.length),o.charCodeAt(0)==43)?(en(1,o.length+1),o.substr(1)):o),-128,127)<<24>>24);case 11:return zn(aw(this,(Ci(),lvt),n));case 12:return zn(aw(this,(Ci(),uvt),n));case 13:return n==null?null:new o1e(Nc(n,!0));case 15:case 14:return tJt(n);case 16:return zn(aw(this,(Ci(),avt),n));case 17:return MKe((Ci(),n));case 18:return MKe(n);case 28:case 29:case 35:case 38:case 39:case 41:case 54:case 19:return Nc(n,!0);case 21:case 20:return fJt(n);case 22:return zn(aw(this,(Ci(),fvt),n));case 23:return zn(aw(this,(Ci(),hvt),n));case 24:return zn(aw(this,(Ci(),dvt),n));case 25:return zn(aw(this,(Ci(),gvt),n));case 26:return zn(aw(this,(Ci(),pvt),n));case 27:return UBt(n);case 30:return AKe((Ci(),n));case 31:return AKe(n);case 32:return n==null?null:Pe(Hu((S=Nc(n,!0),S.length>0&&(en(0,S.length),S.charCodeAt(0)==43)?(en(1,S.length+1),S.substr(1)):S),ls,di));case 33:return n==null?null:new O0((M=Nc(n,!0),M.length>0&&(en(0,M.length),M.charCodeAt(0)==43)?(en(1,M.length+1),M.substr(1)):M));case 34:return n==null?null:Pe(Hu((L=Nc(n,!0),L.length>0&&(en(0,L.length),L.charCodeAt(0)==43)?(en(1,L.length+1),L.substr(1)):L),ls,di));case 36:return n==null?null:fv(BQ((P=Nc(n,!0),P.length>0&&(en(0,P.length),P.charCodeAt(0)==43)?(en(1,P.length+1),P.substr(1)):P)));case 37:return n==null?null:fv(BQ((z=Nc(n,!0),z.length>0&&(en(0,z.length),z.charCodeAt(0)==43)?(en(1,z.length+1),z.substr(1)):z)));case 40:return Hzt((Ci(),n));case 42:return NKe((Ci(),n));case 43:return NKe(n);case 44:return n==null?null:new O0((H=Nc(n,!0),H.length>0&&(en(0,H.length),H.charCodeAt(0)==43)?(en(1,H.length+1),H.substr(1)):H));case 45:return n==null?null:new O0((X=Nc(n,!0),X.length>0&&(en(0,X.length),X.charCodeAt(0)==43)?(en(1,X.length+1),X.substr(1)):X));case 46:return Nc(n,!1);case 47:return zn(aw(this,(Ci(),bvt),n));case 59:case 48:return qzt((Ci(),n));case 49:return zn(aw(this,(Ci(),mvt),n));case 50:return n==null?null:pS(Hu((ie=Nc(n,!0),ie.length>0&&(en(0,ie.length),ie.charCodeAt(0)==43)?(en(1,ie.length+1),ie.substr(1)):ie),FG,32767)<<16>>16);case 51:return n==null?null:pS(Hu((a=Nc(n,!0),a.length>0&&(en(0,a.length),a.charCodeAt(0)==43)?(en(1,a.length+1),a.substr(1)):a),FG,32767)<<16>>16);case 53:return zn(aw(this,(Ci(),wvt),n));case 55:return n==null?null:pS(Hu((d=Nc(n,!0),d.length>0&&(en(0,d.length),d.charCodeAt(0)==43)?(en(1,d.length+1),d.substr(1)):d),FG,32767)<<16>>16);case 56:return n==null?null:pS(Hu((b=Nc(n,!0),b.length>0&&(en(0,b.length),b.charCodeAt(0)==43)?(en(1,b.length+1),b.substr(1)):b),FG,32767)<<16>>16);case 57:return n==null?null:fv(BQ((v=Nc(n,!0),v.length>0&&(en(0,v.length),v.charCodeAt(0)==43)?(en(1,v.length+1),v.substr(1)):v)));case 58:return n==null?null:fv(BQ((x=Nc(n,!0),x.length>0&&(en(0,x.length),x.charCodeAt(0)==43)?(en(1,x.length+1),x.substr(1)):x)));case 60:return n==null?null:Pe(Hu((i=Nc(n,!0),i.length>0&&(en(0,i.length),i.charCodeAt(0)==43)?(en(1,i.length+1),i.substr(1)):i),ls,di));case 61:return n==null?null:Pe(Hu(Nc(n,!0),ls,di));default:throw J(new qt(p9+t.ve()+xw))}};var yvt,UTe,xvt,JTe;C(Dr,"XMLTypeFactoryImpl",2007),T(589,187,{110:1,95:1,94:1,159:1,199:1,57:1,244:1,115:1,52:1,101:1,162:1,187:1,118:1,119:1,687:1,2023:1,589:1},Hqe),f.N=!1,f.O=!1;var kvt=!1;C(Dr,"XMLTypePackageImpl",589),T(1940,1,{843:1},aB),f.Ik=function(){return kye(),Nvt},C(Dr,"XMLTypePackageImpl/1",1940),T(1949,1,ui,fB),f.dk=function(t){return Kr(t)},f.ek=function(t){return ye(nt,Be,2,t,6,1)},C(Dr,"XMLTypePackageImpl/10",1949),T(1950,1,ui,JW),f.dk=function(t){return Kr(t)},f.ek=function(t){return ye(nt,Be,2,t,6,1)},C(Dr,"XMLTypePackageImpl/11",1950),T(1951,1,ui,j2),f.dk=function(t){return Kr(t)},f.ek=function(t){return ye(nt,Be,2,t,6,1)},C(Dr,"XMLTypePackageImpl/12",1951),T(1952,1,ui,Ej),f.dk=function(t){return P2(t)},f.ek=function(t){return ye(kr,Be,347,t,7,1)},C(Dr,"XMLTypePackageImpl/13",1952),T(1953,1,ui,aN),f.dk=function(t){return Kr(t)},f.ek=function(t){return ye(nt,Be,2,t,6,1)},C(Dr,"XMLTypePackageImpl/14",1953),T(1954,1,ui,A4),f.dk=function(t){return oe(t,16)},f.ek=function(t){return ye(Ju,Tv,16,t,0,1)},C(Dr,"XMLTypePackageImpl/15",1954),T(1955,1,ui,hB),f.dk=function(t){return oe(t,16)},f.ek=function(t){return ye(Ju,Tv,16,t,0,1)},C(Dr,"XMLTypePackageImpl/16",1955),T(1956,1,ui,dB),f.dk=function(t){return Kr(t)},f.ek=function(t){return ye(nt,Be,2,t,6,1)},C(Dr,"XMLTypePackageImpl/17",1956),T(1957,1,ui,gB),f.dk=function(t){return oe(t,165)},f.ek=function(t){return ye(O9,Be,165,t,0,1)},C(Dr,"XMLTypePackageImpl/18",1957),T(1958,1,ui,Cj),f.dk=function(t){return Kr(t)},f.ek=function(t){return ye(nt,Be,2,t,6,1)},C(Dr,"XMLTypePackageImpl/19",1958),T(1941,1,ui,fN),f.dk=function(t){return oe(t,849)},f.ek=function(t){return ye(eI,Lt,849,t,0,1)},C(Dr,"XMLTypePackageImpl/2",1941),T(1959,1,ui,XW),f.dk=function(t){return Kr(t)},f.ek=function(t){return ye(nt,Be,2,t,6,1)},C(Dr,"XMLTypePackageImpl/20",1959),T(1960,1,ui,VW),f.dk=function(t){return Kr(t)},f.ek=function(t){return ye(nt,Be,2,t,6,1)},C(Dr,"XMLTypePackageImpl/21",1960),T(1961,1,ui,WW),f.dk=function(t){return Kr(t)},f.ek=function(t){return ye(nt,Be,2,t,6,1)},C(Dr,"XMLTypePackageImpl/22",1961),T(1962,1,ui,bB),f.dk=function(t){return Kr(t)},f.ek=function(t){return ye(nt,Be,2,t,6,1)},C(Dr,"XMLTypePackageImpl/23",1962),T(1963,1,ui,mB),f.dk=function(t){return oe(t,198)},f.ek=function(t){return ye(Rl,Be,198,t,0,2)},C(Dr,"XMLTypePackageImpl/24",1963),T(1964,1,ui,N4),f.dk=function(t){return Kr(t)},f.ek=function(t){return ye(nt,Be,2,t,6,1)},C(Dr,"XMLTypePackageImpl/25",1964),T(1965,1,ui,Mj),f.dk=function(t){return Kr(t)},f.ek=function(t){return ye(nt,Be,2,t,6,1)},C(Dr,"XMLTypePackageImpl/26",1965),T(1966,1,ui,wB),f.dk=function(t){return oe(t,16)},f.ek=function(t){return ye(Ju,Tv,16,t,0,1)},C(Dr,"XMLTypePackageImpl/27",1966),T(1967,1,ui,vB),f.dk=function(t){return oe(t,16)},f.ek=function(t){return ye(Ju,Tv,16,t,0,1)},C(Dr,"XMLTypePackageImpl/28",1967),T(1968,1,ui,yB),f.dk=function(t){return Kr(t)},f.ek=function(t){return ye(nt,Be,2,t,6,1)},C(Dr,"XMLTypePackageImpl/29",1968),T(1942,1,ui,xB),f.dk=function(t){return oe(t,678)},f.ek=function(t){return ye(dX,Lt,2098,t,0,1)},C(Dr,"XMLTypePackageImpl/3",1942),T(1969,1,ui,kB),f.dk=function(t){return oe(t,15)},f.ek=function(t){return ye(Lr,Be,15,t,0,1)},C(Dr,"XMLTypePackageImpl/30",1969),T(1970,1,ui,OB),f.dk=function(t){return Kr(t)},f.ek=function(t){return ye(nt,Be,2,t,6,1)},C(Dr,"XMLTypePackageImpl/31",1970),T(1971,1,ui,Aj),f.dk=function(t){return oe(t,192)},f.ek=function(t){return ye(Ow,Be,192,t,0,1)},C(Dr,"XMLTypePackageImpl/32",1971),T(1972,1,ui,SB),f.dk=function(t){return Kr(t)},f.ek=function(t){return ye(nt,Be,2,t,6,1)},C(Dr,"XMLTypePackageImpl/33",1972),T(1973,1,ui,jB),f.dk=function(t){return Kr(t)},f.ek=function(t){return ye(nt,Be,2,t,6,1)},C(Dr,"XMLTypePackageImpl/34",1973),T(1974,1,ui,Oc),f.dk=function(t){return Kr(t)},f.ek=function(t){return ye(nt,Be,2,t,6,1)},C(Dr,"XMLTypePackageImpl/35",1974),T(1975,1,ui,hN),f.dk=function(t){return Kr(t)},f.ek=function(t){return ye(nt,Be,2,t,6,1)},C(Dr,"XMLTypePackageImpl/36",1975),T(1976,1,ui,KW),f.dk=function(t){return oe(t,16)},f.ek=function(t){return ye(Ju,Tv,16,t,0,1)},C(Dr,"XMLTypePackageImpl/37",1976),T(1977,1,ui,TB),f.dk=function(t){return oe(t,16)},f.ek=function(t){return ye(Ju,Tv,16,t,0,1)},C(Dr,"XMLTypePackageImpl/38",1977),T(1978,1,ui,YW),f.dk=function(t){return Kr(t)},f.ek=function(t){return ye(nt,Be,2,t,6,1)},C(Dr,"XMLTypePackageImpl/39",1978),T(1943,1,ui,ZW),f.dk=function(t){return oe(t,679)},f.ek=function(t){return ye(tI,Lt,2099,t,0,1)},C(Dr,"XMLTypePackageImpl/4",1943),T(1979,1,ui,eK),f.dk=function(t){return Kr(t)},f.ek=function(t){return ye(nt,Be,2,t,6,1)},C(Dr,"XMLTypePackageImpl/40",1979),T(1980,1,ui,Nj),f.dk=function(t){return Kr(t)},f.ek=function(t){return ye(nt,Be,2,t,6,1)},C(Dr,"XMLTypePackageImpl/41",1980),T(1981,1,ui,_4),f.dk=function(t){return Kr(t)},f.ek=function(t){return ye(nt,Be,2,t,6,1)},C(Dr,"XMLTypePackageImpl/42",1981),T(1982,1,ui,dN),f.dk=function(t){return Kr(t)},f.ek=function(t){return ye(nt,Be,2,t,6,1)},C(Dr,"XMLTypePackageImpl/43",1982),T(1983,1,ui,_j),f.dk=function(t){return Kr(t)},f.ek=function(t){return ye(nt,Be,2,t,6,1)},C(Dr,"XMLTypePackageImpl/44",1983),T(1984,1,ui,gN),f.dk=function(t){return oe(t,193)},f.ek=function(t){return ye(Sw,Be,193,t,0,1)},C(Dr,"XMLTypePackageImpl/45",1984),T(1985,1,ui,T2),f.dk=function(t){return Kr(t)},f.ek=function(t){return ye(nt,Be,2,t,6,1)},C(Dr,"XMLTypePackageImpl/46",1985),T(1986,1,ui,Rp),f.dk=function(t){return Kr(t)},f.ek=function(t){return ye(nt,Be,2,t,6,1)},C(Dr,"XMLTypePackageImpl/47",1986),T(1987,1,ui,t6),f.dk=function(t){return Kr(t)},f.ek=function(t){return ye(nt,Be,2,t,6,1)},C(Dr,"XMLTypePackageImpl/48",1987),T(1988,1,ui,tK),f.dk=function(t){return oe(t,193)},f.ek=function(t){return ye(Sw,Be,193,t,0,1)},C(Dr,"XMLTypePackageImpl/49",1988),T(1944,1,ui,EB),f.dk=function(t){return oe(t,680)},f.ek=function(t){return ye(QTe,Lt,2100,t,0,1)},C(Dr,"XMLTypePackageImpl/5",1944),T(1989,1,ui,CB),f.dk=function(t){return oe(t,192)},f.ek=function(t){return ye(Ow,Be,192,t,0,1)},C(Dr,"XMLTypePackageImpl/50",1989),T(1990,1,ui,MB),f.dk=function(t){return Kr(t)},f.ek=function(t){return ye(nt,Be,2,t,6,1)},C(Dr,"XMLTypePackageImpl/51",1990),T(1991,1,ui,AB),f.dk=function(t){return oe(t,15)},f.ek=function(t){return ye(Lr,Be,15,t,0,1)},C(Dr,"XMLTypePackageImpl/52",1991),T(1945,1,ui,nK),f.dk=function(t){return Kr(t)},f.ek=function(t){return ye(nt,Be,2,t,6,1)},C(Dr,"XMLTypePackageImpl/6",1945),T(1946,1,ui,pN),f.dk=function(t){return oe(t,198)},f.ek=function(t){return ye(Rl,Be,198,t,0,2)},C(Dr,"XMLTypePackageImpl/7",1946),T(1947,1,ui,NB),f.dk=function(t){return L2(t)},f.ek=function(t){return ye(ir,Be,476,t,8,1)},C(Dr,"XMLTypePackageImpl/8",1947),T(1948,1,ui,_B),f.dk=function(t){return oe(t,224)},f.ek=function(t){return ye(ak,Be,224,t,0,1)},C(Dr,"XMLTypePackageImpl/9",1948);var Uh,s0,VC,gX,ne;T(53,63,H1,Qn),C(Ug,"RegEx/ParseException",53),T(828,1,{},DB),f._l=function(t){return t<this.j&&ms(this.i,t)==63},f.am=function(){var t,n,i,r,o;if(this.c!=10)throw J(new Qn(Vn((Bn(),DG))));switch(t=this.a,t){case 101:t=27;break;case 102:t=12;break;case 110:t=10;break;case 114:t=13;break;case 116:t=9;break;case 120:if(bi(this),this.c!=0)throw J(new Qn(Vn((Bn(),Gg))));if(this.a==123){o=0,i=0;do{if(bi(this),this.c!=0)throw J(new Qn(Vn((Bn(),Gg))));if((o=pb(this.a))<0)break;if(i>i*16)throw J(new Qn(Vn((Bn(),fut))));i=i*16+o}while(!0);if(this.a!=125)throw J(new Qn(Vn((Bn(),hut))));if(i>y9)throw J(new Qn(Vn((Bn(),dut))));t=i}else{if(o=0,this.c!=0||(o=pb(this.a))<0)throw J(new Qn(Vn((Bn(),Gg))));if(i=o,bi(this),this.c!=0||(o=pb(this.a))<0)throw J(new Qn(Vn((Bn(),Gg))));i=i*16+o,t=i}break;case 117:if(r=0,bi(this),this.c!=0||(r=pb(this.a))<0)throw J(new Qn(Vn((Bn(),Gg))));if(n=r,bi(this),this.c!=0||(r=pb(this.a))<0)throw J(new Qn(Vn((Bn(),Gg))));if(n=n*16+r,bi(this),this.c!=0||(r=pb(this.a))<0)throw J(new Qn(Vn((Bn(),Gg))));if(n=n*16+r,bi(this),this.c!=0||(r=pb(this.a))<0)throw J(new Qn(Vn((Bn(),Gg))));n=n*16+r,t=n;break;case 118:if(bi(this),this.c!=0||(r=pb(this.a))<0)throw J(new Qn(Vn((Bn(),Gg))));if(n=r,bi(this),this.c!=0||(r=pb(this.a))<0)throw J(new Qn(Vn((Bn(),Gg))));if(n=n*16+r,bi(this),this.c!=0||(r=pb(this.a))<0)throw J(new Qn(Vn((Bn(),Gg))));if(n=n*16+r,bi(this),this.c!=0||(r=pb(this.a))<0)throw J(new Qn(Vn((Bn(),Gg))));if(n=n*16+r,bi(this),this.c!=0||(r=pb(this.a))<0)throw J(new Qn(Vn((Bn(),Gg))));if(n=n*16+r,bi(this),this.c!=0||(r=pb(this.a))<0)throw J(new Qn(Vn((Bn(),Gg))));if(n=n*16+r,n>y9)throw J(new Qn(Vn((Bn(),"parser.descappe.4"))));t=n;break;case 65:case 90:case 122:throw J(new Qn(Vn((Bn(),gut))))}return t},f.bm=function(t){var n,i;switch(t){case 100:i=(this.e&32)==32?Q0("Nd",!0):(wi(),pX);break;case 68:i=(this.e&32)==32?Q0("Nd",!1):(wi(),ZTe);break;case 119:i=(this.e&32)==32?Q0("IsWord",!0):(wi(),u8);break;case 87:i=(this.e&32)==32?Q0("IsWord",!1):(wi(),tEe);break;case 115:i=(this.e&32)==32?Q0("IsSpace",!0):(wi(),Fk);break;case 83:i=(this.e&32)==32?Q0("IsSpace",!1):(wi(),eEe);break;default:throw J(new Mo((n=t,gat+n.toString(16))))}return i},f.cm=function(t){var n,i,r,o,a,d,b,v,x,S,M,L;for(this.b=1,bi(this),n=null,this.c==0&&this.a==94?(bi(this),t?S=(wi(),wi(),new $u(5)):(n=(wi(),wi(),new $u(4)),Ac(n,0,y9),S=new $u(4))):S=(wi(),wi(),new $u(4)),o=!0;(L=this.c)!=1&&!(L==0&&this.a==93&&!o);){if(o=!1,i=this.a,r=!1,L==10)switch(i){case 100:case 68:case 119:case 87:case 115:case 83:kv(S,this.bm(i)),r=!0;break;case 105:case 73:case 99:case 67:i=this.sm(S,i),i<0&&(r=!0);break;case 112:case 80:if(M=pve(this,i),!M)throw J(new Qn(Vn((Bn(),soe))));kv(S,M),r=!0;break;default:i=this.am()}else if(L==20){if(d=A6(this.i,58,this.d),d<0)throw J(new Qn(Vn((Bn(),x5e))));if(b=!0,ms(this.i,this.d)==94&&(++this.d,b=!1),a=Fa(this.i,this.d,d),v=XUe(a,b,(this.e&512)==512),!v)throw J(new Qn(Vn((Bn(),out))));if(kv(S,v),r=!0,d+1>=this.j||ms(this.i,d+1)!=93)throw J(new Qn(Vn((Bn(),x5e))));this.d=d+2}if(bi(this),!r)if(this.c!=0||this.a!=45)Ac(S,i,i);else{if(bi(this),(L=this.c)==1)throw J(new Qn(Vn((Bn(),LG))));L==0&&this.a==93?(Ac(S,i,i),Ac(S,45,45)):(x=this.a,L==10&&(x=this.am()),bi(this),Ac(S,i,x))}(this.e&Ga)==Ga&&this.c==0&&this.a==44&&bi(this)}if(this.c==1)throw J(new Qn(Vn((Bn(),LG))));return n&&(WT(n,S),S=n),$x(S),JT(S),this.b=0,bi(this),S},f.dm=function(){var t,n,i,r;for(i=this.cm(!1);(r=this.c)!=7;)if(t=this.a,r==0&&(t==45||t==38)||r==4){if(bi(this),this.c!=9)throw J(new Qn(Vn((Bn(),lut))));if(n=this.cm(!1),r==4)kv(i,n);else if(t==45)WT(i,n);else if(t==38)Drt(i,n);else throw J(new Mo("ASSERT"))}else throw J(new Qn(Vn((Bn(),uut))));return bi(this),i},f.em=function(){var t,n;return t=this.a-48,n=(wi(),wi(),new gee(12,null,t)),!this.g&&(this.g=new vz),wz(this.g,new jde(t)),bi(this),n},f.fm=function(){return bi(this),wi(),jvt},f.gm=function(){return bi(this),wi(),Svt},f.hm=function(){throw J(new Qn(Vn((Bn(),ja))))},f.im=function(){throw J(new Qn(Vn((Bn(),ja))))},f.jm=function(){return bi(this),mRt()},f.km=function(){return bi(this),wi(),Evt},f.lm=function(){return bi(this),wi(),Mvt},f.mm=function(){var t;if(this.d>=this.j||((t=ms(this.i,this.d++))&65504)!=64)throw J(new Qn(Vn((Bn(),iut))));return bi(this),wi(),wi(),new Rd(0,t-64)},f.nm=function(){return bi(this),JWt()},f.om=function(){return bi(this),wi(),Avt},f.pm=function(){var t;return t=(wi(),wi(),new Rd(0,105)),bi(this),t},f.qm=function(){return bi(this),wi(),Cvt},f.rm=function(){return bi(this),wi(),Tvt},f.sm=function(t,n){return this.am()},f.tm=function(){return bi(this),wi(),KTe},f.um=function(){var t,n,i,r,o;if(this.d+1>=this.j)throw J(new Qn(Vn((Bn(),eut))));if(r=-1,n=null,t=ms(this.i,this.d),49<=t&&t<=57){if(r=t-48,!this.g&&(this.g=new vz),wz(this.g,new jde(r)),++this.d,ms(this.i,this.d)!=41)throw J(new Qn(Vn((Bn(),Eb))));++this.d}else switch(t==63&&--this.d,bi(this),n=Xye(this),n.e){case 20:case 21:case 22:case 23:break;case 8:if(this.c!=7)throw J(new Qn(Vn((Bn(),Eb))));break;default:throw J(new Qn(Vn((Bn(),tut))))}if(bi(this),o=nw(this),i=null,o.e==2){if(o.Nm()!=2)throw J(new Qn(Vn((Bn(),nut))));i=o.Jm(1),o=o.Jm(0)}if(this.c!=7)throw J(new Qn(Vn((Bn(),Eb))));return bi(this),wi(),wi(),new HJe(r,n,o,i)},f.vm=function(){return bi(this),wi(),YTe},f.wm=function(){var t;if(bi(this),t=sq(24,nw(this)),this.c!=7)throw J(new Qn(Vn((Bn(),Eb))));return bi(this),t},f.xm=function(){var t;if(bi(this),t=sq(20,nw(this)),this.c!=7)throw J(new Qn(Vn((Bn(),Eb))));return bi(this),t},f.ym=function(){var t;if(bi(this),t=sq(22,nw(this)),this.c!=7)throw J(new Qn(Vn((Bn(),Eb))));return bi(this),t},f.zm=function(){var t,n,i,r,o;for(t=0,i=0,n=-1;this.d<this.j&&(n=ms(this.i,this.d),o=xve(n),o!=0);)t|=o,++this.d;if(this.d>=this.j)throw J(new Qn(Vn((Bn(),v5e))));if(n==45){for(++this.d;this.d<this.j&&(n=ms(this.i,this.d),o=xve(n),o!=0);)i|=o,++this.d;if(this.d>=this.j)throw J(new Qn(Vn((Bn(),v5e))))}if(n==58){if(++this.d,bi(this),r=bqe(nw(this),t,i),this.c!=7)throw J(new Qn(Vn((Bn(),Eb))));bi(this)}else if(n==41)++this.d,bi(this),r=bqe(nw(this),t,i);else throw J(new Qn(Vn((Bn(),Zlt))));return r},f.Am=function(){var t;if(bi(this),t=sq(21,nw(this)),this.c!=7)throw J(new Qn(Vn((Bn(),Eb))));return bi(this),t},f.Bm=function(){var t;if(bi(this),t=sq(23,nw(this)),this.c!=7)throw J(new Qn(Vn((Bn(),Eb))));return bi(this),t},f.Cm=function(){var t,n;if(bi(this),t=this.f++,n=qZ(nw(this),t),this.c!=7)throw J(new Qn(Vn((Bn(),Eb))));return bi(this),n},f.Dm=function(){var t;if(bi(this),t=qZ(nw(this),0),this.c!=7)throw J(new Qn(Vn((Bn(),Eb))));return bi(this),t},f.Em=function(t){return bi(this),this.c==5?(bi(this),KF(t,(wi(),wi(),new Z2(9,t)))):KF(t,(wi(),wi(),new Z2(3,t)))},f.Fm=function(t){var n;return bi(this),n=(wi(),wi(),new E7(2)),this.c==5?(bi(this),wb(n,KC),wb(n,t)):(wb(n,t),wb(n,KC)),n},f.Gm=function(t){return bi(this),this.c==5?(bi(this),wi(),wi(),new Z2(9,t)):(wi(),wi(),new Z2(3,t))},f.a=0,f.b=0,f.c=0,f.d=0,f.e=0,f.f=1,f.g=null,f.j=0,C(Ug,"RegEx/RegexParser",828),T(1927,828,{},RLe),f._l=function(t){return!1},f.am=function(){return Zve(this)},f.bm=function(t){return RS(t)},f.cm=function(t){return Est(this)},f.dm=function(){throw J(new Qn(Vn((Bn(),ja))))},f.em=function(){throw J(new Qn(Vn((Bn(),ja))))},f.fm=function(){throw J(new Qn(Vn((Bn(),ja))))},f.gm=function(){throw J(new Qn(Vn((Bn(),ja))))},f.hm=function(){return bi(this),RS(67)},f.im=function(){return bi(this),RS(73)},f.jm=function(){throw J(new Qn(Vn((Bn(),ja))))},f.km=function(){throw J(new Qn(Vn((Bn(),ja))))},f.lm=function(){throw J(new Qn(Vn((Bn(),ja))))},f.mm=function(){return bi(this),RS(99)},f.nm=function(){throw J(new Qn(Vn((Bn(),ja))))},f.om=function(){throw J(new Qn(Vn((Bn(),ja))))},f.pm=function(){return bi(this),RS(105)},f.qm=function(){throw J(new Qn(Vn((Bn(),ja))))},f.rm=function(){throw J(new Qn(Vn((Bn(),ja))))},f.sm=function(t,n){return kv(t,RS(n)),-1},f.tm=function(){return bi(this),wi(),wi(),new Rd(0,94)},f.um=function(){throw J(new Qn(Vn((Bn(),ja))))},f.vm=function(){return bi(this),wi(),wi(),new Rd(0,36)},f.wm=function(){throw J(new Qn(Vn((Bn(),ja))))},f.xm=function(){throw J(new Qn(Vn((Bn(),ja))))},f.ym=function(){throw J(new Qn(Vn((Bn(),ja))))},f.zm=function(){throw J(new Qn(Vn((Bn(),ja))))},f.Am=function(){throw J(new Qn(Vn((Bn(),ja))))},f.Bm=function(){throw J(new Qn(Vn((Bn(),ja))))},f.Cm=function(){var t;if(bi(this),t=qZ(nw(this),0),this.c!=7)throw J(new Qn(Vn((Bn(),Eb))));return bi(this),t},f.Dm=function(){throw J(new Qn(Vn((Bn(),ja))))},f.Em=function(t){return bi(this),KF(t,(wi(),wi(),new Z2(3,t)))},f.Fm=function(t){var n;return bi(this),n=(wi(),wi(),new E7(2)),wb(n,t),wb(n,KC),n},f.Gm=function(t){return bi(this),wi(),wi(),new Z2(3,t)};var D3=null,c8=null;C(Ug,"RegEx/ParserForXMLSchema",1927),T(122,1,x9,km),f.Hm=function(t){throw J(new Mo("Not supported."))},f.Im=function(){return-1},f.Jm=function(t){return null},f.Km=function(){return null},f.Lm=function(t){},f.Mm=function(t){},f.Nm=function(){return 0},f.Ib=function(){return this.Om(0)},f.Om=function(t){return this.e==11?".":""},f.e=0;var XTe,l8,WC,Ovt,VTe,gy=null,pX,_ae=null,WTe,KC,Dae=null,KTe,YTe,ZTe,eEe,tEe,Svt,Fk,jvt,Tvt,Evt,Cvt,u8,Mvt,Avt,unn=C(Ug,"RegEx/Token",122);T(140,122,{3:1,140:1,122:1},$u),f.Om=function(t){var n,i,r;if(this.e==4)if(this==WTe)i=".";else if(this==pX)i="\\d";else if(this==u8)i="\\w";else if(this==Fk)i="\\s";else{for(r=new yg,r.a+="[",n=0;n<this.b.length;n+=2)(t&Ga)!=0&&n>0&&(r.a+=","),this.b[n]===this.b[n+1]?Ys(r,YD(this.b[n])):(Ys(r,YD(this.b[n])),r.a+="-",Ys(r,YD(this.b[n+1])));r.a+="]",i=r.a}else if(this==ZTe)i="\\D";else if(this==tEe)i="\\W";else if(this==eEe)i="\\S";else{for(r=new yg,r.a+="[^",n=0;n<this.b.length;n+=2)(t&Ga)!=0&&n>0&&(r.a+=","),this.b[n]===this.b[n+1]?Ys(r,YD(this.b[n])):(Ys(r,YD(this.b[n])),r.a+="-",Ys(r,YD(this.b[n+1])));r.a+="]",i=r.a}return i},f.a=!1,f.c=!1,C(Ug,"RegEx/RangeToken",140),T(587,1,{587:1},jde),f.a=0,C(Ug,"RegEx/RegexParser/ReferencePosition",587),T(586,1,{3:1,586:1},ZPe),f.Fb=function(t){var n;return t==null||!oe(t,586)?!1:(n=c(t,586),Ot(this.b,n.b)&&this.a==n.a)},f.Hb=function(){return Dg(this.b+"/"+Uve(this.a))},f.Ib=function(){return this.c.Om(this.a)},f.a=0,C(Ug,"RegEx/RegularExpression",586),T(230,122,x9,Rd),f.Im=function(){return this.a},f.Om=function(t){var n,i,r;switch(this.e){case 0:switch(this.a){case 124:case 42:case 43:case 63:case 40:case 41:case 46:case 91:case 123:case 92:r="\\"+gZ(this.a&_r);break;case 12:r="\\f";break;case 10:r="\\n";break;case 13:r="\\r";break;case 9:r="\\t";break;case 27:r="\\e";break;default:this.a>=Is?(i=(n=this.a>>>0,"0"+n.toString(16)),r="\\v"+Fa(i,i.length-6,i.length)):r=""+gZ(this.a&_r)}break;case 8:this==KTe||this==YTe?r=""+gZ(this.a&_r):r="\\"+gZ(this.a&_r);break;default:r=null}return r},f.a=0,C(Ug,"RegEx/Token/CharToken",230),T(323,122,x9,Z2),f.Jm=function(t){return this.a},f.Lm=function(t){this.b=t},f.Mm=function(t){this.c=t},f.Nm=function(){return 1},f.Om=function(t){var n;if(this.e==3)if(this.c<0&&this.b<0)n=this.a.Om(t)+"*";else if(this.c==this.b)n=this.a.Om(t)+"{"+this.c+"}";else if(this.c>=0&&this.b>=0)n=this.a.Om(t)+"{"+this.c+","+this.b+"}";else if(this.c>=0&&this.b<0)n=this.a.Om(t)+"{"+this.c+",}";else throw J(new Mo("Token#toString(): CLOSURE "+this.c+Jc+this.b));else if(this.c<0&&this.b<0)n=this.a.Om(t)+"*?";else if(this.c==this.b)n=this.a.Om(t)+"{"+this.c+"}?";else if(this.c>=0&&this.b>=0)n=this.a.Om(t)+"{"+this.c+","+this.b+"}?";else if(this.c>=0&&this.b<0)n=this.a.Om(t)+"{"+this.c+",}?";else throw J(new Mo("Token#toString(): NONGREEDYCLOSURE "+this.c+Jc+this.b));return n},f.b=0,f.c=0,C(Ug,"RegEx/Token/ClosureToken",323),T(829,122,x9,spe),f.Jm=function(t){return t==0?this.a:this.b},f.Nm=function(){return 2},f.Om=function(t){var n;return this.b.e==3&&this.b.Jm(0)==this.a?n=this.a.Om(t)+"+":this.b.e==9&&this.b.Jm(0)==this.a?n=this.a.Om(t)+"+?":n=this.a.Om(t)+(""+this.b.Om(t)),n},C(Ug,"RegEx/Token/ConcatToken",829),T(1925,122,x9,HJe),f.Jm=function(t){if(t==0)return this.d;if(t==1)return this.b;throw J(new Mo("Internal Error: "+t))},f.Nm=function(){return this.b?2:1},f.Om=function(t){var n;return this.c>0?n="(?("+this.c+")":this.a.e==8?n="(?("+this.a+")":n="(?"+this.a,this.b?n+=this.d+"|"+this.b+")":n+=this.d+")",n},f.c=0,C(Ug,"RegEx/Token/ConditionToken",1925),T(1926,122,x9,bQe),f.Jm=function(t){return this.b},f.Nm=function(){return 1},f.Om=function(t){return"(?"+(this.a==0?"":Uve(this.a))+(this.c==0?"":Uve(this.c))+":"+this.b.Om(t)+")"},f.a=0,f.c=0,C(Ug,"RegEx/Token/ModifierToken",1926),T(830,122,x9,gpe),f.Jm=function(t){return this.a},f.Nm=function(){return 1},f.Om=function(t){var n;switch(n=null,this.e){case 6:this.b==0?n="(?:"+this.a.Om(t)+")":n="("+this.a.Om(t)+")";break;case 20:n="(?="+this.a.Om(t)+")";break;case 21:n="(?!"+this.a.Om(t)+")";break;case 22:n="(?<="+this.a.Om(t)+")";break;case 23:n="(?<!"+this.a.Om(t)+")";break;case 24:n="(?>"+this.a.Om(t)+")"}return n},f.b=0,C(Ug,"RegEx/Token/ParenToken",830),T(521,122,{3:1,122:1,521:1},gee),f.Km=function(){return this.b},f.Om=function(t){return this.e==12?"\\"+this.a:BUt(this.b)},f.a=0,C(Ug,"RegEx/Token/StringToken",521),T(469,122,x9,E7),f.Hm=function(t){wb(this,t)},f.Jm=function(t){return c(Bm(this.a,t),122)},f.Nm=function(){return this.a?this.a.a.c.length:0},f.Om=function(t){var n,i,r,o,a;if(this.e==1){if(this.a.a.c.length==2)n=c(Bm(this.a,0),122),i=c(Bm(this.a,1),122),i.e==3&&i.Jm(0)==n?o=n.Om(t)+"+":i.e==9&&i.Jm(0)==n?o=n.Om(t)+"+?":o=n.Om(t)+(""+i.Om(t));else{for(a=new yg,r=0;r<this.a.a.c.length;r++)Ys(a,c(Bm(this.a,r),122).Om(t));o=a.a}return o}if(this.a.a.c.length==2&&c(Bm(this.a,1),122).e==7)o=c(Bm(this.a,0),122).Om(t)+"?";else if(this.a.a.c.length==2&&c(Bm(this.a,0),122).e==7)o=c(Bm(this.a,1),122).Om(t)+"??";else{for(a=new yg,Ys(a,c(Bm(this.a,0),122).Om(t)),r=1;r<this.a.a.c.length;r++)a.a+="|",Ys(a,c(Bm(this.a,r),122).Om(t));o=a.a}return o},C(Ug,"RegEx/Token/UnionToken",469),T(518,1,{596:1},VN),f.Ib=function(){return this.a.b},C(wat,"XMLTypeUtil/PatternMatcherImpl",518),T(1690,1505,{},bN);var Nvt;C(wat,"XMLTypeValidator",1690),T(272,1,Jd,Xp),f.Ic=function(t){ws(this,t)},f.Jc=function(){return(this.b-this.a)*this.c<0?wp:new S0(this)},f.a=0,f.b=0,f.c=0;var wp;C(z5e,"ExclusiveRange",272),T(1065,1,Ud,mN),f.Rb=function(t){c(t,15),ujt()},f.Nb=function(t){gs(this,t)},f.Pb=function(){return Z9t()},f.Ub=function(){return e8t()},f.Wb=function(t){c(t,15),fjt()},f.Ob=function(){return!1},f.Sb=function(){return!1},f.Tb=function(){return-1},f.Vb=function(){return-1},f.Qb=function(){throw J(new vg(xat))},C(z5e,"ExclusiveRange/1",1065),T(261,1,Ud,S0),f.Rb=function(t){c(t,15),ajt()},f.Nb=function(t){gs(this,t)},f.Pb=function(){return zRt(this)},f.Ub=function(){return BLt(this)},f.Wb=function(t){c(t,15),hjt()},f.Ob=function(){return this.c.c<0?this.a>=this.c.b:this.a<=this.c.b},f.Sb=function(){return this.b>0},f.Tb=function(){return this.b},f.Vb=function(){return this.b-1},f.Qb=function(){throw J(new vg(xat))},f.a=0,f.b=0,C(z5e,"ExclusiveRange/RangeIterator",261);var Na=F6(PG,"C"),Fn=F6(kE,"I"),kl=F6(K5,"Z"),qw=F6(OE,"J"),Rl=F6(vE,"B"),ns=F6(yE,"D"),py=F6(xE,"F"),L3=F6(SE,"S"),ann=Ki("org.eclipse.elk.core.labels","ILabelManager"),nEe=Ki(_s,"DiagnosticChain"),iEe=Ki(Vut,"ResourceSet"),rEe=C(_s,"InvocationTargetException",null),_vt=(jz(),eLt),Dvt=Dvt=Eqt;zPt(e9t),YPt("permProps",[[["locale","default"],[kat,"gecko1_8"]],[["locale","default"],[kat,"safari"]]]),Dvt(null,"elk",null)}).call(this)}).call(this,typeof Pvt<"u"?Pvt:typeof self<"u"?self:typeof window<"u"?window:{})},{}],3:[function(u,h,g){function w(Y){"@babel/helpers - typeof";return w=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(Z){return typeof Z}:function(Z){return Z&&typeof Symbol=="function"&&Z.constructor===Symbol&&Z!==Symbol.prototype?"symbol":typeof Z},w(Y)}function p(Y,Z,ee){return Object.defineProperty(Y,"prototype",{writable:!1}),Y}function k(Y,Z){if(!(Y instanceof Z))throw new TypeError("Cannot call a class as a function")}function j(Y,Z,ee){return Z=I(Z),A(Y,D()?Reflect.construct(Z,ee||[],I(Y).constructor):Z.apply(Y,ee))}function A(Y,Z){if(Z&&(w(Z)=="object"||typeof Z=="function"))return Z;if(Z!==void 0)throw new TypeError("Derived constructors may only return object or undefined");return _(Y)}function _(Y){if(Y===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return Y}function D(){try{var Y=!Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){}))}catch{}return(D=function(){return!!Y})()}function I(Y){return I=Object.setPrototypeOf?Object.getPrototypeOf.bind():function(Z){return Z.__proto__||Object.getPrototypeOf(Z)},I(Y)}function B(Y,Z){if(typeof Z!="function"&&Z!==null)throw new TypeError("Super expression must either be null or a function");Y.prototype=Object.create(Z&&Z.prototype,{constructor:{value:Y,writable:!0,configurable:!0}}),Object.defineProperty(Y,"prototype",{writable:!1}),Z&&F(Y,Z)}function F(Y,Z){return F=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(ee,ce){return ee.__proto__=ce,ee},F(Y,Z)}var U=u("./elk-api.js").default,K=(function(Y){function Z(){var ee=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{};k(this,Z);var ce=Object.assign({},ee),fe=!1;try{u.resolve("web-worker"),fe=!0}catch{}if(ee.workerUrl)if(fe){var be=u("web-worker");ce.workerFactory=function(Te){return new be(Te)}}else console.warn(`Web worker requested but 'web-worker' package not installed. 
Consider installing the package or pass your own 'workerFactory' to ELK's constructor.
... Falling back to non-web worker version.`);if(!ce.workerFactory){var me=u("./elk-worker.min.js"),Re=me.Worker;ce.workerFactory=function(Te){return new Re(Te)}}return j(this,Z,[ce])}return B(Z,Y),p(Z)})(U);Object.defineProperty(h.exports,"__esModule",{value:!0}),h.exports=K,K.default=K},{"./elk-api.js":1,"./elk-worker.min.js":2,"web-worker":4}],4:[function(u,h,g){var w=typeof Worker<"u"?Worker:void 0;h.exports=w},{}]},{},[3])(3)})})(aCe)),aCe.exports}var Cvn=Evn();const Mvn=xMe(Cvn),Avn=new Mvn;function r4t(l,s){const u=[...new Set(l)].sort((w,p)=>w-p),h=new Map;let g=0;for(;g<u.length;){let w=g;for(;w<u.length&&u[w]-u[g]<=s;)w++;const p=u.slice(g,w),k=p[Math.floor(p.length/2)];for(const j of p)h.set(j,k);g=w}return h}function Nvn(l,s=20){const u=[...l.values()],h=r4t(u.map(w=>w.x),s),g=r4t(u.map(w=>w.y),s);for(const w of l.values())w.x=h.get(w.x)??w.x,w.y=g.get(w.y)??w.y}async function LAe(l,s){const u={id:"root",layoutOptions:{"elk.algorithm":"layered","elk.direction":"RIGHT","elk.spacing.nodeNode":"60","elk.layered.spacing.nodeNodeBetweenLayers":"120","elk.layered.crossingMinimization.strategy":"LAYER_SWEEP"},children:l.map(w=>({id:w.id,width:240,height:70})),edges:s.map(w=>({id:w.id,sources:[w.source],targets:[w.target]}))},h=await Avn.layout(u),g=new Map;for(const w of h.children||[])g.set(w.id,{x:w.x??0,y:w.y??0});return Nvn(g),l.map(w=>({...w,position:g.get(w.id)||w.position}))}const _vn=50,Dvn=1e3,Lvn=3e4;function Pvn({setNodesRaw:l,setEdgesRaw:s,setPreamble:u,preambleRef:h,nodeIdCounter:g,fitView:w}){const{setSyncBanner:p}=Da(),{addToast:k}=sO(),[j,A]=pe.useState("reconnecting"),_=pe.useRef(0);return pe.useEffect(()=>{const I=`${window.location.protocol==="https:"?"wss:":"ws:"}//${window.location.host}/ws/sync`;let B=null,F=null,U=!0;function K(){U&&(B=new WebSocket(I),B.onopen=()=>{U&&(_.current=0,A("connected"))},B.onmessage=async Y=>{try{const Z=JSON.parse(Y.data);if(Z.type==="graph_update"&&Z.graph){if(Da.getState().dirty)return;const ee=Z.graph,ce=ee.nodes||[],fe=(ee.edges||[]).map(me=>({...me,type:"default",animated:!1}));if(ce.some(me=>me.position&&(me.position.x!==0||me.position.y!==0)))l(ce);else{const me=await LAe(ce,fe);l(me)}s(fe),ee.preamble!==void 0&&(u(ee.preamble||""),h.current=ee.preamble||""),g.current=ce.length,p(null),k("info","Pipeline updated from file"),setTimeout(()=>w({padding:.8}),100)}Z.type==="parse_error"&&p(Z.error||"Parse error in pipeline file")}catch(Z){k("error",`WebSocket sync error: ${Z instanceof Error?Z.message:String(Z)}`)}},B.onclose=()=>{if(!U)return;if(_.current+=1,_.current>_vn){A("disconnected");return}A("reconnecting");const Y=Math.min(Dvn*2**(_.current-1),Lvn);F=setTimeout(K,Y)},B.onerror=()=>{B==null||B.close()})}return K(),()=>{U=!1,F&&clearTimeout(F),B==null||B.close()}},[l,s,u,h,g,w,p,k]),j}function Pfe(l,s,u={}){return{nodeId:l,nodeLabel:s,status:"ok",row_count:0,column_count:0,columns:[],preview:[],error:null,...u}}function s4t(l){return String(l.data.label||l.id)}function Ivn(l,s,u){const h=u.status==="ok"||u.status==="error"||u.status==="loading"?u.status:"ok";return Pfe(l,s,{status:h,row_count:u.row_count??0,column_count:u.column_count??0,columns:u.columns??[],preview:u.preview??[],error:u.error??null,error_line:u.error_line??null,timing_ms:u.timing_ms??0,memory_bytes:u.memory_bytes??0,timings:u.timings??[],memory:u.memory??[],schema_warnings:u.schema_warnings??[]})}function Rvn({selectedNode:l,graphRef:s,parentGraphRef:u,submodelsRef:h,setNodes:g,setNodesRaw:w,setEdgesRaw:p,setPreamble:k,preambleRef:j,pipelineNameRef:A,sourceFileRef:_,lastSavedRef:D,nodeIdCounter:I}){const B=Kc(ge=>ge.rowLimit),F=Kc(ge=>ge.activeScenario),U=Da(ge=>ge.setDirty),K=sO(ge=>ge.addToast),[Y,Z]=pe.useState(!0),[ee,ce]=pe.useState(null),[fe,be]=pe.useState({}),me=pe.useRef(null),Re=pe.useRef(null),Te=pe.useRef(B);Te.current=B;const Ke=pe.useRef(F);Ke.current=F,pe.useEffect(()=>{kfn().then(ge=>{const He=ge.nodes??[],ae=ge.edges??[];w(He),p(ae.map(Le=>({...Le,type:"default",animated:!1}))),ge.preamble!==void 0&&(k(ge.preamble||""),j.current=ge.preamble||""),ge.pipeline_name&&(A.current=ge.pipeline_name),ge.source_file&&(_.current=ge.source_file),ge.submodels&&(h.current=ge.submodels),ge.scenarios&&Array.isArray(ge.scenarios)&&Kc.getState().setScenarios(ge.scenarios),ge.active_scenario&&Kc.getState().setActiveScenario(ge.active_scenario),I.current=He.length,D.current=JSON.stringify({nodes:He,edges:ae,preamble:ge.preamble||""}),Z(!1)}).catch(ge=>{K("error",`Failed to load pipeline: ${ge.message}`),Z(!1)})},[w,p,k,j,A,_,h,I,D,K]);const ze=pe.useCallback(ge=>{var Ye;(Ye=me.current)==null||Ye.abort();const He=new AbortController;me.current=He;const ae=s4t(ge),{getPreview:Le,setPreview:Oe,graphVersion:Qe}=ll.getState(),kt=Le(ge.id);if(kt){if(ce(kt.data),kt.graphVersion===Qe)return}else ce(Pfe(ge.id,ae,{status:"loading"}));const Ae=gkt(s,u,h,j);hkt(Ae,ge.id,Te.current,Ke.current,{signal:He.signal}).then(mt=>{const Ue=Ivn(ge.id,ae,mt);ce(Ue),Oe(ge.id,Ue,ll.getState().graphVersion),mt.node_statuses&&be(mt.node_statuses),mt.columns&&g(Pt=>Pt.map(rn=>rn.id===ge.id?{...rn,data:{...rn.data,_columns:mt.columns,_schemaWarnings:mt.schema_warnings??[]}}:rn))}).catch(mt=>{(mt instanceof v8||mt.name!=="AbortError")&&(ce(Pfe(ge.id,ae,{status:"error",error:mt.message})),be({}))})},[s,u,h,j,g]),je=pe.useCallback(ge=>{Re.current&&clearTimeout(Re.current);const He=ll.getState().getPreview(ge.id);ce(He?He.data:Pfe(ge.id,s4t(ge),{status:"loading"})),Re.current=setTimeout(()=>ze(ge),200)},[ze]),te=pe.useCallback(()=>{const{nodes:ge,edges:He}=s.current,{scenarios:ae,activeScenario:Le}=Kc.getState();Ofn({name:A.current,description:"",graph:{nodes:ge,edges:He,submodels:h.current},preamble:j.current,source_file:_.current,scenarios:ae,active_scenario:Le}).then(Oe=>{D.current=JSON.stringify({nodes:ge,edges:He,preamble:j.current}),U(!1),K("success",`Saved → ${Oe.file}`)}).catch(Oe=>{console.warn("Pipeline save failed:",Oe),K("error","Failed to save pipeline")})},[s,h,j,_,A,D,U,K]);return pe.useEffect(()=>{l||be({})},[l]),pe.useEffect(()=>()=>{var ge;(ge=me.current)==null||ge.abort(),Re.current&&clearTimeout(Re.current)},[]),{loading:Y,previewData:ee,setPreviewData:ce,nodeStatuses:fe,fetchPreview:je,handleSave:te}}function EM(l){return l.data}function $vn({nodes:l,edges:s,selectedNode:u,graphRef:h,parentGraphRef:g,submodelsRef:w,preambleRef:p,nodeStatuses:k}){const j=sO(Te=>Te.addToast),A=Kc(Te=>Te.rowLimit),_=Kc(Te=>Te.activeScenario),[D,I]=pe.useState(null),[B,F]=pe.useState(null),U=pe.useCallback(()=>{I(null),F(null)},[]),K=pe.useCallback((Te,Ke)=>{if(!u)return;const ze=gkt(h,g,w,p);F({rowIndex:Te,column:Ke}),Sfn({graph:ze,row_index:Te,target_node_id:u.id,column:Ke,row_limit:A,scenario:_}).then(je=>{je.status==="ok"&&je.trace?I(je.trace):(j("error",je.error||"Trace failed"),U())}).catch(je=>{j("error",`Trace error: ${je.message}`),U()})},[u,h,g,w,p,A,_,j,U]),Y=pe.useMemo(()=>{const Te=new Map;for(const Ke of l){const ze=EM(Ke);if(ze.nodeType===Ln.SUBMODEL){const te=(ze.config||{}).childNodeIds||[];for(const ge of te)Te.set(ge,Ke.id)}}return Te},[l]),Z=pe.useMemo(()=>{const Te=new Map;for(const Ke of l)Ke.id.startsWith("port_in__")?Te.set(Ke.id.replace("port_in__",""),Ke.id):Ke.id.startsWith("port_out__")&&Te.set(Ke.id.replace("port_out__",""),Ke.id);return Te},[l]),ee=pe.useCallback(Te=>Y.get(Te)||Z.get(Te)||Te,[Y,Z]),ce=pe.useMemo(()=>{if(!D)return new Set;const Te=new Set;for(const Ke of D.steps)Te.add(ee(Ke.node_id));return Te},[D,ee]),{traceValueMap:fe,relevantNodeIds:be}=pe.useMemo(()=>{if(!D)return{traceValueMap:new Map,relevantNodeIds:new Set};const Te=new Map,Ke=new Set;for(const ze of D.steps){if(!ze.column_relevant)continue;const je=ee(ze.node_id);if(Ke.add(je),D.column&&ze.output_values[D.column]!==void 0)Te.set(je,ze.output_values[D.column]);else{const te=ze.schema_diff.columns_added[0]||ze.schema_diff.columns_modified[0];te&&Te.set(je,ze.output_values[te])}}return{traceValueMap:Te,relevantNodeIds:Ke}},[D,ee]),me=pe.useMemo(()=>{const Te=D!==null;return l.map(Ke=>{const ze=k[Ke.id],je=ce.has(Ke.id),te=Te&&!je;return{...Ke,data:{...Ke.data,_status:ze,_traceActive:Te&&be.has(Ke.id),_traceDimmed:te,_traceValue:fe.get(Ke.id)},style:{...Ke.style||{},opacity:te?.4:1,transition:"opacity 0.2s ease",...te?{outline:"1px solid rgba(255,255,255,.08)"}:{}}}})},[l,k,D,ce,be,fe]),Re=pe.useMemo(()=>D?s.map(Te=>{const Ke=ce.has(Te.source),ze=ce.has(Te.target);return Ke&&ze?{...Te,style:{stroke:"var(--accent)",strokeWidth:2.5,filter:"drop-shadow(0 0 4px var(--accent))"},markerEnd:{type:wM.ArrowClosed,width:14,height:14,color:"var(--accent)"},animated:!0}:{...Te,style:{stroke:"rgba(255,255,255,.05)",strokeWidth:1},markerEnd:{type:wM.ArrowClosed,width:14,height:14,color:"rgba(255,255,255,.05)"}}}):s,[s,D,ce]);return{traceResult:D,tracedCell:B,handleCellClick:K,clearTrace:U,nodesWithStatus:me,edgesWithTrace:Re}}function vfe(l){return l.map(s=>({...s,type:"default",animated:!1}))}function Bvn({graphRef:l,parentGraphRef:s,submodelsRef:u,setNodesRaw:h,setEdgesRaw:g,setSelectedNode:w,setPreviewData:p,preambleRef:k,sourceFileRef:j,pipelineNameRef:A,fitView:_}){const{addToast:D}=sO(),{setDirty:I}=Da(),[B,F]=pe.useState([{type:"pipeline",name:"main",file:""}]),U=pe.useCallback(async(ee,ce)=>{try{const fe={nodes:l.current.nodes,edges:l.current.edges,submodels:u.current},me=(await Tfn({name:ee,node_ids:ce,graph:fe,preamble:k.current,source_file:j.current,pipeline_name:A.current})).graph;me&&(h(me.nodes??[]),g(vfe(me.edges??[])),u.current=me.submodels??{},D("success",`Submodel "${ee}" created`),I(!1),setTimeout(()=>_({padding:.8}),100))}catch(fe){D("error",`Create submodel failed: ${fe instanceof Error?fe.message:String(fe)}`)}},[l,u,h,g,k,j,A,_,D,I]),K=pe.useCallback(async ee=>{const ce=ee.replace("submodel__","");try{const be=(await Efn(ce)).graph;if(be){const me=[...l.current.nodes],Re=[...l.current.edges];s.current={nodes:me,edges:Re,submodels:{...u.current}},F(Qe=>{const kt=[...Qe];return kt.length>0&&(kt[kt.length-1]={...kt[kt.length-1],_savedNodes:me,_savedEdges:Re}),[...kt,{type:"submodel",name:ce,file:`modules/${ce}.py`}]});const Te=be.nodes??[],Ke=vfe(be.edges??[]),ze=`submodel__${ce}`,je=new Map(me.map(Qe=>[Qe.id,Qe])),te=new Set(Te.map(Qe=>Qe.id)),ge=Re.filter(Qe=>Qe.target===ze),He=new Map;for(const Qe of ge){const kt=Qe.targetHandle,Ae=kt?kt.replace("in__",""):"__unconnected__",Ye=He.get(Qe.source)||[];Ye.push(Ae),He.set(Qe.source,Ye)}for(const[Qe,kt]of He){const Ae=je.get(Qe),Ye=Ae?String(EM(Ae).label||Qe):Qe,mt=`port_in__${Qe}`;Te.push({id:mt,type:Ln.SUBMODEL_PORT,position:{x:0,y:0},data:{label:Ye,portDirection:"input",portName:Ye}});for(const Ue of[...new Set(kt)])te.has(Ue)&&Ke.push({id:`e_${mt}_${Ue}`,source:mt,target:Ue,type:"default",animated:!1,style:{strokeDasharray:"6 3",opacity:.5}})}const ae=Re.filter(Qe=>Qe.source===ze&&Qe.sourceHandle),Le=new Map;for(const Qe of ae){const kt=Qe.sourceHandle.replace("out__","");if(!te.has(kt))continue;const Ae=Le.get(Qe.target)||[];Ae.push(kt),Le.set(Qe.target,Ae)}for(const[Qe,kt]of Le){const Ae=je.get(Qe),Ye=Ae?String(EM(Ae).label||Qe):Qe,mt=`port_out__${Qe}`;Te.push({id:mt,type:Ln.SUBMODEL_PORT,position:{x:0,y:0},data:{label:Ye,portDirection:"output",portName:Ye}});for(const Ue of[...new Set(kt)])Ke.push({id:`e_${Ue}_${mt}`,source:Ue,target:mt,type:"default",animated:!1,style:{strokeDasharray:"6 3",opacity:.5}})}const Oe=await LAe(Te,Ke);h(Oe),g(Ke),w(null),p(null),setTimeout(()=>_({padding:.8}),100)}}catch(fe){D("error",`Drill-down failed: ${fe instanceof Error?fe.message:String(fe)}`)}},[l,s,u,h,g,w,p,_,D]),Y=pe.useCallback(ee=>{F(ce=>{if(ee>=ce.length-1)return ce;const fe=ce[ee];return fe._savedNodes&&fe._savedEdges&&(h(fe._savedNodes),g(vfe(fe._savedEdges)),w(null),p(null),setTimeout(()=>_({padding:.8}),100)),ee===0&&(s.current=null),ce.slice(0,ee+1)})},[s,h,g,w,p,_]),Z=pe.useCallback(async ee=>{try{const ce={nodes:l.current.nodes,edges:l.current.edges,submodels:u.current},be=(await Cfn({submodel_name:ee,graph:ce,preamble:k.current,source_file:j.current,pipeline_name:A.current})).graph;be&&(h(be.nodes??[]),g(vfe(be.edges??[])),u.current={},D("success",`Submodel "${ee}" dissolved`),I(!1),setTimeout(()=>_({padding:.8}),100))}catch(ce){D("error",`Dissolve failed: ${ce instanceof Error?ce.message:String(ce)}`)}},[l,u,h,g,k,j,A,_,D,I]);return{viewStack:B,handleDrillIntoSubmodel:K,handleBreadcrumbNavigate:Y,handleCreateSubmodel:U,handleDissolveSubmodel:Z}}function zvn({handleSave:l,setNodes:s,setEdges:u,undo:h,redo:g,fitView:w,graphRef:p,clipboard:k,nodeIdCounter:j,setSelectedNode:A,setPreviewData:_,clearTrace:D}){const{addToast:I}=sO(),{setShortcutsOpen:B,setSubmodelDialog:F}=Da();pe.useEffect(()=>{const U=K=>{var fe,be;const Y=(fe=K.target)==null?void 0:fe.tagName,Z=K.target,ee=Y==="INPUT"||Y==="TEXTAREA"||((be=Z.closest)==null?void 0:be.call(Z,".cm-editor"))!=null,ce=K.ctrlKey||K.metaKey;if(ce&&K.key==="s"){K.preventDefault(),l();return}if(ce&&K.key==="z"&&!K.shiftKey){K.preventDefault(),h();return}if(ce&&K.key==="z"&&K.shiftKey){K.preventDefault(),g();return}if(ce&&K.key==="y"){K.preventDefault(),g();return}if(ce&&K.key==="c"&&!ee){const{nodes:me,edges:Re}=p.current,Te=me.filter(je=>je.selected);if(Te.length===0)return;const Ke=new Set(Te.map(je=>je.id)),ze=Re.filter(je=>Ke.has(je.source)&&Ke.has(je.target));k.current={nodes:Te,edges:ze},I("info",`Copied ${Te.length} node${Te.length>1?"s":""}`);return}if(ce&&K.key==="v"&&!ee){const{nodes:me,edges:Re}=k.current;if(me.length===0)return;K.preventDefault();const Te=new Map,Ke=me.map(je=>{j.current+=1;const te=`${je.type}_${j.current}`;return Te.set(je.id,te),{...je,id:te,position:{x:je.position.x+60,y:je.position.y+60},selected:!0,data:{...je.data,label:`${je.data.label} copy`}}}),ze=Re.flatMap(je=>{const te=Te.get(je.source),ge=Te.get(je.target);return!te||!ge?[]:[{...je,id:`e-${te}-${ge}`,source:te,target:ge}]});s(je=>[...je.map(te=>({...te,selected:!1})),...Ke]),u(je=>[...je,...ze]),I("info",`Pasted ${Ke.length} node${Ke.length>1?"s":""}`);return}if(ce&&K.key==="a"&&!ee){K.preventDefault(),s(me=>me.map(Re=>({...Re,selected:!0})));return}if(ce&&K.key==="1"){K.preventDefault(),w({padding:.8});return}if(K.key==="Escape"){D();return}if(K.key==="?"&&!ee){K.preventDefault(),B(me=>!me);return}if(ce&&K.key==="g"){K.preventDefault();const{nodes:me}=p.current,Re=me.filter(Te=>Te.selected).map(Te=>Te.id);Re.length>=2?F({nodeIds:Re}):I("info","Select at least 2 nodes to create a submodel (Ctrl+G)");return}if((K.key==="Delete"||K.key==="Backspace")&&!ee){const{nodes:me,edges:Re}=p.current,Te=new Set(me.filter(ze=>ze.selected).map(ze=>ze.id)),Ke=new Set(Re.filter(ze=>ze.selected).map(ze=>ze.id));if(Te.size===0&&Ke.size===0)return;Te.size>0?(s(me.filter(ze=>!Te.has(ze.id))),u(Re.filter(ze=>!Te.has(ze.source)&&!Te.has(ze.target))),A(null),_(null)):u(Re.filter(ze=>!Ke.has(ze.id)))}};return window.addEventListener("keydown",U),()=>window.removeEventListener("keydown",U)},[l,s,u,h,g,w,p,k,j,A,_,D,I,B,F])}const o4t=500,Fvn=5e3,qvn=1440*60*1e3,Hvn=5;function Qvn(l,s){const{jobs:u,pollFn:h,onProgress:g,onComplete:w,onFail:p,labelFn:k,jobIdFn:j,isComplete:A,isError:_,getResult:D,getErrorMessage:I,addToast:B,successLabel:F,failLabel:U}=l,K=Object.keys(u),Y=Object.keys(s.current);for(const Z of K){let ee=function(me){if(Date.now()-me.startedAt>=qvn){delete s.current[Z],p(Z,"Job timed out after 24 hours"),B("error",`${U}: ${k(ce)} — Job timed out after 24 hours`);return}const Te=me.consecutiveErrors===0?o4t:Math.min(o4t*Math.pow(2,me.consecutiveErrors),Fvn);me.timeoutId=setTimeout(async()=>{try{const Ke=await h(j(ce));if(me.consecutiveErrors=0,me.toastedWarning=!1,A(Ke)||_(Ke)){if(delete s.current[Z],A(Ke)&&D(Ke))w(Z,D(Ke)),B("success",`${F}: ${k(ce)}`);else{const ze=I(Ke)||"Unknown error";p(Z,ze),B("error",`${U}: ${k(ce)} — ${ze}`)}return}g(Z,Ke)}catch(Ke){me.consecutiveErrors+=1,console.warn(`${U} poll failed (attempt ${me.consecutiveErrors}, will retry):`,Ke),me.consecutiveErrors>=Hvn&&!me.toastedWarning&&(me.toastedWarning=!0,B("warning",`Polling is struggling for ${k(ce)} — ${me.consecutiveErrors} consecutive errors`))}s.current[Z]&&ee(me)},Te)};if(s.current[Z])continue;const ce=u[Z],be={startedAt:Date.now(),consecutiveErrors:0,toastedWarning:!1};s.current[Z]=be,ee(be)}for(const Z of Y)u[Z]||(clearTimeout(s.current[Z].timeoutId),delete s.current[Z])}function c4t(l){const s=pe.useRef({});pe.useEffect(()=>{Qvn(l,s)},[l.jobs,l.pollFn,l.onProgress,l.onComplete,l.onFail,l.addToast]),pe.useEffect(()=>{const u=s.current;return()=>{for(const h of Object.values(u))clearTimeout(h.timeoutId)}},[])}function Gvn(){const l=sO(B=>B.addToast),s=ll(B=>B.solveJobs),u=ll(B=>B.updateSolveProgress),h=ll(B=>B.completeSolveJob),g=ll(B=>B.failSolveJob),w=pe.useCallback(B=>$fn(B),[]),p=pe.useCallback((B,F)=>h(B,F.result),[h]);c4t({jobs:s,pollFn:w,onProgress:u,onComplete:p,onFail:g,labelFn:B=>B.nodeLabel,jobIdFn:B=>B.jobId,isComplete:B=>B.status==="completed",isError:B=>B.status==="error",getResult:B=>B.result?B:void 0,getErrorMessage:B=>B.message||"Unknown error",addToast:l,successLabel:"Optimisation complete",failLabel:"Optimisation failed"});const k=ll(B=>B.trainJobs),j=ll(B=>B.updateTrainProgress),A=ll(B=>B.completeTrainJob),_=ll(B=>B.failTrainJob),D=pe.useCallback(B=>_fn(B),[]),I=pe.useCallback((B,F)=>A(B,F.result),[A]);c4t({jobs:k,pollFn:D,onProgress:j,onComplete:I,onFail:_,labelFn:B=>B.nodeLabel,jobIdFn:B=>B.jobId,isComplete:B=>B.status==="completed",isError:B=>B.status==="error",getResult:B=>B.result?B:void 0,getErrorMessage:B=>B.message||"Unknown error",addToast:l,successLabel:"Training complete",failLabel:"Training failed"})}function Uvn({graphRef:l,nodeIdCounter:s,lastSelectedNodeRef:u,setNodes:h,setEdges:g,setSelectedNode:w,setPreviewData:p,onUpdateNode:k,fitView:j}){const A=sO(K=>K.addToast),_=ll(K=>K.clearNode),D=pe.useCallback(K=>{var ee;const{nodes:Y,edges:Z}=l.current;h(()=>Y.filter(ce=>ce.id!==K)),g(()=>Z.filter(ce=>ce.source!==K&&ce.target!==K)),w(ce=>(ce==null?void 0:ce.id)===K?null:ce),p(ce=>(ce==null?void 0:ce.nodeId)===K?null:ce),_(K),((ee=u.current)==null?void 0:ee.id)===K&&(u.current=null)},[l,u,h,g,w,p,_]),I=pe.useCallback(K=>{const{nodes:Y}=l.current,Z=Y.find(fe=>fe.id===K);if(!Z)return;s.current+=1;const ee=`${Z.type}_${s.current}`,ce={...Z,id:ee,position:{x:Z.position.x+40,y:Z.position.y+40},selected:!0,data:{...Z.data,label:`${Z.data.label} copy`}};h(fe=>[...fe.map(be=>({...be,selected:!1})),ce]),w(ce)},[l,s,h,w]),B=pe.useCallback(K=>{const{nodes:Y}=l.current,Z=Y.find(me=>me.id===K);if(!Z)return;s.current+=1;const ee=EM(Z),ce=ee.nodeType||Ln.TRANSFORM,be={id:`${ce}_${s.current}`,type:Z.type,position:{x:Z.position.x+60,y:Z.position.y+80},selected:!0,data:{label:`${ee.label} instance`,description:`Instance of ${ee.label}`,nodeType:ce,config:{instanceOf:K}}};h(me=>[...me.map(Re=>({...Re,selected:!1})),be]),w(be),A("info",`Created instance of "${ee.label}"`)},[l,s,h,w,A]),F=pe.useCallback(K=>{const{nodes:Y}=l.current,Z=Y.find(ce=>ce.id===K);if(!Z)return;const ee=prompt("Rename node:",String(Z.data.label));ee!==null&&ee.trim()&&k(K,{...Z.data,label:ee.trim()})},[l,k]),U=pe.useCallback(async()=>{const{nodes:K,edges:Y}=l.current;if(K.length===0)return;const Z=await LAe(K,Y);h(()=>Z),setTimeout(()=>j({padding:.8}),50),A("info","Auto-layout applied")},[l,h,j,A]);return{handleDeleteNode:D,handleDuplicateNode:I,handleCreateInstance:B,handleRenameNode:F,handleAutoLayout:U}}const Jvn={[Ln.API_INPUT]:"API Input",[Ln.DATA_SOURCE]:"Data Source",[Ln.TRANSFORM]:"Polars",[Ln.MODEL_SCORE]:"Model Scoring",[Ln.RATING_STEP]:"Rating Step",[Ln.BANDING]:"Banding",[Ln.OUTPUT]:"API Output",[Ln.DATA_SINK]:"Data Sink",[Ln.EXTERNAL_FILE]:"Load File",[Ln.LIVE_SWITCH]:"Source Switch",[Ln.MODELLING]:"Model Training",[Ln.OPTIMISER]:"Optimisation",[Ln.OPTIMISER_APPLY]:"Apply Optimisation",[Ln.SCENARIO_EXPANDER]:"Expander",[Ln.CONSTANT]:"Constant",[Ln.SUBMODEL]:"Submodel",[Ln.SUBMODEL_PORT]:"Port"};function Xvn({graphRef:l,nodeIdCounter:s,lastSelectedNodeRef:u,setNodes:h,setEdges:g,setSelectedNode:w,setContextMenu:p,fetchPreview:k,clearTrace:j,screenToFlowPosition:A}){const _=pe.useCallback(Y=>{if(Y.source===Y.target)return;const{edges:Z,nodes:ee}=l.current;if(Z.some(be=>be.source===Y.source&&be.target===Y.target))return;const fe=ee.find(be=>be.id===Y.target);if(fe&&EM(fe).nodeType===Ln.SUBMODEL&&Y.targetHandle){g(be=>yCe({...Y,targetHandle:null},be));return}g(be=>yCe(Y,be))},[l,g]),D=pe.useCallback(({nodes:Y})=>{Y.length!==1&&(w(null),j())},[w,j]),I=pe.useCallback((Y,Z)=>{w(ee=>((ee==null?void 0:ee.id)!==Z.id&&(k(Z),j()),Z)),u.current=Z},[w,k,j,u]),B=pe.useCallback(Y=>{g(Z=>Z.filter(ee=>ee.id!==Y))},[g]),F=pe.useCallback((Y,Z)=>{Y.preventDefault(),p({x:Y.clientX,y:Y.clientY,nodeId:Z.id,nodeLabel:String(Z.data.label),isSubmodel:EM(Z).nodeType===Ln.SUBMODEL})},[p]),U=pe.useCallback(Y=>{Y.preventDefault(),Y.dataTransfer.dropEffect="move"},[]),K=pe.useCallback(Y=>{Y.preventDefault();const Z=Y.dataTransfer.getData("application/reactflow-type");if(!Z)return;let ee={};try{ee=JSON.parse(Y.dataTransfer.getData("application/reactflow-config")||"{}")}catch{}const ce=A({x:Y.clientX,y:Y.clientY});s.current+=1;const be={id:`${Z}_${s.current}`,type:Z,position:ce,data:{label:`${Jvn[Z]||"Node"} ${s.current}`,description:"",nodeType:Z,config:ee}};h(me=>[...me.map(Re=>({...Re,selected:!1})),{...be,selected:!0}]),w(be)},[A,s,h,w]);return{onConnect:_,onSelectionChange:D,onNodeClick:I,handleDeleteEdge:B,onNodeContextMenu:F,onDragOver:U,onDrop:K}}const Vvn={[Ln.API_INPUT]:l0,[Ln.DATA_SOURCE]:l0,[Ln.TRANSFORM]:l0,[Ln.MODEL_SCORE]:l0,[Ln.RATING_STEP]:l0,[Ln.BANDING]:l0,[Ln.OUTPUT]:l0,[Ln.DATA_SINK]:l0,[Ln.EXTERNAL_FILE]:l0,[Ln.LIVE_SWITCH]:l0,[Ln.MODELLING]:l0,[Ln.OPTIMISER]:l0,[Ln.OPTIMISER_APPLY]:l0,[Ln.SCENARIO_EXPANDER]:l0,[Ln.CONSTANT]:l0,[Ln.SUBMODEL]:jhn,[Ln.SUBMODEL_PORT]:Ehn};function Wvn(){var _y;const{nodes:l,edges:s,setNodes:u,setEdges:h,setNodesRaw:g,setEdgesRaw:w,onNodesChange:p,onEdgesChange:k,undo:j,redo:A,canUndo:_,canRedo:D}=Tvn(),{screenToFlowPosition:I,fitView:B}=Ihe(),F=Kc(Ti=>Ti.fetchMlflow),U=Da(Ti=>Ti.paletteOpen),K=Da(Ti=>Ti.setPaletteOpen),Y=Da(Ti=>Ti.utilityOpen),Z=Da(Ti=>Ti.setUtilityOpen),ee=Da(Ti=>Ti.importsOpen),ce=Da(Ti=>Ti.setImportsOpen),fe=Da(Ti=>Ti.gitOpen),be=Da(Ti=>Ti.setGitOpen),me=Da(Ti=>Ti.shortcutsOpen),Re=Da(Ti=>Ti.setShortcutsOpen),Te=Da(Ti=>Ti.submodelDialog),Ke=Da(Ti=>Ti.setSubmodelDialog),ze=Da(Ti=>Ti.syncBanner),je=Da(Ti=>Ti.setSyncBanner),te=Da(Ti=>Ti.dirty),ge=Da(Ti=>Ti.setDirty);pe.useEffect(()=>{F()},[F]);const[He,ae]=pe.useState(null),[Le,Oe]=pe.useState(null),[Qe,kt]=pe.useState(""),Ae=pe.useRef(null),Ye=ll(Ti=>Ti.bumpGraphVersion),mt=ll(Ti=>Ti.getOptimiserPreview),Ue=ll(Ti=>Ti.clearNode),Pt=pe.useRef({}),rn=pe.useRef({nodes:[],edges:[]}),Cn=pe.useRef({nodes:[],edges:[]}),Pn=pe.useRef(null),mi=pe.useRef(""),er=pe.useRef(""),Mr=pe.useRef("main"),hr=pe.useRef(""),Gn=pe.useRef(0);pe.useEffect(()=>{Cn.current={nodes:l,edges:s},Ye()},[l,s,Ye]);const Ir=pe.useRef(null);pe.useEffect(()=>{if(mi.current){const Ti=Ir.current;Ti&&(Ti.nodes!==l||Ti.edges!==s||Ti.preamble!==Qe)&&ge(!0)}Ir.current={nodes:l,edges:s,preamble:Qe}},[l,s,Qe,ge]);const is=Pvn({setNodesRaw:g,setEdgesRaw:w,setPreamble:kt,preambleRef:er,nodeIdCounter:Gn,fitView:B}),{loading:bs,previewData:bo,setPreviewData:Bl,nodeStatuses:Zl,fetchPreview:rs,handleSave:Ls}=Rvn({selectedNode:He,graphRef:Cn,parentGraphRef:Pn,submodelsRef:Pt,setNodes:u,setNodesRaw:g,setEdgesRaw:w,setPreamble:kt,preambleRef:er,pipelineNameRef:Mr,sourceFileRef:hr,lastSavedRef:mi,nodeIdCounter:Gn}),{traceResult:f1,tracedCell:mo,handleCellClick:eu,clearTrace:Un,nodesWithStatus:Rc,edgesWithTrace:io}=$vn({nodes:l,edges:s,selectedNode:He,graphRef:Cn,parentGraphRef:Pn,submodelsRef:Pt,preambleRef:er,nodeStatuses:Zl}),{viewStack:zf,handleDrillIntoSubmodel:tu,handleBreadcrumbNavigate:Kw,handleCreateSubmodel:uO,handleDissolveSubmodel:aO}=Bvn({graphRef:Cn,parentGraphRef:Pn,submodelsRef:Pt,setNodesRaw:g,setEdgesRaw:w,setSelectedNode:ae,setPreviewData:Ti=>Bl(Ti),preambleRef:er,sourceFileRef:hr,pipelineNameRef:Mr,fitView:B});zvn({handleSave:Ls,setNodes:u,setEdges:h,undo:j,redo:A,fitView:B,graphRef:Cn,clipboard:rn,nodeIdCounter:Gn,setSelectedNode:ae,setPreviewData:Ti=>Bl(Ti),clearTrace:Un}),Gvn();const Cp=pe.useCallback((Ti,gu)=>{u(gh=>gh.map(h0=>h0.id===Ti?{...h0,data:gu}:h0)),ae(gh=>gh&&gh.id===Ti?{...gh,data:gu}:gh)},[u]),{handleDeleteNode:Ff,handleDuplicateNode:lg,handleCreateInstance:qf,handleRenameNode:fO,handleAutoLayout:hO}=Uvn({graphRef:Cn,nodeIdCounter:Gn,lastSelectedNodeRef:Ae,setNodes:u,setEdges:h,setSelectedNode:ae,setPreviewData:Bl,onUpdateNode:Cp,fitView:B}),{onConnect:dO,onSelectionChange:Yw,onNodeClick:Zw,handleDeleteEdge:e2,onNodeContextMenu:f0,onDragOver:t2,onDrop:im}=Xvn({graphRef:Cn,nodeIdCounter:Gn,lastSelectedNodeRef:Ae,setNodes:u,setEdges:h,setSelectedNode:ae,setContextMenu:Oe,fetchPreview:rs,clearTrace:Un,screenToFlowPosition:I});if(bs)return E.jsx("div",{className:"h-full w-full flex items-center justify-center",style:{background:"var(--bg-base)"},children:E.jsx("div",{className:"text-sm",style:{color:"var(--text-muted)"},children:"Loading pipeline..."})});const gO=Pt.current;return E.jsxs("div",{className:"h-full w-full flex flex-col",style:{background:"var(--bg-base)"},children:[E.jsx(xvn,{nodeCount:l.length,dirty:te,canUndo:_,canRedo:D,onUndo:j,onRedo:A,onShowShortcuts:()=>Re(!0),onOpenUtility:()=>{Z(!0),ae(null),Ae.current=null},onOpenImports:()=>{ce(!0),ae(null),Ae.current=null},onOpenGit:()=>{be(!0),ae(null),Ae.current=null},onCentre:()=>B({padding:.8}),onAutoLayout:hO,onSave:Ls,wsStatus:is,timings:bo==null?void 0:bo.timings,memory:bo==null?void 0:bo.memory}),E.jsxs("div",{className:"flex-1 flex min-h-0",children:[E.jsx("nav",{"aria-label":"Node palette",children:U?E.jsx(EX,{name:"NodePalette",children:E.jsx(Mhn,{onCollapse:()=>K(!1),nodes:l})}):E.jsx("button",{onClick:()=>K(!0),"aria-label":"Show node palette",className:"shrink-0 flex items-center justify-center w-10 h-full transition-colors",style:{background:"var(--chrome)",borderRight:"1px solid var(--chrome-border)"},onMouseEnter:Ti=>Ti.currentTarget.style.background="var(--chrome-hover)",onMouseLeave:Ti=>Ti.currentTarget.style.background="var(--chrome)",title:"Show node palette",children:E.jsx(Aan,{size:16,style:{color:"var(--text-muted)"}})})}),E.jsxs("main",{className:"flex-1 flex flex-col min-w-0",children:[ze&&E.jsxs("div",{className:"flex items-center gap-2 px-3 py-1.5 text-[12px] font-medium",style:{background:"rgba(239, 68, 68, 0.15)",color:"#f87171",borderBottom:"1px solid rgba(239, 68, 68, 0.3)"},children:[E.jsx("span",{className:"flex-1 truncate",children:ze}),E.jsx("button",{onClick:()=>je(null),className:"opacity-60 hover:opacity-100",children:"✕"})]}),E.jsx(EX,{name:"Canvas",children:E.jsxs("div",{className:"flex-1 min-h-0 relative",children:[E.jsx(mvn,{viewStack:zf,onNavigate:Kw}),E.jsx(Wln,{nodes:Rc,edges:io,onNodesChange:p,onEdgesChange:k,onConnect:dO,onSelectionChange:Yw,onNodeClick:(Ti,gu)=>{Z(!1),ce(!1),be(!1),Zw(Ti,gu)},onNodeContextMenu:f0,onNodeDoubleClick:(Ti,gu)=>{EM(gu).nodeType===Ln.SUBMODEL&&tu(gu.id)},onPaneClick:()=>{Oe(null),Un(),ae(null),Ae.current=null,Z(!1),ce(!1),be(!1)},onDrop:im,onDragOver:t2,nodeTypes:Vvn,panOnDrag:[2],selectionOnDrag:!0,selectNodesOnDrag:!0,selectionMode:TI.Partial,selectionKeyCode:null,fitView:!0,fitViewOptions:{padding:.8},proOptions:{hideAttribution:!0},defaultEdgeOptions:{type:"default",animated:!1,style:{stroke:"rgba(255,255,255,.12)",strokeWidth:1.5},markerEnd:{type:wM.ArrowClosed,width:14,height:14,color:"rgba(255,255,255,.15)"}},children:E.jsx(iun,{variant:tO.Dots,gap:24,size:1,color:"rgba(255,255,255,.06)"})})]})}),E.jsx(EX,{name:"DataPreview",children:(()=>{var gh;const Ti=(He==null?void 0:He.id)??((gh=Ae.current)==null?void 0:gh.id),gu=Ti?mt(Ti):null;return gu?E.jsx(ovn,{data:gu,onClose:()=>{Ti&&Ue(Ti)}}):E.jsx(svn,{data:bo,onClose:()=>{Bl(null),Un()},onCellClick:eu,tracedCell:mo})})()})]}),E.jsx("aside",{"aria-label":"Node properties",children:E.jsx(EX,{name:"NodePanel",children:fe?E.jsx(jvn,{onClose:()=>be(!1)}):Y?E.jsx(Ovn,{onClose:()=>Z(!1),onImportAdded:Ti=>{const gu=er.current;if(!gu.includes(Ti)){const gh=gu?`${gu}
${Ti}`:Ti;kt(gh),er.current=gh,ge(!0)}}}):ee?E.jsx(Svn,{preamble:Qe,onPreambleChange:Ti=>{kt(Ti),er.current=Ti,ge(!0)},onClose:()=>ce(!1)}):f1?E.jsx(lvn,{trace:f1,onClose:Un}):E.jsx(ivn,{node:He??Ae.current,edges:s,allNodes:l,submodels:gO,preamble:Qe,onClose:()=>{ae(null),Ae.current=null},onUpdateNode:Cp,onDeleteEdge:e2,onRefreshPreview:()=>{He&&rs(He)},dimmed:!He&&!!Ae.current,errorLine:(bo==null?void 0:bo.nodeId)===((_y=He??Ae.current)==null?void 0:_y.id)?(bo==null?void 0:bo.error_line)??null:null})})})]}),Le&&E.jsx(dvn,{x:Le.x,y:Le.y,nodeId:Le.nodeId,nodeLabel:Le.nodeLabel,onClose:()=>Oe(null),onDelete:Ff,onDuplicate:lg,onRename:fO,onCreateInstance:qf,isSubmodel:Le.isSubmodel,onDissolveSubmodel:aO}),me&&E.jsx(bvn,{onClose:()=>Re(!1)}),Te&&E.jsx(kvn,{nodeCount:Te.nodeIds.length,onClose:()=>Ke(null),onSubmit:Ti=>{uO(Ti,Te.nodeIds),Ke(null)}}),E.jsx(EX,{name:"Toast",children:E.jsx(hvn,{})})]})}function Kvn(){return E.jsx(U5t,{children:E.jsx(Wvn,{})})}xnn.createRoot(document.getElementById("root")).render(E.jsx(pe.StrictMode,{children:E.jsx(Kvn,{})}));
